
function [pts,pts_bar,stats_matrix]=pts_leb(deg)
%---------------------------------------------------------------------
% PURPOSE:
%---------
% SET OF POINTS FOR THE UNIT SIMPLEX, HAVING VERTICES
% [0,0], [1,0], [0,1] AND GAUSS-LEGENDRE-LOBATTO DISTRIBUTION ON THE
% SIDES. THE LEBESGUE CONSTANTS ARE PARTICULARLY LOW.
%---------------------------------------------------------------------
% INPUT:
%---------
% deg: DEGREE OF THE SET.
%---------------------------------------------------------------------
% OUTPUT:
%---------
% pts: CARTESIAN COORDINATES, STORED IN A "n x 2" MATRIX.
% pts_bar: BARYCENTRIC COORDINATES, STORED IN A "n x 3" MATRIX.
% stats_matrix: MATRIX WITH STATISTICS WITH COLUMNS THAT CONSIST OF
% DEGREE, LEBESGUE CONSTANT, ABS. VALUE OF VANDERMONDE MATRIX "V"
% DETERMINANT (w.r.t DUBINER BASIS), CONDITIONING OF "V".
%---------------------------------------------------------------------

% POINTS ON THE SIMPLEX [0 0; 1 0; 0 1] WITH LOW LEBESGUE CONSTANT.
     
      	 % Deg |  Card. | Leb. Const. |    AbsDet.  |Conditioning | Out |
 	 % -----------------------------------------------------------------
 	 %   1 |      3 | 1.00000e+00 | 5.87878e+01 | 3.70699e+00 |  0  |
 	 %   2 |      6 | 1.48853e+00 | 2.42798e+04 | 1.06220e+01 |  0  |
 	 %   3 |     10 | 1.97517e+00 | 2.01059e+08 | 1.98710e+01 |  0  |
 	 %   4 |     15 | 2.42354e+00 | 4.31505e+13 | 1.73433e+01 |  0  |
 	 %   5 |     21 | 2.90426e+00 | 2.80572e+20 | 4.54886e+01 |  0  |
 	 %   6 |     28 | 3.40132e+00 | 4.12857e+28 | 6.06455e+01 |  0  |
 	 %   7 |     36 | 4.13949e+00 | 1.88501e+39 | 9.14441e+01 |  0  |*
 	 %   8 |     45 | 5.21483e+00 | 8.03675e+50 | 1.16434e+02 |  0  |*
 	 %   9 |     55 | 5.49590e+00 | 1.43106e+64 | 1.47749e+02 |  0  |+
 	 %  10 |     66 | 5.93588e+00 | 4.57515e+79 | 1.64229e+02 |  0  |
 	 %  11 |     78 | 6.66424e+00 | 4.43645e+96 | 1.82180e+02 |  0  |*
 	 %  12 |     91 | 6.98481e+00 | 2.71864e+115 | 2.20876e+02 |  0  |
 	 %  13 |    105 | 7.74381e+00 | 5.70766e+135 | 2.90055e+02 |  0  |*
 	 %  14 |    120 | 8.30571e+00 | 9.94900e+157 | 3.45193e+02 |  0  |*
 	 %  15 |    136 | 8.91347e+00 | 9.40546e+182 | 3.66112e+02 |  0  |+
 	 %  16 |    153 | 8.59051e+00 | 2.70064e+209 | 3.80206e+02 |  0  |*
 	 %  17 |    171 | 9.12237e+00 | 7.85856e+237 | 4.33620e+02 |  0  |*
 	 %  18 |    190 | 9.88509e+00 | 1.43972e+268 | 5.07510e+02 |  0  |*
 
 % *: SAME OF POINTS IN THE SET pointset_simplex_lebesgue_lobatto
 % +  : SAME OF POINTS IN THE SET pointset_simplex_symm_lebesgue_lobatto
     
%--------------------------------------------------------------------------
%% Copyright (C) 2016
%% Matteo Briani, Alvise Sommariva, Marco Vianello.
%%
%% This program is free software; you can redistribute it and/or modify
%% it under the terms of the GNU General Public License as published by
%% the Free Software Foundation; either version 2 of the License, or
%% (at your option) any later version.
%%
%% This program is distributed in the hope that it will be useful,
%% but WITHOUT ANY WARRANTY; without even the implied warranty of
%% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%% GNU General Public License for more details.
%%
%% You should have received a copy of the GNU General Public License
%% along with this program; if not, write to the Free Software
%% Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
%%
%% Author:
%%          Matteo Briani
%%          Alvise Sommariva  <alvise@math.unipd.it>
%%          Marco Vianello  <marcov@math.unipd.it>
%%
%% Date: December 28, 2016.
%--------------------------------------------------------------------------

switch deg
    % ----------------- DEGREE  1 --------------------
 
 	 case   1 

 	 % LEBESGUE CONST.               : 1.00000e+00
 	 % ABS.DET.VAND.MATRIX           : 5.87878e+01
 	 % CONDITIONING                  : 3.70699e+00
 	 % CARDINALITY                   :      3
 	 % POINTS OUTSIDE DOMAIN         :      0
 
 	 pts=[
 	 1.0000000000000000000000000e+00 0.0000000000000000000000000e+00
 	 0.0000000000000000000000000e+00 1.0000000000000000000000000e+00
 	 0.0000000000000000000000000e+00 0.0000000000000000000000000e+00
 	 ]; 
 

 	 % ----------------- DEGREE  2 --------------------
 
 	 case   2 

 	 % LEBESGUE CONST.               : 1.48853e+00
 	 % ABS.DET.VAND.MATRIX           : 2.42798e+04
 	 % CONDITIONING                  : 1.06220e+01
 	 % CARDINALITY                   :      6
 	 % POINTS OUTSIDE DOMAIN         :      0
 
 	 pts=[
 	 1.0000000000000000000000000e+00 0.0000000000000000000000000e+00
 	 4.8059082031250000000000000e-01 4.8059082031250000000000000e-01
 	 0.0000000000000000000000000e+00 1.0000000000000000000000000e+00
 	 4.8059082031250000000000000e-01 3.8818359375000000000000000e-02
 	 3.8818359375000000000000000e-02 4.8059082031250000000000000e-01
 	 0.0000000000000000000000000e+00 0.0000000000000000000000000e+00
 	 ]; 
 

 	 % ----------------- DEGREE  3 --------------------
 
 	 case   3 

 	 % LEBESGUE CONST.               : 1.97517e+00
 	 % ABS.DET.VAND.MATRIX           : 2.01059e+08
 	 % CONDITIONING                  : 1.98710e+01
 	 % CARDINALITY                   :     10
 	 % POINTS OUTSIDE DOMAIN         :      0
 
 	 pts=[
 	 3.9438882353489856508508039e-09 9.9999983118888957633885184e-01
 	 7.0142386594187988713144932e-01 2.5527340980818973709132180e-02
 	 7.0519375757332425358470118e-01 2.7518752083257841389851706e-01
 	 9.9999977377831017477660680e-01 2.2622168980266351768267791e-07
 	 2.2553168660681525287126092e-02 2.7305653764434700825347591e-01
 	 0.0000000000000000000000000e+00 3.1320151060360366910236322e-07
 	 2.7690088468282386680030527e-01 7.0001556150865695826723822e-01
 	 1.9848131028909227202561283e-02 7.0227542487054350761610522e-01
 	 3.2856299757033330388722447e-01 3.3320865829650514466919731e-01
 	 2.7792860529527346757916462e-01 1.6461332038402484712058538e-02
 	 ]; 
 

 	 % ----------------- DEGREE  4 --------------------
 
 	 case   4 

 	 % LEBESGUE CONST.               : 2.42354e+00
 	 % ABS.DET.VAND.MATRIX           : 4.31505e+13
 	 % CONDITIONING                  : 1.73433e+01
 	 % CARDINALITY                   :     15
 	 % POINTS OUTSIDE DOMAIN         :      0
 
 	 pts=[
 	 1.6804930365238440748143489e-01 8.2204603507939311146657246e-01
 	 8.2095363994211079106122497e-01 1.7253189878103017407262598e-01
 	 2.2135401769899382129480614e-01 2.3534506027522755777781072e-01
 	 2.2604415584882308482006508e-02 4.9029083971870535130221924e-01
 	 1.7099549963862642476541964e-01 9.9184237175010056541957226e-03
 	 6.0104077273104685244509149e-03 1.6780675518178858607321047e-01
 	 5.4697298584401476961858179e-01 2.1774131881805489086012528e-01
 	 4.8096754010798981049390477e-01 4.9662982771771480017264366e-01
 	 8.3561956884267915568464957e-03 8.1981885208245752760802816e-01
 	 9.9999982771579876139611542e-01 1.7228420131978124583995685e-07
 	 4.8596962784673553015224456e-01 2.2188444715117355832134649e-02
 	 2.3880121025600192785631748e-01 5.4050928206016735089178837e-01
 	 8.2555233741244438139261774e-01 7.0385142698029942373572077e-03
 	 0.0000000000000000000000000e+00 1.0000000000000000000000000e+00
 	 0.0000000000000000000000000e+00 1.2432123574616806548233773e-06
 	 ]; 
 

 	 % ----------------- DEGREE  5 --------------------
 
 	 case   5 

 	 % LEBESGUE CONST.               : 2.90426e+00
 	 % ABS.DET.VAND.MATRIX           : 2.80572e+20
 	 % CONDITIONING                  : 4.54886e+01
 	 % CARDINALITY                   :     21
 	 % POINTS OUTSIDE DOMAIN         :      0
 
 	 pts=[
 	 8.9770591923529749126117391e-06 8.7955400096967140122217188e-01
 	 6.1563736923237788456475528e-01 1.4746733405371923245064103e-02
 	 3.6454783579343125188287900e-01 1.6402623290155467217221741e-02
 	 1.1179717565670906802895862e-05 1.1277912996066075113077432e-01
 	 6.7306423024132655541507120e-01 1.6735741826058594949877545e-01
 	 3.6985361675190120411826911e-01 6.1601883885578334609789408e-01
 	 1.5734168867866035745883835e-02 3.7365555342051698373140312e-01
 	 9.9999983519247870322743665e-01 1.5147354738125010678032793e-07
 	 1.1627002934893286567596959e-01 8.8370564152592923079510001e-01
 	 3.4728106804423140519997009e-06 9.9999648402122010004688946e-01
 	 8.8435370841044524947704986e-01 1.7548159337012171014175133e-03
 	 8.5534266943638415004629635e-07 1.3046207008762499622946986e-05
 	 1.6013119237945275252776867e-01 1.6452746044599469987801399e-01
 	 4.0132316194955824917300902e-01 4.2265905100910328151542217e-01
 	 6.2228072093910380413461780e-01 3.6156359213361655147167539e-01
 	 1.6177838179759276848734828e-02 6.1563522870170761525088210e-01
 	 1.7917361356347838441394060e-01 4.1051273580842356780706837e-01
 	 8.7928161742988075744165144e-01 1.2012961306599567734565426e-01
 	 4.1843187634025452714681137e-01 1.7035198371705928543917707e-01
 	 1.6001812713560464862538879e-01 6.7458012401569100724429973e-01
 	 1.1927983899697607028667079e-01 2.8842775041380933368981299e-05
 	 ]; 
 

 	 % ----------------- DEGREE  6 --------------------
 
 	 case   6 

 	 % LEBESGUE CONST.               : 3.40132e+00
 	 % ABS.DET.VAND.MATRIX           : 4.12857e+28
 	 % CONDITIONING                  : 6.06455e+01
 	 % CARDINALITY                   :     28
 	 % POINTS OUTSIDE DOMAIN         :      0
 
 	 pts=[
 	 9.9999951233238859593654979e-01 3.4898566503893805308233848e-07
 	 1.1093419479846244879439610e-01 8.8906551909244269094045876e-01
 	 1.3421294342452982917279769e-01 3.3367278174681963553993569e-01
 	 8.9267806160928886427541329e-01 1.9833634198010267531729176e-19
 	 7.6570466586141294751399755e-01 1.1584690501055254496787228e-01
 	 1.2260388390317569773380058e-01 1.2557621002733859727484855e-01
 	 7.1589944032751717806206671e-01 1.0519318916699119115243377e-02
 	 1.2287682965846946636645498e-01 7.5735471993737379925448749e-01
 	 7.8747129309630695126465127e-02 4.0827331971462322386320909e-04
 	 1.3036439004444989116400511e-04 9.2140476462934395307513569e-01
 	 1.4754092035149671197925220e-20 1.1094039633678472686995027e-07
 	 9.6656872858484378652210722e-03 2.5727620262949546514619215e-01
 	 9.0007828841287529364478814e-01 9.9793036485157152193359309e-02
 	 3.3685460968749469934380159e-01 1.3126543810003252210627522e-01
 	 9.9406250130129776565457433e-03 7.0940385795095228793627484e-01
 	 3.3231970110233982618197501e-01 5.3663864092630986224463641e-01
 	 4.9045264997873677659256941e-01 1.1141238951610744553621934e-02
 	 5.4317619859894228362406920e-01 1.4256324666517350419070453e-01
 	 1.2286688651589147691645110e-02 4.8602148878373224727411639e-01
 	 5.4901833069396943631801378e-01 3.1498908864279362429527964e-01
 	 2.5278676645960002078439288e-01 7.3667142878529823235567164e-01
 	 1.6943090733136824605877869e-07 7.9297190422945917909203217e-02
 	 2.6585641279856081498067510e-01 1.2077678556401766352124127e-02
 	 2.6103978931865430497822352e-19 9.9999979687991336074759374e-01
 	 6.8659843570506096099848037e-01 3.0079980404644329761154609e-01
 	 1.4023872688985439260989097e-01 5.4570147594410867153413847e-01
 	 4.8069765293798855099183243e-01 5.0739473331349871365603121e-01
 	 3.1713340206012136102131649e-01 3.3462899278998375907079321e-01
 	 ]; 
 

 	 % ----------------- DEGREE  7 --------------------
 
 	 case   7 

 	 % LEBESGUE CONST.               : 4.13949e+00
 	 % ABS.DET.VAND.MATRIX           : 1.88501e+39
 	 % CONDITIONING                  : 9.14441e+01
 	 % CARDINALITY                   :     36
 	 % POINTS OUTSIDE DOMAIN         :      0
 
 	 pts=[
 	 8.9206952778089626532320722e-02 8.1959064206673137853442768e-01
 	 2.6237620402564731936223552e-01 1.0113113042681398656696956e-01
 	 1.0640883777534533571884623e-01 2.5381255303781857790568210e-01
 	 4.5393752517901786447396262e-01 2.6248795504383504173517849e-01
 	 4.4131487577167266556088521e-01 4.5805270293935052006162323e-01
 	 9.1200060074724517700239801e-02 8.9213955909454759063414997e-02
 	 6.3652758907417983369469994e-01 2.6235092312033286843231394e-01
 	 6.3974558349857890693357376e-01 1.0641458455373478675376475e-01
 	 2.8355350836197051878073694e-01 4.5395547714644107761827740e-01
 	 1.0061575398947217307998869e-01 4.4132716362437623969228184e-01
 	 8.1960688132349979184709809e-01 9.1194233969185467536533451e-02
 	 1.0113367543353200816991233e-01 6.3651800236482647399327561e-01
 	 2.5381791542609144496367435e-01 6.3976115027860425144012879e-01
 	 2.6245092856611090814666909e-01 2.8356768319778830056421270e-01
 	 4.5804618569974664410437981e-01 1.0060335397281700009486372e-01
 	 1.0000000000000000000000000e+00 0.0000000000000000000000000e+00
 	 0.0000000000000000000000000e+00 1.0000000000000000000000000e+00
 	 0.0000000000000000000000000e+00 0.0000000000000000000000000e+00
 	 6.4129925745196714181872721e-02 9.3587007425480328581812728e-01
 	 2.0414990928342899301206614e-01 7.9585009071657097923235824e-01
 	 3.9535039104876057436399606e-01 6.0464960895123942563600394e-01
 	 6.0464960895123931461370148e-01 3.9535039104876068538629852e-01
 	 7.9585009071657131229926563e-01 2.0414990928342868770073437e-01
 	 9.3587007425480317479582482e-01 6.4129925745196825204175184e-02
 	 6.4129925745196714181872721e-02 0.0000000000000000000000000e+00
 	 2.0414990928342899301206614e-01 0.0000000000000000000000000e+00
 	 3.9535039104876057436399606e-01 0.0000000000000000000000000e+00
 	 6.0464960895123931461370148e-01 0.0000000000000000000000000e+00
 	 7.9585009071657131229926563e-01 0.0000000000000000000000000e+00
 	 9.3587007425480317479582482e-01 0.0000000000000000000000000e+00
 	 0.0000000000000000000000000e+00 6.4129925745196714181872721e-02
 	 0.0000000000000000000000000e+00 2.0414990928342899301206614e-01
 	 0.0000000000000000000000000e+00 3.9535039104876057436399606e-01
 	 0.0000000000000000000000000e+00 6.0464960895123931461370148e-01
 	 0.0000000000000000000000000e+00 7.9585009071657131229926563e-01
 	 0.0000000000000000000000000e+00 9.3587007425480317479582482e-01
 	 ]; 
 

 	 % ----------------- DEGREE  8 --------------------
 
 	 case   8 

 	 % LEBESGUE CONST.               : 5.21483e+00
 	 % ABS.DET.VAND.MATRIX           : 8.03675e+50
 	 % CONDITIONING                  : 1.16434e+02
 	 % CARDINALITY                   :     45
 	 % POINTS OUTSIDE DOMAIN         :      0
 
 	 pts=[
 	 7.3902788828497634199266031e-01 2.1077216238173276940948142e-01
 	 3.0148586947333583241359634e-01 5.2561231178461031987581009e-01
 	 6.4599298345089672945817938e-01 2.0163245998015180693307968e-01
 	 9.4654551532921571421752560e-02 8.2672991426915143353681970e-01
 	 4.4885416842888509192377455e-01 3.2263207939699595216964667e-01
 	 2.8287144260197433220938024e-01 6.6904386378939173507518490e-01
 	 4.8964733924590392311060327e-01 4.2906127098337604186539807e-01
 	 5.0163121915075270518258321e-02 7.3907048902612704210923766e-01
 	 1.7288730300636978576278580e-01 3.0147179058286766029084447e-01
 	 1.5236743222623846949481674e-01 6.4599503596700869056945749e-01
 	 7.8649459084338305125960744e-02 9.4644077729438100266001754e-02
 	 2.2849645272874871682056153e-01 4.4886480555703706096792871e-01
 	 4.8080167340106692852597092e-02 2.8285660240774085361081802e-01
 	 8.1289879276647186712168036e-02 4.8963993144526068990174394e-01
 	 2.1075609299984254807469597e-01 5.0172810646129425982131522e-02
 	 5.2561971987592104316178165e-01 1.7288073002878520667557893e-01
 	 2.0164627313113298034963350e-01 1.5236022744483410096272280e-01
 	 8.2673720818600959781008441e-01 7.8614528184201920568696664e-02
 	 3.2264248641333231892858180e-01 2.2850405184638331035351655e-01
 	 6.6904576349975897198163466e-01 4.8083455890805211485616866e-02
 	 4.2904795513803406503683391e-01 8.1291343750827527170343956e-02
 	 1.0000000000000000000000000e+00 0.0000000000000000000000000e+00
 	 0.0000000000000000000000000e+00 1.0000000000000000000000000e+00
 	 0.0000000000000000000000000e+00 0.0000000000000000000000000e+00
 	 5.0121002294269967336504124e-02 9.4987899770573003266349588e-01
 	 1.6140686024463110626037121e-01 8.3859313975536886598405317e-01
 	 3.1844126808691092245240384e-01 6.8155873191308913305874739e-01
 	 5.0000000000000011102230246e-01 4.9999999999999988897769754e-01
 	 6.8155873191308913305874739e-01 3.1844126808691086694125261e-01
 	 8.3859313975536897700635564e-01 1.6140686024463102299364436e-01
 	 9.4987899770572981061889095e-01 5.0121002294270189381109049e-02
 	 5.0121002294269967336504124e-02 0.0000000000000000000000000e+00
 	 1.6140686024463110626037121e-01 0.0000000000000000000000000e+00
 	 3.1844126808691092245240384e-01 0.0000000000000000000000000e+00
 	 5.0000000000000011102230246e-01 0.0000000000000000000000000e+00
 	 6.8155873191308913305874739e-01 0.0000000000000000000000000e+00
 	 8.3859313975536897700635564e-01 0.0000000000000000000000000e+00
 	 9.4987899770572981061889095e-01 0.0000000000000000000000000e+00
 	 0.0000000000000000000000000e+00 5.0121002294269967336504124e-02
 	 0.0000000000000000000000000e+00 1.6140686024463110626037121e-01
 	 0.0000000000000000000000000e+00 3.1844126808691092245240384e-01
 	 0.0000000000000000000000000e+00 5.0000000000000011102230246e-01
 	 0.0000000000000000000000000e+00 6.8155873191308913305874739e-01
 	 0.0000000000000000000000000e+00 8.3859313975536897700635564e-01
 	 0.0000000000000000000000000e+00 9.4987899770572981061889095e-01
 	 ]; 
 

 	 % ----------------- DEGREE  9 --------------------
 
 	 case   9 

 	 % LEBESGUE CONST.               : 5.49590e+00
 	 % ABS.DET.VAND.MATRIX           : 1.43106e+64
 	 % CONDITIONING                  : 1.47749e+02
 	 % CARDINALITY                   :     55
 	 % POINTS OUTSIDE DOMAIN         :      0
 
 	 pts=[
 	 3.3333333333333331482961626e-01 3.3333333333333331482961626e-01
 	 5.2083828297463316547855072e-02 5.2083828297463316547855072e-02
 	 1.8358423280209493211323490e-01 1.8358423280209493211323490e-01
 	 5.2083828297463316547855072e-02 8.9583234340507333914871424e-01
 	 1.8358423280209493211323490e-01 6.3283153439581008026237896e-01
 	 8.9583234340507333914871424e-01 5.2083828297463316547855072e-02
 	 6.3283153439581008026237896e-01 1.8358423280209493211323490e-01
 	 4.6777783536752609583331264e-01 4.6777783536752609583331264e-01
 	 4.6777783536752609583331264e-01 6.4444329264947808333374724e-02
 	 6.4444329264947808333374724e-02 4.6777783536752609583331264e-01
 	 3.3359060382027372337887527e-01 4.7964829650825513418510582e-01
 	 1.7230536230958071186591951e-01 7.6177934223573873229184983e-01
 	 3.0938247275652719370242494e-01 6.2258297317208866061832850e-01
 	 3.3359060382027372337887527e-01 1.8676109967147114243601891e-01
 	 1.7230536230958071186591951e-01 6.5915295454680555842230660e-02
 	 3.0938247275652719370242494e-01 6.8034554071384145679246558e-02
 	 4.7964829650825513418510582e-01 3.3359060382027372337887527e-01
 	 7.6177934223573873229184983e-01 1.7230536230958071186591951e-01
 	 6.2258297317208866061832850e-01 3.0938247275652719370242494e-01
 	 4.7964829650825513418510582e-01 1.8676109967147114243601891e-01
 	 7.6177934223573873229184983e-01 6.5915295454680555842230660e-02
 	 6.2258297317208866061832850e-01 6.8034554071384145679246558e-02
 	 1.8676109967147114243601891e-01 3.3359060382027372337887527e-01
 	 6.5915295454680555842230660e-02 1.7230536230958071186591951e-01
 	 6.8034554071384145679246558e-02 3.0938247275652719370242494e-01
 	 1.8676109967147114243601891e-01 4.7964829650825513418510582e-01
 	 6.5915295454680555842230660e-02 7.6177934223573873229184983e-01
 	 6.8034554071384145679246558e-02 6.2258297317208866061832850e-01
 	 1.0000000000000000000000000e+00 0.0000000000000000000000000e+00
 	 0.0000000000000000000000000e+00 1.0000000000000000000000000e+00
 	 0.0000000000000000000000000e+00 0.0000000000000000000000000e+00
 	 4.0233045916770515670890518e-02 9.5976695408322942881795825e-01
 	 1.3061306744724759942855030e-01 8.6938693255275234506029847e-01
 	 2.6103752509477784471414452e-01 7.3896247490522215528585548e-01
 	 4.1736052116680649737290310e-01 5.8263947883319344711594567e-01
 	 5.8263947883319333609364321e-01 4.1736052116680666390635679e-01
 	 7.3896247490522237733046040e-01 2.6103752509477762266953960e-01
 	 8.6938693255275234506029847e-01 1.3061306744724765493970153e-01
 	 9.5976695408322920677335333e-01 4.0233045916770793226646674e-02
 	 4.0233045916770515670890518e-02 0.0000000000000000000000000e+00
 	 1.3061306744724759942855030e-01 0.0000000000000000000000000e+00
 	 2.6103752509477784471414452e-01 0.0000000000000000000000000e+00
 	 4.1736052116680649737290310e-01 0.0000000000000000000000000e+00
 	 5.8263947883319333609364321e-01 0.0000000000000000000000000e+00
 	 7.3896247490522237733046040e-01 0.0000000000000000000000000e+00
 	 8.6938693255275234506029847e-01 0.0000000000000000000000000e+00
 	 9.5976695408322920677335333e-01 0.0000000000000000000000000e+00
 	 0.0000000000000000000000000e+00 4.0233045916770515670890518e-02
 	 0.0000000000000000000000000e+00 1.3061306744724759942855030e-01
 	 0.0000000000000000000000000e+00 2.6103752509477784471414452e-01
 	 0.0000000000000000000000000e+00 4.1736052116680649737290310e-01
 	 0.0000000000000000000000000e+00 5.8263947883319333609364321e-01
 	 0.0000000000000000000000000e+00 7.3896247490522237733046040e-01
 	 0.0000000000000000000000000e+00 8.6938693255275234506029847e-01
 	 0.0000000000000000000000000e+00 9.5976695408322920677335333e-01
 	 ]; 
 

 	 % ----------------- DEGREE 10 --------------------
 
 	 case  10 

 	 % LEBESGUE CONST.               : 5.93588e+00
 	 % ABS.DET.VAND.MATRIX           : 4.57515e+79
 	 % CONDITIONING                  : 1.64229e+02
 	 % CARDINALITY                   :     66
 	 % POINTS OUTSIDE DOMAIN         :      0
 
 	 pts=[
 	 3.8406625808009381417562622e-01 2.3474236559725708550772083e-01
 	 3.8119137632264915582780418e-01 3.8406625808009381417562622e-01
 	 2.3474236559725708550772083e-01 3.8119137632264915582780418e-01
 	 9.0245311410743556113089880e-01 4.1584687366443995326648064e-02
 	 5.5962198526120443542453131e-02 9.0245311410743556113089880e-01
 	 4.1584687366443995326648064e-02 5.5962198526120443542453131e-02
 	 1.3651505507979921905103993e-01 5.8488086295952659843244703e-02
 	 8.0499685862424807947235195e-01 1.3651505507979921905103993e-01
 	 5.8488086295952659843244703e-02 8.0499685862424807947235195e-01
 	 6.8091532671114907149245710e-01 1.1568829255905452302322090e-01
 	 2.0339638072979640548432201e-01 6.8091532671114907149245710e-01
 	 1.1568829255905452302322090e-01 2.0339638072979640548432201e-01
 	 1.8264175967507070841300276e-01 1.2301719345109123071591029e-01
 	 6.9434104687383813026002599e-01 1.8264175967507070841300276e-01
 	 1.2301719345109123071591029e-01 6.9434104687383813026002599e-01
 	 3.8032226769010618605548757e-01 1.0153603356972847049366493e-01
 	 5.1814169874016535732863531e-01 3.8032226769010618605548757e-01
 	 1.0153603356972847049366493e-01 5.1814169874016535732863531e-01
 	 5.4929895854287247303204822e-01 2.2312781586932747823759371e-01
 	 2.2757322558780004873035807e-01 5.4929895854287247303204822e-01
 	 2.2312781586932747823759371e-01 2.2757322558780004873035807e-01
 	 2.6887138669767990384329437e-01 3.6511807687709195435754594e-02
 	 6.9461680561461081051533029e-01 2.6887138669767990384329437e-01
 	 3.6511807687709195435754594e-02 6.9461680561461081051533029e-01
 	 6.7848558924181623375204708e-01 3.4207198393496937582902717e-02
 	 2.8730721236468681478726239e-01 6.7848558924181623375204708e-01
 	 3.4207198393496937582902717e-02 2.8730721236468681478726239e-01
 	 5.2059108703099443715700545e-01 9.7824873804756032336094052e-02
 	 3.8158403916424954438468831e-01 5.2059108703099443715700545e-01
 	 9.7824873804756032336094052e-02 3.8158403916424954438468831e-01
 	 4.7191146011387274938897463e-01 3.6218137706307294843011135e-02
 	 4.9187040217981997658469595e-01 4.7191146011387274938897463e-01
 	 3.6218137706307294843011135e-02 4.9187040217981997658469595e-01
 	 7.9619621213452973496060849e-01 5.8164206316463962220808526e-02
 	 1.4563958154900630281858298e-01 7.9619621213452973496060849e-01
 	 5.8164206316463962220808526e-02 1.4563958154900630281858298e-01
 	 1.0000000000000000000000000e+00 0.0000000000000000000000000e+00
 	 9.6700071520402963720641765e-01 0.0000000000000000000000000e+00
 	 8.9224173683157226300011189e-01 0.0000000000000000000000000e+00
 	 7.8261766349810257814567649e-01 0.0000000000000000000000000e+00
 	 6.4787906779346970953525897e-01 0.0000000000000000000000000e+00
 	 5.0000000000000000000000000e-01 0.0000000000000000000000000e+00
 	 3.5212093220653029046474103e-01 0.0000000000000000000000000e+00
 	 2.1738233650189747736547474e-01 0.0000000000000000000000000e+00
 	 1.0775826316842779251103934e-01 0.0000000000000000000000000e+00
 	 3.2999284795970418304733585e-02 0.0000000000000000000000000e+00
 	 0.0000000000000000000000000e+00 0.0000000000000000000000000e+00
 	 0.0000000000000000000000000e+00 1.0000000000000000000000000e+00
 	 0.0000000000000000000000000e+00 9.6700071520402963720641765e-01
 	 0.0000000000000000000000000e+00 8.9224173683157226300011189e-01
 	 0.0000000000000000000000000e+00 7.8261766349810257814567649e-01
 	 0.0000000000000000000000000e+00 6.4787906779346970953525897e-01
 	 0.0000000000000000000000000e+00 5.0000000000000000000000000e-01
 	 0.0000000000000000000000000e+00 3.5212093220653029046474103e-01
 	 0.0000000000000000000000000e+00 2.1738233650189747736547474e-01
 	 0.0000000000000000000000000e+00 1.0775826316842779251103934e-01
 	 0.0000000000000000000000000e+00 3.2999284795970418304733585e-02
 	 3.2999284795970418304733585e-02 9.6700071520402963720641765e-01
 	 1.0775826316842779251103934e-01 8.9224173683157226300011189e-01
 	 2.1738233650189747736547474e-01 7.8261766349810257814567649e-01
 	 3.5212093220653029046474103e-01 6.4787906779346970953525897e-01
 	 5.0000000000000000000000000e-01 5.0000000000000000000000000e-01
 	 6.4787906779346970953525897e-01 3.5212093220653029046474103e-01
 	 7.8261766349810257814567649e-01 2.1738233650189747736547474e-01
 	 8.9224173683157226300011189e-01 1.0775826316842779251103934e-01
 	 9.6700071520402963720641765e-01 3.2999284795970418304733585e-02
 	 ]; 
 

 	 % ----------------- DEGREE 11 --------------------
 
 	 case  11 

 	 % LEBESGUE CONST.               : 6.66424e+00
 	 % ABS.DET.VAND.MATRIX           : 4.43645e+96
 	 % CONDITIONING                  : 1.82180e+02
 	 % CARDINALITY                   :     78
 	 % POINTS OUTSIDE DOMAIN         :      0
 
 	 pts=[
 	 6.9351770198338746897803730e-01 8.4377528428345990874070992e-02
 	 2.2210476958826652627010390e-01 6.9351770198338746897803730e-01
 	 8.4377528428345990874070992e-02 2.2210476958826652627010390e-01
 	 4.0311470490903791863424033e-02 4.0311470490903791863424033e-02
 	 9.1937705901819244402872755e-01 4.0311470490903791863424033e-02
 	 4.0311470490903791863424033e-02 9.1937705901819244402872755e-01
 	 7.4553090101456620519826402e-01 2.7298229491530833640267062e-02
 	 2.2717086949390297156980978e-01 7.4553090101456620519826402e-01
 	 2.7298229491530833640267062e-02 2.2717086949390297156980978e-01
 	 5.6495374320220637098799443e-01 4.4131599177984877357960869e-02
 	 3.9091465761980875859293860e-01 5.6495374320220637098799443e-01
 	 4.4131599177984877357960869e-02 3.9091465761980875859293860e-01
 	 8.2495126960113840386412676e-01 5.0722134022280540577298780e-02
 	 1.2432659637658105555857446e-01 8.2495126960113840386412676e-01
 	 5.0722134022280540577298780e-02 1.2432659637658105555857446e-01
 	 1.5969983813122679006113458e-01 1.0321977918324988510168083e-01
 	 7.3708038268552333871497240e-01 1.5969983813122679006113458e-01
 	 1.0321977918324988510168083e-01 7.3708038268552333871497240e-01
 	 5.5092060836475587048965963e-01 1.2365705769670772007362558e-01
 	 3.2542233393853642331450260e-01 5.5092060836475587048965963e-01
 	 1.2365705769670772007362558e-01 3.2542233393853642331450260e-01
 	 4.2737137848053580180263111e-01 2.6830798423248086725934058e-01
 	 3.0432063728698338644917953e-01 4.2737137848053580180263111e-01
 	 2.6830798423248086725934058e-01 3.0432063728698338644917953e-01
 	 3.7495473164237586027880411e-01 1.9113296643987093270666833e-01
 	 4.3391230191775326252567879e-01 3.7495473164237586027880411e-01
 	 1.9113296643987093270666833e-01 4.3391230191775326252567879e-01
 	 2.2948861577152193658157842e-01 2.9522084417162256647637619e-02
 	 7.4098929981131578248465530e-01 2.2948861577152193658157842e-01
 	 2.9522084417162256647637619e-02 7.4098929981131578248465530e-01
 	 4.0327364621373307240759232e-01 2.7505549487669197356032313e-02
 	 5.6922080429859778227807965e-01 4.0327364621373307240759232e-01
 	 2.7505549487669197356032313e-02 5.6922080429859778227807965e-01
 	 1.0894013417964920620306657e-01 4.8958205296899738601101859e-02
 	 8.4210166052345103437914986e-01 1.0894013417964920620306657e-01
 	 4.8958205296899738601101859e-02 8.4210166052345103437914986e-01
 	 3.2070128023529026473070758e-01 9.5588154428349225710803694e-02
 	 5.8371056533636056506963996e-01 3.2070128023529026473070758e-01
 	 9.5588154428349225710803694e-02 5.8371056533636056506963996e-01
 	 2.0667240615042631324271838e-01 2.0667240615042631324271838e-01
 	 5.8665518769914726249226078e-01 2.0667240615042631324271838e-01
 	 2.0667240615042631324271838e-01 5.8665518769914726249226078e-01
 	 4.5023971782244887052115700e-01 8.8426654561742548676939180e-02
 	 4.6133362761580859467969162e-01 4.5023971782244887052115700e-01
 	 8.8426654561742548676939180e-02 4.6133362761580859467969162e-01
 	 1.0000000000000000000000000e+00 0.0000000000000000000000000e+00
 	 9.7244963611144108472927883e-01 0.0000000000000000000000000e+00
 	 9.0963966082200331531026904e-01 0.0000000000000000000000000e+00
 	 8.1643807651593025553893312e-01 0.0000000000000000000000000e+00
 	 6.9976547048267445649827323e-01 0.0000000000000000000000000e+00
 	 5.6827646642746376670629616e-01 0.0000000000000000000000000e+00
 	 4.3172353357253623329370384e-01 0.0000000000000000000000000e+00
 	 3.0023452951732554350172677e-01 0.0000000000000000000000000e+00
 	 1.8356192348406968894991564e-01 0.0000000000000000000000000e+00
 	 9.0360339177996684689730955e-02 0.0000000000000000000000000e+00
 	 2.7550363888558915270721172e-02 0.0000000000000000000000000e+00
 	 0.0000000000000000000000000e+00 0.0000000000000000000000000e+00
 	 0.0000000000000000000000000e+00 1.0000000000000000000000000e+00
 	 0.0000000000000000000000000e+00 9.7244963611144108472927883e-01
 	 0.0000000000000000000000000e+00 9.0963966082200331531026904e-01
 	 0.0000000000000000000000000e+00 8.1643807651593025553893312e-01
 	 0.0000000000000000000000000e+00 6.9976547048267445649827323e-01
 	 0.0000000000000000000000000e+00 5.6827646642746376670629616e-01
 	 0.0000000000000000000000000e+00 4.3172353357253623329370384e-01
 	 0.0000000000000000000000000e+00 3.0023452951732554350172677e-01
 	 0.0000000000000000000000000e+00 1.8356192348406968894991564e-01
 	 0.0000000000000000000000000e+00 9.0360339177996684689730955e-02
 	 0.0000000000000000000000000e+00 2.7550363888558915270721172e-02
 	 2.7550363888558915270721172e-02 9.7244963611144108472927883e-01
 	 9.0360339177996684689730955e-02 9.0963966082200331531026904e-01
 	 1.8356192348406968894991564e-01 8.1643807651593025553893312e-01
 	 3.0023452951732554350172677e-01 6.9976547048267445649827323e-01
 	 4.3172353357253623329370384e-01 5.6827646642746376670629616e-01
 	 5.6827646642746376670629616e-01 4.3172353357253623329370384e-01
 	 6.9976547048267445649827323e-01 3.0023452951732554350172677e-01
 	 8.1643807651593025553893312e-01 1.8356192348406968894991564e-01
 	 9.0963966082200331531026904e-01 9.0360339177996684689730955e-02
 	 9.7244963611144108472927883e-01 2.7550363888558915270721172e-02
 	 ]; 
 

 	 % ----------------- DEGREE 12 --------------------
 
 	 case  12 

 	 % LEBESGUE CONST.               : 6.98481e+00
 	 % ABS.DET.VAND.MATRIX           : 2.71864e+115
 	 % CONDITIONING                  : 2.20876e+02
 	 % CARDINALITY                   :     91
 	 % POINTS OUTSIDE DOMAIN         :      0
 
 	 pts=[
 	 4.8833194230728110829531374e-01 9.9139249403952106609594352e-02
 	 4.1250230902090989637542862e-01 4.8833675844718954506262776e-01
 	 9.9118433050496210223734295e-02 4.1252281597712453509174679e-01
 	 7.2900870069636480863550787e-01 9.9718417650047436184834737e-02
 	 1.7122669521593525399083546e-01 7.2905382337365021161446066e-01
 	 9.9729195976620901853415546e-02 1.7127001819343071198353812e-01
 	 4.5568925071324976883158087e-02 4.3713630744616774337352183e-02
 	 9.1071287591951755047148254e-01 4.5563607564416054584999216e-02
 	 4.3713732276029426682129042e-02 9.1072296369291128037559702e-01
 	 2.7558172012736509293162612e-01 2.4152438490213459787447903e-01
 	 4.8290138580271013690747850e-01 2.7558066973532602261798274e-01
 	 2.4147875120615525101896992e-01 4.8289198023993390451735763e-01
 	 2.2085970300340135308303502e-01 1.5339050567567166782900756e-01
 	 6.2579871420127741732386539e-01 2.2081083319595720682038120e-01
 	 1.5340093254494074903604428e-01 6.2578124857297823258051039e-01
 	 5.8307423156860171964410711e-01 1.5877732238124814267976603e-01
 	 2.5810318592085773614641653e-01 5.8306736095926936513933470e-01
 	 1.5879203822509585508626628e-01 2.5811263744193135849513965e-01
 	 8.4965905742573311076881737e-01 3.6096279224288006781673488e-02
 	 1.1423451740758608363712767e-01 8.4967606550390795128180343e-01
 	 3.6085602584052522967539289e-02 1.1421956669357889724292221e-01
 	 4.1970092634263134190319988e-01 3.7443706936923677741635430e-02
 	 5.4284764094013882029798879e-01 4.1968057848357853689691410e-01
 	 3.7467479935237815724669019e-02 5.4285174246197487324394615e-01
 	 3.7220585130208866386780642e-01 1.2110859189110892430996103e-01
 	 5.0663993177696420300293312e-01 3.7220189013132976008080277e-01
 	 1.2114387317883731909340383e-01 5.0664780613756577043460538e-01
 	 6.3741198189358061476639250e-01 7.8064349878611369315528634e-02
 	 2.8447650111889394297648437e-01 6.3743461119252575741711553e-01
 	 7.8049781430158976514022129e-02 2.8450685262563751853903682e-01
 	 2.8115436089783957251952984e-01 8.1664440978951369221050527e-02
 	 6.3715340856291746707285029e-01 2.8117189819456822608145785e-01
 	 8.1664195981782747302268888e-02 6.3716833727063826309233718e-01
 	 1.7095362616072445893777854e-01 7.8746842535131644780221905e-02
 	 7.5032189667147075606834505e-01 1.7090363057202870300521624e-01
 	 7.8745264254505453749288790e-02 7.5032933817839442269814754e-01
 	 2.7785452266607030269440770e-01 2.1529215985260651694543910e-02
 	 7.0062894917600626598641611e-01 2.7782466899386404346472546e-01
 	 2.1527028566987335689297822e-02 7.0063275017285653323284578e-01
 	 4.1924664693666874315525206e-01 1.9482237769308644037558054e-01
 	 3.8595462224422616426267041e-01 4.1919152977245777158543660e-01
 	 1.9487882854783541985987938e-01 3.8590394146374151773670746e-01
 	 1.3536205326289707517872785e-01 2.4234924787352066927192951e-02
 	 8.4040563192280304249948131e-01 1.3531661822629123537176099e-01
 	 2.4217602752773407376318815e-02 8.4044572085273105965796958e-01
 	 7.3316928542901782517304810e-01 3.0703904696533525914281526e-02
 	 2.3612995021829721875583630e-01 7.3317209665689275777111789e-01
 	 3.0693079518256581594837229e-02 2.3609015788719192596722962e-01
 	 5.7725441774451236032206225e-01 2.7750693224280083976074351e-02
 	 3.9500528742115748048746582e-01 5.7725893093914160125734725e-01
 	 2.7707330837891969849140494e-02 3.9501066722258110219812011e-01
 	 9.2120330697889218907192799e-02 8.5026459962981262852288467e-02
 	 8.2287265514846330560772003e-01 9.2062735392526934274926020e-02
 	 8.5007486783677518871193968e-02 8.2289233941444717146396215e-01
 	 9.9999643938213855776098171e-01 3.5606178614422390182880918e-06
 	 9.7662672892136448421496198e-01 1.4370019744908695357821053e-05
 	 9.2311524910948872246763131e-01 4.2959586347553870629579348e-05
 	 8.4309295541659867723183197e-01 1.8020336765674131002893527e-05
 	 7.4145451774505855002672661e-01 1.2094988354316491455217771e-05
 	 6.2458286002238816436715751e-01 7.7311296193950706026609687e-05
 	 4.9996771830191433227952302e-01 6.5199225261467123426588344e-05
 	 3.7532751953081089357766587e-01 7.3716265361128006298845061e-05
 	 2.5856116400122186593790730e-01 0.0000000000000000000000000e+00
 	 1.5689543429403890462126014e-01 0.0000000000000000000000000e+00
 	 7.6825734026995148862049234e-02 1.4542120229814945299526979e-05
 	 2.3353464364485838206109136e-02 7.1520382443360325740687455e-05
 	 9.6035521277204840320243159e-06 4.0307338423833831552865921e-06
 	 0.0000000000000000000000000e+00 9.9999248470869206428801590e-01
 	 3.8614019774646180991044958e-05 9.7660647522117927099571943e-01
 	 1.6534604582596295046376111e-05 9.2316067766448539622103908e-01
 	 0.0000000000000000000000000e+00 8.4310470333208586968254394e-01
 	 3.8145044533797278589731111e-06 7.4140410943887025130294433e-01
 	 7.2619444207864749943684424e-05 6.2461016294242133195524502e-01
 	 7.6289186928701915543261924e-05 4.9996052692632608760447965e-01
 	 4.1063632079512431391401378e-05 3.7537725673002103610187419e-01
 	 0.0000000000000000000000000e+00 2.5854817595071832858621974e-01
 	 2.1445674289089464192078344e-05 1.5689979103080606281928056e-01
 	 4.9928838883595435497054355e-05 7.6843438426217297587683674e-02
 	 2.3339846973387405512081680e-05 2.3355270549759832299230311e-02
 	 2.3349903943378574888711796e-02 9.7660797083240769023149142e-01
 	 7.6830192242474615316183417e-02 9.2313220650027361102729628e-01
 	 1.5688771892308650546254967e-01 8.4308029304633480549568958e-01
 	 2.5853541355229686660166522e-01 7.4146458644770307788718355e-01
 	 3.7534919974589103786044575e-01 6.2460184296238596690642453e-01
 	 4.9994408332503548209047040e-01 4.9994434269335286113999928e-01
 	 6.2461712052050366583699770e-01 3.7533138163938895015547814e-01
 	 7.4143612609133335844546764e-01 2.5856387390866664155453236e-01
 	 8.4310833488621361730963599e-01 1.5689162520111446519344156e-01
 	 9.2315409243450297083199985e-01 7.6830553839060816700978762e-02
 	 9.7662699590868695675993649e-01 2.3350254028626067637208763e-02
 	 3.3336638731165141313894651e-01 3.3330631117014719588809157e-01
 	 ]; 
 

 	 % ----------------- DEGREE 13 --------------------
 
 	 case  13 

 	 % LEBESGUE CONST.               : 7.74381e+00
 	 % ABS.DET.VAND.MATRIX           : 5.70766e+135
 	 % CONDITIONING                  : 2.90055e+02
 	 % CARDINALITY                   :    105
 	 % POINTS OUTSIDE DOMAIN         :      0
 
 	 pts=[
 	 4.8254395679038292188423043e-01 2.1801649387528723722518009e-02
 	 4.9565439382208842378219060e-01 4.8254395679038292188423043e-01
 	 2.1801649387528723722518009e-02 4.9565439382208842378219060e-01
 	 2.7035531005290119876960375e-01 2.1187797951754575725979990e-02
 	 7.0845689199534411795156075e-01 2.7035531005290119876960375e-01
 	 2.1187797951754575725979990e-02 7.0845689199534411795156075e-01
 	 3.7175753808656258891929269e-01 4.0802877624889474783564935e-02
 	 5.8743958428854803344165703e-01 3.7175753808656258891929269e-01
 	 4.0802877624889474783564935e-02 5.8743958428854803344165703e-01
 	 2.7949525761827420655691867e-01 6.8647202036655197154857433e-02
 	 6.5185754034507059628822390e-01 2.7949525761827420655691867e-01
 	 6.8647202036655197154857433e-02 6.5185754034507059628822390e-01
 	 7.7520423964579876496827637e-01 3.2945383574945995286409328e-02
 	 1.9185037677925523280642039e-01 7.7520423964579876496827637e-01
 	 3.2945383574945995286409328e-02 1.9185037677925523280642039e-01
 	 5.8840573881630142683007989e-01 6.7125037749079158322373928e-02
 	 3.4446922343461938709197057e-01 5.8840573881630142683007989e-01
 	 6.7125037749079158322373928e-02 3.4446922343461938709197057e-01
 	 1.3305442687245128130513194e-01 2.2936784149999066978464768e-02
 	 8.4400878897754960661359291e-01 1.3305442687245128130513194e-01
 	 2.2936784149999066978464768e-02 8.4400878897754960661359291e-01
 	 3.3808504766535157903817321e-01 2.1810242661584300360999578e-01
 	 4.4381252571880536184067978e-01 3.3808504766535157903817321e-01
 	 2.1810242661584300360999578e-01 4.4381252571880536184067978e-01
 	 1.8116385225097764166690695e-01 1.5120191226325155331444705e-01
 	 6.6763423548577083277422162e-01 1.8116385225097764166690695e-01
 	 1.5120191226325155331444705e-01 6.6763423548577083277422162e-01
 	 3.2183509682876670909834615e-01 1.3300919379865164260401400e-01
 	 5.4515570937258173156436669e-01 3.2183509682876670909834615e-01
 	 1.3300919379865164260401400e-01 5.4515570937258173156436669e-01
 	 3.9618555819577079557536337e-02 2.9891071374288341599978480e-02
 	 9.3049037280613455802580347e-01 3.9618555819577079557536337e-02
 	 2.9891071374288341599978480e-02 9.3049037280613455802580347e-01
 	 1.4714091454213237830650485e-01 6.2544565377791558336006972e-02
 	 7.9031452008007607723527599e-01 1.4714091454213237830650485e-01
 	 6.2544565377791558336006972e-02 7.9031452008007607723527599e-01
 	 4.5815699799597475738721641e-01 1.5974444694755424167809110e-01
 	 3.8209855505647100093469248e-01 4.5815699799597475738721641e-01
 	 1.5974444694755424167809110e-01 3.8209855505647100093469248e-01
 	 8.0278437400087956921090893e-02 5.9537844480298703075948907e-02
 	 8.6018371811961324979733945e-01 8.0278437400087956921090893e-02
 	 5.9537844480298703075948907e-02 8.6018371811961324979733945e-01
 	 6.8979175262087999431770413e-01 6.6843340857118335729403213e-02
 	 2.4336490652200165607510485e-01 6.8979175262087999431770413e-01
 	 6.6843340857118335729403213e-02 2.4336490652200165607510485e-01
 	 6.0321881295188140015284262e-01 1.4801120509892598531287433e-01
 	 2.4876998194919261453428305e-01 6.0321881295188140015284262e-01
 	 1.4801120509892598531287433e-01 2.4876998194919261453428305e-01
 	 4.3929956988621743363410133e-01 7.0848237340666767036800877e-02
 	 4.8985219277311581320688560e-01 4.3929956988621743363410133e-01
 	 7.0848237340666767036800877e-02 4.8985219277311581320688560e-01
 	 2.3516747335230311910514445e-01 2.3516125307306637304272101e-01
 	 5.2967127357463050785213454e-01 2.3516747335230311910514445e-01
 	 2.3516125307306637304272101e-01 5.2967127357463050785213454e-01
 	 7.5875390221366512122358472e-01 8.3937225401591153417513169e-02
 	 1.5730887238474372535890211e-01 7.5875390221366512122358472e-01
 	 8.3937225401591153417513169e-02 1.5730887238474372535890211e-01
 	 4.0235017434608083553015945e-01 2.6067230244277200812419437e-01
 	 3.3697752321114710083449495e-01 4.0235017434608083553015945e-01
 	 2.6067230244277200812419437e-01 3.3697752321114710083449495e-01
 	 8.8476340755026594564469633e-01 3.4110729300994256651957670e-02
 	 8.1125863148739790764452096e-02 8.8476340755026594564469633e-01
 	 3.4110729300994256651957670e-02 8.1125863148739790764452096e-02
 	 6.4827611647845850839644299e-01 2.2306027539705081813581344e-02
 	 3.2941785598183642713721042e-01 6.4827611647845850839644299e-01
 	 2.2306027539705081813581344e-02 3.2941785598183642713721042e-01
 	 1.0000000000000000000000000e+00 0.0000000000000000000000000e+00
 	 9.7996752263363040569288387e-01 0.0000000000000000000000000e+00
 	 9.3390052691517366767470776e-01 0.0000000000000000000000000e+00
 	 8.6443429954566308737184954e-01 0.0000000000000000000000000e+00
 	 7.7531970146432360735389011e-01 0.0000000000000000000000000e+00
 	 6.7136200667135637054627750e-01 0.0000000000000000000000000e+00
 	 5.5816593444185191863482487e-01 0.0000000000000000000000000e+00
 	 4.4183406555814808136517513e-01 0.0000000000000000000000000e+00
 	 3.2863799332864357394257127e-01 0.0000000000000000000000000e+00
 	 2.2468029853567644815726112e-01 0.0000000000000000000000000e+00
 	 1.3556570045433691262815046e-01 0.0000000000000000000000000e+00
 	 6.6099473084826387836443473e-02 0.0000000000000000000000000e+00
 	 2.0032477366369538795964900e-02 0.0000000000000000000000000e+00
 	 0.0000000000000000000000000e+00 0.0000000000000000000000000e+00
 	 0.0000000000000000000000000e+00 1.0000000000000000000000000e+00
 	 0.0000000000000000000000000e+00 9.7996752263363040569288387e-01
 	 0.0000000000000000000000000e+00 9.3390052691517366767470776e-01
 	 0.0000000000000000000000000e+00 8.6443429954566308737184954e-01
 	 0.0000000000000000000000000e+00 7.7531970146432360735389011e-01
 	 0.0000000000000000000000000e+00 6.7136200667135637054627750e-01
 	 0.0000000000000000000000000e+00 5.5816593444185191863482487e-01
 	 0.0000000000000000000000000e+00 4.4183406555814808136517513e-01
 	 0.0000000000000000000000000e+00 3.2863799332864357394257127e-01
 	 0.0000000000000000000000000e+00 2.2468029853567644815726112e-01
 	 0.0000000000000000000000000e+00 1.3556570045433691262815046e-01
 	 0.0000000000000000000000000e+00 6.6099473084826387836443473e-02
 	 0.0000000000000000000000000e+00 2.0032477366369538795964900e-02
 	 2.0032477366369538795964900e-02 9.7996752263363040569288387e-01
 	 6.6099473084826387836443473e-02 9.3390052691517366767470776e-01
 	 1.3556570045433691262815046e-01 8.6443429954566308737184954e-01
 	 2.2468029853567644815726112e-01 7.7531970146432360735389011e-01
 	 3.2863799332864357394257127e-01 6.7136200667135637054627750e-01
 	 4.4183406555814808136517513e-01 5.5816593444185191863482487e-01
 	 5.5816593444185191863482487e-01 4.4183406555814808136517513e-01
 	 6.7136200667135637054627750e-01 3.2863799332864357394257127e-01
 	 7.7531970146432360735389011e-01 2.2468029853567644815726112e-01
 	 8.6443429954566308737184954e-01 1.3556570045433691262815046e-01
 	 9.3390052691517366767470776e-01 6.6099473084826387836443473e-02
 	 9.7996752263363040569288387e-01 2.0032477366369538795964900e-02
 	 ]; 
 

 	 % ----------------- DEGREE 14 --------------------
 
 	 case  14 

 	 % LEBESGUE CONST.               : 8.30571e+00
 	 % ABS.DET.VAND.MATRIX           : 9.94900e+157
 	 % CONDITIONING                  : 3.45193e+02
 	 % CARDINALITY                   :    120
 	 % POINTS OUTSIDE DOMAIN         :      0
 
 	 pts=[
 	 4.6250424530281358803662783e-02 1.9770301520200830869278263e-02
 	 9.3397927394951774093811991e-01 4.6250424530281358803662783e-02
 	 1.9770301520200830869278263e-02 9.3397927394951774093811991e-01
 	 9.2632659737287770251867869e-01 1.8200162675740781670352675e-02
 	 5.5473239951381515810968637e-02 9.2632659737287770251867869e-01
 	 1.8200162675740781670352675e-02 5.5473239951381515810968637e-02
 	 3.2703462743708006099652152e-01 2.8360705357229724909995383e-02
 	 6.4460466720569020715458919e-01 3.2703462743708006099652152e-01
 	 2.8360705357229724909995383e-02 6.4460466720569020715458919e-01
 	 6.0061284473864329225278880e-01 1.8143146066022009660345660e-02
 	 3.8124400919533468767852469e-01 6.0061284473864329225278880e-01
 	 1.8143146066022009660345660e-02 3.8124400919533468767852469e-01
 	 5.2180999892365897974144673e-01 6.1906819780296877542280498e-02
 	 4.1628318129604413577737887e-01 5.2180999892365897974144673e-01
 	 6.1906819780296877542280498e-02 4.1628318129604413577737887e-01
 	 3.2395972089484870171105513e-01 2.9417523955654206746501700e-01
 	 3.8186503954860923082392787e-01 3.2395972089484870171105513e-01
 	 2.9417523955654206746501700e-01 3.8186503954860923082392787e-01
 	 2.8514037742473380410146433e-01 7.5846247172451211615573641e-02
 	 6.3901337540281488713844738e-01 2.8514037742473380410146433e-01
 	 7.5846247172451211615573641e-02 6.3901337540281488713844738e-01
 	 6.1318041430696523796939346e-01 6.7273468516794332483499375e-02
 	 3.1954611717624042954710717e-01 6.1318041430696523796939346e-01
 	 6.7273468516794332483499375e-02 3.1954611717624042954710717e-01
 	 7.3400669070495827561728674e-01 1.8944884399017512116580875e-02
 	 2.4704842489602421573557933e-01 7.3400669070495827561728674e-01
 	 1.8944884399017512116580875e-02 2.4704842489602421573557933e-01
 	 4.0635332371784116389790142e-01 7.9858479870070414596838759e-02
 	 5.1378819641208839374968420e-01 4.0635332371784116389790142e-01
 	 7.9858479870070414596838759e-02 5.1378819641208839374968420e-01
 	 1.2900790858202898503392930e-01 3.2529851099023031346657575e-02
 	 8.3846224031894789341379237e-01 1.2900790858202898503392930e-01
 	 3.2529851099023031346657575e-02 8.3846224031894789341379237e-01
 	 2.1380717697122103571061302e-01 3.3356666827464936941893825e-02
 	 7.5283615620131394408076630e-01 2.1380717697122103571061302e-01
 	 3.3356666827464936941893825e-02 7.5283615620131394408076630e-01
 	 1.6975705122904435895314634e-01 1.2348723696213652345488043e-01
 	 7.0675571180881913146976103e-01 1.6975705122904435895314634e-01
 	 1.2348723696213652345488043e-01 7.0675571180881913146976103e-01
 	 8.7568274655439903852993666e-01 5.6942259049036408891097949e-02
 	 6.7374994396564552578965390e-02 8.7568274655439903852993666e-01
 	 5.6942259049036408891097949e-02 6.7374994396564552578965390e-02
 	 8.3115363065833536282411842e-01 2.8265520062899601033690189e-02
 	 1.4058084927876504655053225e-01 8.3115363065833536282411842e-01
 	 2.8265520062899601033690189e-02 1.4058084927876504655053225e-01
 	 5.1248647535317315426794949e-01 1.2169602901547478535082547e-01
 	 3.6581749563135207425901285e-01 5.1248647535317315426794949e-01
 	 1.2169602901547478535082547e-01 3.6581749563135207425901285e-01
 	 7.8872899184734601707447155e-01 9.2070255006848886192294401e-02
 	 1.1920075314580509673323405e-01 7.8872899184734601707447155e-01
 	 9.2070255006848886192294401e-02 1.1920075314580509673323405e-01
 	 4.9301718193275584356527474e-01 1.9295747045566474797695378e-01
 	 3.1402534761157946396892271e-01 4.9301718193275584356527474e-01
 	 1.9295747045566474797695378e-01 3.1402534761157946396892271e-01
 	 3.2480621143418386687073962e-01 1.3314682439648198308823623e-01
 	 5.4204696416933417779659976e-01 3.2480621143418386687073962e-01
 	 1.3314682439648198308823623e-01 5.4204696416933417779659976e-01
 	 6.4001591711854499688882925e-01 1.3719362348223684833214975e-01
 	 2.2279045939921815477902101e-01 6.4001591711854499688882925e-01
 	 1.3719362348223684833214975e-01 2.2279045939921815477902101e-01
 	 2.7227276488947277366392541e-01 2.1552003579406989186573185e-01
 	 5.1220719931645741773706959e-01 2.7227276488947277366392541e-01
 	 2.1552003579406989186573185e-01 5.1220719931645741773706959e-01
 	 2.2634306457364944398236162e-01 1.6293922236272717629645967e-01
 	 6.1071771306362332421002748e-01 2.2634306457364944398236162e-01
 	 1.6293922236272717629645967e-01 6.1071771306362332421002748e-01
 	 4.5350667224656393550219491e-01 3.2435444015977143994433618e-02
 	 5.1405788373745897601452270e-01 4.5350667224656393550219491e-01
 	 3.2435444015977143994433618e-02 5.1405788373745897601452270e-01
 	 7.1854633569919634794587182e-01 6.7035604956334662873906893e-02
 	 2.1441805934446900305800909e-01 7.1854633569919634794587182e-01
 	 6.7035604956334662873906893e-02 2.1441805934446900305800909e-01
 	 1.5839343085936782862255257e-01 7.0744953014075559472040311e-02
 	 7.7086161612655657027204370e-01 1.5839343085936782862255257e-01
 	 7.0744953014075559472040311e-02 7.7086161612655657027204370e-01
 	 4.2060092672949378478364224e-01 1.6959660738383425249153902e-01
 	 4.0980246588667196272481874e-01 4.2060092672949378478364224e-01
 	 1.6959660738383425249153902e-01 4.0980246588667196272481874e-01
 	 1.0000000000000000000000000e+00 0.0000000000000000000000000e+00
 	 9.8262296325191922363728736e-01 0.0000000000000000000000000e+00
 	 9.4254102211148815815278112e-01 0.0000000000000000000000000e+00
 	 8.8175984497590764732422031e-01 0.0000000000000000000000000e+00
 	 8.0312660273492286755470104e-01 0.0000000000000000000000000e+00
 	 7.1031902735683627447826893e-01 0.0000000000000000000000000e+00
 	 6.0767697768189710139097315e-01 0.0000000000000000000000000e+00
 	 5.0000000000000000000000000e-01 0.0000000000000000000000000e+00
 	 3.9232302231810289860902685e-01 0.0000000000000000000000000e+00
 	 2.8968097264316372552173107e-01 0.0000000000000000000000000e+00
 	 1.9687339726507713244529896e-01 0.0000000000000000000000000e+00
 	 1.1824015502409240818693092e-01 0.0000000000000000000000000e+00
 	 5.7458977888511841847218875e-02 0.0000000000000000000000000e+00
 	 1.7377036748080720851561409e-02 0.0000000000000000000000000e+00
 	 0.0000000000000000000000000e+00 0.0000000000000000000000000e+00
 	 0.0000000000000000000000000e+00 1.0000000000000000000000000e+00
 	 0.0000000000000000000000000e+00 9.8262296325191922363728736e-01
 	 0.0000000000000000000000000e+00 9.4254102211148815815278112e-01
 	 0.0000000000000000000000000e+00 8.8175984497590764732422031e-01
 	 0.0000000000000000000000000e+00 8.0312660273492286755470104e-01
 	 0.0000000000000000000000000e+00 7.1031902735683627447826893e-01
 	 0.0000000000000000000000000e+00 6.0767697768189710139097315e-01
 	 0.0000000000000000000000000e+00 5.0000000000000000000000000e-01
 	 0.0000000000000000000000000e+00 3.9232302231810289860902685e-01
 	 0.0000000000000000000000000e+00 2.8968097264316372552173107e-01
 	 0.0000000000000000000000000e+00 1.9687339726507713244529896e-01
 	 0.0000000000000000000000000e+00 1.1824015502409240818693092e-01
 	 0.0000000000000000000000000e+00 5.7458977888511841847218875e-02
 	 0.0000000000000000000000000e+00 1.7377036748080720851561409e-02
 	 1.7377036748080720851561409e-02 9.8262296325191922363728736e-01
 	 5.7458977888511841847218875e-02 9.4254102211148815815278112e-01
 	 1.1824015502409240818693092e-01 8.8175984497590764732422031e-01
 	 1.9687339726507713244529896e-01 8.0312660273492286755470104e-01
 	 2.8968097264316372552173107e-01 7.1031902735683627447826893e-01
 	 3.9232302231810289860902685e-01 6.0767697768189710139097315e-01
 	 5.0000000000000000000000000e-01 5.0000000000000000000000000e-01
 	 6.0767697768189710139097315e-01 3.9232302231810289860902685e-01
 	 7.1031902735683627447826893e-01 2.8968097264316372552173107e-01
 	 8.0312660273492286755470104e-01 1.9687339726507713244529896e-01
 	 8.8175984497590764732422031e-01 1.1824015502409240818693092e-01
 	 9.4254102211148815815278112e-01 5.7458977888511841847218875e-02
 	 9.8262296325191922363728736e-01 1.7377036748080720851561409e-02
 	 ]; 
 

 	 % ----------------- DEGREE 15 --------------------
 
 	 case  15 

 	 % LEBESGUE CONST.               : 8.91347e+00
 	 % ABS.DET.VAND.MATRIX           : 9.40546e+182
 	 % CONDITIONING                  : 3.66112e+02
 	 % CARDINALITY                   :    136
 	 % POINTS OUTSIDE DOMAIN         :      0
 
 	 pts=[
 	 3.3333333333333331482961626e-01 3.3333333333333331482961626e-01
 	 2.2598875088653245374326062e-02 2.2598875088653245374326062e-02
 	 6.3377525298164080758134276e-02 6.3377525298164080758134276e-02
 	 1.2999961081360736359080477e-01 1.2999961081360736359080477e-01
 	 2.2598875088653245374326062e-02 9.5480224982269346067909055e-01
 	 6.3377525298164080758134276e-02 8.7324494940367181072815583e-01
 	 1.2999961081360736359080477e-01 7.4000077837278521730723924e-01
 	 9.5480224982269346067909055e-01 2.2598875088653245374326062e-02
 	 8.7324494940367181072815583e-01 6.3377525298164080758134276e-02
 	 7.4000077837278521730723924e-01 1.2999961081360736359080477e-01
 	 4.7681846240213421328490995e-01 4.7681846240213421328490995e-01
 	 4.1352424223746864218043129e-01 4.1352424223746864218043129e-01
 	 4.4750113426597187826772029e-01 4.4750113426597187826772029e-01
 	 4.7681846240213421328490995e-01 4.6363075195731573430180106e-02
 	 4.1352424223746864218043129e-01 1.7295151552506271563913742e-01
 	 4.4750113426597187826772029e-01 1.0499773146805624346455943e-01
 	 4.6363075195731573430180106e-02 4.7681846240213421328490995e-01
 	 1.7295151552506271563913742e-01 4.1352424223746864218043129e-01
 	 1.0499773146805624346455943e-01 4.4750113426597187826772029e-01
 	 1.9843813150281341961544967e-01 6.6606916227937063013087027e-01
 	 2.7065925923136757713649558e-01 6.4880561717659845921701844e-01
 	 2.9280738393188215917817274e-01 6.8315975921649918500833110e-01
 	 2.6285662173580054412624918e-01 5.3927556777259644249511439e-01
 	 3.2579094977746797523465716e-01 5.4793847747286550387002535e-01
 	 4.2144555288954915761578945e-01 5.6271751826191629408668859e-01
 	 3.5837336387544804772176121e-01 5.8802029704790781394763144e-01
 	 1.9379725040746456632412276e-01 7.4974615739929484359294065e-01
 	 1.1993829492966248673191387e-01 8.2866459682844462175665967e-01
 	 8.4980119536665454926804841e-02 8.9708902231731557641580821e-01
 	 3.2586045052288248324856568e-01 4.4351858121692228076327069e-01
 	 1.7960479140384336127489462e-01 8.0401987653903683739287089e-01
 	 1.9843813150281341961544967e-01 1.3549270621781595025368006e-01
 	 2.7065925923136757713649558e-01 8.0535123592033963646485972e-02
 	 2.9280738393188215917817274e-01 2.4032856851618711324647393e-02
 	 2.6285662173580054412624918e-01 1.9786781049160295786748520e-01
 	 3.2579094977746797523465716e-01 1.2627057274966646538416626e-01
 	 4.2144555288954915761578945e-01 1.5836928848534603808673182e-02
 	 3.5837336387544804772176121e-01 5.3606339076644138330607348e-02
 	 1.9379725040746456632412276e-01 5.6456592193240617838512208e-02
 	 1.1993829492966248673191387e-01 5.1397108241892919267002071e-02
 	 8.4980119536665454926804841e-02 1.7930858146018913146235718e-02
 	 3.2586045052288248324856568e-01 2.3062096826019523598816363e-01
 	 1.7960479140384336127489462e-01 1.6375332057119829087810103e-02
 	 6.6606916227937063013087027e-01 1.9843813150281341961544967e-01
 	 6.4880561717659845921701844e-01 2.7065925923136757713649558e-01
 	 6.8315975921649918500833110e-01 2.9280738393188215917817274e-01
 	 5.3927556777259644249511439e-01 2.6285662173580054412624918e-01
 	 5.4793847747286550387002535e-01 3.2579094977746797523465716e-01
 	 5.6271751826191629408668859e-01 4.2144555288954915761578945e-01
 	 5.8802029704790781394763144e-01 3.5837336387544804772176121e-01
 	 7.4974615739929484359294065e-01 1.9379725040746456632412276e-01
 	 8.2866459682844462175665967e-01 1.1993829492966248673191387e-01
 	 8.9708902231731557641580821e-01 8.4980119536665454926804841e-02
 	 4.4351858121692228076327069e-01 3.2586045052288248324856568e-01
 	 8.0401987653903683739287089e-01 1.7960479140384336127489462e-01
 	 6.6606916227937063013087027e-01 1.3549270621781595025368006e-01
 	 6.4880561717659845921701844e-01 8.0535123592033963646485972e-02
 	 6.8315975921649918500833110e-01 2.4032856851618711324647393e-02
 	 5.3927556777259644249511439e-01 1.9786781049160295786748520e-01
 	 5.4793847747286550387002535e-01 1.2627057274966646538416626e-01
 	 5.6271751826191629408668859e-01 1.5836928848534603808673182e-02
 	 5.8802029704790781394763144e-01 5.3606339076644138330607348e-02
 	 7.4974615739929484359294065e-01 5.6456592193240617838512208e-02
 	 8.2866459682844462175665967e-01 5.1397108241892919267002071e-02
 	 8.9708902231731557641580821e-01 1.7930858146018913146235718e-02
 	 4.4351858121692228076327069e-01 2.3062096826019523598816363e-01
 	 8.0401987653903683739287089e-01 1.6375332057119829087810103e-02
 	 1.3549270621781595025368006e-01 1.9843813150281341961544967e-01
 	 8.0535123592033963646485972e-02 2.7065925923136757713649558e-01
 	 2.4032856851618711324647393e-02 2.9280738393188215917817274e-01
 	 1.9786781049160295786748520e-01 2.6285662173580054412624918e-01
 	 1.2627057274966646538416626e-01 3.2579094977746797523465716e-01
 	 1.5836928848534603808673182e-02 4.2144555288954915761578945e-01
 	 5.3606339076644138330607348e-02 3.5837336387544804772176121e-01
 	 5.6456592193240617838512208e-02 1.9379725040746456632412276e-01
 	 5.1397108241892919267002071e-02 1.1993829492966248673191387e-01
 	 1.7930858146018913146235718e-02 8.4980119536665454926804841e-02
 	 2.3062096826019523598816363e-01 3.2586045052288248324856568e-01
 	 1.6375332057119829087810103e-02 1.7960479140384336127489462e-01
 	 1.3549270621781595025368006e-01 6.6606916227937063013087027e-01
 	 8.0535123592033963646485972e-02 6.4880561717659845921701844e-01
 	 2.4032856851618711324647393e-02 6.8315975921649918500833110e-01
 	 1.9786781049160295786748520e-01 5.3927556777259644249511439e-01
 	 1.2627057274966646538416626e-01 5.4793847747286550387002535e-01
 	 1.5836928848534603808673182e-02 5.6271751826191629408668859e-01
 	 5.3606339076644138330607348e-02 5.8802029704790781394763144e-01
 	 5.6456592193240617838512208e-02 7.4974615739929484359294065e-01
 	 5.1397108241892919267002071e-02 8.2866459682844462175665967e-01
 	 1.7930858146018913146235718e-02 8.9708902231731557641580821e-01
 	 2.3062096826019523598816363e-01 4.4351858121692228076327069e-01
 	 1.6375332057119829087810103e-02 8.0401987653903683739287089e-01
 	 1.0000000000000000000000000e+00 0.0000000000000000000000000e+00
 	 0.0000000000000000000000000e+00 1.0000000000000000000000000e+00
 	 0.0000000000000000000000000e+00 0.0000000000000000000000000e+00
 	 1.5215976864891178621519430e-02 9.8478402313510882137848057e-01
 	 5.0399733453263984017667099e-02 9.4960026654673601598233290e-01
 	 1.0399585406909234164274380e-01 8.9600414593090760284610496e-01
 	 1.7380564855875341168101045e-01 8.2619435144124664383014078e-01
 	 2.5697028905643126694968714e-01 7.4302971094356873305031286e-01
 	 3.5008476554961842630575575e-01 6.4991523445038157369424425e-01
 	 4.4933686323902521930762077e-01 5.5066313676097478069237923e-01
 	 5.5066313676097455864777430e-01 4.4933686323902544135222570e-01
 	 6.4991523445038157369424425e-01 3.5008476554961842630575575e-01
 	 7.4302971094356884407261532e-01 2.5697028905643115592738468e-01
 	 8.2619435144124664383014078e-01 1.7380564855875335616985922e-01
 	 8.9600414593090760284610496e-01 1.0399585406909239715389504e-01
 	 9.4960026654673601598233290e-01 5.0399733453263984017667099e-02
 	 9.8478402313510904342308550e-01 1.5215976864890956576914505e-02
 	 1.5215976864891178621519430e-02 0.0000000000000000000000000e+00
 	 5.0399733453263984017667099e-02 0.0000000000000000000000000e+00
 	 1.0399585406909234164274380e-01 0.0000000000000000000000000e+00
 	 1.7380564855875341168101045e-01 0.0000000000000000000000000e+00
 	 2.5697028905643126694968714e-01 0.0000000000000000000000000e+00
 	 3.5008476554961842630575575e-01 0.0000000000000000000000000e+00
 	 4.4933686323902521930762077e-01 0.0000000000000000000000000e+00
 	 5.5066313676097455864777430e-01 0.0000000000000000000000000e+00
 	 6.4991523445038157369424425e-01 0.0000000000000000000000000e+00
 	 7.4302971094356884407261532e-01 0.0000000000000000000000000e+00
 	 8.2619435144124664383014078e-01 0.0000000000000000000000000e+00
 	 8.9600414593090760284610496e-01 0.0000000000000000000000000e+00
 	 9.4960026654673601598233290e-01 0.0000000000000000000000000e+00
 	 9.8478402313510904342308550e-01 0.0000000000000000000000000e+00
 	 0.0000000000000000000000000e+00 1.5215976864891178621519430e-02
 	 0.0000000000000000000000000e+00 5.0399733453263984017667099e-02
 	 0.0000000000000000000000000e+00 1.0399585406909234164274380e-01
 	 0.0000000000000000000000000e+00 1.7380564855875341168101045e-01
 	 0.0000000000000000000000000e+00 2.5697028905643126694968714e-01
 	 0.0000000000000000000000000e+00 3.5008476554961842630575575e-01
 	 0.0000000000000000000000000e+00 4.4933686323902521930762077e-01
 	 0.0000000000000000000000000e+00 5.5066313676097455864777430e-01
 	 0.0000000000000000000000000e+00 6.4991523445038157369424425e-01
 	 0.0000000000000000000000000e+00 7.4302971094356884407261532e-01
 	 0.0000000000000000000000000e+00 8.2619435144124664383014078e-01
 	 0.0000000000000000000000000e+00 8.9600414593090760284610496e-01
 	 0.0000000000000000000000000e+00 9.4960026654673601598233290e-01
 	 0.0000000000000000000000000e+00 9.8478402313510904342308550e-01
 	 ]; 
 

 	 % ----------------- DEGREE 16 --------------------
 
 	 case  16 

 	 % LEBESGUE CONST.               : 8.59051e+00
 	 % ABS.DET.VAND.MATRIX           : 2.70064e+209
 	 % CONDITIONING                  : 3.80206e+02
 	 % CARDINALITY                   :    153
 	 % POINTS OUTSIDE DOMAIN         :      0
 
 	 pts=[
 	 2.5515331892265313840084673e-01 1.5591927414369158300111451e-01
 	 5.8892740693365530635361438e-01 2.5515331892265313840084673e-01
 	 1.5591927414369158300111451e-01 5.8892740693365530635361438e-01
 	 8.6403386919974600743898918e-01 1.8228653000364899994245604e-02
 	 1.1773747779988909256676521e-01 8.6403386919974600743898918e-01
 	 1.8228653000364899994245604e-02 1.1773747779988909256676521e-01
 	 3.1886869347913843197872552e-01 2.8363437830191418065339803e-01
 	 3.9749692821894733185672521e-01 3.1886869347913843197872552e-01
 	 2.8363437830191418065339803e-01 3.9749692821894733185672521e-01
 	 1.8393603889431450748581653e-01 1.3090750663905176276458064e-01
 	 6.8515645446663375750517844e-01 1.8393603889431450748581653e-01
 	 1.3090750663905176276458064e-01 6.8515645446663375750517844e-01
 	 1.0634675919178909753171069e-01 1.0406283232907509450626549e-01
 	 7.8959040847913586347317505e-01 1.0634675919178909753171069e-01
 	 1.0406283232907509450626549e-01 7.8959040847913586347317505e-01
 	 6.4915858575902221638820322e-02 2.9455293558382722451938207e-02
 	 9.0562884786571506978702928e-01 6.4915858575902221638820322e-02
 	 2.9455293558382722451938207e-02 9.0562884786571506978702928e-01
 	 1.0645992700380052520259255e-01 1.5730625686895073622739716e-02
 	 8.7780944730930443586913725e-01 1.0645992700380052520259255e-01
 	 1.5730625686895073622739716e-02 8.7780944730930443586913725e-01
 	 6.1518016423017496396852266e-01 1.5642373011992249942636590e-01
 	 2.2839610564990253660511144e-01 6.1518016423017496396852266e-01
 	 1.5642373011992249942636590e-01 2.2839610564990253660511144e-01
 	 3.4092600755102270282392851e-01 4.7099332022150837417928670e-02
 	 6.1197466042682635567473426e-01 3.4092600755102270282392851e-01
 	 4.7099332022150837417928670e-02 6.1197466042682635567473426e-01
 	 2.0255140048153236209671491e-01 2.1284521218177015339234615e-02
 	 7.7616407830029066072796695e-01 2.0255140048153236209671491e-01
 	 2.1284521218177015339234615e-02 7.7616407830029066072796695e-01
 	 4.0344188383906653960764288e-01 2.3836966169360085388007064e-01
 	 3.5818845446733260651228647e-01 4.0344188383906653960764288e-01
 	 2.3836966169360085388007064e-01 3.5818845446733260651228647e-01
 	 4.3627935051797706034193425e-01 1.5079703273560238555028867e-02
 	 5.4864094620846270977665426e-01 4.3627935051797706034193425e-01
 	 1.5079703273560238555028867e-02 5.4864094620846270977665426e-01
 	 8.5129665947546140358781486e-01 5.5844021498011736648336978e-02
 	 9.2859319026526859763848165e-02 8.5129665947546140358781486e-01
 	 5.5844021498011736648336978e-02 9.2859319026526859763848165e-02
 	 2.5097510400894773585633857e-01 2.3778457269911967841835576e-01
 	 5.1124032329193258572530567e-01 2.5097510400894773585633857e-01
 	 2.3778457269911967841835576e-01 5.1124032329193258572530567e-01
 	 6.1956525237229098657110171e-01 9.4671973515152635370029088e-02
 	 2.8576277411255635030329358e-01 6.1956525237229098657110171e-01
 	 9.4671973515152635370029088e-02 2.8576277411255635030329358e-01
 	 3.4481644015751750087517280e-01 1.7674087222546266962019956e-01
 	 4.7844268761701980174905202e-01 3.4481644015751750087517280e-01
 	 1.7674087222546266962019956e-01 4.7844268761701980174905202e-01
 	 3.6927348756674033269931101e-01 1.0953736833793063787378941e-01
 	 5.2118914409532912657141424e-01 3.6927348756674033269931101e-01
 	 1.0953736833793063787378941e-01 5.2118914409532912657141424e-01
 	 5.1265200691670032018265601e-01 8.8668603776415000350397122e-02
 	 3.9867938930688467946694686e-01 5.1265200691670032018265601e-01
 	 8.8668603776415000350397122e-02 3.9867938930688467946694686e-01
 	 1.8214435570638423667055861e-01 6.0887003661334690440831707e-02
 	 7.5696864063228108676639749e-01 1.8214435570638423667055861e-01
 	 6.0887003661334690440831707e-02 7.5696864063228108676639749e-01
 	 7.1114693883535240459536908e-01 1.0630610443578662749342101e-01
 	 1.8254695672886095403342210e-01 7.1114693883535240459536908e-01
 	 1.0630610443578662749342101e-01 1.8254695672886095403342210e-01
 	 4.4666959090079005889606378e-01 5.4943681745501467272863039e-02
 	 4.9838672735370848076996708e-01 4.4666959090079005889606378e-01
 	 5.4943681745501467272863039e-02 4.9838672735370848076996708e-01
 	 9.2591337936627438054415506e-01 2.1577478461966264483562483e-02
 	 5.2509142171759351502835500e-02 9.2591337936627438054415506e-01
 	 2.1577478461966264483562483e-02 5.2509142171759351502835500e-02
 	 2.5990799867759534214073369e-01 1.0137629001168226017259855e-01
 	 6.3871571131072235605330434e-01 2.5990799867759534214073369e-01
 	 1.0137629001168226017259855e-01 6.3871571131072235605330434e-01
 	 5.0056284757716251743175917e-01 1.6905310354945313200403234e-01
 	 3.3038404887338435056420849e-01 5.0056284757716251743175917e-01
 	 1.6905310354945313200403234e-01 3.3038404887338435056420849e-01
 	 2.7492981906957647542100176e-02 1.5705147069652057589816962e-02
 	 9.5680187102339031568476457e-01 2.7492981906957647542100176e-02
 	 1.5705147069652057589816962e-02 9.5680187102339031568476457e-01
 	 7.8791709294041245570383580e-01 4.8981566103405788092928219e-02
 	 1.6310134095618175620323598e-01 7.8791709294041245570383580e-01
 	 4.8981566103405788092928219e-02 1.6310134095618175620323598e-01
 	 3.1066022793966152626410349e-01 1.6556870427365616427195505e-02
 	 6.7278290163297282955312539e-01 3.1066022793966152626410349e-01
 	 1.6556870427365616427195505e-02 6.7278290163297282955312539e-01
 	 7.1011117829207237583943879e-01 5.2791675781055591443191588e-02
 	 2.3709714592687203271736962e-01 7.1011117829207237583943879e-01
 	 5.2791675781055591443191588e-02 2.3709714592687203271736962e-01
 	 4.2220960028294618471278454e-01 1.3486798115263390340778926e-01
 	 4.4292241856441993963500181e-01 4.2220960028294618471278454e-01
 	 1.3486798115263390340778926e-01 4.4292241856441993963500181e-01
 	 1.1340354354198708963785691e-01 4.1947936622481772628301400e-02
 	 8.4464851983553113079494779e-01 1.1340354354198708963785691e-01
 	 4.1947936622481772628301400e-02 8.4464851983553113079494779e-01
 	 7.7021335570576110463036912e-01 1.4626677409636272206294727e-02
 	 2.1515996688460262142861268e-01 7.7021335570576110463036912e-01
 	 1.4626677409636272206294727e-02 2.1515996688460262142861268e-01
 	 6.5346977505869741076338642e-01 2.1509366318981926191611365e-02
 	 3.2502085862232066304500222e-01 6.5346977505869741076338642e-01
 	 2.1509366318981926191611365e-02 3.2502085862232066304500222e-01
 	 5.5134971587723180519446942e-01 2.4761021692896387214055665e-02
 	 4.2388926242987179371368711e-01 5.5134971587723180519446942e-01
 	 2.4761021692896387214055665e-02 4.2388926242987179371368711e-01
 	 2.5618667888885587879954642e-01 5.0829194625929330353386604e-02
 	 6.9298412648521479084706698e-01 2.5618667888885587879954642e-01
 	 5.0829194625929330353386604e-02 6.9298412648521479084706698e-01
 	 5.7864532101011234566101393e-01 5.2296112893211996186515478e-02
 	 3.6905856609667564427468278e-01 5.7864532101011234566101393e-01
 	 5.2296112893211996186515478e-02 3.6905856609667564427468278e-01
 	 1.0000000000000000000000000e+00 0.0000000000000000000000000e+00
 	 9.8656608831570924422749158e-01 0.0000000000000000000000000e+00
 	 9.5543999795778677963653536e-01 0.0000000000000000000000000e+00
 	 9.0784812561088512605778078e-01 0.0000000000000000000000000e+00
 	 8.4551449031384229293450971e-01 0.0000000000000000000000000e+00
 	 7.7069269966505071778328784e-01 0.0000000000000000000000000e+00
 	 6.8608721678273854038820900e-01 0.0000000000000000000000000e+00
 	 5.9475598675915875013231471e-01 0.0000000000000000000000000e+00
 	 5.0000000000000000000000000e-01 0.0000000000000000000000000e+00
 	 4.0524401324084130537883652e-01 0.0000000000000000000000000e+00
 	 3.1391278321726145961179100e-01 0.0000000000000000000000000e+00
 	 2.2930730033494922670556093e-01 0.0000000000000000000000000e+00
 	 1.5448550968615765155433905e-01 0.0000000000000000000000000e+00
 	 9.2151874389114873942219219e-02 0.0000000000000000000000000e+00
 	 4.4560002042213220363464643e-02 0.0000000000000000000000000e+00
 	 1.3433911684290811283659650e-02 0.0000000000000000000000000e+00
 	 0.0000000000000000000000000e+00 0.0000000000000000000000000e+00
 	 0.0000000000000000000000000e+00 1.0000000000000000000000000e+00
 	 0.0000000000000000000000000e+00 9.8656608831570924422749158e-01
 	 0.0000000000000000000000000e+00 9.5543999795778677963653536e-01
 	 0.0000000000000000000000000e+00 9.0784812561088512605778078e-01
 	 0.0000000000000000000000000e+00 8.4551449031384229293450971e-01
 	 0.0000000000000000000000000e+00 7.7069269966505071778328784e-01
 	 0.0000000000000000000000000e+00 6.8608721678273854038820900e-01
 	 0.0000000000000000000000000e+00 5.9475598675915875013231471e-01
 	 0.0000000000000000000000000e+00 5.0000000000000000000000000e-01
 	 0.0000000000000000000000000e+00 4.0524401324084130537883652e-01
 	 0.0000000000000000000000000e+00 3.1391278321726145961179100e-01
 	 0.0000000000000000000000000e+00 2.2930730033494922670556093e-01
 	 0.0000000000000000000000000e+00 1.5448550968615765155433905e-01
 	 0.0000000000000000000000000e+00 9.2151874389114873942219219e-02
 	 0.0000000000000000000000000e+00 4.4560002042213220363464643e-02
 	 0.0000000000000000000000000e+00 1.3433911684290811283659650e-02
 	 1.3433911684290811283659650e-02 9.8656608831570924422749158e-01
 	 4.4560002042213220363464643e-02 9.5543999795778677963653536e-01
 	 9.2151874389114873942219219e-02 9.0784812561088512605778078e-01
 	 1.5448550968615765155433905e-01 8.4551449031384229293450971e-01
 	 2.2930730033494922670556093e-01 7.7069269966505071778328784e-01
 	 3.1391278321726145961179100e-01 6.8608721678273854038820900e-01
 	 4.0524401324084130537883652e-01 5.9475598675915875013231471e-01
 	 5.0000000000000000000000000e-01 5.0000000000000000000000000e-01
 	 5.9475598675915875013231471e-01 4.0524401324084130537883652e-01
 	 6.8608721678273854038820900e-01 3.1391278321726145961179100e-01
 	 7.7069269966505071778328784e-01 2.2930730033494922670556093e-01
 	 8.4551449031384229293450971e-01 1.5448550968615765155433905e-01
 	 9.0784812561088512605778078e-01 9.2151874389114873942219219e-02
 	 9.5543999795778677963653536e-01 4.4560002042213220363464643e-02
 	 9.8656608831570924422749158e-01 1.3433911684290811283659650e-02
 	 ]; 
 

 	 % ----------------- DEGREE 17 --------------------
 
 	 case  17 

 	 % LEBESGUE CONST.               : 9.12237e+00
 	 % ABS.DET.VAND.MATRIX           : 7.85856e+237
 	 % CONDITIONING                  : 4.33620e+02
 	 % CARDINALITY                   :    171
 	 % POINTS OUTSIDE DOMAIN         :      0
 
 	 pts=[
 	 7.1683136220809728911262937e-01 1.4183697899418746396493773e-02
 	 2.6898493989248395408253600e-01 7.1683136220809728911262937e-01
 	 1.4183697899418746396493773e-02 2.6898493989248395408253600e-01
 	 7.8771739787696515300297051e-01 5.6493564651380966112892423e-02
 	 1.5578903747165387394524316e-01 7.8771739787696515300297051e-01
 	 5.6493564651380966112892423e-02 1.5578903747165387394524316e-01
 	 3.4619714737722045994061659e-01 2.7228587894146638603842803e-01
 	 3.8151697368131309850980415e-01 3.4619714737722045994061659e-01
 	 2.7228587894146638603842803e-01 3.8151697368131309850980415e-01
 	 1.0512577105666533194838763e-01 9.7524154616770497572275644e-02
 	 7.9735007432656423986827576e-01 1.0512577105666533194838763e-01
 	 9.7524154616770497572275644e-02 7.9735007432656423986827576e-01
 	 5.6904316653812692106129134e-01 1.2027038844952203655580547e-01
 	 3.1068644501235104238290319e-01 5.6904316653812692106129134e-01
 	 1.2027038844952203655580547e-01 3.1068644501235104238290319e-01
 	 6.8299086001599851325494228e-01 8.3268346527433576009791238e-02
 	 2.3374079345656789685747867e-01 6.8299086001599851325494228e-01
 	 8.3268346527433576009791238e-02 2.3374079345656789685747867e-01
 	 3.0283136648192138240531790e-01 1.5837797929540872732268042e-01
 	 5.3879065422266991802757730e-01 3.0283136648192138240531790e-01
 	 1.5837797929540872732268042e-01 5.3879065422266991802757730e-01
 	 2.6989551913114212533528757e-01 2.2532151487422846791730535e-01
 	 5.0478296599462946225855831e-01 2.6989551913114212533528757e-01
 	 2.2532151487422846791730535e-01 5.0478296599462946225855831e-01
 	 7.2412697107428003473472700e-01 1.2195866201846243537243453e-01
 	 1.5391436690725751601505067e-01 7.2412697107428003473472700e-01
 	 1.2195866201846243537243453e-01 1.5391436690725751601505067e-01
 	 4.5276579239502165452613269e-02 1.8154239706691291389439868e-02
 	 9.3656918105380659866909809e-01 4.5276579239502165452613269e-02
 	 1.8154239706691291389439868e-02 9.3656918105380659866909809e-01
 	 1.4379881215919843029382719e-01 4.4391914827031218881980834e-02
 	 8.1180927301377037164087369e-01 1.4379881215919843029382719e-01
 	 4.4391914827031218881980834e-02 8.1180927301377037164087369e-01
 	 4.9590878706952951082698178e-01 1.9982229955817804034623464e-02
 	 4.8410898297465265738281914e-01 4.9590878706952951082698178e-01
 	 1.9982229955817804034623464e-02 4.8410898297465265738281914e-01
 	 4.5023871976102836089950188e-01 5.5262109917621558830003181e-02
 	 4.9449917032135010108717665e-01 4.5023871976102836089950188e-01
 	 5.5262109917621558830003181e-02 4.9449917032135010108717665e-01
 	 5.4928665819820066129608449e-01 1.9735304306319778611111815e-01
 	 2.5336029873860155259279736e-01 5.4928665819820066129608449e-01
 	 1.9735304306319778611111815e-01 2.5336029873860155259279736e-01
 	 5.6841606731765359494801260e-01 3.8901302310999121003565193e-02
 	 3.9268263037134726323174050e-01 5.6841606731765359494801260e-01
 	 3.8901302310999121003565193e-02 3.9268263037134726323174050e-01
 	 4.6071019599056906024259206e-01 2.3450565007787188553933788e-01
 	 3.0478415393155905421807006e-01 4.6071019599056906024259206e-01
 	 2.3450565007787188553933788e-01 3.0478415393155905421807006e-01
 	 9.6187740751332395650052831e-01 1.2139996084219296587636272e-02
 	 2.5982596402456745177111941e-02 9.6187740751332395650052831e-01
 	 1.2139996084219296587636272e-02 2.5982596402456745177111941e-02
 	 8.0517274273296390862952876e-01 2.0693557388547143688350971e-02
 	 1.7413369987848895115156722e-01 8.0517274273296390862952876e-01
 	 2.0693557388547143688350971e-02 1.7413369987848895115156722e-01
 	 3.7791655655563644033989590e-01 1.9774955376374930837712895e-01
 	 4.2433388968061430679412638e-01 3.7791655655563644033989590e-01
 	 1.9774955376374930837712895e-01 4.2433388968061430679412638e-01
 	 1.9681701329921219567609114e-01 1.4745224595270223222343020e-02
 	 7.8843776210551763661271707e-01 1.9681701329921219567609114e-01
 	 1.4745224595270223222343020e-02 7.8843776210551763661271707e-01
 	 8.5803931509557049284175889e-02 5.2990384764524500749161007e-02
 	 8.6120568372591854711117776e-01 8.5803931509557049284175889e-02
 	 5.2990384764524500749161007e-02 8.6120568372591854711117776e-01
 	 2.2558333734735291908890531e-01 4.5607566814774284924549619e-02
 	 7.2880909583787278904765117e-01 2.2558333734735291908890531e-01
 	 4.5607566814774284924549619e-02 7.2880909583787278904765117e-01
 	 7.1710756467630842880822684e-01 4.1455160335278136429781881e-02
 	 2.4143727498841344170088519e-01 7.1710756467630842880822684e-01
 	 4.1455160335278136429781881e-02 2.4143727498841344170088519e-01
 	 9.1743773315339094409637255e-01 2.7264029097145134339363892e-02
 	 5.5298237749463921564263558e-02 9.1743773315339094409637255e-01
 	 2.7264029097145134339363892e-02 5.5298237749463921564263558e-02
 	 6.3380449344161871039204925e-01 1.4600349097315251656326041e-01
 	 2.2019201558522877304469034e-01 6.3380449344161871039204925e-01
 	 1.4600349097315251656326041e-01 2.2019201558522877304469034e-01
 	 2.5911472386313016968983902e-01 9.0238509921614543096701766e-02
 	 6.5064676621525530109124702e-01 2.5911472386313016968983902e-01
 	 9.0238509921614543096701766e-02 6.5064676621525530109124702e-01
 	 6.3725020045307201321804769e-01 5.2779811166596635185754849e-02
 	 3.0996998838033135159619746e-01 6.3725020045307201321804769e-01
 	 5.2779811166596635185754849e-02 3.0996998838033135159619746e-01
 	 2.1522374480863756818216359e-01 1.6240986781221589119184046e-01
 	 6.2236638737914651287042034e-01 2.1522374480863756818216359e-01
 	 1.6240986781221589119184046e-01 6.2236638737914651287042034e-01
 	 3.5887613440457094560187556e-01 8.9779522660667840372461512e-02
 	 5.5134434293476120014787512e-01 3.5887613440457094560187556e-01
 	 8.9779522660667840372461512e-02 5.5134434293476120014787512e-01
 	 4.7950530924884221528614603e-01 1.4112411684572320758057629e-01
 	 3.7937057390543460488885330e-01 4.7950530924884221528614603e-01
 	 1.4112411684572320758057629e-01 3.7937057390543460488885330e-01
 	 3.9143034732965098498880252e-01 2.1835818743607245118187876e-02
 	 5.8673383392674172132075228e-01 3.9143034732965098498880252e-01
 	 2.1835818743607245118187876e-02 5.8673383392674172132075228e-01
 	 3.3932150802276972445525871e-01 4.9780874460494728417359056e-02
 	 6.1089761751673554712738223e-01 3.3932150802276972445525871e-01
 	 4.9780874460494728417359056e-02 6.1089761751673554712738223e-01
 	 5.2731130330054576393905563e-01 8.1084692517589887494899870e-02
 	 3.9160400418186436244383231e-01 5.2731130330054576393905563e-01
 	 8.1084692517589887494899870e-02 3.9160400418186436244383231e-01
 	 2.9950385603663909339644533e-01 1.6722191167590785831897904e-02
 	 6.8377395279577013464944457e-01 2.9950385603663909339644533e-01
 	 1.6722191167590785831897904e-02 6.8377395279577013464944457e-01
 	 8.9028402121870242602597045e-01 1.4703876037150434910594221e-02
 	 9.5012102744147133859264898e-02 8.9028402121870242602597045e-01
 	 1.4703876037150434910594221e-02 9.5012102744147133859264898e-02
 	 1.0993821079547889951744111e-01 1.4083897839562289217019142e-02
 	 8.7597789136495873840715376e-01 1.0993821079547889951744111e-01
 	 1.4083897839562289217019142e-02 8.7597789136495873840715376e-01
 	 1.7383399202414168138730588e-01 1.0098980444934264888434683e-01
 	 7.2517620352651568360613510e-01 1.7383399202414168138730588e-01
 	 1.0098980444934264888434683e-01 7.2517620352651568360613510e-01
 	 4.1272044351923065086396036e-01 1.1598232415962334007630830e-01
 	 4.7129723232114600905973134e-01 4.1272044351923065086396036e-01
 	 1.1598232415962334007630830e-01 4.7129723232114600905973134e-01
 	 8.5677779639565510017007455e-01 4.2807772603824942314609814e-02
 	 1.0041443100051995751531564e-01 8.5677779639565510017007455e-01
 	 4.2807772603824942314609814e-02 1.0041443100051995751531564e-01
 	 6.1316811613748112286259584e-01 1.4943465995199056370323909e-02
 	 3.7188841786731979821567506e-01 6.1316811613748112286259584e-01
 	 1.4943465995199056370323909e-02 3.7188841786731979821567506e-01
 	 1.0000000000000000000000000e+00 0.0000000000000000000000000e+00
 	 9.8805277870609931056833375e-01 0.0000000000000000000000000e+00
 	 9.6032459267376690803530437e-01 0.0000000000000000000000000e+00
 	 9.1779676760904504995153275e-01 0.0000000000000000000000000e+00
 	 8.6183966464162131693171887e-01 0.0000000000000000000000000e+00
 	 7.9425241715933081465550458e-01 0.0000000000000000000000000e+00
 	 7.1720751845606200980398626e-01 0.0000000000000000000000000e+00
 	 6.3318132643914049051403481e-01 0.0000000000000000000000000e+00
 	 5.4487454674232604912020861e-01 0.0000000000000000000000000e+00
 	 4.5512545325767395087979139e-01 0.0000000000000000000000000e+00
 	 3.6681867356085950948596519e-01 0.0000000000000000000000000e+00
 	 2.8279248154393799019601374e-01 0.0000000000000000000000000e+00
 	 2.0574758284066912983334419e-01 0.0000000000000000000000000e+00
 	 1.3816033535837868306828113e-01 0.0000000000000000000000000e+00
 	 8.2203232390954894537316022e-02 0.0000000000000000000000000e+00
 	 3.9675407326233036453544401e-02 0.0000000000000000000000000e+00
 	 1.1947221293900744942817482e-02 0.0000000000000000000000000e+00
 	 0.0000000000000000000000000e+00 0.0000000000000000000000000e+00
 	 0.0000000000000000000000000e+00 1.0000000000000000000000000e+00
 	 0.0000000000000000000000000e+00 9.8805277870609931056833375e-01
 	 0.0000000000000000000000000e+00 9.6032459267376690803530437e-01
 	 0.0000000000000000000000000e+00 9.1779676760904504995153275e-01
 	 0.0000000000000000000000000e+00 8.6183966464162131693171887e-01
 	 0.0000000000000000000000000e+00 7.9425241715933081465550458e-01
 	 0.0000000000000000000000000e+00 7.1720751845606200980398626e-01
 	 0.0000000000000000000000000e+00 6.3318132643914049051403481e-01
 	 0.0000000000000000000000000e+00 5.4487454674232604912020861e-01
 	 0.0000000000000000000000000e+00 4.5512545325767395087979139e-01
 	 0.0000000000000000000000000e+00 3.6681867356085950948596519e-01
 	 0.0000000000000000000000000e+00 2.8279248154393799019601374e-01
 	 0.0000000000000000000000000e+00 2.0574758284066912983334419e-01
 	 0.0000000000000000000000000e+00 1.3816033535837868306828113e-01
 	 0.0000000000000000000000000e+00 8.2203232390954894537316022e-02
 	 0.0000000000000000000000000e+00 3.9675407326233036453544401e-02
 	 0.0000000000000000000000000e+00 1.1947221293900744942817482e-02
 	 1.1947221293900744942817482e-02 9.8805277870609931056833375e-01
 	 3.9675407326233036453544401e-02 9.6032459267376690803530437e-01
 	 8.2203232390954894537316022e-02 9.1779676760904504995153275e-01
 	 1.3816033535837868306828113e-01 8.6183966464162131693171887e-01
 	 2.0574758284066912983334419e-01 7.9425241715933081465550458e-01
 	 2.8279248154393799019601374e-01 7.1720751845606200980398626e-01
 	 3.6681867356085950948596519e-01 6.3318132643914049051403481e-01
 	 4.5512545325767395087979139e-01 5.4487454674232604912020861e-01
 	 5.4487454674232604912020861e-01 4.5512545325767395087979139e-01
 	 6.3318132643914049051403481e-01 3.6681867356085950948596519e-01
 	 7.1720751845606200980398626e-01 2.8279248154393799019601374e-01
 	 7.9425241715933081465550458e-01 2.0574758284066912983334419e-01
 	 8.6183966464162131693171887e-01 1.3816033535837868306828113e-01
 	 9.1779676760904504995153275e-01 8.2203232390954894537316022e-02
 	 9.6032459267376690803530437e-01 3.9675407326233036453544401e-02
 	 9.8805277870609931056833375e-01 1.1947221293900744942817482e-02
 	 ]; 
 

 	 % ----------------- DEGREE 18 --------------------
 
 	 case  18 

 	 % LEBESGUE CONST.               : 9.88509e+00
 	 % ABS.DET.VAND.MATRIX           : 1.43972e+268
 	 % CONDITIONING                  : 5.07510e+02
 	 % CARDINALITY                   :    190
 	 % POINTS OUTSIDE DOMAIN         :      0
 
 	 pts=[
 	 7.1038982376255532802389325e-01 1.2109581483091533260498807e-02
 	 2.7750059475435312483782013e-01 7.1038982376255532802389325e-01
 	 1.2109581483091533260498807e-02 2.7750059475435312483782013e-01
 	 1.4893155105524155668028641e-01 3.9766367624870853358931555e-02
 	 8.1130208131988756914410033e-01 1.4893155105524155668028641e-01
 	 3.9766367624870853358931555e-02 8.1130208131988756914410033e-01
 	 7.6103300646853133670788338e-01 3.2775122591127532623023200e-02
 	 2.0619187094034113760798732e-01 7.6103300646853133670788338e-01
 	 3.2775122591127532623023200e-02 2.0619187094034113760798732e-01
 	 4.1056760590618934791962147e-01 3.6245000386424322535994236e-02
 	 5.5318739370738634342217210e-01 4.1056760590618934791962147e-01
 	 3.6245000386424322535994236e-02 5.5318739370738634342217210e-01
 	 6.7073064284931038780968038e-01 3.7022520301589319224877528e-02
 	 2.9224683684910029990433600e-01 6.7073064284931038780968038e-01
 	 3.7022520301589319224877528e-02 2.9224683684910029990433600e-01
 	 8.2592229343640155558858851e-01 3.0220603567774562137060457e-02
 	 1.4385710299582388227435104e-01 8.2592229343640155558858851e-01
 	 3.0220603567774562137060457e-02 1.4385710299582388227435104e-01
 	 3.9555041178380373478873366e-01 1.1931570562534324353443083e-01
 	 4.8513388259085299392125989e-01 3.9555041178380373478873366e-01
 	 1.1931570562534324353443083e-01 4.8513388259085299392125989e-01
 	 8.1416794542000014978100353e-01 1.0822988276362494053373098e-02
 	 1.7500906630363735616562337e-01 8.1416794542000014978100353e-01
 	 1.0822988276362494053373098e-02 1.7500906630363735616562337e-01
 	 2.6522931351791112497551239e-01 1.3638627417978055333946941e-01
 	 5.9838441230230832168501820e-01 2.6522931351791112497551239e-01
 	 1.3638627417978055333946941e-01 5.9838441230230832168501820e-01
 	 5.1456457985907304297779064e-02 1.9608355709183608595047588e-02
 	 9.2893518630490912180164287e-01 5.1456457985907304297779064e-02
 	 1.9608355709183608595047588e-02 9.2893518630490912180164287e-01
 	 6.0067086215312481822792279e-01 1.5631548502179220400121196e-02
 	 3.8369758934469594402472126e-01 6.0067086215312481822792279e-01
 	 1.5631548502179220400121196e-02 3.8369758934469594402472126e-01
 	 2.6620013756642180169365020e-01 2.1821879478743855251821060e-01
 	 5.1558106764613964578813921e-01 2.6620013756642180169365020e-01
 	 2.1821879478743855251821060e-01 5.1558106764613964578813921e-01
 	 5.0398767986704340327008822e-01 1.9396710855527177219670421e-01
 	 3.0204521157768482453320757e-01 5.0398767986704340327008822e-01
 	 1.9396710855527177219670421e-01 3.0204521157768482453320757e-01
 	 7.3998096895470488743029591e-01 8.5053135267822113640967530e-02
 	 1.7496589577747301280652437e-01 7.3998096895470488743029591e-01
 	 8.5053135267822113640967530e-02 1.7496589577747301280652437e-01
 	 5.4350285675381049266263744e-01 1.2781833651469109991438700e-01
 	 3.2867880673149840742297556e-01 5.4350285675381049266263744e-01
 	 1.2781833651469109991438700e-01 3.2867880673149840742297556e-01
 	 8.1930192956532713055572970e-02 5.3145241526043919544353145e-02
 	 8.6492456551742336046117998e-01 8.1930192956532713055572970e-02
 	 5.3145241526043919544353145e-02 8.6492456551742336046117998e-01
 	 1.4589210907509408965410103e-01 7.6009883656017990238851212e-02
 	 7.7809800726888789235147215e-01 1.4589210907509408965410103e-01
 	 7.6009883656017990238851212e-02 7.7809800726888789235147215e-01
 	 1.9980794074180641128890557e-01 9.9559759241343748215058440e-02
 	 7.0063230001684984049603599e-01 1.9980794074180641128890557e-01
 	 9.9559759241343748215058440e-02 7.0063230001684984049603599e-01
 	 3.7880737677766102011744920e-01 1.3790450701181079448676137e-02
 	 6.0740217252115791257693900e-01 3.7880737677766102011744920e-01
 	 1.3790450701181079448676137e-02 6.0740217252115791257693900e-01
 	 4.2799284807036724886941670e-01 1.8133108613095175187801544e-01
 	 3.9067606579868108251929470e-01 4.2799284807036724886941670e-01
 	 1.8133108613095175187801544e-01 3.9067606579868108251929470e-01
 	 5.2477479692275397216150168e-01 3.6086177100524904903799950e-02
 	 4.3913902597672110905691056e-01 5.2477479692275397216150168e-01
 	 3.6086177100524904903799950e-02 4.3913902597672110905691056e-01
 	 4.2885951199870764316557370e-01 2.4665729200266003906527601e-01
 	 3.2448319599863229001357467e-01 4.2885951199870764316557370e-01
 	 2.4665729200266003906527601e-01 3.2448319599863229001357467e-01
 	 2.0101251899050642801825006e-01 1.7600773169411015883767391e-01
 	 6.2297974931538346865522726e-01 2.0101251899050642801825006e-01
 	 1.7600773169411015883767391e-01 6.2297974931538346865522726e-01
 	 2.7412306196502284061367050e-01 7.5661412103677147533709046e-02
 	 6.5021552593130005348598388e-01 2.7412306196502284061367050e-01
 	 7.5661412103677147533709046e-02 6.5021552593130005348598388e-01
 	 2.0709617988313031716751667e-02 1.0647339544325042093309008e-02
 	 9.6864304246736188108712895e-01 2.0709617988313031716751667e-02
 	 1.0647339544325042093309008e-02 9.6864304246736188108712895e-01
 	 4.9529109813865263012289120e-01 1.0129153976517932256307120e-01
 	 4.0341736209616796404731076e-01 4.9529109813865263012289120e-01
 	 1.0129153976517932256307120e-01 4.0341736209616796404731076e-01
 	 3.3769470319797956214813439e-01 1.6322317028282673501138333e-01
 	 4.9908212651919370284048227e-01 3.3769470319797956214813439e-01
 	 1.6322317028282673501138333e-01 4.9908212651919370284048227e-01
 	 6.5759824611908923586156561e-01 1.2092806349013841826778304e-01
 	 2.2147369039077235974843916e-01 6.5759824611908923586156561e-01
 	 1.2092806349013841826778304e-01 2.2147369039077235974843916e-01
 	 2.6734041196440633259001629e-01 1.3746637938650088997527554e-02
 	 7.1891295009694367035280038e-01 2.6734041196440633259001629e-01
 	 1.3746637938650088997527554e-02 7.1891295009694367035280038e-01
 	 4.9335316525936800946539051e-01 1.1335134962157987145725535e-02
 	 4.9531169977847400165416047e-01 4.9335316525936800946539051e-01
 	 1.1335134962157987145725535e-02 4.9531169977847400165416047e-01
 	 9.3741312121193309803146576e-01 2.0457832672630082287978937e-02
 	 4.2129046115436816211108351e-02 9.3741312121193309803146576e-01
 	 2.0457832672630082287978937e-02 4.2129046115436816211108351e-02
 	 9.5592292806083306588860182e-02 1.2843976050588273157826436e-02
 	 8.9156373114332843066165424e-01 9.5592292806083306588860182e-02
 	 1.2843976050588273157826436e-02 8.9156373114332843066165424e-01
 	 8.9919441294213442450455887e-01 1.3556933505220544397551485e-02
 	 8.7248653552645036302060078e-02 8.9919441294213442450455887e-01
 	 1.3556933505220544397551485e-02 8.7248653552645036302060078e-02
 	 1.7670786259161005982143422e-01 1.5977248774526310592936085e-02
 	 8.0731488863386358101337237e-01 1.7670786259161005982143422e-01
 	 1.5977248774526310592936085e-02 8.0731488863386358101337237e-01
 	 4.4056682953284115322745151e-01 7.3086237804823331321024682e-02
 	 4.8634693266233558484046284e-01 4.4056682953284115322745151e-01
 	 7.3086237804823331321024682e-02 4.8634693266233558484046284e-01
 	 8.2978592994847744090947117e-01 7.4205289008458449884209074e-02
 	 9.6008781043064109206319756e-02 8.2978592994847744090947117e-01
 	 7.4205289008458449884209074e-02 9.6008781043064109206319756e-02
 	 6.5837903678940146168230285e-01 7.3603536311690143101316153e-02
 	 2.6801742689890839521638100e-01 6.5837903678940146168230285e-01
 	 7.3603536311690143101316153e-02 2.6801742689890839521638100e-01
 	 3.1705863417413504556918724e-01 3.6583245566699368334084852e-02
 	 6.4635812025916561385230352e-01 3.1705863417413504556918724e-01
 	 3.6583245566699368334084852e-02 6.4635812025916561385230352e-01
 	 5.8071906287123287171425545e-01 1.7325514647294307235547706e-01
 	 2.4602579065582405593026749e-01 5.8071906287123287171425545e-01
 	 1.7325514647294307235547706e-01 2.4602579065582405593026749e-01
 	 5.8686000048975528464723084e-01 5.9864044835404695010794285e-02
 	 3.5327595467484002034197488e-01 5.8686000048975528464723084e-01
 	 5.9864044835404695010794285e-02 3.5327595467484002034197488e-01
 	 8.8747539463515101587631762e-01 4.5508837861934804680519306e-02
 	 6.7015767502914186382056982e-02 8.8747539463515101587631762e-01
 	 4.5508837861934804680519306e-02 6.7015767502914186382056982e-02
 	 3.4514648042267931371540612e-01 8.5017974333284618282391421e-02
 	 5.6983554524403601249105122e-01 3.4514648042267931371540612e-01
 	 8.5017974333284618282391421e-02 5.6983554524403601249105122e-01
 	 3.1854409565954938665655050e-01 2.5352454362284659872273096e-01
 	 4.2793136071760407013186978e-01 3.1854409565954938665655050e-01
 	 2.5352454362284659872273096e-01 4.2793136071760407013186978e-01
 	 7.3029425779457490808255216e-01 1.3475633020021907104712966e-01
 	 1.3494941200520602087031818e-01 7.3029425779457490808255216e-01
 	 1.3475633020021907104712966e-01 1.3494941200520602087031818e-01
 	 2.1422107853641420005530449e-01 4.5291351092758384833114604e-02
 	 7.4048757037082735266153577e-01 2.1422107853641420005530449e-01
 	 4.5291351092758384833114604e-02 7.4048757037082735266153577e-01
 	 1.0000000000000000000000000e+00 0.0000000000000000000000000e+00
 	 9.8930588311103995202699934e-01 0.0000000000000000000000000e+00
 	 9.6445076407629315440317441e-01 0.0000000000000000000000000e+00
 	 9.2623028889832303978124628e-01 0.0000000000000000000000000e+00
 	 8.7574710127630650546848301e-01 0.0000000000000000000000000e+00
 	 8.1445406863261027297085093e-01 0.0000000000000000000000000e+00
 	 7.4411464284035677696493849e-01 0.0000000000000000000000000e+00
 	 6.6675242391224931459703384e-01 0.0000000000000000000000000e+00
 	 5.8459301170464073038601782e-01 0.0000000000000000000000000e+00
 	 5.0000000000000000000000000e-01 0.0000000000000000000000000e+00
 	 4.1540698829535921410283095e-01 0.0000000000000000000000000e+00
 	 3.3324757608775068540296616e-01 0.0000000000000000000000000e+00
 	 2.5588535715964322303506151e-01 0.0000000000000000000000000e+00
 	 1.8554593136738972702914907e-01 0.0000000000000000000000000e+00
 	 1.2425289872369349453151699e-01 0.0000000000000000000000000e+00
 	 7.3769711101676960218753720e-02 0.0000000000000000000000000e+00
 	 3.5549235923706845596825588e-02 0.0000000000000000000000000e+00
 	 1.0694116888959992461849424e-02 0.0000000000000000000000000e+00
 	 0.0000000000000000000000000e+00 0.0000000000000000000000000e+00
 	 0.0000000000000000000000000e+00 1.0000000000000000000000000e+00
 	 0.0000000000000000000000000e+00 9.8930588311103995202699934e-01
 	 0.0000000000000000000000000e+00 9.6445076407629315440317441e-01
 	 0.0000000000000000000000000e+00 9.2623028889832303978124628e-01
 	 0.0000000000000000000000000e+00 8.7574710127630650546848301e-01
 	 0.0000000000000000000000000e+00 8.1445406863261027297085093e-01
 	 0.0000000000000000000000000e+00 7.4411464284035677696493849e-01
 	 0.0000000000000000000000000e+00 6.6675242391224931459703384e-01
 	 0.0000000000000000000000000e+00 5.8459301170464073038601782e-01
 	 0.0000000000000000000000000e+00 5.0000000000000000000000000e-01
 	 0.0000000000000000000000000e+00 4.1540698829535921410283095e-01
 	 0.0000000000000000000000000e+00 3.3324757608775068540296616e-01
 	 0.0000000000000000000000000e+00 2.5588535715964322303506151e-01
 	 0.0000000000000000000000000e+00 1.8554593136738972702914907e-01
 	 0.0000000000000000000000000e+00 1.2425289872369349453151699e-01
 	 0.0000000000000000000000000e+00 7.3769711101676960218753720e-02
 	 0.0000000000000000000000000e+00 3.5549235923706845596825588e-02
 	 0.0000000000000000000000000e+00 1.0694116888959992461849424e-02
 	 1.0694116888959992461849424e-02 9.8930588311103995202699934e-01
 	 3.5549235923706845596825588e-02 9.6445076407629315440317441e-01
 	 7.3769711101676960218753720e-02 9.2623028889832303978124628e-01
 	 1.2425289872369349453151699e-01 8.7574710127630650546848301e-01
 	 1.8554593136738972702914907e-01 8.1445406863261027297085093e-01
 	 2.5588535715964322303506151e-01 7.4411464284035677696493849e-01
 	 3.3324757608775068540296616e-01 6.6675242391224931459703384e-01
 	 4.1540698829535921410283095e-01 5.8459301170464073038601782e-01
 	 5.0000000000000000000000000e-01 5.0000000000000000000000000e-01
 	 5.8459301170464073038601782e-01 4.1540698829535921410283095e-01
 	 6.6675242391224931459703384e-01 3.3324757608775068540296616e-01
 	 7.4411464284035677696493849e-01 2.5588535715964322303506151e-01
 	 8.1445406863261027297085093e-01 1.8554593136738972702914907e-01
 	 8.7574710127630650546848301e-01 1.2425289872369349453151699e-01
 	 9.2623028889832303978124628e-01 7.3769711101676960218753720e-02
 	 9.6445076407629315440317441e-01 3.5549235923706845596825588e-02
 	 9.8930588311103995202699934e-01 1.0694116888959992461849424e-02
 	 3.3333333333333331482961626e-01 3.3333333333333331482961626e-01
 	 ]; 
 

 	 
 
 


 
        
    otherwise
        
        pts=[];
        pts_bar=[];
        stats_matrix=[];
        
        
end

if isempty(pts) == 0
    
    % BARYCENTRIC COORDINATES.
    xx=pts(:,1); yy=pts(:,2);
    pts_bar=[1-xx-yy xx yy];
    
    % STATS
    % |DEGR|  CARD | LEBESGUE   | ABS.DET.VAND.| COND. VAND. | PTS OUT
 	 stats_matrix=[
 	   1      3 1.00000e+00  5.87878e+01 3.70699e+00   0
 	   2      6 1.48853e+00  2.42798e+04 1.06220e+01   0
 	   3     10 1.97517e+00  2.01059e+08 1.98710e+01   0
 	   4     15 2.42354e+00  4.31505e+13 1.73433e+01   0
 	   5     21 2.90426e+00  2.80572e+20 4.54886e+01   0
 	   6     28 3.40132e+00  4.12857e+28 6.06455e+01   0
 	   7     36 4.13949e+00  1.88501e+39 9.14441e+01   0
 	   8     45 5.21483e+00  8.03675e+50 1.16434e+02   0
 	   9     55 5.49590e+00  1.43106e+64 1.47749e+02   0
 	  10     66 5.93588e+00  4.57515e+79 1.64229e+02   0
 	  11     78 6.66424e+00  4.43645e+96 1.82180e+02   0
 	  12     91 6.98481e+00  2.71864e+115 2.20876e+02   0
 	  13    105 7.74381e+00  5.70766e+135 2.90055e+02   0
 	  14    120 8.30571e+00  9.94900e+157 3.45193e+02   0
 	  15    136 8.91347e+00  9.40546e+182 3.66112e+02   0
 	  16    153 8.59051e+00  2.70064e+209 3.80206e+02   0
 	  17    171 9.12237e+00  7.85856e+237 4.33620e+02   0
 	  18    190 9.88509e+00  1.43972e+268 5.07510e+02   0
 	 ];
    
end
