
function pts=pts_waldron(deg)

%--------------------------------------------------------------------------
% POINTS
%--------------------------------------------------------------------------
% Waldron points of degree "deg" on the unit-simplex with vertices (0,0),
% (1,0),(0,1).
%--------------------------------------------------------------------------
% INPUT
%--------------------------------------------------------------------------
% deg: degree of the pointset,
%--------------------------------------------------------------------------
% OUTPUT
%--------------------------------------------------------------------------
% pts: Waldron points on the simplex with vertices (0,0),(1,0),(0,1).
%--------------------------------------------------------------------------
% AUTHORS
%--------------------------------------------------------------------------
% Authors: Dimitri J. Kenne, Alvise Sommariva and Marco Vianello.
% Written: October 2023
% Modified: November 22, 2023.
%
% Acknowledgements: 
% The authors thank Leokadia Białas-Cież for her precious help.
%--------------------------------------------------------------------------
% LICENSE
%--------------------------------------------------------------------------
% Copyright(C) 2023 Dimitri Jordan Kenne, Alvise Sommariva, Marco Vianello.
%
% This program is free software; you can redistribute it and/or modify
% it under the terms of the GNU General Public License as published by
% the Free Software Foundation; either version 3 of the License, or
% (at your option) any later version.
%
% This program is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% GNU General Public License for more details.
%
% You should have received a copy of the GNU General Public License
% along with this program; if not, write to the Free Software
% Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
%
% Authors:
%
% D.J. Kenne <dimitri.kenne@doctoral.uj.edu.pl>
% Alvise Sommariva <alvise@math.unipd.it>
% Marco Vianello   <marcov@math.unipd.it>
%
% Date: November 22, 2023
%--------------------------------------------------------------------------



[A1 A2 A3]=meshgrid(0:deg);
alphaV=[A1(:) A2(:) A3(:)];
alphaV_abs=sum(alphaV,2);
iok=find(alphaV_abs == deg);
coeffs0=alphaV(iok,:)/deg;
w=@(x) (1-cos(pi*x))/2;
coeffs=feval(w,coeffs0);

correction=(1-sum(coeffs,2))/3;
coeffs=coeffs+[correction correction correction];
vertM=[0 0; 1 0; 0 1];
pts=coeffs*vertM;
