
function [pts,stats_matrix]=set_disk_cg(deg)

%--------------------------------------------------------------------------
% OBJECT:
% Carnicer-Godes points on the unit disk, for degrees deg=1,...,50
%
% See:
% J.M. Carnicer and C. Godes,
% "Interpolation on the disk",
% Numer. Algo., 66 (2014), pp. 1-16.
%--------------------------------------------------------------------------
% INPUT:
% deg: DEGREE OF THE INTERPOLATORY SET.
%--------------------------------------------------------------------------
% OUTPUT:
%  pts: MATRIX N x 2 WHOSE COMPONENTS ARE THE CARTESIAN COORDINATES OF
%       EACH POINT IN THE POINTSET.
%
%  stats_matrix: MATRIX WITH STATISTICS WITH COLUMNS THAT CONSIST OF
%       DEGREE, CARDINALITY, LEBESGUE CONSTANT, ABS. VALUE OF VANDERMONDE
%       MATRIX "V" DETERMINANT, CONDITIONING OF "V", POINTS OUT OF THE
%       DOMAIN.
%--------------------------------------------------------------------------
% Copyright (C) 2018
% Gerard Meurant, Alvise Sommariva.
%
% This program is free software; you can redistribute it and/or modify
% it under the terms of the GNU General Public License as published by
% the Free Software Foundation; either version 2 of the License, or
% (at your option) any later version.
%
% This program is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% GNU General Public License for more details.
%
% You should have received a copy of the GNU General Public License
% along with this program; if not, write to the Free Software
% Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
%
% Authors:
% * Gerard Meurant    <gerard.meurant@gmail.com>
% * Alvise Sommariva  <alvise@math.unipd.it>
%
% Date: February 10, 2018.
%--------------------------------------------------------------------------
% STATISTICS.
%--------------------------------------------------------------------------
% |DEGR|  Card |  Leb. Const. |    Abs.Det.   |  Cond.Vand. | Out |
%--------------------------------------------------------------------------
%   1  |     3 | 1.666667e+00 | 1.866324e+00  | 3.15470e+00 |   0 |
%   2  |     6 | 1.988854e+00 | 3.747290e+01  | 7.65685e+00 |   0 |
%   3  |    10 | 2.624243e+00 | 4.825122e+03  | 1.72057e+01 |   0 |
%   4  |    15 | 3.234295e+00 | 6.733137e+06  | 2.45034e+01 |   0 |
%   5  |    21 | 3.720900e+00 | 9.153200e+10  | 3.17993e+01 |   0 |
%   6  |    28 | 4.323847e+00 | 1.620891e+16  | 5.00588e+01 |   0 |
%   7  |    36 | 4.983226e+00 | 3.217450e+22  | 5.89269e+01 |   0 |
%   8  |    45 | 5.554802e+00 | 1.262142e+30  | 8.05944e+01 |   0 |
%   9  |    55 | 6.182261e+00 | 7.598155e+38  | 9.14804e+01 |   0 |
%  10  |    66 | 6.749062e+00 | 1.360546e+49  | 1.11260e+02 |   0 |
%  11  |    78 | 7.405524e+00 | 2.108225e+60  | 1.35391e+02 |   0 |
%  12  |    91 | 8.162840e+00 | 1.195508e+73  | 1.45078e+02 |   0 |
%  13  |   105 | 8.991463e+00 | 1.465915e+87  | 1.83330e+02 |   0 |
%  14  |   120 | 1.004867e+01 | 4.277556e+102  | 2.12398e+02 |   0 |
%  15  |   136 | 1.121936e+01 | 2.962789e+119  | 2.38705e+02 |   0 |
%  16  |   153 | 1.249401e+01 | 5.963697e+137  | 2.37760e+02 |   0 |
%  17  |   171 | 1.421432e+01 | 2.753255e+157  | 2.97516e+02 |   0 |
%  18  |   190 | 1.599920e+01 | 4.265156e+178  | 3.21053e+02 |   0 |
%  19  |   210 | 1.815374e+01 | 1.708011e+201  | 2.88924e+02 |   0 |
%  20  |   231 | 2.081821e+01 | 2.014247e+225  | 5.21700e+02 |   0 |
%  21  |   253 | 2.387934e+01 | 7.502870e+250  | 4.53959e+02 |   0 |
%  22  |   276 | 2.730824e+01 | 1.001076e+278  | 5.90091e+02 |   0 |
%  23  |   300 | 3.185851e+01 | 3.226770e+306  | 6.23600e+02 |   0 |
%  24  |   325 | 3.690146e+01 | Inf            | 8.78540e+02 |   0 |
%  25  |   351 | 4.283253e+01 | Inf            | 9.03984e+02 |   0 |
%  26  |   378 | 5.019800e+01 | Inf            | 1.28209e+03 |   0 |
%  27  |   406 | 5.901037e+01 | Inf            | 1.35813e+03 |   0 |
%  28  |   435 | 6.911262e+01 | Inf            | 2.13004e+03 |   0 |
%  29  |   465 | 8.156621e+01 | Inf            | 2.41223e+03 |   0 |
%  30  |   496 | 9.696407e+01 | Inf            | 2.40515e+03 |   0 |
%  31  |   528 | 1.141081e+02 | Inf            | 4.34404e+03 |   0 |
%  32  |   561 | 1.349488e+02 | Inf            | 4.52780e+03 |   0 |
%  33  |   595 | 1.615081e+02 | Inf            | 6.55369e+03 |   0 |
%  34  |   630 | 1.914702e+02 | Inf            | 5.39328e+03 |   0 |
%  35  |   666 | 2.274826e+02 | Inf            | 9.60598e+03 |   0 |
%  36  |   703 | 2.726611e+02 | Inf            | 1.05343e+04 |   0 |
%  37  |   741 | 3.282607e+02 | Inf            | 9.91628e+03 |   0 |
%  38  |   780 | 3.925808e+02 | Inf            | 8.83661e+03 |   0 |
%  39  |   820 | 4.681878e+02 | Inf            | 1.08768e+04 |   0 |
%  40  |   861 | 5.585461e+02 | Inf            | 2.35881e+04 |   0 |
%  41  |   903 | 6.790970e+02 | Inf            | 2.84811e+04 |   0 |
%  42  |   946 | 8.178868e+02 | Inf            | 2.72116e+04 |   0 |
%  43  |   990 | 9.811301e+02 | Inf            | 5.07726e+04 |   0 |
%  44  |  1035 | 1.172621e+03 | Inf            | 4.13907e+04 |   0 |
%  45  |  1081 | 1.401024e+03 | Inf            | 7.52671e+04 |   0 |
%  46  |  1128 | 1.682256e+03 | Inf            | 4.56739e+04 |   0 |
%  47  |  1176 | 2.043017e+03 | Inf            | 1.13121e+05 |   0 |
%  48  |  1225 | 2.478395e+03 | Inf            | 6.66960e+04 |   0 |
%  49  |  1275 | 3.009753e+03 | Inf            | 1.45684e+05 |   0 |
%  50  |  1326 | 3.661137e+03 | Inf            | 1.02176e+05 |   0 |
%--------------------------------------------------------------------------
% CAPTION.
%--------------------------------------------------------------------------
% Card.      : cardinality of the point set
% Leb. Const.: Lebesgue Constant (evaluated on a WAM of degree  500.
% Abs.Det.   : Absolute value of the determinant of the Vandermonde matrix
%           (on the point set).
% Cond.Vand. : Conditioning of the Vandermonde matrix
%           (on the point set). We used Koornwinder IIb polynomial basis.
% Out        : Points outside the domain.
%
% The polynomial basis is the orthonormal Koornwinder type II.
% The cardinality of the WAM is 250501.
%--------------------------------------------------------------------------


switch deg
    case    1
        
        % DEGREE.             :           1
        % CARDIN.             :           3
        % LEBESGUE CONST.     : 1.66667e+00
        % ABS.DET.VAND.MATRIX : 1.86632e+00
        % CONDITIONING VAND.  : 3.15470e+00
        % POINTS OUT DISK     : 0.00000e+00
        
        pts=[
            5.00000000000000111022302462515654e-01 8.66025403784438596588302061718423e-01
            -1.00000000000000000000000000000000e+00 1.22464679914735320717376402945840e-16
            5.00000000000000111022302462515654e-01 -8.66025403784438596588302061718423e-01
            ];
        
    case    2
        
        % DEGREE.             :           2
        % CARDIN.             :           6
        % LEBESGUE CONST.     : 1.98885e+00
        % ABS.DET.VAND.MATRIX : 3.74729e+01
        % CONDITIONING VAND.  : 7.65685e+00
        % POINTS OUT DISK     : 0.00000e+00
        
        pts=[
            8.09016994374947451262869435595348e-01 5.87785252292473137103456792829093e-01
            -3.09016994374947340240566973079694e-01 9.51056516295153642204240895807743e-01
            -1.00000000000000000000000000000000e+00 1.22464679914735320717376402945840e-16
            -3.09016994374947562285171898111003e-01 -9.51056516295153531181938433292089e-01
            8.09016994374947118195962048048386e-01 -5.87785252292473248125759255344747e-01
            -0.00000000000000000000000000000000e+00 0.00000000000000000000000000000000e+00
            ];
        
    case    3
        
        % DEGREE.             :           3
        % CARDIN.             :          10
        % LEBESGUE CONST.     : 2.62424e+00
        % ABS.DET.VAND.MATRIX : 4.82512e+03
        % CONDITIONING VAND.  : 1.72057e+01
        % POINTS OUT DISK     : 0.00000e+00
        
        pts=[
            9.00968867902419145998749172576936e-01 4.33883739117558120401696442058892e-01
            2.22520933956314448387558968533995e-01 9.74927912181823619341969333618181e-01
            -6.23489801858733483364005678595277e-01 7.81831482468029914656426626606844e-01
            -1.00000000000000000000000000000000e+00 1.22464679914735320717376402945840e-16
            -6.23489801858733705408610603626585e-01 -7.81831482468029692611821701575536e-01
            2.22520933956313338164534343377454e-01 -9.74927912181823841386574258649489e-01
            9.00968867902419368043354097608244e-01 -4.33883739117557509779032898222795e-01
            2.36232968921762265246400147589156e-01 4.09167504595331688044268503290368e-01
            -4.72465937843524419470497832662659e-01 5.78603898486224573470662773972696e-17
            2.36232968921762265246400147589156e-01 -4.09167504595331688044268503290368e-01
            ];
        
    case    4
        
        % DEGREE.             :           4
        % CARDIN.             :          15
        % LEBESGUE CONST.     : 3.23430e+00
        % ABS.DET.VAND.MATRIX : 6.73314e+06
        % CONDITIONING VAND.  : 2.45034e+01
        % POINTS OUT DISK     : 0.00000e+00
        
        pts=[
            9.39692620785908427905042117345147e-01 3.42020143325668712908083080037613e-01
            5.00000000000000111022302462515654e-01 8.66025403784438596588302061718423e-01
            -1.73648177666930303431058746355120e-01 9.84807753012208020315654266596539e-01
            -7.66044443118977902429378445958719e-01 6.42787609686539473941024880332407e-01
            -1.00000000000000000000000000000000e+00 1.22464679914735320717376402945840e-16
            -7.66044443118978346518588296021335e-01 -6.42787609686538918829512567754136e-01
            -1.73648177666930331186634361984034e-01 -9.84807753012208020315654266596539e-01
            4.99999999999999333866185224906076e-01 -8.66025403784439040677511911781039e-01
            9.39692620785908427905042117345147e-01 -3.42020143325668601885780617521959e-01
            5.54991998190062396645316766807809e-01 4.03225289387754592951296217506751e-01
            -2.11988079824383640614726687090297e-01 6.52432223352899298696172536438098e-01
            -6.86007836731357345527726465661544e-01 8.40117301443056893874878245617061e-17
            -2.11988079824383807148180380863778e-01 -6.52432223352899187673870073922444e-01
            5.54991998190062285623014304292155e-01 -4.03225289387754759484749911280232e-01
            -0.00000000000000000000000000000000e+00 0.00000000000000000000000000000000e+00
            ];
        
    case    5
        
        % DEGREE.             :           5
        % CARDIN.             :          21
        % LEBESGUE CONST.     : 3.72090e+00
        % ABS.DET.VAND.MATRIX : 9.15320e+10
        % CONDITIONING VAND.  : 3.17993e+01
        % POINTS OUT DISK     : 0.00000e+00
        
        pts=[
            9.59492973614497368650688713387353e-01 2.81732556841429671035115234190016e-01
            6.54860733945285100610078643512679e-01 7.55749574354258268904516171460273e-01
            1.42314838273285115821664703616989e-01 9.89821441880932684220795181317953e-01
            -4.15415013001886324062184030481149e-01 9.09631995354518441132540829130448e-01
            -8.41253532831181094486794336262392e-01 5.40640817455597777474451959278667e-01
            -1.00000000000000000000000000000000e+00 5.66553889764797961538732358338787e-16
            -8.41253532831181205509096798778046e-01 -5.40640817455597555429847034247359e-01
            -4.15415013001887156729452499348554e-01 -9.09631995354517997043330979067832e-01
            1.42314838273284866021484162956767e-01 -9.89821441880932795243097643833607e-01
            6.54860733945284545498566330934409e-01 -7.55749574354258712993726021522889e-01
            9.59492973614497368650688713387353e-01 -2.81732556841429782057417696705670e-01
            6.84949786076307520765737990586786e-01 3.29854432131996111454697029330418e-01
            1.69168626731490301384752683588886e-01 7.41176181196402716899740426015342e-01
            -4.73999958953245648096697095752461e-01 5.94377148581119785220039375417400e-01
            -7.60236907709104237085284694330767e-01 9.31021695619636244307607029598624e-17
            -4.73999958953245814630150789525942e-01 -5.94377148581119674197736912901746e-01
            1.69168626731489468717484214721480e-01 -7.41176181196402938944345351046650e-01
            6.84949786076307742810342915618094e-01 -3.29854432131995611854335948009975e-01
            1.46874654572324486734302695367660e-01 2.54394364063394440300669430143898e-01
            -2.93749309144648917957454159477493e-01 3.59739151195740627447077367650221e-17
            1.46874654572324486734302695367660e-01 -2.54394364063394440300669430143898e-01
            ];
        
    case    6
        
        % DEGREE.             :           6
        % CARDIN.             :          28
        % LEBESGUE CONST.     : 4.32385e+00
        % ABS.DET.VAND.MATRIX : 1.62089e+16
        % CONDITIONING VAND.  : 5.00588e+01
        % POINTS OUT DISK     : 0.00000e+00
        
        pts=[
            9.70941817426052011796855367720127e-01 2.39315664287557738898470915955841e-01
            7.48510748171101081283040912239812e-01 6.63122658240795193052008471568115e-01
            3.54604887042535565910839068237692e-01 9.35016242685414833424317748722387e-01
            -1.20536680255322881105684018621105e-01 9.92708874098053972723221249907510e-01
            -5.68064746731155700842919031856582e-01 8.22983865893656463263994282897329e-01
            -8.85456025653209577441771216399502e-01 4.64723172043769061634321815290605e-01
            -1.00000000000000000000000000000000e+00 -3.21624529935327320103979552447107e-16
            -8.85456025653210132553283528977772e-01 -4.64723172043768062433599652649718e-01
            -5.68064746731155922887523956887890e-01 -8.22983865893656352241691820381675e-01
            -1.20536680255323547239498793715029e-01 -9.92708874098053750678616324876202e-01
            3.54604887042535565910839068237692e-01 -9.35016242685414833424317748722387e-01
            7.48510748171100748216133524692850e-01 -6.63122658240795526118915859115077e-01
            9.70941817426052011796855367720127e-01 -2.39315664287557794409622147213668e-01
            7.44579006746622806822699658368947e-01 2.71004595515264512517461525931139e-01
            3.96182214415974176535684136979398e-01 6.86207724423613885100792231241940e-01
            -1.37592639114765880048452117989655e-01 7.80326632724792412787451212352607e-01
            -6.06986367631856649218491384090157e-01 5.09322037209528066803443380194949e-01
            -7.92364428831948131026763348927489e-01 9.70366561527266026955864847932019e-17
            -6.06986367631857093307701234152773e-01 -5.09322037209527622714233530132333e-01
            -1.37592639114765907804027733618568e-01 -7.80326632724792412787451212352607e-01
            3.96182214415973510401869361885474e-01 -6.86207724423614329190002081304556e-01
            7.44579006746622806822699658368947e-01 -2.71004595515264457006310294673312e-01
            3.56125634147834546627819918285240e-01 2.58740418521279991193040359576116e-01
            -1.36027887979362549497608370074886e-01 4.18650791430803859149989420984639e-01
            -4.40195492336943883238120633905055e-01 5.39084000689531565749410659900300e-17
            -1.36027887979362660519910832590540e-01 -4.18650791430803803638838189726812e-01
            3.56125634147834491116668687027413e-01 -2.58740418521280102215342822091770e-01
            -0.00000000000000000000000000000000e+00 0.00000000000000000000000000000000e+00
            ];
        
    case    7
        
        % DEGREE.             :           7
        % CARDIN.             :          36
        % LEBESGUE CONST.     : 4.98323e+00
        % ABS.DET.VAND.MATRIX : 3.21745e+22
        % CONDITIONING VAND.  : 5.89269e+01
        % POINTS OUT DISK     : 0.00000e+00
        
        pts=[
            9.78147600733805466788339799677487e-01 2.07911690817759259308772357144335e-01
            8.09016994374947451262869435595348e-01 5.87785252292473137103456792829093e-01
            5.00000000000000111022302462515654e-01 8.66025403784438596588302061718423e-01
            1.04528463267653456969519254471379e-01 9.94521895368273289861349439888727e-01
            -3.09016994374947340240566973079694e-01 9.51056516295153642204240895807743e-01
            -6.69130606358857904503167901566485e-01 7.43144825477394466162195385550149e-01
            -9.13545457642600977621327729139011e-01 4.06736643075800041735590184543980e-01
            -1.00000000000000000000000000000000e+00 5.66553889764797961538732358338787e-16
            -9.13545457642600866599025266623357e-01 -4.06736643075800208269043878317461e-01
            -6.69130606358858459614680214144755e-01 -7.43144825477394022072985535487533e-01
            -3.09016994374947562285171898111003e-01 -9.51056516295153531181938433292089e-01
            1.04528463267652985124733788779849e-01 -9.94521895368273400883651902404381e-01
            5.00000000000000111022302462515654e-01 -8.66025403784438596588302061718423e-01
            8.09016994374947118195962048048386e-01 -5.87785252292473248125759255344747e-01
            9.78147600733805688832944724708796e-01 -2.07911690817758981753016200855200e-01
            7.93159769780071521871889217436546e-01 2.32892721540324698636936773255002e-01
            5.41337147074031466154053759964881e-01 6.24736371073258078823187133821193e-01
            1.17643805077491822586033265451988e-01 8.18230636966695512590774796990445e-01
            -3.43400613799745679788344432381564e-01 7.51942456964622585324775627668714e-01
            -6.95417764148356098985459539107978e-01 4.46917859847798748518243883154355e-01
            -8.26644687966985758365012770809699e-01 4.68338763421103436804033766769865e-16
            -6.95417764148356210007762001623632e-01 -4.46917859847798526473638958123047e-01
            -3.43400613799746345922159207475488e-01 -7.51942456964622141235565777606098e-01
            1.17643805077491614419216148235137e-01 -8.18230636966695623613077259506099e-01
            5.41337147074031022064843909902265e-01 -6.24736371073258522912396983883809e-01
            7.93159769780071521871889217436546e-01 -2.32892721540324809659239235770656e-01
            4.89118915562888001424823869456304e-01 2.35547255313749565042158451433352e-01
            1.20802395936439321832978066595388e-01 5.29269878401625981645395313535118e-01
            -3.38480791749946330337905919805053e-01 4.24441487915102111383447436310234e-01
            -5.42881039498761874817489569977624e-01 6.64837527339946579359214548501647e-17
            -3.38480791749946441360208382320707e-01 -4.24441487915102000361144973794580e-01
            1.20802395936438725088102330573747e-01 -5.29269878401626203690000238566427e-01
            4.89118915562888112447126331971958e-01 -2.35547255313749231975251063886390e-01
            9.69839735629910715264401233071112e-02 1.67981169731017260238203903099929e-01
            -1.93967947125982087541729015356395e-01 2.37542225585017014220666725838636e-17
            9.69839735629910715264401233071112e-02 -1.67981169731017260238203903099929e-01
            ];
        
    case    8
        
        % DEGREE.             :           8
        % CARDIN.             :          45
        % LEBESGUE CONST.     : 5.55480e+00
        % ABS.DET.VAND.MATRIX : 1.26214e+30
        % CONDITIONING VAND.  : 8.05944e+01
        % POINTS OUT DISK     : 0.00000e+00
        
        pts=[
            9.82973099683901785361683778319275e-01 1.83749517816570340222881441150093e-01
            8.50217135729614215122751375020016e-01 5.26432162877355724894812283309875e-01
            6.02634636379256405369631011126330e-01 7.98017227280239493936164762999397e-01
            2.73662990072083001091840515073272e-01 9.61825643172819044757204665074823e-01
            -9.22683594633018910879940222002915e-02 9.95734176295034578707543460041052e-01
            -4.45738355776537809038728710220312e-01 8.95163291355062562537625581171596e-01
            -7.39008917220659311553276893391740e-01 6.73695643646557096317906143667642e-01
            -9.32472229404355701376516663003713e-01 3.61241666187153309675039736248436e-01
            -1.00000000000000000000000000000000e+00 1.22464679914735320717376402945840e-16
            -9.32472229404355923421121588035021e-01 -3.61241666187152699052376192412339e-01
            -7.39008917220659089508671968360431e-01 -6.73695643646557207340208606183296e-01
            -4.45738355776538863750602104119025e-01 -8.95163291355062007426113268593326e-01
            -9.22683594633019188435696378292050e-02 -9.95734176295034578707543460041052e-01
            2.73662990072082779047235590041964e-01 -9.61825643172819044757204665074823e-01
            6.02634636379256183325026086095022e-01 -7.98017227280239715980769688030705e-01
            8.50217135729613882055843987473054e-01 -5.26432162877356168984022133372491e-01
            9.82973099683901785361683778319275e-01 -1.83749517816570062667125284860958e-01
            8.31062177349354946898074558703229e-01 2.04838429519771297870889270598127e-01
            6.40675847903570905295111970190192e-01 5.67589272927015109360127098625526e-01
            3.03518402684037513772352667729137e-01 8.00312254098928255174882906430867e-01
            -1.03171450797133842924857560774399e-01 8.49693342664982642631343878747430e-01
            -4.86225968251449425228116751895868e-01 7.04419926341324886820416395494249e-01
            -7.57891976037490255890816115424968e-01 3.97772394073250490365012410620693e-01
            -8.55934065701778878931804683816154e-01 -2.75289391536968214609866592451524e-16
            -7.57891976037490811002328428003239e-01 -3.97772394073249657697743941753288e-01
            -4.86225968251449591761570445669349e-01 -7.04419926341324886820416395494249e-01
            -1.03171450797134439669733296796039e-01 -8.49693342664982642631343878747430e-01
            3.03518402684037513772352667729137e-01 -8.00312254098928255174882906430867e-01
            6.40675847903570572228204582643230e-01 -5.67589272927015331404732023656834e-01
            8.31062177349354946898074558703229e-01 -2.04838429519771353382040501855954e-01
            5.83022715474206254526734483079053e-01 2.12202914333664283130786998299300e-01
            3.10219907328099231413887082453584e-01 5.37316641011576390241089029586874e-01
            -1.07738243167056838012207720112201e-01 6.11013939750881474033405993395718e-01
            -4.75284472307149319370012108265655e-01 3.98811025417217301924921457612072e-01
            -6.20439814656198351805471702391515e-01 7.59819633082290386164913450281910e-17
            -4.75284472307149596925768264554790e-01 -3.98811025417216968858014070065110e-01
            -1.07738243167056851889995527926658e-01 -6.11013939750881474033405993395718e-01
            3.10219907328098787324677232390968e-01 -5.37316641011576723307996417133836e-01
            5.83022715474206254526734483079053e-01 -2.12202914333664227619635767041473e-01
            2.67835001382030479799567501686397e-01 1.94593518992419722835052198206540e-01
            -1.02303867151060545737095708318520e-01 3.14858927720183312537471920222742e-01
            -3.31062268461939757102641124220099e-01 4.05434347390376259080292292929264e-17
            -1.02303867151060615126034747390804e-01 -3.14858927720183312537471920222742e-01
            2.67835001382030424288416270428570e-01 -1.94593518992419806101779045093281e-01
            -0.00000000000000000000000000000000e+00 0.00000000000000000000000000000000e+00
            ];
        
    case    9
        
        % DEGREE.             :           9
        % CARDIN.             :          55
        % LEBESGUE CONST.     : 6.18226e+00
        % ABS.DET.VAND.MATRIX : 7.59815e+38
        % CONDITIONING VAND.  : 9.14804e+01
        % POINTS OUT DISK     : 0.00000e+00
        
        pts=[
            9.86361303402722322530848941823933e-01 1.64594590280733893417064450659382e-01
            8.79473751206489073872774042683886e-01 4.75947393037073562815919558488531e-01
            6.77281571625741096731587731483160e-01 7.35723910673131586968054307362763e-01
            4.01695424652969534928814709928702e-01 9.15773326655057395839776290813461e-01
            8.25793454723323938626577955801622e-02 9.96584493006669847048328847449739e-01
            -2.45485487140798902538918468962947e-01 9.69400265939330485487346322770463e-01
            -5.46948158122427030569667749659857e-01 8.37166478262528435116962555184728e-01
            -7.89140509396393463603658346983138e-01 6.14212712689667927890013743308373e-01
            -9.45817241700634747658682499604765e-01 3.24699469204683233147790133443777e-01
            -1.00000000000000000000000000000000e+00 1.22464679914735320717376402945840e-16
            -9.45817241700634747658682499604765e-01 -3.24699469204683399681243827217259e-01
            -7.89140509396393907692868197045755e-01 -6.14212712689667483800803893245757e-01
            -5.46948158122426919547365287144203e-01 -8.37166478262528546139265017700382e-01
            -2.45485487140799124583523393994255e-01 -9.69400265939330374465043860254809e-01
            8.25793454723323661070821799512487e-02 -9.96584493006669847048328847449739e-01
            4.01695424652968702261546241061296e-01 -9.15773326655057728906683678360423e-01
            6.77281571625741096731587731483160e-01 -7.35723910673131475945751844847109e-01
            8.79473751206488740805866655136924e-01 -4.75947393037074173438583102324628e-01
            9.86361303402722433553151404339587e-01 -1.64594590280733726883610756885901e-01
            8.60371809838225032329717123502633e-01 1.82877673657027201015168316189374e-01
            7.11605707684683119751412050391082e-01 5.17011809804273525514872744679451e-01
            4.39796513937556476925294646207476e-01 7.61749907131521464265233589685522e-01
            9.19425075047278078654855448803573e-02 8.74774525235075595119837998936418e-01
            -2.71809193747126587314966172925779e-01 8.36542680848410658001057527144440e-01
            -5.88562616091097945414389869256411e-01 6.53665007191383651274918520357460e-01
            -8.03548215189410885983534171828069e-01 3.57762715430801958582662791741313e-01
            -8.79593027875112731805984367383644e-01 4.98336851352641456306678740368615e-16
            -8.03548215189410885983534171828069e-01 -3.57762715430802125116116485514794e-01
            -5.88562616091098500525902181834681e-01 -6.53665007191383207185708670294844e-01
            -2.71809193747126809359571097957087e-01 -8.36542680848410546978755064628785e-01
            9.19425075047273915318513104466547e-02 -8.74774525235075706142140461452072e-01
            4.39796513937556476925294646207476e-01 -7.61749907131521464265233589685522e-01
            7.11605707684683008729109587875428e-01 -5.17011809804273636537175207195105e-01
            8.60371809838225032329717123502633e-01 -1.82877673657026895703836544271326e-01
            6.53035005437007098905155544343870e-01 1.91748378412455622310517355799675e-01
            4.45701005335616629032813307276228e-01 5.14366379920712657458636840601685e-01
            9.68600852129859885009111053477682e-02 6.73676690143314438330435223178938e-01
            -2.82733227584109070296136678734911e-01 6.19099411217447936905955430120230e-01
            -5.72560738320774254006551018392202e-01 3.67962443577450060150368926770170e-01
            -6.80604260161452589983355210279115e-01 3.85598990984963471456384852490620e-16
            -5.72560738320774365028853480907856e-01 -3.67962443577449893616915232996689e-01
            -2.82733227584109625407648991313181e-01 -6.19099411217447603839048042573268e-01
            9.68600852129858219674574115742871e-02 -6.73676690143314549352737685694592e-01
            4.45701005335616240454754688471439e-01 -5.14366379920712990525544228148647e-01
            6.53035005437007098905155544343870e-01 -1.91748378412455705577244202686416e-01
            3.91785341860478697473268994144746e-01 1.88673876660837319674257628321357e-01
            9.67629884750133978377206744880823e-02 4.23946352611206500604623670369620e-01
            -2.71123868837388648511677047281410e-01 3.39978578115750551535967360905488e-01
            -4.34848922996206810331898395816097e-01 5.32536341659978558044858133734058e-17
            -2.71123868837388759533979509797064e-01 -3.39978578115750440513664898389834e-01
            9.67629884750129259929352087965526e-02 -4.23946352611206611626926132885274e-01
            3.91785341860478808495571456660400e-01 -1.88673876660837042118501472032221e-01
            7.63798523178393501398275589053810e-02 1.32293784889105203728121296080644e-01
            -1.52759704635678672524079502181849e-01 1.87076683320778987152856104554500e-17
            7.63798523178393501398275589053810e-02 -1.32293784889105203728121296080644e-01
            ];
        
    case   10
        
        % DEGREE.             :          10
        % CARDIN.             :          66
        % LEBESGUE CONST.     : 6.74906e+00
        % ABS.DET.VAND.MATRIX : 1.36055e+49
        % CONDITIONING VAND.  : 1.11260e+02
        % POINTS OUT DISK     : 0.00000e+00
        
        pts=[
            9.88830826225128522999341385002481e-01 1.49042266176174442726676261372631e-01
            9.00968867902419145998749172576936e-01 4.33883739117558120401696442058892e-01
            7.33051871829826340309921306470642e-01 6.80172737770919355604348766064504e-01
            5.00000000000000111022302462515654e-01 8.66025403784438596588302061718423e-01
            2.22520933956314448387558968533995e-01 9.74927912181823619341969333618181e-01
            -7.47300935864240456485418917509378e-02 9.97203797181180129349797880422557e-01
            -3.65341024366395095146486937665031e-01 9.30873748644204246360800425463822e-01
            -6.23489801858733483364005678595277e-01 7.81831482468029914656426626606844e-01
            -8.26238774315995017083480433939258e-01 5.63320058063621842414647744590184e-01
            -9.55572805786140566652875349973328e-01 2.94755174410904596804527955100639e-01
            -1.00000000000000000000000000000000e+00 1.22464679914735320717376402945840e-16
            -9.55572805786140788697480275004636e-01 -2.94755174410903930670713180006715e-01
            -8.26238774315994906061177971423604e-01 -5.63320058063622064459252669621492e-01
            -6.23489801858733705408610603626585e-01 -7.81831482468029692611821701575536e-01
            -3.65341024366394873101882012633723e-01 -9.30873748644204246360800425463822e-01
            -7.47300935864247256601444746593188e-02 -9.97203797181180129349797880422557e-01
            2.22520933956314226342954043502687e-01 -9.74927912181823619341969333618181e-01
            4.99999999999999333866185224906076e-01 -8.66025403784439040677511911781039e-01
            7.33051871829826562354526231501950e-01 -6.80172737770919133559743841033196e-01
            9.00968867902419034976446710061282e-01 -4.33883739117558342446301367090200e-01
            9.88830826225128411977038922486827e-01 -1.49042266176175275393944730240037e-01
            8.85597428235318839817580283124698e-01 1.65546850132687939360920381659525e-01
            7.65992588287384812417712964816019e-01 4.74282530960880410741964396947878e-01
            5.42936204779781994567144920438295e-01 7.18963727892577342259983197436668e-01
            2.46553278303301842688810552317591e-01 8.66544889456835942809220796334557e-01
            -8.31280346069172421108461890071339e-02 8.97094362008956425214023511216510e-01
            -4.01582445815130639754642061234335e-01 8.06486270000303928640050799003802e-01
            -6.65800922470861089585980607807869e-01 6.06957738333416263465380779962288e-01
            -8.40099295216629626814608400309226e-01 3.25456200835669506865599487355212e-01
            -9.00937602992496588960591452632798e-01 1.10333035173624975440400429445618e-16
            -8.40099295216629848859213325340534e-01 -3.25456200835668951754087174776942e-01
            -6.65800922470860978563678145292215e-01 -6.06957738333416374487683242477942e-01
            -4.01582445815131583444212992617395e-01 -8.06486270000303373528538486425532e-01
            -8.31280346069172698664218046360475e-02 -8.97094362008956425214023511216510e-01
            2.46553278303301648399781242915196e-01 -8.66544889456835942809220796334557e-01
            5.42936204779781883544842457922641e-01 -7.18963727892577564304588122467976e-01
            7.65992588287384479350805577269057e-01 -4.74282530960880799320023015752668e-01
            8.85597428235318839817580283124698e-01 -1.65546850132687689560739840999304e-01
            7.10602017634654914424174876330653e-01 1.75147666772801330337117065027996e-01
            5.47811659077212520507771387201501e-01 4.85318780618956224781612718288670e-01
            2.59524251271344541525110116708674e-01 6.84309210550644753112692342256196e-01
            -8.82170348945128107720492494081554e-02 7.26532647165162859259623928664951e-01
            -4.15748861496556432193472119251965e-01 6.02316209981697103792441794212209e-01
            -6.48037634246662386239279385335976e-01 3.40116387788632956734602430515224e-01
            -7.31868794690960111637423324282281e-01 -2.35386957066814606223915903455317e-16
            -6.48037634246662719306186772882938e-01 -3.40116387788632235089636424163473e-01
            -4.15748861496556598726925813025446e-01 -6.02316209981696992770139331696555e-01
            -8.82170348945133103724103307285986e-02 -7.26532647165162859259623928664951e-01
            2.59524251271344541525110116708674e-01 -6.84309210550644753112692342256196e-01
            5.47811659077212298463166462170193e-01 -4.85318780618956502337368874577805e-01
            7.10602017634654914424174876330653e-01 -1.75147666772801358092692680656910e-01
            4.88571147756956369878622581381933e-01 1.77825355104806764883207392813347e-01
            2.59963277857998831255059712930233e-01 4.50269605352199175918315177113982e-01
            -9.02842989207266743978408385373768e-02 5.12027703066048167634960464056348e-01
            -3.98286848836229556702903664699988e-01 3.34202347961241430507328686871915e-01
            -5.19926555715997551487816963344812e-01 6.36726392249304420184699292957277e-17
            -3.98286848836229834258659820989124e-01 -3.34202347961241152951572530582780e-01
            -9.02842989207266882756286463518336e-02 -5.12027703066048167634960464056348e-01
            2.59963277857998442677001094125444e-01 -4.50269605352199397962920102145290e-01
            4.88571147756956369878622581381933e-01 -1.77825355104806709372056161555520e-01
            2.21874473558017565322231234858918e-01 1.61201240918700666737706228559546e-01
            -8.47485076631728645457641846405750e-02 2.60829086835118018061763223158778e-01
            -2.74251931789689318286207253549946e-01 3.35861750426221292239035276580898e-17
            -8.47485076631729200569154158984020e-02 -2.60829086835118018061763223158778e-01
            2.21874473558017537566655619230005e-01 -1.61201240918700722248857459817373e-01
            -0.00000000000000000000000000000000e+00 0.00000000000000000000000000000000e+00
            ];
        
    case   11
        
        % DEGREE.             :          11
        % CARDIN.             :          78
        % LEBESGUE CONST.     : 7.40552e+00
        % ABS.DET.VAND.MATRIX : 2.10822e+60
        % CONDITIONING VAND.  : 1.35391e+02
        % POINTS OUT DISK     : 0.00000e+00
        
        pts=[
            9.90685946036330755681831305992091e-01 1.36166649096246594741188573607360e-01
            9.17211301505453047155924650724046e-01 3.98401089846241451830621826957213e-01
            7.75711290704419798025526233686833e-01 6.31087944326052752153088931663660e-01
            5.76680322114867083271860792592634e-01 8.16969893010441983172142954572337e-01
            3.34879612170986218355750452246866e-01 9.42260922118820287707308125391137e-01
            6.82424133646712255396593604928057e-02 9.97668769190539150848451299680164e-01
            -2.03456013052633805093805108299421e-01 9.79084087682322690149305799423018e-01
            -4.60065037731152093325448504401720e-01 8.87885218402375220314581838465529e-01
            -6.82553143218654234658515633782372e-01 7.30835964278123917381435603601858e-01
            -8.54419404546488348017874159268104e-01 5.19583950035433894676373256515944e-01
            -9.62917287347799133456760500848759e-01 2.69796771157024217746567273934488e-01
            -1.00000000000000000000000000000000e+00 1.22464679914735320717376402945840e-16
            -9.62917287347799244479062963364413e-01 -2.69796771157024439791172198965796e-01
            -8.54419404546488792107084009330720e-01 -5.19583950035433228542558481422020e-01
            -6.82553143218654123636213171266718e-01 -7.30835964278124028403738066117512e-01
            -4.60065037731152703948112048237817e-01 -8.87885218402374998269976913434220e-01
            -2.03456013052633666315927030154853e-01 -9.79084087682322912193910724454327e-01
            6.82424133646709896172666276470409e-02 -9.97668769190539150848451299680164e-01
            3.34879612170986051822296758473385e-01 -9.42260922118820509751913050422445e-01
            5.76680322114866972249558330076979e-01 -8.16969893010442205216747879603645e-01
            7.75711290704419575980921308655525e-01 -6.31087944326053085219996319210622e-01
            9.17211301505452825111319725692738e-01 -3.98401089846241895919831677019829e-01
            9.90685946036330755681831305992091e-01 -1.36166649096246344941008032947138e-01
            8.98485340053805869864333999430528e-01 1.49930685550243664172498370135145e-01
            8.01120512022489017489590423792833e-01 4.33544740457076971384964281241992e-01
            6.16941845848015590902946314599831e-01 6.70177495595616568024865955521818e-01
            3.65907957836847486099429715977749e-01 8.34186120211093617982101022789720e-01
            7.52222649471028514955861510316026e-02 9.07797734970404723853221184981521e-01
            -2.23614927543361013961842331809748e-01 8.83035379212490312283989624120295e-01
            -4.98219972891401352566020932499669e-01 7.62582438411258278776472252502572e-01
            -7.18835153497258794175195362186059e-01 5.59491857722470897762434560718248e-01
            -8.61553391345058372507992316968739e-01 2.95771652838803855711802270889166e-01
            -9.10908950862362121192461472674040e-01 1.11554173098826552907556062116610e-16
            -8.61553391345058372507992316968739e-01 -2.95771652838804022245255964662647e-01
            -7.18835153497259238264405212248676e-01 -5.59491857722470453673224710655631e-01
            -4.98219972891401241543718469984015e-01 -7.62582438411258389798774715018226e-01
            -2.23614927543361208250871641212143e-01 -8.83035379212490312283989624120295e-01
            7.52222649471028237400105354026891e-02 -9.07797734970404723853221184981521e-01
            3.65907957836846764454463709625998e-01 -8.34186120211093840026705947821029e-01
            6.16941845848015701925248777115485e-01 -6.70177495595616568024865955521818e-01
            8.01120512022488795444985498761525e-01 -4.33544740457077526496476593820262e-01
            8.98485340053805980886636461946182e-01 -1.49930685550243497639044676361664e-01
            7.45213086985145767293658991548000e-01 1.58399931481065681104780651367037e-01
            6.16358974197054876320578387094429e-01 4.47811007271919248040603633853607e-01
            3.80930795324799453815955985191977e-01 6.59791491670173368966345606168034e-01
            7.96362212932526097874941228837997e-02 7.57688033141126426883715794247109e-01
            -2.35428178872255478015773633160279e-01 7.24573430302291709992346113722306e-01
            -5.09784908112889900699826739582932e-01 5.66173498821226139909867924870923e-01
            -6.95995195490307527741435933421599e-01 3.09877025869207123331960929135676e-01
            -7.61861590649598685587307045352645e-01 4.31635647644926363757770939066865e-16
            -6.95995195490307527741435933421599e-01 -3.09877025869207234354263391651330e-01
            -5.09784908112890344789036589645548e-01 -5.66173498821225806842960537323961e-01
            -2.35428178872255644549227326933760e-01 -7.24573430302291598970043651206652e-01
            7.96362212932522489650111197079241e-02 -7.57688033141126537906018256762763e-01
            3.80930795324799453815955985191977e-01 -6.59791491670173368966345606168034e-01
            6.16358974197054765298275924578775e-01 -4.47811007271919414574057327627088e-01
            7.45213086985145767293658991548000e-01 -1.58399931481065431304600110706815e-01
            5.53379377193801480494528277631616e-01 1.62486845789833495024012677276914e-01
            3.77685334926607052530300734360935e-01 4.35872111908419068715403454916668e-01
            8.20788674172706483878059202652366e-02 5.70871062221257385971284747938626e-01
            -2.39587060555484815393967323871038e-01 5.24622483861024724305366362386849e-01
            -4.85185789643150178207520184514578e-01 3.11809973680255370087621713537374e-01
            -5.76741458678088014799811844568467e-01 3.26755116802694242211643921459888e-16
            -4.85185789643150233718671415772405e-01 -3.11809973680255259065319251021720e-01
            -2.39587060555485287238752789562568e-01 -5.24622483861024502260761437355541e-01
            8.20788674172704957321400343062123e-02 -5.70871062221257496993587210454280e-01
            3.77685334926606719463393346813973e-01 -4.35872111908419290760008379947976e-01
            5.53379377193801480494528277631616e-01 -1.62486845789833550535163908534741e-01
            3.27467301746040995169551024446264e-01 1.57699941010279648390124407342228e-01
            8.08777444156654201634637502138503e-02 3.54348550957546082340599014059990e-01
            -2.26614404065031915802563844408724e-01 2.84165474640619863944124290355830e-01
            -3.63461284193348888038599397987127e-01 4.45111698301371205222083218401719e-17
            -2.26614404065031999069290691295464e-01 -2.84165474640619808432973059098003e-01
            8.08777444156650177076173235946044e-02 -3.54348550957546137851750245317817e-01
            3.27467301746041050680702255704091e-01 -1.57699941010279426345519482310920e-01
            6.32261432572294307385973866075801e-02 1.09510892488149727541646427653177e-01
            -1.26452286514458833721619157586247e-01 1.54859387924796028833006520035925e-17
            6.32261432572294307385973866075801e-02 -1.09510892488149727541646427653177e-01
            ];
        
    case   12
        
        % DEGREE.             :          12
        % CARDIN.             :          91
        % LEBESGUE CONST.     : 8.16284e+00
        % ABS.DET.VAND.MATRIX : 1.19551e+73
        % CONDITIONING VAND.  : 1.45078e+02
        % POINTS OUT DISK     : 0.00000e+00
        
        pts=[
            9.92114701314477875904174197785323e-01 1.25333233564304258322863461216912e-01
            9.29776485888251458256092973897466e-01 3.68124552684677919245359589694999e-01
            8.09016994374947451262869435595348e-01 5.87785252292473137103456792829093e-01
            6.37423989748689745482579382951371e-01 7.70513242775789253258267308410723e-01
            4.25779291565072548486625692021335e-01 9.04827052466019354781678885046858e-01
            1.87381314585724739751881884330942e-01 9.82287250728688610124095248465892e-01
            -6.27905195293134016365499405765149e-02 9.98026728428271558968276622181293e-01
            -3.09016994374947118195962048048386e-01 9.51056516295153642204240895807743e-01
            -5.35826794978996878704435857798671e-01 8.44327925502014964287411658006022e-01
            -7.28968627421411330402634121128358e-01 6.84547105928688837117590537673095e-01
            -8.76306680043863583939867112349020e-01 4.81753674101715212430008250521496e-01
            -9.68583161128630965031049981917022e-01 2.48689887164855238932403835860896e-01
            -1.00000000000000000000000000000000e+00 1.22464679914735320717376402945840e-16
            -9.68583161128631187075654906948330e-01 -2.48689887164854572798589060766972e-01
            -8.76306680043863583939867112349020e-01 -4.81753674101715378963461944294977e-01
            -7.28968627421411774491843971190974e-01 -6.84547105928688393028380687610479e-01
            -5.35826794978996323592923545220401e-01 -8.44327925502015297354319045552984e-01
            -3.09016994374947562285171898111003e-01 -9.51056516295153531181938433292089e-01
            -6.27905195293132073475206311741204e-02 -9.98026728428271558968276622181293e-01
            1.87381314585724267907096418639412e-01 -9.82287250728688721146397710981546e-01
            4.25779291565071826841659685669583e-01 -9.04827052466019909893191197625129e-01
            6.37423989748689301393369532888755e-01 -7.70513242775789586325174695957685e-01
            8.09016994374947118195962048048386e-01 -5.87785252292473248125759255344747e-01
            9.29776485888251458256092973897466e-01 -3.68124552684677863734208358437172e-01
            9.92114701314477764881871735269669e-01 -1.25333233564304646900922080021701e-01
            9.11914192736804074534973096888280e-01 1.37448949040719248237962801795220e-01
            8.30886614842618720366829165868694e-01 4.00133904815111962616214213994681e-01
            6.76031114933815069356626281660283e-01 6.27265207187962969825889558705967e-01
            4.61107283749458807253773784395889e-01 7.98661243194141334811320120934397e-01
            2.05212046867977698783036544227798e-01 8.99092722875382999170312814385397e-01
            -6.89171809359576670317437674384564e-02 9.19635868525720212574015022255480e-01
            -3.36922814775666490394456786816590e-01 8.58465331502010764452847979555372e-01
            -5.74991377961137639651667541329516e-01 7.21016382461291627237187640275806e-01
            -7.61969433906660942312782935914584e-01 5.19501963710608083424347114487318e-01
            -8.81243161801792629361784747743513e-01 2.71827515687420362411330643226393e-01
            -9.22214567498917392462942643760471e-01 1.12938711821460998713036003095889e-16
            -8.81243161801792851406389672774822e-01 -2.71827515687419751788667099390295e-01
            -7.61969433906660831290480473398929e-01 -5.19501963710608305468952039518626e-01
            -5.74991377961137750673970003845170e-01 -7.21016382461291405192582715244498e-01
            -3.36922814775666268349851861785282e-01 -8.58465331502010764452847979555372e-01
            -6.89171809359583054099829269034672e-02 -9.19635868525720212574015022255480e-01
            2.05212046867977476738431619196490e-01 -8.99092722875382999170312814385397e-01
            4.61107283749458085608807778044138e-01 -7.98661243194141778900529970997013e-01
            6.76031114933815291401231206691591e-01 -6.27265207187962747781284633674659e-01
            8.30886614842618609344526703353040e-01 -4.00133904815112184660819139025989e-01
            9.11914192736803963512670634372625e-01 -1.37448949040719997638504423775885e-01
            7.77621059842416917362584172224160e-01 1.45362568757988752654597419677884e-01
            6.72599026763656016036918572353898e-01 4.16455685881400083925285571240238e-01
            4.76738768120595735044986440698267e-01 6.31304154965909858354677908209851e-01
            2.16492297142140327492754181548662e-01 7.60891499745189658909794161445461e-01
            -7.29926581905921550985638646125153e-02 7.87716231238531849889739078207640e-01
            -3.52619550568403161694419623017893e-01 7.08155520816792116711724247579696e-01
            -5.84623218709570346973691812308971e-01 5.32954483283541446958508913667174e-01
            -7.37670281654922876946045562362997e-01 2.85774989580109273212826792587293e-01
            -7.91090885490639883492747230775421e-01 9.68806920750757415971870057671316e-17
            -7.37670281654922987968348024878651e-01 -2.85774989580108773612465711266850e-01
            -5.84623218709570235951389349793317e-01 -5.32954483283541557980811376182828e-01
            -3.52619550568403994361688091885298e-01 -7.08155520816791672622514397517079e-01
            -7.29926581905921828541394802414288e-02 -7.87716231238531849889739078207640e-01
            2.16492297142140160959300487775181e-01 -7.60891499745189658909794161445461e-01
            4.76738768120595568511532746924786e-01 -6.31304154965910080399282833241159e-01
            6.72599026763655793992313647322590e-01 -4.16455685881400472503344190045027e-01
            7.77621059842416917362584172224160e-01 -1.45362568757988530609992494646576e-01
            6.09420352078551719188226343248971e-01 1.50208626068516759577420316418284e-01
            4.69809493728756910613242325780448e-01 4.16214892183432827454936386857298e-01
            2.22570942183871661734784197506087e-01 5.86871342432326636995298940746579e-01
            -7.56559299447139982364163302008819e-02 6.23082640696350997799868309812155e-01
            -3.56550940275760119835268824317609e-01 5.16553214936669280454850650130538e-01
            -5.55764427094264878981277888669865e-01 2.91687672776072215441445223405026e-01
            -6.27658981352882006099491718487116e-01 -2.01870524837307046347436788655659e-16
            -5.55764427094265212048185276216827e-01 -2.91687672776071604818781679568929e-01
            -3.56550940275760230857571286833263e-01 -5.16553214936669169432548187614884e-01
            -7.56559299447144423256261802634981e-02 -6.23082640696350997799868309812155e-01
            2.22570942183871661734784197506087e-01 -5.86871342432326636995298940746579e-01
            4.69809493728756688568637400749139e-01 -4.16214892183433049499541311888606e-01
            6.09420352078551719188226343248971e-01 -1.50208626068516815088571547676111e-01
            4.12459940291431348402539924791199e-01 1.50123141093296108561361279498669e-01
            2.19465350247441626230227029736852e-01 3.80125137129467660646042759253760e-01
            -7.62195162630056460839611531810078e-02 4.32262356882440301752978939475724e-01
            -3.36240424028425632929639732537908e-01 2.82139215789144304213920122492709e-01
            -4.38930700494883141438151596958051e-01 5.37535077408564182925925620442961e-17
            -3.36240424028425854974244657569216e-01 -2.82139215789144082169315197461401e-01
            -7.62195162630056460839611531810078e-02 -4.32262356882440301752978939475724e-01
            2.19465350247441265407744026560977e-01 -3.80125137129467827179496453027241e-01
            4.12459940291431348402539924791199e-01 -1.50123141093296053050210048240842e-01
            1.85138041494658206476131567796983e-01 1.34510660697490375126150752294052e-01
            -7.07164392403710345691436600645829e-02 2.17642820857744084817042562463030e-01
            -2.28843204508574316058400199835887e-01 2.80252097908048691750116774021770e-17
            -7.07164392403710900802948913224100e-02 -2.17642820857744057061466946834116e-01
            1.85138041494658178720555952168070e-01 -1.34510660697490430637301983551879e-01
            -0.00000000000000000000000000000000e+00 0.00000000000000000000000000000000e+00
            ];
        
    case   13
        
        % DEGREE.             :          13
        % CARDIN.             :         105
        % LEBESGUE CONST.     : 8.99146e+00
        % ABS.DET.VAND.MATRIX : 1.46592e+87
        % CONDITIONING VAND.  : 1.83330e+02
        % POINTS OUT DISK     : 0.00000e+00
        
        pts=[
            9.93238357741943023171415916294791e-01 1.16092914125230234345664825923450e-01
            9.39692620785908427905042117345147e-01 3.42020143325668712908083080037613e-01
            8.35487811412936487442948418902233e-01 5.49508978070806008986437518615276e-01
            6.86241637868733600491566448908998e-01 7.27373641573048734798589975980576e-01
            5.00000000000000111022302462515654e-01 8.66025403784438596588302061718423e-01
            2.86803232711090316797708510421216e-01 9.57989512315488900284776718763169e-01
            5.81448289104756765866000023379456e-02 9.98308158271268175631973917916184e-01
            -1.73648177666930081386453821323812e-01 9.84807753012208131337956729112193e-01
            -3.96079766039156788703934353179648e-01 9.18216106880273996715402518020710e-01
            -5.97158591702785956911725406826008e-01 8.02123192755043956658767001499655e-01
            -7.66044443118978235496285833505681e-01 6.42787609686539140874117492785444e-01
            -8.93632640323412164029548421240179e-01 4.48799180200462333178990093074390e-01
            -9.73044870579823806266972496814560e-01 2.30615870742440332019640436556074e-01
            -1.00000000000000000000000000000000e+00 1.22464679914735320717376402945840e-16
            -9.73044870579823806266972496814560e-01 -2.30615870742440082219459895895852e-01
            -8.93632640323412275051850883755833e-01 -4.48799180200462111134385168043082e-01
            -7.66044443118978124473983370990027e-01 -6.42787609686539251896419955301099e-01
            -5.97158591702786178956330331857316e-01 -8.02123192755043734614162076468347e-01
            -3.96079766039156844215085584437475e-01 -9.18216106880273996715402518020710e-01
            -1.73648177666930331186634361984034e-01 -9.84807753012208020315654266596539e-01
            5.81448289104749826972096116151079e-02 -9.98308158271268286654276380431838e-01
            2.86803232711090316797708510421216e-01 -9.57989512315488900284776718763169e-01
            5.00000000000000111022302462515654e-01 -8.66025403784438596588302061718423e-01
            6.86241637868733711513868911424652e-01 -7.27373641573048623776287513464922e-01
            8.35487811412936043353738568839617e-01 -5.49508978070806675120252293709200e-01
            9.39692620785908094838134729798185e-01 -3.42020143325669434553049086389365e-01
            9.93238357741943023171415916294791e-01 -1.16092914125230040056635516521055e-01
            9.23300525722714038323601926094852e-01 1.26904736258219075217823501589010e-01
            8.54823549548711536516520936856978e-01 3.71302265036923484498032621559105e-01
            7.22948221262210810600379318202613e-01 5.88162003412676881453080568462610e-01
            5.37455130672737646513326126296306e-01 7.61400456657440383168022890458815e-01
            3.12101451734888457600902711419621e-01 8.78169321207239339521777310437756e-01
            6.36006358910001651230103902889823e-02 9.29808384560425804643557512463303e-01
            -1.89617148163374965585958875635697e-01 9.12487813621089993709745158412261e-01
            -4.28771895779205269860767657519318e-01 8.27492195899462545938263247080613e-01
            -6.36126593385996641494273262651404e-01 6.81125267532878386766981293476420e-01
            -7.96302691646875060449417560448637e-01 4.84242394014144650338238307085703e-01
            -8.97420662110723910132037417497486e-01 2.51445477392929606086369176409789e-01
            -9.31981047492173142465787805122091e-01 1.14134760667728723421765281343670e-16
            -8.97420662110723799109734954981832e-01 -2.51445477392929772619822870183270e-01
            -7.96302691646875504538627410511253e-01 -4.84242394014144039715574763249606e-01
            -6.36126593385996530471970800135750e-01 -6.81125267532878497789283755992074e-01
            -4.28771895779205880483431201355415e-01 -8.27492195899462323893658322049305e-01
            -1.89617148163374771296929566233302e-01 -9.12487813621089993709745158412261e-01
            6.36006358909999430784054652576742e-02 -9.29808384560425804643557512463303e-01
            3.12101451734888291067449017646140e-01 -8.78169321207239339521777310437756e-01
            5.37455130672737535491023663780652e-01 -7.61400456657440494190325352974469e-01
            7.22948221262210588555774393171305e-01 -5.88162003412677214519987956009572e-01
            8.54823549548711314471916011825670e-01 -3.71302265036923928587242471621721e-01
            9.23300525722714038323601926094852e-01 -1.26904736258218853173218576557701e-01
            8.04828612625775430267083265789552e-01 1.34302141907187672087431451473094e-01
            7.17612944245143657973073914035922e-01 3.88352704733474551890282100430341e-01
            5.52632778443450711769457939226413e-01 6.00319226088804169805257515690755e-01
            3.27766276116341515045604637634824e-01 7.47231844384870336206461161054904e-01
            6.73812119542426674057011837248865e-02 8.13170297845147715953828537749359e-01
            -2.00305652050326077340258734693634e-01 7.90989131896692065915033253986621e-01
            -4.46286290592816103917073178308783e-01 6.83092020046269676747385801718337e-01
            -6.43904884704283864138574244861957e-01 5.01171288559063232703749690699624e-01
            -7.71746393344326153673762291873572e-01 2.64940871482701789663138924879604e-01
            -8.15957205386403150448870746913599e-01 9.99259379817678027608115767539308e-17
            -7.71746393344326153673762291873572e-01 -2.64940871482701956196592618653085e-01
            -6.43904884704284197205481632408919e-01 -5.01171288559062788614539840637008e-01
            -4.46286290592815992894770715793129e-01 -6.83092020046269787769688264233992e-01
            -2.00305652050326271629288044096029e-01 -7.90989131896692065915033253986621e-01
            6.73812119542426396501255680959730e-02 -8.13170297845147715953828537749359e-01
            3.27766276116340793400638631283073e-01 -7.47231844384870558251066086086212e-01
            5.52632778443450822791760401742067e-01 -6.00319226088804169805257515690755e-01
            7.17612944245143324906166526488960e-01 -3.88352704733475051490643181750784e-01
            8.04828612625775541289385728305206e-01 -1.34302141907187533309553373328527e-01
            6.55895321790478824652836919995025e-01 1.39414854415236877382966440563905e-01
            5.42485062030969023005866347375559e-01 3.94138468373125272492529802548233e-01
            3.35274206724233969634241248058970e-01 5.80711960513723979282474374485901e-01
            7.00913952043314691930930848684511e-02 6.66875079078958821199307749338914e-01
            -2.07210855306735053371625099316589e-01 6.37729438101542145389544202771503e-01
            -4.48684466483743438214304433131474e-01 4.98314583686305379028880224723252e-01
            -6.12576457235300519954535047872923e-01 2.72736610705833437684475484275026e-01
            -6.70548413448467828246180033602286e-01 3.79901811914843431099359849634557e-16
            -6.12576457235300519954535047872923e-01 -2.72736610705833548706777946790680e-01
            -4.48684466483743771281211820678436e-01 -4.98314583686305101473124068434117e-01
            -2.07210855306735192149503177461156e-01 -6.37729438101542145389544202771503e-01
            7.00913952043311500039735051359457e-02 -6.66875079078958821199307749338914e-01
            3.35274206724233969634241248058970e-01 -5.80711960513723979282474374485901e-01
            5.42485062030968911983563884859905e-01 -3.94138468373125383514832265063887e-01
            6.55895321790478824652836919995025e-01 -1.39414854415236655338361515532597e-01
            4.81689285526591404185126066295197e-01 1.41436735595160595346797549609619e-01
            3.28756340825753723411395412767888e-01 3.79405042578237650108263778747641e-01
            7.14455807940429649116609311931825e-02 4.96914929290653673010780266849906e-01
            -2.08548646329425185763639660763147e-01 4.56657836986400389456264292675769e-01
            -4.22330151777621953801400422889856e-01 2.71415108029056217908703274588333e-01
            -5.02024818078681711597255343804136e-01 2.84424113440942188500635227570222e-16
            -4.22330151777622064823702885405510e-01 -2.71415108029056106886400812072679e-01
            -2.08548646329425602097273895196849e-01 -4.56657836986400167411659367644461e-01
            7.14455807940428400115706608630717e-02 -4.96914929290653728521931498107733e-01
            3.28756340825753445855639256478753e-01 -3.79405042578237872152868703778950e-01
            4.81689285526591404185126066295197e-01 -1.41436735595160650857948780867446e-01
            2.82833748116020189389274719360401e-01 1.36205554434876974223556089782505e-01
            6.98541670276205672873715002424433e-02 3.06051102728197743640947692256304e-01
            -1.95727026597904113502934819734946e-01 2.45433928362424891300719309583656e-01
            -3.13921777091473175325120337220142e-01 3.84443299497721526812054674943581e-17
            -1.95727026597904169014086050992773e-01 -2.45433928362424835789568078325829e-01
            6.98541670276202203426763048810244e-02 -3.06051102728197854663250154771958e-01
            2.82833748116020244900425950618228e-01 -1.36205554434876779934526780380111e-01
            5.42919403834522112939353633009887e-02 9.40363991856397185564730989426607e-02
            -1.08583880766904394832295110973064e-01 1.32976902020187313189097142484416e-17
            5.42919403834522112939353633009887e-02 -9.40363991856397185564730989426607e-02
            ];
        
    case   14
        
        % DEGREE.             :          14
        % CARDIN.             :         120
        % LEBESGUE CONST.     : 1.00487e+01
        % ABS.DET.VAND.MATRIX : 4.27756e+102
        % CONDITIONING VAND.  : 2.12398e+02
        % POINTS OUT DISK     : 0.00000e+00
        
        pts=[
            9.94137957154359597211623622570187e-01 1.08119018423941767870211094759725e-01
            9.47653171182802456229410381638445e-01 3.19301530135980005109530566187459e-01
            8.56857176167589273951818995556096e-01 5.15553857177021734869981628435198e-01
            7.25995491923130842337741341907531e-01 6.87699458853423317705733097682241e-01
            5.61187065362382386801698430645047e-01 8.27688998156890565205401344428537e-01
            3.70138155339914565189474160433747e-01 9.28976719816791307593462079239544e-01
            1.61781996552764623098497054343170e-01 9.86826522541526141019119222619338e-01
            -5.41389085854172627532143735606951e-02 9.98533413851123929916298038733657e-01
            -2.67528338529220865993352163059171e-01 9.63549992519222908704534802382113e-01
            -4.68408440699790040717687134019798e-01 8.83512044446022937194129553972743e-01
            -6.47386284781827692214051239716355e-01 7.62162055127636461904216957918834e-01
            -7.96093065705643532226076786173508e-01 6.05174215193765463460806586226681e-01
            -9.07575419670957117546095105353743e-01 4.19889101560264432766444997469080e-01
            -9.76620555710086657441593160910998e-01 2.14970440211024266252692882517294e-01
            -1.00000000000000000000000000000000e+00 1.22464679914735320717376402945840e-16
            -9.76620555710086657441593160910998e-01 -2.14970440211024016452512341857073e-01
            -9.07575419670957006523792642838089e-01 -4.19889101560264599299898691242561e-01
            -7.96093065705643976315286636236124e-01 -6.05174215193764908349294273648411e-01
            -6.47386284781827470169446314685047e-01 -7.62162055127636572926519420434488e-01
            -4.68408440699790651340350677855895e-01 -8.83512044446022604127222166425781e-01
            -2.67528338529221310082562013121787e-01 -9.63549992519222797682232339866459e-01
            -5.41389085854179497037108603763045e-02 -9.98533413851123818893995576218003e-01
            1.61781996552764373298316513682948e-01 -9.86826522541526029996816760103684e-01
            3.70138155339914121100264310371131e-01 -9.28976719816791529638067004270852e-01
            5.61187065362382275779395968129393e-01 -8.27688998156890676227703806944191e-01
            7.25995491923130842337741341907531e-01 -6.87699458853423317705733097682241e-01
            8.56857176167589273951818995556096e-01 -5.15553857177021734869981628435198e-01
            9.47653171182802456229410381638445e-01 -3.19301530135979894087228103671805e-01
            9.94137957154359486189321160054533e-01 -1.08119018423942489515177101111476e-01
            9.31877268643755085619773126381915e-01 1.17723476135822555099785802212864e-01
            8.73323992650010705318663895013742e-01 3.45773429445194457887424732689396e-01
            7.59896558337094463198013727378566e-01 5.52097166516805848424098712712293e-01
            5.98722028559809715808626151556382e-01 7.23730608144821485616660083906027e-01
            3.99927591782519631369297030687449e-01 8.49889393968109918553466286539333e-01
            1.76004233582737673602380823467684e-01 9.22646503493835257181387987657217e-01
            -5.89781179113397918678529663338850e-02 9.37430339948565394259105687524425e-01
            -2.90254657350702494067462566817994e-01 8.93311980516702242027804459212348e-01
            -5.03293429186763230376300271018408e-01 7.93063543977325480227591469883919e-01
            -6.84708423883264583054142349283211e-01 6.42984008286164421264174961834215e-01
            -8.23100670125747502225976859335788e-01 4.52503422624616236102923494399874e-01
            -9.09774474111717412760924617032288e-01 2.33590382728387696564809061783308e-01
            -9.39283801972783272127287546027219e-01 1.15029090157692539331105525776174e-16
            -9.09774474111717634805529542063596e-01 -2.33590382728387085942145517947210e-01
            -8.23100670125747502225976859335788e-01 -4.52503422624616402636377188173356e-01
            -6.84708423883264916121049736830173e-01 -6.42984008286164088197267574287253e-01
            -5.03293429186762675264787958440138e-01 -7.93063543977325813294498857430881e-01
            -2.90254657350702938156672416880610e-01 -8.93311980516702131005501996696694e-01
            -5.89781179113396045177175608387188e-02 -9.37430339948565394259105687524425e-01
            1.76004233582737229513170973405067e-01 -9.22646503493835368203690450172871e-01
            3.99927591782518854213179793077870e-01 -8.49889393968110251620373674086295e-01
            5.98722028559809271719416301493766e-01 -7.23730608144821818683567471452989e-01
            7.59896558337094352175711264862912e-01 -5.52097166516805959446401175227948e-01
            8.73323992650010705318663895013742e-01 -3.45773429445194402376273501431569e-01
            9.31877268643754974597470663866261e-01 -1.17723476135822915922268805388740e-01
            8.25967904107322903328736174444202e-01 1.24494630377667100940008992893127e-01
            7.52577031126942297412085736141307e-01 3.62421996888258823865669455699390e-01
            6.12316386301029025318598542071413e-01 5.68146578512591760024008635809878e-01
            4.17648743446067394202714240236674e-01 7.23388843365887601599695244658506e-01
            1.85871176914600116925058159722539e-01 8.14354834946472982970533394109225e-01
            -6.24218593679540315055653820763837e-02 8.32961825704733649367028647247935e-01
            -3.05168439511847910949882134445943e-01 7.77556502856364351039530902198749e-01
            -5.20799464595474992378854039998259e-01 6.53061872478697402755187795264646e-01
            -6.90155171758988217334263026714325e-01 4.70539828816474658967905497775064e-01
            -7.98187563215629003465778623649385e-01 2.46208256433881417235554067701742e-01
            -8.35297486892134566360823555442039e-01 1.02294439365828082933180689409238e-16
            -7.98187563215629225510383548680693e-01 -2.46208256433880862124041755123471e-01
            -6.90155171758988106311960564198671e-01 -4.70539828816474825501359191548545e-01
            -5.20799464595475214423458965029567e-01 -6.53061872478697180710582870233338e-01
            -3.05168439511847744416428440672462e-01 -7.77556502856364351039530902198749e-01
            -6.24218593679545935559715985618823e-02 -8.32961825704733649367028647247935e-01
            1.85871176914599922636028850320145e-01 -8.14354834946472982970533394109225e-01
            4.17648743446066728068899465142749e-01 -7.23388843365888045688905094721122e-01
            6.12316386301029247363203467102721e-01 -5.68146578512591649001706173294224e-01
            7.52577031126942186389783273625653e-01 -3.62421996888259045910274380730698e-01
            8.25967904107322792306433711928548e-01 -1.24494630377667794829399383615964e-01
            6.92729891230118854927866323123453e-01 1.29493659115994391717308076295012e-01
            5.99172880870652790896713213442126e-01 3.70992141135232267323829091765219e-01
            4.24694252818057338405566270012059e-01 5.62386078755736540379928101174301e-01
            1.92858312610289434063659541607194e-01 6.77826660151438331602946618659189e-01
            -6.50242113802998872307270517012512e-02 7.01722995126504156537805556581588e-01
            -3.14124855312385820038656447650283e-01 6.30847751228388098354571411618963e-01
            -5.20801196908622920922482535388554e-01 4.74773022878814565661542701491271e-01
            -6.57140451003294656651121385948500e-01 2.54577566981319336480993342775037e-01
            -7.04729245849029295456489307980519e-01 8.63044415194541837597108769977144e-17
            -6.57140451003294767673423848464154e-01 -2.54577566981318892391783492712420e-01
            -5.20801196908622809900180072872899e-01 -4.74773022878814621172693932749098e-01
            -3.14124855312386541683622454002034e-01 -6.30847751228387765287664024072001e-01
            -6.50242113802999011085148595157079e-02 -7.01722995126504156537805556581588e-01
            1.92858312610289295285781463462627e-01 -6.77826660151438331602946618659189e-01
            4.24694252818057227383263807496405e-01 -5.62386078755736762424533026205609e-01
            5.99172880870652568852108288410818e-01 -3.70992141135232544879585248054354e-01
            6.92729891230118854927866323123453e-01 -1.29493659115994197428278766892618e-01
            5.37142275474489894193652617104817e-01 1.32393680203086033797532650169160e-01
            4.14089453429436982201394812364015e-01 3.66851243991539288646919203529251e-01
            1.96173727922588581051854816905688e-01 5.17267608818282709215452541684499e-01
            -6.66830345016180409123407457627764e-02 5.49184198215212471261281734769000e-01
            -3.14263517339185893817443684383761e-01 4.55289306188090714400118486082647e-01
            -4.89850015640290070706441838410683e-01 2.57093120944216046996899649457191e-01
            -5.53217778690842321154264027427416e-01 -1.77928408023308093277105843866037e-16
            -4.89850015640290403773349225957645e-01 -2.57093120944215547396538568136748e-01
            -3.14263517339186004839746146899415e-01 -4.55289306188090658888967254824820e-01
            -6.66830345016184156126115567531087e-02 -5.49184198215212471261281734769000e-01
            1.96173727922588581051854816905688e-01 -5.17267608818282709215452541684499e-01
            4.14089453429436815667941118590534e-01 -3.66851243991539510691524128560559e-01
            5.37142275474489894193652617104817e-01 -1.32393680203086061553108265798073e-01
            3.60792103426282040334882594834198e-01 1.31317586405459790777072726086772e-01
            1.91973468475539921218597783081350e-01 3.32507801104857225737987391767092e-01
            -6.66716859223547841928336765704444e-02 3.78113920254712743140856900936342e-01
            -2.94120417503927200630897687005927e-01 2.46796333849253007874935406107397e-01
            -3.83946936951079731414893103647046e-01 4.70199387379570426077378213793123e-17
            -2.94120417503927367164351380779408e-01 -2.46796333849252813585906096705003e-01
            -6.66716859223547980706214843849011e-02 -3.78113920254712743140856900936342e-01
            1.91973468475539615907266011163301e-01 -3.32507801104857392271441085540573e-01
            3.60792103426282040334882594834198e-01 -1.31317586405459735265921494828945e-01
            1.61018890606242026652950016796240e-01 1.16987071837677744645667132772360e-01
            -6.15037433807832725762843040229200e-02 1.89289058477688204584765685467573e-01
            -1.99030294450917466519968002103269e-01 2.43741813032671281092228489671312e-17
            -6.15037433807833211485416313735186e-02 -1.89289058477688204584765685467573e-01
            1.61018890606241998897374401167326e-01 -1.16987071837677786279030556215730e-01
            -0.00000000000000000000000000000000e+00 0.00000000000000000000000000000000e+00
            ];
        
    case   15
        
        % DEGREE.             :          15
        % CARDIN.             :         136
        % LEBESGUE CONST.     : 1.12194e+01
        % ABS.DET.VAND.MATRIX : 2.96279e+119
        % CONDITIONING VAND.  : 2.38705e+02
        % POINTS OUT DISK     : 0.00000e+00
        
        pts=[
            9.94869323391895155062059075135039e-01 1.01168321987432169306586615675769e-01
            9.54139256400048818562709129764698e-01 2.99363122973357931311255697437446e-01
            8.74346616144582089447112593916245e-01 4.85301962531081043650260653521400e-01
            7.58758122692790748509139575617155e-01 6.51372482722222145845591967372457e-01
            6.12105982547662907933272435911931e-01 7.90775736937698536799246085138293e-01
            4.40394151557634505600447027973132e-01 8.97804539570741577669821253948612e-01
            2.50652532258720528446360731322784e-01 9.68077118866204289204802080348600e-01
            5.06491688387129893045290884856513e-02 9.98716507171052758629059553641127e-01
            -1.51427777504576782652279121066385e-01 9.88468324328111380694394938473124e-01
            -3.47305252844820167013040190795437e-01 9.37752132147080530444327450823039e-01
            -5.28964010326962497110514505038736e-01 8.48644257494750919867954053188441e-01
            -6.88966919075686301532357447285904e-01 7.24792787229120216707656254584435e-01
            -8.20763441207276289723893114569364e-01 5.71268215094792308761384447279852e-01
            -9.18957811620230602400738462165464e-01 3.94355855113318609639350142970216e-01
            -9.79529941252494484871249369462021e-01 2.01298520088660171101224705125787e-01
            -1.00000000000000000000000000000000e+00 1.22464679914735320717376402945840e-16
            -9.79529941252494484871249369462021e-01 -2.01298520088659921301044164465566e-01
            -9.18957811620230713423040924681118e-01 -3.94355855113318387594745217938907e-01
            -8.20763441207276511768498039600672e-01 -5.71268215094792086716779522248544e-01
            -6.88966919075686745621567297348520e-01 -7.24792787229119772618446404521819e-01
            -5.28964010326962719155119430070044e-01 -8.48644257494750808845651590672787e-01
            -3.47305252844820611102250040858053e-01 -9.37752132147080308399722525791731e-01
            -1.51427777504577032452459661726607e-01 -9.88468324328111380694394938473124e-01
            5.06491688387131835935583978880459e-02 -9.98716507171052758629059553641127e-01
            2.50652532258720084357150881260168e-01 -9.68077118866204400227104542864254e-01
            4.40394151557633894977783484137035e-01 -8.97804539570741910736728641495574e-01
            6.12105982547662463844062585849315e-01 -7.90775736937698869866153472685255e-01
            7.58758122692791081576046963164117e-01 -6.51372482722221923800987042341148e-01
            8.74346616144581867402507668884937e-01 -4.85301962531081543250621734841843e-01
            9.54139256400048707540406667249044e-01 -2.99363122973358541933919241273543e-01
            9.94869323391895155062059075135039e-01 -1.01168321987431961139769498458918e-01
            9.39370671135496881909432431712048e-01 1.09796684557995016806586363600218e-01
            8.88728955107546791936101726605557e-01 3.23470885989651013581180905021029e-01
            7.90175631070832995561659117811359e-01 5.19706688230286872887120352970669e-01
            6.49023734233751814493018628127174e-01 6.87924968387365720623449760751100e-01
            4.72882799890597116387880305410363e-01 8.19057035435940328227388818049803e-01
            2.71248631404189699534157398375100e-01 9.06033525699151853771695641626138e-01
            5.49913789886909351589672212412552e-02 9.44165514073885159262999877682887e-01
            -1.64230472902075458341286662289349e-01 9.31397295196760954816284083790379e-01
            -3.74598617489218133069783789323992e-01 8.68417207052375239584307564655319e-01
            -5.64772053646278471283892486098921e-01 7.58620522494380389311174894828582e-01
            -7.24498482205471194816936986171640e-01 6.07926409207109719190498253738042e-01
            -8.45167010059523882148369011702016e-01 4.24458825843598452909333218485699e-01
            -9.20272365637941347493722332728794e-01 2.18108557311786382948426421535260e-01
            -9.45765599781194010731155685789417e-01 1.15822881451571587893922985965905e-16
            -9.20272365637941347493722332728794e-01 -2.18108557311786160903821496503951e-01
            -8.45167010059523993170671474217670e-01 -4.24458825843598230864728293454391e-01
            -7.24498482205471083794634523655986e-01 -6.07926409207109830212800716253696e-01
            -5.64772053646278693328497411130229e-01 -7.58620522494380278288872432312928e-01
            -3.74598617489218188580935020581819e-01 -8.68417207052375239584307564655319e-01
            -1.64230472902075708141467202949570e-01 -9.31397295196760843793981621274725e-01
            5.49913789886902829029402539617877e-02 -9.44165514073885159262999877682887e-01
            2.71248631404189699534157398375100e-01 -9.06033525699151853771695641626138e-01
            4.72882799890597116387880305410363e-01 -8.19057035435940328227388818049803e-01
            6.49023734233751925515321090642828e-01 -6.87924968387365609601147298235446e-01
            7.90175631070832551472449267748743e-01 -5.19706688230287427998632665548939e-01
            8.88728955107546458869194339058595e-01 -3.23470885989651679714995680114953e-01
            9.39370671135496881909432431712048e-01 -1.09796684557994836395344862012280e-01
            8.44254887454951918890344586543506e-01 1.16040163351276384706700639526389e-01
            7.81640364661535858026297773903934e-01 3.39514321986489508997664188427734e-01
            6.61055151787909522909103543497622e-01 5.37808256534639150814314234594349e-01
            4.91442502432267336320848016839591e-01 6.96215413004678596031737924931804e-01
            2.85381810871076835312010189227294e-01 8.02987457265746717993692982417997e-01
            5.81556559324926253262688646827883e-02 8.50205595244600709214921607781434e-01
            -1.73383637962181674785355767198780e-01 8.34367873655957326128884687932441e-01
            -3.92063860606566061406397238897625e-01 7.56648903857290666685742053232389e-01
            -5.81666500282579157499185384949669e-01 6.22812746297938812922723172960104e-01
            -7.28129596579811577683472023636568e-01 4.42785416524398622861724561516894e-01
            -8.20590651669980686300220895645907e-01 2.29918718015739181881329500356514e-01
            -8.52192252078229350864546631783014e-01 1.04363451376577789419413649840149e-16
            -8.20590651669980575277918433130253e-01 -2.29918718015739320659207578501082e-01
            -7.28129596579812021772681873699185e-01 -4.42785416524398012239061017680797e-01
            -5.81666500282579046476882922434015e-01 -6.22812746297938923945025635475758e-01
            -3.92063860606566561006758320218069e-01 -7.56648903857290444641137128201080e-01
            -1.73383637962181508251902073425299e-01 -8.34367873655957326128884687932441e-01
            5.81556559324924310372395552803937e-02 -8.50205595244600709214921607781434e-01
            2.85381810871076613267405264195986e-01 -8.02987457265746717993692982417997e-01
            4.91442502432267225298545554323937e-01 -6.96215413004678818076342849963112e-01
            6.61055151787909411886801080981968e-01 -5.37808256534639372858919159625657e-01
            7.81640364661535635981692848872626e-01 -3.39514321986489897575722807232523e-01
            8.44254887454951918890344586543506e-01 -1.16040163351276162662095714495081e-01
            7.24278227415366293584497725532856e-01 1.20860659962463201644311538984766e-01
            6.45791443140287246826858336135047e-01 3.49484852034093740336118116829311e-01
            4.97323135514271152946008669459843e-01 5.40236937571618724973632197361439e-01
            2.94962149391750583227178594825091e-01 6.72445968283479134086633166589309e-01
            6.06374375733209486361019457945076e-02 7.31785044257566630321321099472698e-01
            -1.80258281492964744785467701149173e-01 7.11823855871458022193110082298517e-01
            -4.01620218764066283512192967464216e-01 6.14725507616538324739963172760326e-01
            -5.79460373552304064403983829834033e-01 4.51012112162335776499588746446534e-01
            -6.94507005612053363030611308204243e-01 2.38424556181376645636049715903937e-01
            -7.34293027227214789576237308210693e-01 8.99249605430028851803926102578955e-17
            -6.94507005612053363030611308204243e-01 -2.38424556181376784413927794048504e-01
            -5.79460373552304397470891217380995e-01 -4.51012112162335443432681358899572e-01
            -4.01620218764066228001041736206389e-01 -6.14725507616538435762265635275980e-01
            -1.80258281492964911318921394922654e-01 -7.11823855871458022193110082298517e-01
            6.06374375733209278194202340728225e-02 -7.31785044257566630321321099472698e-01
            2.94962149391749972604515050988994e-01 -6.72445968283479356131238091620617e-01
            4.97323135514271208457159900717670e-01 -5.40236937571618724973632197361439e-01
            6.45791443140286913759950948588084e-01 -3.49484852034094184425327966891928e-01
            7.24278227415366293584497725532856e-01 -1.20860659962463076744221268654655e-01
            5.84122442451319501266482348000864e-01 1.24159057961747823495279874350672e-01
            4.83122365565689437794105742796091e-01 3.51008944814026113689919839089271e-01
            2.98586042644847948768216383541585e-01 5.17166196291804047824314238823717e-01
            6.24214803816719801532464373394760e-02 5.93900714123332451599424075538991e-01
            -1.84536322920841489025889359254506e-01 5.67944403064330471941900668753078e-01
            -3.99586119530477734684836832457222e-01 4.43785345102582717835559833474690e-01
            -5.45543845947361494275185123115079e-01 2.42891769309306226887201773934066e-01
            -5.97172085289695786514130304567516e-01 3.38330167779832813000151286480035e-16
            -5.45543845947361383252882660599425e-01 -2.42891769309306310153928620820807e-01
            -3.99586119530478067751744220004184e-01 -4.43785345102582440279803677185555e-01
            -1.84536322920841627803767437399074e-01 -5.67944403064330360919598206237424e-01
            6.24214803816717025974902810503409e-02 -5.93900714123332451599424075538991e-01
            2.98586042644847948768216383541585e-01 -5.17166196291804047824314238823717e-01
            4.83122365565689382282954511538264e-01 -3.51008944814026280223373532862752e-01
            5.84122442451319501266482348000864e-01 -1.24159057961747629206250564948277e-01
            4.25745236034433649496833140801755e-01 1.25010080542007906423407348484034e-01
            2.90574131765591214815458442899399e-01 3.35340424332957187658621478476562e-01
            6.31477937598797500751146571928984e-02 4.39202552800407375332980564053287e-01
            -1.84327522583603797823315062487382e-01 4.03620974010674982146440470387461e-01
            -3.73280152902831841021935588287306e-01 2.39892587822078062753661242823000e-01
            -4.43718972146937784550857486465247e-01 2.51390709632285652133791396522438e-16
            -3.73280152902831896533086819545133e-01 -2.39892587822077979486934395936260e-01
            -1.84327522583604158645798065663257e-01 -4.03620974010674815612986776613980e-01
            6.31477937598796390528121946772444e-02 -4.39202552800407430844131795311114e-01
            2.90574131765590937259702286610263e-01 -3.35340424332957409703226403507870e-01
            4.25745236034433649496833140801755e-01 -1.25010080542007934178982964112947e-01
            2.48537107508279175860366194683593e-01 1.19689162807825308365572425373102e-01
            6.13835963214803062570901204253460e-02 2.68939107615202677159516042593168e-01
            -1.71993014892566686846464563132031e-01 2.15672419030309397980360586188908e-01
            -2.75855377874385521153044464881532e-01 3.37825405541449841251914257974276e-17
            -1.71993014892566742357615794389858e-01 -2.15672419030309342469209354931081e-01
            6.13835963214800009457583485072973e-02 -2.68939107615202732670667273850995e-01
            2.48537107508279231371517425941420e-01 -1.19689162807825127954330923785164e-01
            4.74881604218978653486615826295747e-02 8.22519066087085692906555323133944e-02
            -9.49763208437957029417475496302359e-02 1.16312447316146454743656549839936e-17
            4.74881604218978653486615826295747e-02 -8.22519066087085692906555323133944e-02
            ];
        
    case   16
        
        % DEGREE.             :          16
        % CARDIN.             :         153
        % LEBESGUE CONST.     : 1.24940e+01
        % ABS.DET.VAND.MATRIX : 5.96370e+137
        % CONDITIONING VAND.  : 2.37760e+02
        % POINTS OUT DISK     : 0.00000e+00
        
        pts=[
            9.95471922573084588847791565058287e-01 9.50560433041826580158328852121485e-02
            9.59492973614497368650688713387353e-01 2.81732556841429671035115234190016e-01
            8.88835448654923476752287569979671e-01 4.58226521727410407436309469630942e-01
            7.86053094742787505921910451434087e-01 6.18158986220605166650443607068155e-01
            6.54860733945285100610078643512679e-01 7.55749574354258268904516171460273e-01
            5.00000000000000111022302462515654e-01 8.66025403784438596588302061718423e-01
            3.27067963317421550595298640473629e-01 9.45000818714668455733374230476329e-01
            1.42314838273285337866269628648297e-01 9.89821441880932684220795181317953e-01
            -4.75819158237422781820846751088538e-02 9.98867339183007962866156503878301e-01
            -2.35758935509426947874089819379151e-01 9.71811568323541763447792618535459e-01
            -4.15415013001886546106788955512457e-01 9.09631995354518330110238366614794e-01
            -5.80056909571198042741002609545831e-01 8.14575952050335727605556712660473e-01
            -7.23734038105070198731993968976894e-01 6.90079011482111925879223690571962e-01
            -8.41253532831181094486794336262392e-01 5.40640817455597777474451959278667e-01
            -9.28367933016072566232423923793249e-01 3.71662455660327573081502805507625e-01
            -9.81928697262706595694226052728482e-01 1.89251244360410492140189830934105e-01
            -1.00000000000000000000000000000000e+00 1.22464679914735320717376402945840e-16
            -9.81928697262706817738830977759790e-01 -1.89251244360409826006375055840181e-01
            -9.28367933016072677254726386308903e-01 -3.71662455660327351036897880476317e-01
            -8.41253532831181427553701723809354e-01 -5.40640817455597222362939646700397e-01
            -7.23734038105070309754296431492548e-01 -6.90079011482111814856921228056308e-01
            -5.80056909571198264785607534577139e-01 -8.14575952050335616583254250144819e-01
            -4.15415013001886379573335261738976e-01 -9.09631995354518441132540829130448e-01
            -2.35758935509426975629665435008064e-01 -9.71811568323541763447792618535459e-01
            -4.75819158237427500268701408003835e-02 -9.98867339183007962866156503878301e-01
            1.42314838273284866021484162956767e-01 -9.89821441880932795243097643833607e-01
            3.27067963317421550595298640473629e-01 -9.45000818714668566755676692991983e-01
            5.00000000000000111022302462515654e-01 -8.66025403784438596588302061718423e-01
            6.54860733945284545498566330934409e-01 -7.55749574354258712993726021522889e-01
            7.86053094742787172855003063887125e-01 -6.18158986220605610739653457130771e-01
            8.88835448654923365729985107464017e-01 -4.58226521727410629480914394662250e-01
            9.59492973614497368650688713387353e-01 -2.81732556841429782057417696705670e-01
            9.95471922573084477825489102542633e-01 -9.50560433041834351719501228217268e-02
            9.45478032748349628278106138168368e-01 1.02826932727485345631102120478317e-01
            9.01268530760395925049976995069301e-01 3.03672725092046236206044795835624e-01
            8.14916713962112737590359756723046e-01 4.90319118339295700881308448515483e-01
            6.90460297333836736655143795360345e-01 6.54038734563559320811521047289716e-01
            5.33718724593733817584961798274890e-01 7.87176226471474671519956700649345e-01
            3.52021057477385546086168233159697e-01 8.83506232913121691829871906520566e-01
            1.53863276956698991071448290313128e-01 9.38524469850402054404980844992679e-01
            -5.14889793877322324289202981617564e-02 9.49658345672506620793740239605540e-01
            -2.54433668281884128870018457746482e-01 9.16387252720407663453272562037455e-01
            -4.45481321629886406476828142331215e-01 8.40266910322381987974438288802048e-01
            -6.15698763495403200707301039074082e-01 7.24856621087276664638920919969678e-01
            -7.57126815479901016381347744754748e-01 5.75552841870402231982950524979969e-01
            -8.63152459058575627359743975830497e-01 3.99336851448706287026624295322108e-01
            -9.28818052976726593605860671232222e-01 2.04448313684302246384660861622251e-01
            -9.51053147044807478671657463564770e-01 1.16470419234744052048714571702349e-16
            -9.28818052976726593605860671232222e-01 -2.04448313684302024340055936590943e-01
            -8.63152459058575516337441513314843e-01 -3.99336851448706453560077989095589e-01
            -7.57126815479901349448255132301711e-01 -5.75552841870401676871438212401699e-01
            -6.15698763495402978662696114042774e-01 -7.24856621087276775661223382485332e-01
            -4.45481321629886961588340454909485e-01 -8.40266910322381654907530901255086e-01
            -2.54433668281884572959228307809099e-01 -9.16387252720407552430970099521801e-01
            -5.14889793877328846849472654412239e-02 -9.49658345672506509771437777089886e-01
            1.53863276956698769026843365281820e-01 -9.38524469850402165427283307508333e-01
            3.52021057477385157508109614354908e-01 -8.83506232913121913874476831551874e-01
            5.33718724593733706562659335759236e-01 -7.87176226471474782542259163164999e-01
            6.90460297333836736655143795360345e-01 -6.54038734563559320811521047289716e-01
            8.14916713962112737590359756723046e-01 -4.90319118339295700881308448515483e-01
            9.01268530760395925049976995069301e-01 -3.03672725092046125183742333319969e-01
            9.45478032748349517255803675652714e-01 -1.02826932727486025642704703386698e-01
            8.59361480129758326107491939183092e-01 1.08562601645319917187393343738222e-01
            8.05364637822763018704108617384918e-01 3.18866417409264468751928234269144e-01
            7.00763773397415357102602229133481e-01 5.09134683458734027539094313397072e-01
            5.52131343860629675290851992031094e-01 6.67412144880106694699861691333354e-01
            3.68806471392040480239415956020821e-01 7.83753646668493342275496615911834e-01
            1.62308131950567646750727135440684e-01 8.50849024392416164452868088119430e-01
            -5.43886243489131032680106159205025e-02 8.64482428709943295785933514707722e-01
            -2.67667943353183057642041831059032e-01 8.23797222687650543271331571304472e-01
            -4.64128701062738457938650071810116e-01 7.31349807449639399692387087270617e-01
            -6.31426545538561367898466869519325e-01 5.92948994093124737148059466562700e-01
            -7.59049537933804807643412004836136e-01 4.17291014723881636960811647441005e-01
            -8.38978656271741174421663345128763e-01 2.15413106210538801699172495318635e-01
            -8.66191660088464154831910946086282e-01 1.06077884397546977204847599427958e-16
            -8.38978656271741396466268270160072e-01 -2.15413106210538218832084567111451e-01
            -7.59049537933804807643412004836136e-01 -4.17291014723881803494265341214486e-01
            -6.31426545538561811987676719581941e-01 -5.92948994093124293058849616500083e-01
            -4.64128701062737958338288990489673e-01 -7.31349807449639732759294474817580e-01
            -2.67667943353183446220100449863821e-01 -8.23797222687650543271331571304472e-01
            -5.43886243489129367345569221470214e-02 -8.64482428709943295785933514707722e-01
            1.62308131950567258172668516635895e-01 -8.50849024392416275475170550635085e-01
            3.68806471392039758594449949669070e-01 -7.83753646668493675342404003458796e-01
            5.52131343860629342223944604484132e-01 -6.67412144880107027766769078880316e-01
            7.00763773397415357102602229133481e-01 -5.09134683458734249583699238428380e-01
            8.05364637822763018704108617384918e-01 -3.18866417409264413240777003011317e-01
            8.59361480129758215085189476667438e-01 -1.08562601645320264132088539099641e-01
            7.50548149285214405423971584241372e-01 1.13126931399217867113549118585070e-01
            6.83858652494920726816474143561209e-01 3.29328969893471656948946701959358e-01
            5.56405313366187148638175585801946e-01 5.16268684176310443945112638175488e-01
            3.79512920400367992357359980815090e-01 6.57335660262280185861527570523322e-01
            1.68899138991956576649755561447819e-01 7.39995478263914541194878893293208e-01
            -5.67220721175531808477821016367670e-02 7.56903450605131644657319611724233e-01
            -2.77303278198705149826253091305261e-01 7.06557229743999926085962215438485e-01
            -4.73244871086509311108869724193937e-01 5.93430298344782114483564328111243e-01
            -6.27136580377367525152010330202756e-01 4.27574480711659876686070447249222e-01
            -7.25304452358143558754477453476284e-01 2.23726794087604374805522411406855e-01
            -7.59025840800735762670115036598872e-01 9.29538566406749521966765959634022e-17
            -7.25304452358143669776779915991938e-01 -2.23726794087603875205161330086412e-01
            -6.27136580377367414129707867687102e-01 -4.27574480711660043219524141022703e-01
            -4.73244871086509477642323417967418e-01 -5.93430298344781892438959403079934e-01
            -2.77303278198704983292799397531780e-01 -7.06557229743999926085962215438485e-01
            -5.67220721175537012648248946788954e-02 -7.56903450605131644657319611724233e-01
            1.68899138991956410116301867674338e-01 -7.39995478263914541194878893293208e-01
            3.79512920400367381734696436978993e-01 -6.57335660262280518928434958070284e-01
            5.56405313366187259660478048317600e-01 -5.16268684176310221900507713144179e-01
            6.83858652494920615794171681045555e-01 -3.29328969893471823482400395732839e-01
            7.50548149285214294401669121725718e-01 -1.13126931399218505491788278050080e-01
            6.23403286614352181160825239203405e-01 1.16534270731812189536569235315255e-01
            5.39209218360223063726266445883084e-01 3.33864213194419501284926354855997e-01
            3.82191957305122287369414380009403e-01 5.06103943659650834518970441422425e-01
            1.73557554617220582970915643272747e-01 6.09991532114882661907984129356919e-01
            -5.85167575373465587151855515912757e-02 6.31496384078235939441015034390148e-01
            -2.82688057333947695415332646007300e-01 5.67714150129561390123456021683523e-01
            -4.68680768558999150119603882558295e-01 4.27258974393186274909339772420935e-01
            -5.91375544940365371893165047367802e-01 2.29100106641305062415980842160934e-01
            -6.34201777052517789989849461562699e-01 7.76673176280929191623354311262181e-17
            -5.91375544940365593937769972399110e-01 -2.29100106641304673837922223356145e-01
            -4.68680768558998983586150188784814e-01 -4.27258974393186330420491003678762e-01
            -2.82688057333948361549147421101225e-01 -5.67714150129561057056548634136561e-01
            -5.85167575373465725929733594057325e-02 -6.31496384078235939441015034390148e-01
            1.73557554617220444193037565128179e-01 -6.09991532114882661907984129356919e-01
            3.82191957305122176347111917493748e-01 -5.06103943659651056563575366453733e-01
            5.39209218360222841681661520851776e-01 -3.33864213194419778840682511145133e-01
            6.23403286614352181160825239203405e-01 -1.16534270731812009125327733727318e-01
            4.79989177254803278671602129179519e-01 1.18306706688240975688941603038984e-01
            3.70029441242381129661964678234654e-01 3.27817479312820736492284368068795e-01
            1.75300419579510202705563415293000e-01 4.62229218055726254199555569357472e-01
            -5.95878156099545336354950109125639e-02 4.90749813408007828918755421909736e-01
            -2.80825200354203607933101238813833e-01 4.06845540684891704419356983635225e-01
            -4.37728916007844359725709182384890e-01 2.29737857611143375669016108986398e-01
            -4.94354212209383803156015346758068e-01 -1.58996441123392109112954634265671e-16
            -4.37728916007844637281465338674025e-01 -2.29737857611142903824230643294868e-01
            -2.80825200354203718955403701329487e-01 -4.06845540684891648908205752377398e-01
            -5.95878156099548736412963023667544e-02 -4.90749813408007828918755421909736e-01
            1.75300419579510202705563415293000e-01 -4.62229218055726254199555569357472e-01
            3.70029441242380963128510984461172e-01 -3.27817479312820903025738061842276e-01
            4.79989177254803278671602129179519e-01 -1.18306706688241003444517218667897e-01
            3.20658341791754564198413390840869e-01 1.16710091781356897766563918139582e-01
            1.70618739946884562241891103440139e-01 2.95520326311385583828439393982990e-01
            -5.92552665352087670758152171401889e-02 3.36053315817731235171095249825157e-01
            -2.61403075256545769367022558071767e-01 2.19343224036374406793470370757859e-01
            -3.41237479893769068972630975622451e-01 4.17895387501013564145680843663512e-17
            -2.61403075256545880389325020587421e-01 -2.19343224036374212504441061355465e-01
            -5.92552665352087809536030249546457e-02 -3.36053315817731235171095249825157e-01
            1.70618739946884312441710562779917e-01 -2.95520326311385750361893087756471e-01
            3.20658341791754564198413390840869e-01 -1.16710091781356856133200494696212e-01
            1.42489165327715411324405181403563e-01 1.03524438390572182111526444714400e-01
            -5.44260181265842218900630200550950e-02 1.67506059982190258494938461808488e-01
            -1.76126294402262351113108707068022e-01 2.15692502685414973686188995342844e-17
            -5.44260181265842635234264434984652e-02 -1.67506059982190230739362846179574e-01
            1.42489165327715411324405181403563e-01 -1.03524438390572209867102060343313e-01
            -0.00000000000000000000000000000000e+00 0.00000000000000000000000000000000e+00
            ];
        
    case   17
        
        % DEGREE.             :          17
        % CARDIN.             :         171
        % LEBESGUE CONST.     : 1.42143e+01
        % ABS.DET.VAND.MATRIX : 2.75326e+157
        % CONDITIONING VAND.  : 2.97516e+02
        % POINTS OUT DISK     : 0.00000e+00
        
        pts=[
            9.95974293995238846299855595134431e-01 8.96393089034334816789240107937076e-02
            9.63962860695853240855512922280468e-01 2.66036845566675117513710802086280e-01
            9.00968867902419145998749172576936e-01 4.33883739117558120401696442058892e-01
            8.09016994374947451262869435595348e-01 5.87785252292473137103456792829093e-01
            6.91062648986864647149275242554722e-01 7.22794863827391442789860320772277e-01
            5.50896981452102640908208286418812e-01 8.34573253721302532603942836431088e-01
            3.93025031653923662133820471353829e-01 9.19527772551450572890985313279089e-01
            2.22520933956314448387558968533995e-01 9.74927912181823619341969333618181e-01
            4.48648303505149864678358540004410e-02 9.98993066541314589379396693402668e-01
            -1.34233265817655406104691451218969e-01 9.90949761767934811373947923129890e-01
            -3.09016994374947340240566973079694e-01 9.51056516295153642204240895807743e-01
            -4.73868662472998580792449274667888e-01 8.80595531856738000797690801846329e-01
            -6.23489801858733483364005678595277e-01 7.81831482468029914656426626606844e-01
            -7.53071466003610856532191064616200e-01 6.57938725939712698576045113441069e-01
            -8.58448793601866100289043970406055e-01 5.12899277405906239835076121380553e-01
            -9.36234870639737204456309882516507e-01 3.51374824081342795878413198806811e-01
            -9.83929588598629667473005611100234e-01 1.78556894798636761612087298090046e-01
            -1.00000000000000000000000000000000e+00 1.22464679914735320717376402945840e-16
            -9.83929588598629667473005611100234e-01 -1.78556894798636511811906757429824e-01
            -9.36234870639737204456309882516507e-01 -3.51374824081342573833808273775503e-01
            -8.58448793601866433355951357953018e-01 -5.12899277405905684723563808802282e-01
            -7.53071466003611078576795989647508e-01 -6.57938725939712476531440188409761e-01
            -6.23489801858733705408610603626585e-01 -7.81831482468029692611821701575536e-01
            -4.73868662472998802837054199699196e-01 -8.80595531856737889775388339330675e-01
            -3.09016994374947562285171898111003e-01 -9.51056516295153531181938433292089e-01
            -1.34233265817655655904871991879190e-01 -9.90949761767934700351645460614236e-01
            4.48648303505147436065492172474478e-02 -9.98993066541314700401699155918323e-01
            2.22520933956314226342954043502687e-01 -9.74927912181823619341969333618181e-01
            3.93025031653923440089215546322521e-01 -9.19527772551450683913287775794743e-01
            5.50896981452102307841300898871850e-01 -8.34573253721302754648547761462396e-01
            6.91062648986864536126972780039068e-01 -7.22794863827391664834465245803585e-01
            8.09016994374947118195962048048386e-01 -5.87785252292473248125759255344747e-01
            9.00968867902419034976446710061282e-01 -4.33883739117558342446301367090200e-01
            9.63962860695853240855512922280468e-01 -2.66036845566675339558315727117588e-01
            9.95974293995238957322158057650086e-01 -8.96393089034337453568923592683859e-02
            9.50688059098072635322296264348552e-01 9.66755265350101450350095433350361e-02
            9.11766778257493526460564225999406e-01 2.86068672189795092375419471864006e-01
            8.35517658387004980014012289757375e-01 4.63750132793488034632645167221199e-01
            7.25062347412996133222407024732092e-01 6.22445608472288691714879860228393e-01
            5.84922898744690611394503321207594e-01 7.55658087805979983286874812620226e-01
            4.20836637876255137413750162522774e-01 8.57933836238839342414053135144059e-01
            2.39521275606960126758337992214365e-01 9.25085672613135012731788719975157e-01
            4.83998841717616715141225824936555e-02 9.54364392857697585448306654143380e-01
            -1.44703004208174251798979526029143e-01 9.44571322725611284276681089977501e-01
            -3.31881734593945876277132356335642e-01 8.96107391658720553451189516636077e-01
            -5.05473187770993592771162639110116e-01 8.10956718689173738923159362457227e-01
            -6.58370509250118751687352869339520e-01 6.92605382373123856787344720942201e-01
            -7.84314064725294191049442815710790e-01 5.45898700325040842074031388619915e-01
            -8.78147710237626277773870242526755e-01 3.76842861345277113649387956684222e-01
            -9.36029885314855092381947088142624e-01 1.92359031344881609149055634588876e-01
            -9.55590886908451953019039137871005e-01 1.17026132094681597131383591722197e-16
            -9.36029885314855092381947088142624e-01 -1.92359031344881359348875093928655e-01
            -8.78147710237626388796172705042409e-01 -3.76842861345276891604783031652914e-01
            -7.84314064725294413094047740742099e-01 -5.45898700325040620029426463588607e-01
            -6.58370509250119195776562719402136e-01 -6.92605382373123523720437333395239e-01
            -5.05473187770993814815767564141424e-01 -8.10956718689173627900856899941573e-01
            -3.31881734593946264855190975140431e-01 -8.96107391658720331406584591604769e-01
            -1.44703004208174501599160066689365e-01 -9.44571322725611284276681089977501e-01
            4.83998841717618588642579879888217e-02 -9.54364392857697585448306654143380e-01
            2.39521275606959682669128142151749e-01 -9.25085672613135123754091182490811e-01
            4.20836637876254582302237849944504e-01 -8.57933836238839564458658060175367e-01
            5.84922898744690167305293471144978e-01 -7.55658087805980316353782200167188e-01
            7.25062347412996244244709487247746e-01 -6.22445608472288358647972472681431e-01
            8.35517658387004757969407364726067e-01 -4.63750132793488534233006248541642e-01
            9.11766778257493415438261763483752e-01 -2.86068672189795647486931784442277e-01
            9.50688059098072635322296264348552e-01 -9.66755265350099507459802339326416e-02
            8.72290947955634110577705087052891e-01 1.01956189391891785533950098852074e-01
            8.25265517167249607055623528140131e-01 3.00372083615182472460247709022951e-01
            7.33749808736361419647664661169983e-01 4.82594841062362722716727603256004e-01
            6.02677458192437009998343455663417e-01 6.38800785712852370323844297672622e-01
            4.39114609880112749529246229940327e-01 7.60568814658141523210588275105692e-01
            2.51878979288571169803390148445033e-01 8.41334381939310538278675721812760e-01
            5.10644877271388408779273504478624e-02 8.76743394918843343965875192225212e-01
            -1.52502903585212984394203772353649e-01 8.64886944541732205493644869420677e-01
            -3.47848823891381220274610086562461e-01 8.06404215116734657264885299809976e-01
            -5.24442124064252612747338844201295e-01 7.04448025724842996631025471288012e-01
            -6.72762613582036483883541677641915e-01 5.64514860926549455477641004108591e-01
            -7.84814296463500316036743242875673e-01 3.94148553856480787782601282742689e-01
            -8.54556437481008068779431141592795e-01 2.02533596226458334488285117913620e-01
            -8.78229219760225277013887534849346e-01 1.07552060289703735319766800828098e-16
            -8.54556437481008068779431141592795e-01 -2.02533596226458112443680192882312e-01
            -7.84814296463500427059045705391327e-01 -3.94148553856480565737996357711381e-01
            -6.72762613582036483883541677641915e-01 -5.64514860926549566499943466624245e-01
            -5.24442124064252834791943769232603e-01 -7.04448025724842885608723008772358e-01
            -3.47848823891381275785761317820288e-01 -8.06404215116734657264885299809976e-01
            -1.52502903585213206438808697384957e-01 -8.64886944541732094471342406905023e-01
            5.10644877271382302552638066117652e-02 -8.76743394918843454988177654740866e-01
            2.51878979288571169803390148445033e-01 -8.41334381939310538278675721812760e-01
            4.39114609880112749529246229940327e-01 -7.60568814658141523210588275105692e-01
            6.02677458192437121020645918179071e-01 -6.38800785712852259301541835156968e-01
            7.33749808736361086580757273623021e-01 -4.82594841062363277828239915834274e-01
            8.25265517167249273988716140593169e-01 -3.00372083615183083082911252859049e-01
            8.72290947955634110577705087052891e-01 -1.01956189391891619000496405078593e-01
            7.73048213755580415629253820952727e-01 1.06253031324496136078572305905254e-01
            7.15714764201589970227246340073179e-01 3.10878792715425289472364056564402e-01
            6.05300024763949284789532612194307e-01 4.92448096226495990457294738007477e-01
            4.49992951552925457558984589923057e-01 6.37494777240585897004621074302122e-01
            2.61311959705996299518915293447208e-01 7.35261386971293173786534680402838e-01
            5.32506552303452160290753170102107e-02 7.78497023227370354980791944399243e-01
            -1.58760006738202757992084457328019e-01 7.63995096657579142451766074373154e-01
            -3.58996165285682011791834611358354e-01 6.92831148813701336308668032870628e-01
            -5.32607220552099636101672786026029e-01 5.70283084153918151670836778066587e-01
            -6.66717234786075252372938848566264e-01 4.05439732013954501343988567896304e-01
            -7.51379881744367650320270968222758e-01 2.10526769713872685674260765154031e-01
            -7.80316120207917962581234405661235e-01 9.55611638935708050256450562974619e-17
            -7.51379881744367650320270968222758e-01 -2.10526769713872824452138843298599e-01
            -6.66717234786075585439846236113226e-01 -4.05439732013953946232476255318034e-01
            -5.32607220552099525079370323510375e-01 -5.70283084153918262693139240582241e-01
            -3.58996165285682455881044461420970e-01 -6.92831148813701114264063107839320e-01
            -1.58760006738202619214206379183452e-01 -7.63995096657579142451766074373154e-01
            5.32506552303450356178338154222729e-02 -7.78497023227370354980791944399243e-01
            2.61311959705996077474310368415900e-01 -7.35261386971293173786534680402838e-01
            4.49992951552925402047833358665230e-01 -6.37494777240586119049225999333430e-01
            6.05300024763949062744927687162999e-01 -4.92448096226496268013050894296612e-01
            7.15714764201589859204943877557525e-01 -3.10878792715425622539271444111364e-01
            7.73048213755580415629253820952727e-01 -1.06253031324495941789542996502860e-01
            6.57017039750419695742778003477724e-01 1.09636752873533832586261382857629e-01
            5.85819048823696841843400306970580e-01 3.17029415257253643911639073849074e-01
            4.51138474037816927797450716752792e-01 4.90067021279627645924392709275708e-01
            2.67570045455265970169023148628185e-01 6.09998261373033701104873216536362e-01
            5.50062506706092968489230088380282e-02 6.63826724748423413480225008242996e-01
            -1.63518324884127125296018334665860e-01 6.45719262164406893056423086818540e-01
            -3.64323152689436380313736663083546e-01 5.57638098158193096232082552887732e-01
            -5.25647913844676240024966773489723e-01 4.09128193569933296114271570331766e-01
            -6.30010567267092924659266373055289e-01 2.16282900930361815516889123500732e-01
            -6.66101800104951680125964230683167e-01 8.15739437404819170143445467524139e-17
            -6.30010567267092924659266373055289e-01 -2.16282900930361926539191586016386e-01
            -5.25647913844676573091874161036685e-01 -4.09128193569933018558515414042631e-01
            -3.64323152689436324802585431825719e-01 -5.57638098158193207254385015403386e-01
            -1.63518324884127264073896412810427e-01 -6.45719262164406893056423086818540e-01
            5.50062506706092829711352010235714e-02 -6.63826724748423413480225008242996e-01
            2.67570045455265415057510836049914e-01 -6.09998261373033923149478141567670e-01
            4.51138474037816983308601948010619e-01 -4.90067021279627645924392709275708e-01
            5.85819048823696619798795381939271e-01 -3.17029415257254032489697692653863e-01
            6.57017039750419806765080465993378e-01 -1.09636752873533721563958920341975e-01
            5.26243970009007910881848602002719e-01 1.11856608864696949190431496390374e-01
            4.35251606818068625948114913626341e-01 3.16228802735994962702648081176449e-01
            2.69000286671571942065384064335376e-01 4.65922163765755570352666836697608e-01
            5.62363731686753021143942987691844e-02 5.35053349910441067294186723302118e-01
            -1.66251320146496711638306464919879e-01 5.11668951048525610936223984026583e-01
            -3.59992649862511004954512827680446e-01 3.99812342183828717256943718894036e-01
            -4.91487979986743983573660443653353e-01 2.18824547174446049080387410867843e-01
            -5.38000573343143773108465666155098e-01 3.04806317523249593838597691423860e-16
            -4.91487979986743928062509212395526e-01 -2.18824547174446132347114257754583e-01
            -3.59992649862511282510268983969581e-01 -3.99812342183828495212338793862727e-01
            -1.66251320146496822660608927435533e-01 -5.11668951048525610936223984026583e-01
            5.62363731686750523142137581089628e-02 -5.35053349910441178316489185817773e-01
            2.69000286671571942065384064335376e-01 -4.65922163765755570352666836697608e-01
            4.35251606818068570436963682368514e-01 -3.16228802735995073724950543692103e-01
            5.26243970009007910881848602002719e-01 -1.11856608864696768779189994802437e-01
            3.81515413120827096005172052173293e-01 1.12023032756600582349193473419291e-01
            2.60386965114059620862718702483107e-01 3.00502576886507333231435268317000e-01
            5.65874954899572776834126841549732e-02 3.93574676104695320155713034182554e-01
            -1.65178104124069385916229180111259e-01 3.61689596525418266548257406611810e-01
            -3.34500822771417460899101570248604e-01 2.14970625625889977250437823386164e-01
            -3.97621893658714142816279490943998e-01 2.25274230507989334520514750741304e-16
            -3.34500822771417516410252801506431e-01 -2.14970625625889893983710976499424e-01
            -1.65178104124069718983136567658221e-01 -3.61689596525418100014803712838329e-01
            5.65874954899571736000041255465476e-02 -3.93574676104695375666864265440381e-01
            2.60386965114059398818113777451799e-01 -3.00502576886507555276040193348308e-01
            3.81515413120827096005172052173293e-01 -1.12023032756600623982556896862661e-01
            2.21761119888155028290199766161095e-01 1.06794526776468917672602287893824e-01
            5.47704735099182465907219352629909e-02 2.39965123455384565787085193733219e-01
            -1.53463456535339159980679824002436e-01 1.92437087775939597023011629062239e-01
            -2.46136273725468202044908139214385e-01 3.01429999771951380221723677492566e-17
            -1.53463456535339215491831055260263e-01 -1.92437087775939541511860397804412e-01
            5.47704735099179690349657789738558e-02 -2.39965123455384621298236424991046e-01
            2.21761119888155083801350997418922e-01 -1.06794526776468765016936401934800e-01
            4.22218381387292132633781704953435e-02 7.31303688452283467968939589809452e-02
            -8.44436762774584126489685331762303e-02 1.03413677861424722860435019887563e-17
            4.22218381387292132633781704953435e-02 -7.31303688452283467968939589809452e-02
            ];
        
    case   18
        
        % DEGREE.             :          18
        % CARDIN.             :         190
        % LEBESGUE CONST.     : 1.59992e+01
        % ABS.DET.VAND.MATRIX : 4.26516e+178
        % CONDITIONING VAND.  : 3.21053e+02
        % POINTS OUT DISK     : 0.00000e+00
        
        pts=[
            9.96397488542526521548836626607226e-01 8.48059244755091923284595623044879e-02
            9.67732946933498872077450414508348e-01 2.51978061385125184923339247689000e-01
            9.11228490388135692334969917283161e-01 4.11901248243992657016576686146436e-01
            8.28509649243842183352626307168975e-01 5.59974786137595437196523562306538e-01
            7.21956093954524535938332974183140e-01 6.91938868977546084337859610968735e-01
            5.94633176304286692470668640453368e-01 8.03997130366940426782207396172453e-01
            4.50203744817673279232650429548812e-01 8.92925858149568485444547150109429e-01
            2.92822771276550430918916845257627e-01 9.56166734739250956387479618570069e-01
            1.27017819746878646292032044584630e-01 9.91900435258876944644157447328325e-01
            -4.24412031961481153730098014875693e-02 9.99098966204681526726005813543452e-01
            -2.10679269995726226039067796591553e-01 9.77555238947686033768036395485979e-01
            -3.72856477780308503966466560086701e-01 9.27889027296509349973518965271069e-01
            -5.24307283557231551540667169319931e-01 8.51529137733311403124503158323932e-01
            -6.60674723390081264362549973157002e-01 7.50672305252724436641642569156829e-01
            -7.78035754318439631838089098891942e-01 6.28219997295642151868833025218919e-01
            -8.73014113161187932377060860744677e-01 4.87694943813634873563955807185266e-01
            -9.42877445461083985023265086056199e-01 3.33139794742057515630762054570368e-01
            -9.85615910347708457095450285123661e-01 1.69000820321849126726121426145255e-01
            -1.00000000000000000000000000000000e+00 1.22464679914735320717376402945840e-16
            -9.85615910347708457095450285123661e-01 -1.69000820321848876925940885485034e-01
            -9.42877445461084207067870011087507e-01 -3.33139794742057349097308360796887e-01
            -8.73014113161188265443968248291640e-01 -4.87694943813634262941292263349169e-01
            -7.78035754318439520815786636376288e-01 -6.28219997295642373913437950250227e-01
            -6.60674723390081486407154898188310e-01 -7.50672305252724325619340106641175e-01
            -5.24307283557232106652179481898202e-01 -8.51529137733311070057595770776970e-01
            -3.72856477780308726011071485118009e-01 -9.27889027296509238951216502755415e-01
            -2.10679269995726087261189718446985e-01 -9.77555238947686255812641320517287e-01
            -4.24412031961485802789013632718707e-02 -9.99098966204681415703703351027798e-01
            1.27017819746877952402641653861792e-01 -9.91900435258876944644157447328325e-01
            2.92822771276549986829706995195011e-01 -9.56166734739251067409782081085723e-01
            4.50203744817673279232650429548812e-01 -8.92925858149568485444547150109429e-01
            5.94633176304286914515273565484677e-01 -8.03997130366940315759904933656799e-01
            7.21956093954524313893728049151832e-01 -6.91938868977546306382464536000043e-01
            8.28509649243841739263416457106359e-01 -5.59974786137595992308035874884808e-01
            9.11228490388135581312667454767507e-01 -4.11901248243992934572332842435571e-01
            9.67732946933498872077450414508348e-01 -2.51978061385125129412188016431173e-01
            9.96397488542526410526534164091572e-01 -8.48059244755096225398816045526473e-02
            9.55143947806655901899830496404320e-01 9.12051886202463607533630352008913e-02
            9.20622556929640789569191383634461e-01 2.70319172711202260206420078247902e-01
            8.52827468186512560599510379688581e-01 4.39663117590640639686938584418385e-01
            7.54208972722828718815435422584414e-01 5.93116491869273509962567914044484e-01
            6.28331399912630317317052686121315e-01 7.25133090781804545699174013861921e-01
            4.79744293208095140546021184491110e-01 8.30941490477641209189130222512176e-01
            3.13817977785455115569135386976996e-01 9.06717499710679497582077601691708e-01
            1.36549463000883247731920278056350e-01 9.49722376074771168497079543158179e-01
            -4.56543051526966253694794772854948e-02 9.58401811290005345433939965005266e-01
            -2.26208007766925789372436383928289e-01 9.32442107953655785479440964991227e-01
            -3.98585963601243320475475684361299e-01 8.72781517381645111086641009023879e-01
            -5.56557984205412581424354812043021e-01 7.81576328761398819722217012895271e-01
            -6.94414549162714833663301305932691e-01 6.62122935242453358739567192969844e-01
            -8.07173163033815921352243094588630e-01 5.18738693699364983302757536876015e-01
            -8.90758435723711716747175159980543e-01 3.56605884205497603023360397855868e-01
            -9.42149377698085377375036841840483e-01 1.81584408928875229438659744118922e-01
            -9.59488586416190059047437443950912e-01 1.17503462617300563777639716785741e-16
            -9.42149377698085599419641766871791e-01 -1.81584408928874591060420584653912e-01
            -8.90758435723711827769477622496197e-01 -3.56605884205497380978755472824560e-01
            -8.07173163033816254419150482135592e-01 -5.18738693699364428191245224297745e-01
            -6.94414549162714944685603768448345e-01 -6.62122935242453247717264730454190e-01
            -5.56557984205412803468959737074329e-01 -7.81576328761398708699914550379617e-01
            -3.98585963601243153942021990587818e-01 -8.72781517381645222108943471539533e-01
            -2.26208007766925817128011999557202e-01 -9.32442107953655785479440964991227e-01
            -4.56543051526970763975832312553393e-02 -9.58401811290005345433939965005266e-01
            1.36549463000882803642710427993734e-01 -9.49722376074771279519382005673833e-01
            3.13817977785455115569135386976996e-01 -9.06717499710679608604380064207362e-01
            4.79744293208095140546021184491110e-01 -8.30941490477641209189130222512176e-01
            6.28331399912629762205540373543045e-01 -7.25133090781804989788383863924537e-01
            7.54208972722828385748528035037452e-01 -5.93116491869273954051777764107101e-01
            8.52827468186512449577207917172927e-01 -4.39663117590640806220392278191866e-01
            9.20622556929640789569191383634461e-01 -2.70319172711202371228722540763556e-01
            9.55143947806655790877528033888666e-01 -9.12051886202471101539046571815561e-02
            8.83403067269652231274790210591163e-01 9.60758733921513036202455282364099e-02
            8.42096121676113473775160400691675e-01 2.83735219117300818680860174936242e-01
            7.61413697355617258288873472338310e-01 4.58127421345571717026246005843859e-01
            6.45128414797315752338136007892899e-01 6.11098094523781720788235816144152e-01
            4.98677644571826506059153416572371e-01 7.35494499988809891100061122415354e-01
            3.28909261926552953791969002850237e-01 8.25500000077785900387539186340291e-01
            1.43761447749982257393597251393658e-01 8.76906037640478031036650463647675e-01
            -4.81084919440038158433559090099152e-02 8.87308923494161794209844629222061e-01
            -2.37728932023437311560343232486048e-01 8.56222230258295913252197806286858e-01
            -4.16233431458185310081177021857002e-01 7.85099537158211790988104894495336e-01
            -5.75275318248181455338396972365445e-01 6.77266462276073455406333323480794e-01
            -7.07417970529486073161251624696888e-01 5.37765160345515025319684809801402e-01
            -8.06482544747435969867410676670261e-01 3.73118557200247502603218663352891e-01
            -8.67836891513965036359934401843930e-01 1.91025345011788555416032409084437e-01
            -8.88612149764729686296504951315001e-01 1.08823602489282465203862895556338e-16
            -8.67836891513965036359934401843930e-01 -1.91025345011788333371427484053129e-01
            -8.06482544747435858845108214154607e-01 -3.73118557200247613625521125868545e-01
            -7.07417970529486517250461474759504e-01 -5.37765160345514581230474959738785e-01
            -5.75275318248181233293792047334136e-01 -6.77266462276073566428635785996448e-01
            -4.16233431458185865192689334435272e-01 -7.85099537158211568943499969464028e-01
            -2.37728932023437700138401851290837e-01 -8.56222230258295802229895343771204e-01
            -4.81084919440044264660194528460124e-02 -8.87308923494161683187542166706407e-01
            1.43761447749982063104567941991263e-01 -8.76906037640478142058952926163329e-01
            3.28909261926552565213910384045448e-01 -8.25500000077786122432144111371599e-01
            4.98677644571826395036850954056717e-01 -7.35494499988810002122363584931009e-01
            6.45128414797315752338136007892899e-01 -6.11098094523781720788235816144152e-01
            7.61413697355617258288873472338310e-01 -4.58127421345571717026246005843859e-01
            8.42096121676113473775160400691675e-01 -2.83735219117300707658557712420588e-01
            8.83403067269652120252487748075509e-01 -9.60758733921519558762724955158774e-02
            7.92427337399524756023083682521246e-01 1.00106852997386419623637721088016e-01
            7.42636213446827286865925543679623e-01 2.94030477251081778788943665858824e-01
            6.46182524978324845932320386054926e-01 4.69479085250639416315721064165700e-01
            5.09126811972345771906134359596763e-01 6.15428595700602931728440125880297e-01
            3.40080788932708877325694629689679e-01 7.22708464094649283282478791079484e-01
            1.49666239194778227794557778906892e-01 7.84577901753823248043318017153069e-01
            -5.01523907856848347175393598718074e-02 7.97149424370124259908720887324307e-01
            -2.46819761605491932998646120722697e-01 7.59633116942744046617974618129665e-01
            -4.27978539064040930384180683176965e-01 6.74386267042671794236241566977696e-01
            -5.82245850918231444559580722852843e-01 5.46765247765112705202739107335219e-01
            -6.99928514608780139027999211975839e-01 3.84788957108552098773657235142309e-01
            -7.73632095569447453264899650093867e-01 1.98634961122069075845075758479652e-01
            -7.98725526745665326266987449344015e-01 9.78156659726362678115434863375596e-17
            -7.73632095569447564287202112609521e-01 -1.98634961122068548489139061530295e-01
            -6.99928514608780139027999211975839e-01 -3.84788957108552209795959697657963e-01
            -5.82245850918231777626488110399805e-01 -5.46765247765112372135831719788257e-01
            -4.27978539064040486294970833114348e-01 -6.74386267042672016280846492009005e-01
            -2.46819761605492293821129123898572e-01 -7.59633116942743935595672155614011e-01
            -5.01523907856846751229795700055547e-02 -7.97149424370124259908720887324307e-01
            1.49666239194777839216499160102103e-01 -7.84577901753823359065620479668723e-01
            3.40080788932708211191879854595754e-01 -7.22708464094649505327083716110792e-01
            5.09126811972345438839226972049801e-01 -6.15428595700603264795347513427259e-01
            6.46182524978324734910017923539272e-01 -4.69479085250639582849174757939181e-01
            7.42636213446827286865925543679623e-01 -2.94030477251081778788943665858824e-01
            7.92427337399524645000781220005592e-01 -1.00106852997386724934969493006065e-01
            6.85985940602537591637144487322075e-01 1.03395744186801336050862687443441e-01
            6.25033079380285960802154932025587e-01 3.01000066944656974321503639657749e-01
            5.08543286142605244215531001827912e-01 4.71859212837442754118200127777527e-01
            3.46867190225701116368384191446239e-01 6.00791596949572848096465804701438e-01
            1.54370422255651174037183182008448e-01 6.76341011142236436803898413927527e-01
            -5.18428351752531837992599150766182e-02 6.91794558421271688075648853555322e-01
            -2.53449629192301684188493027249933e-01 6.45779123294161205848240570048802e-01
            -4.32536311410235962959802691329969e-01 5.42383379107360008575255960749928e-01
            -5.73190244205032617408335227082716e-01 3.90794491476614547220691520124092e-01
            -6.62913708398256251719260490062879e-01 2.04481798304793876974727595552395e-01
            -6.93734380451402121714465920376824e-01 8.49579588478281709879509668536234e-17
            -6.62913708398256362741562952578533e-01 -2.04481798304793405129942129860865e-01
            -5.73190244205032617408335227082716e-01 -3.90794491476614713754145213897573e-01
            -4.32536311410236073982105153845623e-01 -5.42383379107359786530651035718620e-01
            -2.53449629192301573166190564734279e-01 -6.45779123294161205848240570048802e-01
            -5.18428351752536556440453807681479e-02 -6.91794558421271688075648853555322e-01
            1.54370422255651007503729488234967e-01 -6.76341011142236436803898413927527e-01
            3.46867190225700616768023110125796e-01 -6.00791596949573181163373192248400e-01
            5.08543286142605355237833464343566e-01 -4.71859212837442587584746434004046e-01
            6.25033079380285849779852469509933e-01 -3.01000066944657140854957333431230e-01
            6.85985940602537480614842024806421e-01 -1.03395744186801918917950615650625e-01
            5.66055574032251040961227772640996e-01 1.05814125350180712747949485219578e-01
            4.89606632136979968983325761655578e-01 3.03151592085690591016344797026250e-01
            3.47033601567604987891968448820990e-01 4.59546756489066898776485459165997e-01
            1.57591760126955277021565393624769e-01 5.53877584992111038353357344021788e-01
            -5.31337217649281642883885012906831e-02 5.73404176500321827170125743577955e-01
            -2.56683200108341669221090342034586e-01 5.15489356629936668063862725830404e-01
            -4.25566189946411876920961958603584e-01 3.87954842721546011574673684663139e-01
            -5.36974107688554247452827894449001e-01 2.08024877571616306770607707221643e-01
            -5.75860696711109953938034777820576e-01 7.05225958982025598348309647454561e-17
            -5.36974107688554358475130356964655e-01 -2.08024877571615973703700319674681e-01
            -4.25566189946411710387508264830103e-01 -3.87954842721546067085824915920966e-01
            -2.56683200108342279843753885870683e-01 -5.15489356629936334996955338283442e-01
            -5.31337217649281781661763091051398e-02 -5.73404176500321827170125743577955e-01
            1.57591760126955165999262931109115e-01 -5.53877584992111038353357344021788e-01
            3.47033601567604876869665986305336e-01 -4.59546756489067009798787921681651e-01
            4.89606632136979802449872067882097e-01 -3.03151592085690813060949722057558e-01
            5.66055574032251040961227772640996e-01 -1.05814125350180546214495791446097e-01
            4.33610282045744532819497862874414e-01 1.06875335707328156242823524735286e-01
            3.34275391999440174561897265448351e-01 2.96142155698854936396458015224198e-01
            1.58362038101241636711691285199777e-01 4.17566376719636200842700191060430e-01
            -5.38301502565048523019086701424385e-02 4.43331173054305249792150789289735e-01
            -2.53690499914121569968727953892085e-01 3.67534140362044903227456416061614e-01
            -3.95433413343363127090412945108255e-01 2.07539465379385529297806556314754e-01
            -4.46587297264873228641590685583651e-01 -1.43633429557903147434380487008390e-16
            -3.95433413343363349135017870139563e-01 -2.07539465379385085208596706252138e-01
            -2.53690499914121625479879185149912e-01 -3.67534140362044847716305184803787e-01
            -5.38301502565051645521343459677155e-02 -4.43331173054305249792150789289735e-01
            1.58362038101241636711691285199777e-01 -4.17566376719636200842700191060430e-01
            3.34275391999440008028443571674870e-01 -2.96142155698855102929911708997679e-01
            4.33610282045744532819497862874414e-01 -1.06875335707328183998399140364199e-01
            2.88479519274484730306795654541929e-01 1.04997958211335645772877001036250e-01
            1.53496746113221588236896764101402e-01 2.65864163064600311781049413184519e-01
            -5.33088604807287827491713017025177e-02 3.02329571268894203850408075595624e-01
            -2.35170658793755898985367025488813e-01 1.97331613057558613588682305817201e-01
            -3.06993492226443120962642296944978e-01 3.75958597614181433771242250618142e-17
            -2.35170658793756037763245103633380e-01 -1.97331613057558447055228612043720e-01
            -5.33088604807287896880652056097460e-02 -3.02329571268894203850408075595624e-01
            1.53496746113221366192291839070094e-01 -2.65864163064600478314503106958000e-01
            2.88479519274484730306795654541929e-01 -1.04997958211335604139513577592879e-01
            1.27751620007384186772370071594196e-01 9.28169849569451532733665999330697e-02
            -4.87967767249596548473355994701706e-02 1.50181036393624955938008724842803e-01
            -1.57909686564849049972281136433594e-01 1.93383592206004179891163343672220e-17
            -4.87967767249596895418051190063125e-02 -1.50181036393624955938008724842803e-01
            1.27751620007384186772370071594196e-01 -9.28169849569451949067300233764399e-02
            -0.00000000000000000000000000000000e+00 0.00000000000000000000000000000000e+00
            ];
        
    case   19
        
        % DEGREE.             :          19
        % CARDIN.             :         210
        % LEBESGUE CONST.     : 1.81537e+01
        % ABS.DET.VAND.MATRIX : 1.70801e+201
        % CONDITIONING VAND.  : 2.88924e+02
        % POINTS OUT DISK     : 0.00000e+00
        
        pts=[
            9.96757308134209818462068142252974e-01 8.04665687167258614209686129470356e-02
            9.70941817426052011796855367720127e-01 2.39315664287557738898470915955841e-01
            9.19979443658824225238390681624878e-01 3.91966609860075088089814698832924e-01
            8.45190085543794822342533734627068e-01 5.34465826127801024725272327486891e-01
            7.48510748171101081283040912239812e-01 6.63122658240795193052008471568115e-01
            6.32445375595377390354201452282723e-01 7.74604961827654481254512575105764e-01
            4.99999999999999888977697537484346e-01 8.66025403784438707610604524234077e-01
            3.54604887042535787955443993269000e-01 9.35016242685414722402015286206733e-01
            2.00025693776044455329810034527327e-01 9.79790652042267673493824986508116e-01
            4.02659401094152408218107552784204e-02 9.99188998171569586759233061457053e-01
            -1.20536680255323103150288943652413e-01 9.92708874098053972723221249907510e-01
            -2.78217463916452412142632510949625e-01 9.60518111631372351055802027985919e-01
            -4.28692561403054284152602804169874e-01 9.03450434610382213662660433328710e-01
            -5.68064746731155700842919031856582e-01 8.22983865893656463263994282897329e-01
            -6.92724353509599377609617931739194e-01 7.21202447343814556646179880772252e-01
            -7.99442763403500955554648044198984e-01 6.00742264237979162189162707363721e-01
            -8.85456025653209799486376141430810e-01 4.64723172043768673056263196485816e-01
            -9.48536441947145481101699715509312e-01 3.16667993801472480441816514940001e-01
            -9.87050262637912845242738058004761e-01 1.60411280857760074614049017327488e-01
            -1.00000000000000000000000000000000e+00 1.22464679914735320717376402945840e-16
            -9.87050262637912956265040520520415e-01 -1.60411280857759824813868476667267e-01
            -9.48536441947145592124002178024966e-01 -3.16667993801472258397211589908693e-01
            -8.85456025653209910508678603946464e-01 -4.64723172043768451011658271454507e-01
            -7.99442763403501177599252969230292e-01 -6.00742264237978940144557782332413e-01
            -6.92724353509599599654222856770502e-01 -7.21202447343814334601574955740944e-01
            -5.68064746731155922887523956887890e-01 -8.22983865893656352241691820381675e-01
            -4.28692561403054117619149110396393e-01 -9.03450434610382324684962895844365e-01
            -2.78217463916452412142632510949625e-01 -9.60518111631372351055802027985919e-01
            -1.20536680255323547239498793715029e-01 -9.92708874098053750678616324876202e-01
            4.02659401094147759159191934941191e-02 -9.99188998171569697781535523972707e-01
            2.00025693776044205529629493867105e-01 -9.79790652042267784516127449023770e-01
            3.54604887042535565910839068237692e-01 -9.35016242685414833424317748722387e-01
            4.99999999999999333866185224906076e-01 -8.66025403784439040677511911781039e-01
            6.32445375595376724220386677188799e-01 -7.74604961827654925343722425168380e-01
            7.48510748171100748216133524692850e-01 -6.63122658240795526118915859115077e-01
            8.45190085543794600297928809595760e-01 -5.34465826127801357792179715033853e-01
            9.19979443658824114216088219109224e-01 -3.91966609860075254623268392606406e-01
            9.70941817426052011796855367720127e-01 -2.39315664287557794409622147213668e-01
            9.96757308134209818462068142252974e-01 -8.04665687167257503986661504313815e-02
            9.59056145121409464593398297438398e-01 8.63166153650599260460651862558734e-02
            9.28231291503182509572411618137266e-01 2.56175559055799084706706025826861e-01
            8.67572320424792930992907713516615e-01 4.17800809496532754572228895995067e-01
            7.79028861127067373537613548251102e-01 5.65997598152396697024357763439184e-01
            6.65446773245635947446885438694153e-01 6.96002758299267720865088904247386e-01
            5.30476678540660939731310463685077e-01 8.03637817121423014832259923423408e-01
            3.78456626909723981011524074347108e-01 8.85443295265897600820892421324970e-01
            2.14272667894758739315363982314011e-01 9.38789897355356117714109132066369e-01
            4.32018090295175766213375823099341e-02 9.61963019704912825069698101287941e-01
            -1.29257591524499171331541447216296e-01 9.54217859095344844710950837907149e-01
            -2.97562546733417920830078173821676e-01 9.15803351361382689255208333634073e-01
            -4.56303596855045678903906036794069e-01 8.47954170389158101706073011882836e-01
            -6.00378673925902273111887552659027e-01 7.52851044681610903630541997699765e-01
            -7.25157086423561803023574157123221e-01 6.33550666950093654961051470309030e-01
            -8.26628353502330104340956040687161e-01 4.93887449495575225899557381126215e-01
            -9.01531105147458711179808688029880e-01 3.38350283042322064197549025266198e-01
            -9.47457905290883806159740743169095e-01 1.71938260096548445332587107259315e-01
            -9.62932628787298683370465823827544e-01 1.17925236163891168180694063537384e-16
            -9.47457905290883806159740743169095e-01 -1.71938260096548195532406566599093e-01
            -9.01531105147458711179808688029880e-01 -3.38350283042321842152944100234890e-01
            -8.26628353502330437407863428234123e-01 -4.93887449495574726299196299805772e-01
            -7.25157086423562025068179082154529e-01 -6.33550666950093432916446545277722e-01
            -6.00378673925902384134190015174681e-01 -7.52851044681610681585937072668457e-01
            -4.56303596855045900948510961825377e-01 -8.47954170389157990683770549367182e-01
            -2.97562546733418142874683098852984e-01 -9.15803351361382578232905871118419e-01
            -1.29257591524499393376146372247604e-01 -9.54217859095344733688648375391494e-01
            4.32018090295173476378387533713976e-02 -9.61963019704912936092000563803595e-01
            2.14272667894758545026334672911617e-01 -9.38789897355356117714109132066369e-01
            3.78456626909723758966919149315800e-01 -8.85443295265897711843194883840624e-01
            5.30476678540660606664403076138115e-01 -8.03637817121423236876864848454716e-01
            6.65446773245635725402280513662845e-01 -6.96002758299267831887391366763040e-01
            7.79028861127067262515311085735448e-01 -5.65997598152396919068962688470492e-01
            8.67572320424792819970605251000961e-01 -4.17800809496532976616833821026376e-01
            9.28231291503182509572411618137266e-01 -2.56175559055799306751310950858169e-01
            9.59056145121409353571095834922744e-01 -8.63166153650601619684579191016383e-02
            8.93162753892671079647413989732740e-01 9.08257747509229468318991962405562e-02
            8.56596565806137522081087354308693e-01 2.68758906362890626073891553460271e-01
            7.84961213669677748683284335129429e-01 4.35689016770531012401335146932979e-01
            6.81189457216554994367641029384686e-01 5.84781967640299993327346328442218e-01
            5.49529724348623682672609902510885e-01 7.09933876045911183005898692499613e-01
            3.95372179998858763738667221332435e-01 8.06021008152514317757209028059151e-01
            2.25028052145681639606422663746343e-01 8.69109545481906331509946994628990e-01
            4.54712493979873080829356979393197e-02 8.96616635903233483162466654903255e-01
            -1.35947151642706182128605973957747e-01 8.87416135902700742299487046693685e-01
            -3.11799860322034660953249840531498e-01 8.41884715031342767410649230441777e-01
            -4.74887446084851339023202854150441e-01 7.61886435009347717794980781036429e-01
            -6.18533084008048072988117382919881e-01 6.50696434820215108274510384944733e-01
            -7.36855904797404259731763431773288e-01 5.12866846135957787922166062344331e-01
            -8.25011758267461980942414356832160e-01 3.54040428511598725958009481473709e-01
            -8.79391533419284110451030755939428e-01 1.80719554145990862759063588782737e-01
            -8.97768915868802808155635375442216e-01 1.09944982919271875251563264454872e-16
            -8.79391533419284110451030755939428e-01 -1.80719554145990640714458663751429e-01
            -8.25011758267462091964716819347814e-01 -3.54040428511598503913404556442401e-01
            -7.36855904797404481776368356804596e-01 -5.12866846135957565877561137313023e-01
            -6.18533084008048517077327232982498e-01 -6.50696434820214775207602997397771e-01
            -4.74887446084851505556656547923922e-01 -7.61886435009347606772678318520775e-01
            -3.11799860322035049531308459336287e-01 -8.41884715031342545366044305410469e-01
            -1.35947151642706404173210898989055e-01 -8.87416135902700742299487046693685e-01
            4.54712493979874815552832956200291e-02 -8.96616635903233483162466654903255e-01
            2.25028052145681251028364044941554e-01 -8.69109545481906442532249457144644e-01
            3.95372179998858208627154908754164e-01 -8.06021008152514650824116415606113e-01
            5.49529724348623238583400052448269e-01 -7.09933876045911516072806080046576e-01
            6.81189457216555105389943491900340e-01 -5.84781967640299660260438940895256e-01
            7.84961213669677526638679410098121e-01 -4.35689016770531456490544996995595e-01
            8.56596565806137411058784891793039e-01 -2.68758906362891181185403866038541e-01
            8.93162753892671079647413989732740e-01 -9.08257747509227525428698868381616e-02
            8.09429783029856797504919541097479e-01 9.46087729689788770048863852935028e-02
            7.65793213913627091038449634652352e-01 2.78725935467610819173955860605929e-01
            6.80872534417128361106108513922663e-01 4.47816910639664556015304697211832e-01
            5.59245840352915468685068844933994e-01 5.92765960246047107773392781382427e-01
            4.07470058279886748753284564372734e-01 7.05758843503815125330902446876280e-01
            2.33727459895295724967567707608396e-01 7.80704084829424882485682246624492e-01
            4.73845536496511204882509105118515e-02 8.13561366864159918321774966898374e-01
            -1.41512866148280208600240825944638e-01 8.02559345028737269878149618307361e-01
            -3.22781290702918166601875782362185e-01 7.48291141168071716194276632450055e-01
            -4.86648492326938464369590064961812e-01 6.53682368199092977967268325301120e-01
            -6.24280347765346688149179499305319e-01 5.23833409561126228659588832670124e-01
            -7.28257088066779467716571616620058e-01 3.65744456224495473328772732202196e-01
            -7.92973300248211110385909705655649e-01 1.87938124583377941245743159015547e-01
            -8.14940116559773275461964203714160e-01 9.98013805241697219481645910396199e-17
            -7.92973300248211110385909705655649e-01 -1.87938124583377719201138233984238e-01
            -7.28257088066779578738874079135712e-01 -3.65744456224495306795319038428715e-01
            -6.24280347765346688149179499305319e-01 -5.23833409561126339681891295185778e-01
            -4.86648492326938630903043758735294e-01 -6.53682368199092866944965862785466e-01
            -3.22781290702918222113027013620012e-01 -7.48291141168071716194276632450055e-01
            -1.41512866148280430644845750975946e-01 -8.02559345028737269878149618307361e-01
            4.73845536496505584378446940263530e-02 -8.13561366864159918321774966898374e-01
            2.33727459895295724967567707608396e-01 -7.80704084829424882485682246624492e-01
            4.07470058279886748753284564372734e-01 -7.05758843503815125330902446876280e-01
            5.59245840352915579707371307449648e-01 -5.92765960246046996751090318866773e-01
            6.80872534417127917016898663860047e-01 -4.47816910639665111126817009790102e-01
            7.65793213913626757971542247105390e-01 -2.78725935467611429796619404442026e-01
            8.09429783029856797504919541097479e-01 -9.46087729689787243492204993344785e-02
            7.11360727285698435373717529728310e-01 9.77742814670051335612654952456069e-02
            6.58602356401706279243057906569447e-01 2.86071373232182735169004672570736e-01
            5.56998461648700593507044231955661e-01 4.53151859934181278077858223696239e-01
            4.14084539093621750716067708708579e-01 5.86624146216680797394360524776857e-01
            2.40459860584687573625828349577205e-01 6.76589203201188871261706481163856e-01
            4.90013742468529273077493257915194e-02 7.16374734173914617940681637264788e-01
            -1.46091319852500012288487596379127e-01 7.03030028309304499956056133669335e-01
            -3.30349089081710678428294158948120e-01 6.37544801393369442443770367390243e-01
            -4.90106377620254829441392985245329e-01 5.24775793131484924458618479548022e-01
            -6.13514718218192922627451935113641e-01 3.73086564982549717672810629665037e-01
            -6.91421478808969092177960646949941e-01 1.93727213066324926993289068377635e-01
            -7.18048671359279744308423687471077e-01 8.79356007012151636907745623942275e-17
            -6.91421478808969092177960646949941e-01 -1.93727213066325038015591530893289e-01
            -6.13514718218193255694359322660603e-01 -3.73086564982549218072449548344593e-01
            -4.90106377620254773930241753987502e-01 -5.24775793131485035480920942063676e-01
            -3.30349089081711122517504009010736e-01 -6.37544801393369331421467904874589e-01
            -1.46091319852499873510609518234560e-01 -7.03030028309304499956056133669335e-01
            4.90013742468527607742956320180383e-02 -7.16374734173914617940681637264788e-01
            2.40459860584687407092374655803724e-01 -6.76589203201188871261706481163856e-01
            4.14084539093621695204916477450752e-01 -5.86624146216680908416662987292511e-01
            5.56998461648700482484741769440006e-01 -4.53151859934181500122463148727547e-01
            6.58602356401706168220755444053793e-01 -2.86071373232183012724760828859871e-01
            7.11360727285698435373717529728310e-01 -9.77742814670049531500239936576691e-02
            6.00839584033879603452987794298679e-01 1.00262393523892226476768030352105e-01
            5.35729292117081867807826256466797e-01 2.89922194502034880070340250313166e-01
            4.12564418702944246675201611651573e-01 4.48164427099526807563023567126947e-01
            2.44691788925807035548487533560547e-01 5.57841090033204367593100414524088e-01
            5.03030070342571980490653515971644e-02 6.07067015065434811837974393711193e-01
            -1.49536886201029395326855819803313e-01 5.90507809400049987758052338904236e-01
            -3.33172137512576183038248700540862e-01 5.09957919913443857851120810664725e-01
            -4.80703018026268913409637661970919e-01 3.74146176991803469658037784029148e-01
            -5.76142267660976425958097024704330e-01 1.97789890317005861986032755339693e-01
            -6.09147562826237831679065948264906e-01 7.45990613023563440010578142377462e-17
            -5.76142267660976425958097024704330e-01 -1.97789890317005945252759602226433e-01
            -4.80703018026269190965393818260054e-01 -3.74146176991803192102281627740012e-01
            -3.33172137512576127527097469283035e-01 -5.09957919913443857851120810664725e-01
            -1.49536886201029534104733897947881e-01 -5.90507809400049876735749876388581e-01
            5.03030070342571772323836398754793e-02 -6.07067015065434811837974393711193e-01
            2.44691788925806535948126452240103e-01 -5.57841090033204589637705339555396e-01
            4.12564418702944302186352842909400e-01 -4.48164427099526807563023567126947e-01
            5.35729292117081645763221331435489e-01 -2.89922194502035268648398869117955e-01
            6.00839584033879714475290256814333e-01 -1.00262393523892129332253375650907e-01
            4.78909344768143785397995770836133e-01 1.01795323675559823417557936409139e-01
            3.96101568302920314934567613818217e-01 2.87784634781691861515895425327471e-01
            2.44804232208342797960654024791438e-01 4.24013368092738984760359244319261e-01
            5.11780203883117207341868493131187e-02 4.86926338020031823639044432638912e-01
            -1.51297336094577516973913589026779e-01 4.65645320516752614370403762222850e-01
            -3.27612008673566046379477256778046e-01 3.63849996841192846463997057071538e-01
            -4.47279588691232077302117886574706e-01 1.99141703238339962123149007311440e-01
            -4.89608464416685484899005587067222e-01 2.77389579977042849725640190714448e-16
            -4.47279588691232021790966655316879e-01 -1.99141703238340017634300238569267e-01
            -3.27612008673566323935233413067181e-01 -3.63849996841192624419392132040230e-01
            -1.51297336094577600240640435913519e-01 -4.65645320516752558859252530965023e-01
            5.11780203883114917506880203745823e-02 -4.86926338020031879150195663896739e-01
            2.44804232208342797960654024791438e-01 -4.24013368092738984760359244319261e-01
            3.96101568302920259423416382560390e-01 -2.87784634781691917027046656585298e-01
            4.78909344768143785397995770836133e-01 -1.01795323675559656884104242635658e-01
            3.45830733290976632954283331855549e-01 1.01545065366533127093617849823204e-01
            2.36031918994287520652264333875792e-01 2.72395355328871602296203491277993e-01
            5.12946381387584388056311013315280e-02 3.56762044627903118776401925060782e-01
            -1.49728327895232299349359550433292e-01 3.27859305517726518086618625602568e-01
            -3.03213607752297831243737391559989e-01 1.94863553448826859471054717687366e-01
            -3.60430709552984840371436803252436e-01 2.04203420487929693961774786137358e-16
            -3.03213607752297886754888622817816e-01 -1.94863553448826776204327870800626e-01
            -1.49728327895232604660691322351340e-01 -3.27859305517726351553164931829087e-01
            5.12946381387583486000103505375591e-02 -3.56762044627903174287553156318609e-01
            2.36031918994287326363235024473397e-01 -2.72395355328871768829657185051474e-01
            3.45830733290976632954283331855549e-01 -1.01545065366533168726981273266574e-01
            2.00360840353385166734412337063986e-01 9.64886953171375516546959261177108e-02
            4.94850409509777558469956204589835e-02 2.16808130366917178877272931458720e-01
            -1.38654003598392278062689797479834e-01 1.73866621170525786910232568516221e-01
            -2.22383755411941219648497281013988e-01 2.72341554247601713759996589146975e-17
            -1.38654003598392333573841028737661e-01 -1.73866621170525731399081337258394e-01
            4.94850409509775129857089837059902e-02 -2.16808130366917234388424162716547e-01
            2.00360840353385194489987952692900e-01 -9.64886953171374267546056557876000e-02
            3.80416881683889387955055383372382e-02 6.58901367133414433974181179110019e-02
            -7.60833763367778637132232688600197e-02 9.31752632991584809906888571164487e-18
            3.80416881683889387955055383372382e-02 -6.58901367133414433974181179110019e-02
            ];
        
    case   20
        
        % DEGREE.             :          20
        % CARDIN.             :         231
        % LEBESGUE CONST.     : 2.08182e+01
        % ABS.DET.VAND.MATRIX : 2.01425e+225
        % CONDITIONING VAND.  : 5.21700e+02
        % POINTS OUT DISK     : 0.00000e+00
        
        pts=[
            9.97065801183740441082647976145381e-01 7.65492528364956487108017313403252e-02
            9.73695423877779075993998958438169e-01 2.27853508903137547125794526436948e-01
            9.27502451102094727097835402673809e-01 3.73817071840768733181903371587396e-01
            8.59569606987201195735792680352461e-01 5.11018679447110324431946537515614e-01
            7.71489179821942983039662067312747e-01 6.36242442326559798360108288761694e-01
            6.65325700165565470101114442513790e-01 7.46553221611962580794852328835987e-01
            5.43567550001221144739815827051643e-01 8.39365426131949976529256218782393e-01
            4.09068637171340010461051406309707e-01 9.12503616476549983538291144213872e-01
            2.64981502196661666825860947938054e-01 9.64253495453140985205209290143102e-01
            1.14683425398400526407094446312840e-01 9.93402089759675033242558583879145e-01
            -3.83027336900353745918756942501204e-02 9.99266181050809998431816438824171e-01
            -1.90391109164668281827914597670315e-01 9.81708319996854927858009887131630e-01
            -3.38016878408502807751290220039664e-01 9.41140047979561522595304268179461e-01
            -4.77719818512262694998327106077340e-01 8.78512250910942538162373693921836e-01
            -6.06225410966638067478129414666910e-01 7.95292871273426404954420831927564e-01
            -7.20521593600786935951418854529038e-01 6.93432500792241723885922510817181e-01
            -8.17929360766717405972769938671263e-01 5.75318660218620658852728411147837e-01
            -8.96165556961055487228406946087489e-01 4.43719837866959898597940537001705e-01
            -9.53396392054930541526402976160171e-01 3.01720598595192235347184350757743e-01
            -9.88280423780348526996419877832523e-01 1.52649284218874525809184206082136e-01
            -1.00000000000000000000000000000000e+00 5.66553889764797961538732358338787e-16
            -9.88280423780348526996419877832523e-01 -1.52649284218874276009003665421915e-01
            -9.53396392054930541526402976160171e-01 -3.01720598595192401880638044531224e-01
            -8.96165556961055598250709408603143e-01 -4.43719837866959676553335611970397e-01
            -8.17929360766717961084282251249533e-01 -5.75318660218620214763518561085220e-01
            -7.20521593600787157996023779560346e-01 -6.93432500792241612863620048301527e-01
            -6.06225410966637956455826952151256e-01 -7.95292871273426515976723294443218e-01
            -4.77719818512262472953722181046032e-01 -8.78512250910942649184676156437490e-01
            -3.38016878408502807751290220039664e-01 -9.41140047979561522595304268179461e-01
            -1.90391109164668975717304988393153e-01 -9.81708319996854816835707424615975e-01
            -3.83027336900356174531623310031136e-02 -9.99266181050809998431816438824171e-01
            1.14683425398400512529306638498383e-01 -9.93402089759675033242558583879145e-01
            2.64981502196661222736651097875438e-01 -9.64253495453141096227511752658756e-01
            4.09068637171339788416446481278399e-01 -9.12503616476550094560593606729526e-01
            5.43567550001221366784420752082951e-01 -8.39365426131949865506953756266739e-01
            6.65325700165565137034207054966828e-01 -7.46553221611962913861759716382949e-01
            7.71489179821942316905847292218823e-01 -6.36242442326560464493923063855618e-01
            8.59569606987200862668885292805498e-01 -5.11018679447110879543458850093884e-01
            9.27502451102094616075532940158155e-01 -3.73817071840768955226508296618704e-01
            9.73695423877779075993998958438169e-01 -2.27853508903137436103492063921294e-01
            9.97065801183740441082647976145381e-01 -7.65492528364960650444359657740279e-02
            9.62289037545653203054030200291891e-01 8.19028674601321449166846377920592e-02
            9.34605733970705121471667098376201e-01 2.43352406003743859663757120870287e-01
            8.80035525061796386481205445306841e-01 3.97801138897238171221459879234317e-01
            8.00148296373507039724870537611423e-01 5.40805857299369474588957018568181e-01
            6.97242258024887928691271099523874e-01 6.68252575829743400426252719626063e-01
            5.74277829378676440974516026471974e-01 7.76474884437898027478297535708407e-01
            4.34792473166252302352319247802370e-01 8.62359424345037872683406021678820e-01
            2.82798929125498477166189559284248e-01 9.23435453707622588837011790019460e-01
            1.22669774784518029187019294568017e-01 9.57945926361737365439807945222128e-01
            -4.09883656327158368837260127293121e-02 9.64898038842182725893792394344928e-01
            -2.03467345398026355773879458865849e-01 9.44091791530575541457892541075125e-01
            -3.60092940088298674172762048328877e-01 8.96125742280231785130695243424270e-01
            -5.06359316511796442306092558283126e-01 8.22379786996517703201448057370726e-01
            -6.38058657325336620047551150491927e-01 7.24975462544022897226625445910031e-01
            -7.51402212278100334330588339071255e-01 6.06714913993638416123133083601715e-01
            -8.43129293658186673710019931604620e-01 4.71000282010720972003525730542606e-01
            -9.10601080341368329662543601443758e-01 3.21735829462409084200658071495127e-01
            -9.51876531870342157404252247943077e-01 1.63215622883414235300136851947173e-01
            -9.65768228654645399799960614473093e-01 1.18272496994012058644184761088041e-16
            -9.51876531870342157404252247943077e-01 -1.63215622883413985499956311286951e-01
            -9.10601080341368329662543601443758e-01 -3.21735829462408862156053146463819e-01
            -8.43129293658186895754624856635928e-01 -4.71000282010720361380862186706509e-01
            -7.51402212278100223308285876555601e-01 -6.06714913993638638167738008633023e-01
            -6.38058657325336842092156075523235e-01 -7.24975462544022786204322983394377e-01
            -5.06359316511796886395302408345742e-01 -8.22379786996517370134540669823764e-01
            -3.60092940088298896217366973360186e-01 -8.96125742280231674108392780908616e-01
            -2.03467345398026161484850149463455e-01 -9.44091791530575541457892541075125e-01
            -4.09883656327162879118297666991566e-02 -9.64898038842182614871489931829274e-01
            1.22669774784517363053204519474093e-01 -9.57945926361737365439807945222128e-01
            2.82798929125498033076979709221632e-01 -9.23435453707622699859314252535114e-01
            4.34792473166252302352319247802370e-01 -8.62359424345037872683406021678820e-01
            5.74277829378676663019120951503282e-01 -7.76474884437897916455995073192753e-01
            6.97242258024887706646666174492566e-01 -6.68252575829743622470857644657372e-01
            8.00148296373506595635660687548807e-01 -5.40805857299369918678166868630797e-01
            8.80035525061796275458902982791187e-01 -3.97801138897238448777216035523452e-01
            9.34605733970705121471667098376201e-01 -2.43352406003743804152605889612460e-01
            9.62289037545653092031727737776237e-01 -8.19028674601325612503188722257619e-02
            9.01361200110903149074204065982485e-01 8.60695588972392178206405333185103e-02
            8.68783657865194847147449763724580e-01 2.55097898581123028183270662339055e-01
            8.04806010630496615476658917032182e-01 4.14906335559193262252364320374909e-01
            7.11740577270004504129019551328383e-01 5.59718976542241009042299992870539e-01
            5.92950985024987886617964250035584e-01 6.84301915379483260970516766974470e-01
            4.52730599262445854158443125925260e-01 7.84152400063660826035061290895101e-01
            2.96147350064487779874866646423470e-01 8.55661573920387441560819752339739e-01
            1.28860564030805035962146121164551e-01 8.96244909091145514068443844735157e-01
            -4.30835785298761819728241562188487e-02 9.04435618104015737195311430696165e-01
            -2.13470568309318320388001666287892e-01 8.79937667394588562963519962067949e-01
            -3.76142175557921565332009095072863e-01 8.23636476730290723047289702662965e-01
            -5.25219024552981528231043739651795e-01 7.37566917833051505226649169344455e-01
            -6.55313089555876304714843172405381e-01 6.24839768813465368246795605955413e-01
            -7.61722432100620405748259145184420e-01 4.89529282544822641476400804094737e-01
            -8.40601141300809207024258284945972e-01 3.36525932548904560537295083122444e-01
            -8.89098335089475666492830896459054e-01 1.71359658540904402634907910396578e-01
            -9.05461198524891486272281326819211e-01 1.10887015852563453003701495189547e-16
            -8.89098335089475888537435821490362e-01 -1.71359658540903792012244366560481e-01
            -8.40601141300809318046560747461626e-01 -3.36525932548904338492690158091136e-01
            -7.61722432100620738815166532731382e-01 -4.89529282544822141876039722774294e-01
            -6.55313089555876415737145634921035e-01 -6.24839768813465368246795605955413e-01
            -5.25219024552981750275648664683104e-01 -7.37566917833051394204346706828801e-01
            -3.76142175557921398798555401299382e-01 -8.23636476730290834069592165178619e-01
            -2.13470568309318348143577281916805e-01 -8.79937667394588562963519962067949e-01
            -4.30835785298766121842461984670081e-02 -9.04435618104015737195311430696165e-01
            1.28860564030804619628511886730848e-01 -8.96244909091145625090746307250811e-01
            2.96147350064487779874866646423470e-01 -8.55661573920387552583122214855393e-01
            4.52730599262445854158443125925260e-01 -7.84152400063660826035061290895101e-01
            5.92950985024987442528754399972968e-01 -6.84301915379483705059726617037086e-01
            7.11740577270004171062112163781421e-01 -5.59718976542241453131509842933156e-01
            8.04806010630496504454356454516528e-01 -4.14906335559193484296969245406217e-01
            8.68783657865194847147449763724580e-01 -2.55097898581123139205573124854709e-01
            9.01361200110903038051901603466831e-01 -8.60695588972399255878187318558048e-02
            8.23870784252480170550825278041884e-01 8.96013474392572950577573465125170e-02
            7.85347502047444079309457265480887e-01 2.64614382896257327448807927794405e-01
            7.10102243497726326459940082713729e-01 4.27254343906791622664798069308745e-01
            6.01653393264013569563530836603604e-01 5.69916366655341399827250370435650e-01
            4.65071899050994108648637848091312e-01 6.85929733515634354468204492150107e-01
            3.06744159728640997109039290080545e-01 7.69869788392879561556014778034296e-01
            1.34073404419023434197555388891487e-01 8.17811587613687551723273827519733e-01
            -4.48664742693407475604416845271771e-02 8.27513425929976009776112277904758e-01
            -2.21708446486375720940742439779569e-01 7.98521656164893900431422935071168e-01
            -3.88183578156947373116736343945377e-01 7.32191901250619059382529485446867e-01
            -5.36507677147960215791044902289286e-01 6.31625666806715058143595342698973e-01
            -6.59745273440989543622947621770436e-01 5.01525318184437352009297228505602e-01
            -7.52133914002124925879400052508572e-01 3.47974203089210898376393288344843e-01
            -8.09353608681325664697681077086600e-01 1.78152201003082683028466703945014e-01
            -8.28728828150515850481383495207410e-01 1.01490010675566621516702955072518e-16
            -8.09353608681325664697681077086600e-01 -1.78152201003082460983861778913706e-01
            -7.52133914002124814857097589992918e-01 -3.47974203089211009398695750860497e-01
            -6.59745273440989987712157471833052e-01 -5.01525318184436907920087378442986e-01
            -5.36507677147959993746439977257978e-01 -6.31625666806715169165897805214627e-01
            -3.88183578156947928228248656523647e-01 -7.32191901250618837337924560415559e-01
            -2.21708446486376081763225442955445e-01 -7.98521656164893789409120472555514e-01
            -4.48664742693413165497418049199041e-02 -8.27513425929975898753809815389104e-01
            1.34073404419023239908526079489093e-01 -8.17811587613687662745576290035388e-01
            3.06744159728640608530980671275756e-01 -7.69869788392879783600619703065604e-01
            4.65071899050993997626335385575658e-01 -6.85929733515634465490506954665761e-01
            6.01653393264013569563530836603604e-01 -5.69916366655341399827250370435650e-01
            7.10102243497726326459940082713729e-01 -4.27254343906791622664798069308745e-01
            7.85347502047444079309457265480887e-01 -2.64614382896257216426505465278751e-01
            8.23870784252480059528522815526230e-01 -8.96013474392578918026330825341574e-02
            7.33083131847522495583291401999304e-01 9.26099363956238846862234481704945e-02
            6.87020822582378287712856490543345e-01 2.72010786287613548495301074581221e-01
            5.97790468348542325394134877569741e-01 4.34320198091458609113146849267650e-01
            4.70998740468813847925844129349571e-01 5.69339674531262995849090202682419e-01
            3.14612429513232483291318430929095e-01 6.68585445335414751966141011507716e-01
            1.38457862547756965776457604988536e-01 7.25821533723876144428288625931600e-01
            -4.63965211339927643963143566452345e-02 7.37451585763591932476401780149899e-01
            -2.28335640758424718299579581071157e-01 7.02744842512567302605930308345705e-01
            -3.95927592314260945460802076922846e-01 6.23882056291736875053288713388611e-01
            -5.38641957125164050346199928753776e-01 5.05818465996395127959317505883519e-01
            -6.47511466783347588993535737245111e-01 3.55972441212309587132978094814462e-01
            -7.15695449602938515987204937118804e-01 1.83759358771794667486432217629044e-01
            -7.38909655180234770099900742934551e-01 9.04903344075549027562699181568995e-17
            -7.15695449602938627009507399634458e-01 -1.83759358771794195641646751937515e-01
            -6.47511466783347588993535737245111e-01 -3.55972441212309698155280557330116e-01
            -5.38641957125164383413107316300739e-01 -5.05818465996394794892410118336556e-01
            -3.95927592314260501371592226860230e-01 -6.23882056291737097097893638419919e-01
            -2.28335640758425051366486968618119e-01 -7.02744842512567191583627845830051e-01
            -4.63965211339926186795423745934386e-02 -7.37451585763591932476401780149899e-01
            1.38457862547756604953974601812661e-01 -7.25821533723876144428288625931600e-01
            3.14612429513231872668654887092998e-01 -6.68585445335414974010745936539024e-01
            4.70998740468813514858936741802609e-01 -5.69339674531263217893695127713727e-01
            5.97790468348542325394134877569741e-01 -4.34320198091458775646600543041131e-01
            6.87020822582378287712856490543345e-01 -2.72010786287613492984149843323394e-01
            7.33083131847522384560988939483650e-01 -9.26099363956241761197674122740864e-02
            6.30782805577342342573388123128098e-01 9.50752103543424653686599867796758e-02
            5.74734985157047129078478064911906e-01 2.76777781392355592959830801191856e-01
            4.67619439122608615555520827911096e-01 4.33887431934370182418092554144096e-01
            3.18953853808017939730490297733922e-01 5.52444280065382931077522243867861e-01
            1.41947818876651837838309688777372e-01 6.21914029550794889011910981935216e-01
            -4.76709026896475832058008847980091e-02 6.36123988285852925983476779947523e-01
            -2.33053855351661370898241898430570e-01 5.93811539077570227362912191892974e-01
            -3.97728950225681054941873071584268e-01 4.98736328723227817505403436371125e-01
            -5.27064082467399552811571084021125e-01 3.59346206893497166490192284982186e-01
            -6.09567257999260259104801207286073e-01 1.88026597616424956393998968451342e-01
            -6.37907707616035768438678132952191e-01 7.81211632283403846037461865395394e-17
            -6.09567257999260481149406132317381e-01 -1.88026597616424540060364734017639e-01
            -5.27064082467399441789268621505471e-01 -3.59346206893497333023645978755667e-01
            -3.97728950225681165964175534099923e-01 -4.98736328723227706483100973855471e-01
            -2.33053855351661232120363820286002e-01 -5.93811539077570227362912191892974e-01
            -4.76709026896480134172229270461685e-02 -6.36123988285852925983476779947523e-01
            1.41947818876651699060431610632804e-01 -6.21914029550794889011910981935216e-01
            3.18953853808017440130129216413479e-01 -5.52444280065383264144429631414823e-01
            4.67619439122608726577823290426750e-01 -4.33887431934370071395790091628442e-01
            5.74734985157047129078478064911906e-01 -2.76777781392355759493284494965337e-01
            6.30782805577342342573388123128098e-01 -9.50752103543429927245966837290325e-02
            5.18022703830522845969142053945689e-01 9.68352257833953455889997030681116e-02
            4.48060867215317126799334346287651e-01 2.77427543525628927945092527806992e-01
            3.17585927691708680420390464860247e-01 4.20551734235639018688601709072827e-01
            1.44219248828959228925228330808750e-01 5.06878082879519964443204571580281e-01
            -4.86250387345864773513959278261609e-02 5.24747737722104701241221391683212e-01
            -2.34902245376385043762468285422074e-01 4.71747302857726313884967339618015e-01
            -3.89454602141827588290823314309819e-01 3.55034780700366869865547414519824e-01
            -4.91408956845567235216520884932834e-01 1.90372844093789378439041115598229e-01
            -5.26995808936282505996473446430173e-01 6.45383730577888478248264120325458e-17
            -4.91408956845567346238823347448488e-01 -1.90372844093789073127709343680181e-01
            -3.89454602141827477268520851794165e-01 -3.55034780700366925376698645777651e-01
            -2.34902245376385598873980598000344e-01 -4.71747302857726036329211183328880e-01
            -4.86250387345864912291837356406177e-02 -5.24747737722104701241221391683212e-01
            1.44219248828959117902925868293096e-01 -5.06878082879519964443204571580281e-01
            3.17585927691708569398088002344593e-01 -4.20551734235639129710904171588481e-01
            4.48060867215316960265880652514170e-01 -2.77427543525629149989697452838300e-01
            5.18022703830522845969142053945689e-01 -9.68352257833951929333338171090872e-02
            3.95272021784156935009235667166649e-01 9.74258032456882527849728603541735e-02
            3.04719965137660253606810556448181e-01 2.69958332321685701149505121065886e-01
            1.44360236751797710308409250501427e-01 3.80646660813368342690665713234921e-01
            -4.90706821444536478438180893135723e-02 4.04133426602255430015731008097646e-01
            -2.31260099127237522820266235612507e-01 3.35038094692324261991700495855184e-01
            -3.60470614386288412678283066270524e-01 1.89189572935123256902656407874019e-01
            -4.07101656031270131563815084518865e-01 -1.30933878756950561113337753778209e-16
            -3.60470614386288634722887991301832e-01 -1.89189572935122840569022173440317e-01
            -2.31260099127237633842568698128161e-01 -3.35038094692324261991700495855184e-01
            -4.90706821444539253995742456027074e-02 -4.04133426602255430015731008097646e-01
            1.44360236751797710308409250501427e-01 -3.80646660813368342690665713234921e-01
            3.04719965137660142584508093932527e-01 -2.69958332321685812171807583581540e-01
            3.95272021784156935009235667166649e-01 -9.74258032456882666627606681686302e-02
            2.62117661180258532116482683704817e-01 9.54030265450877407173990718547429e-02
            1.39469894400701704961775817537273e-01 2.41568943228281374224764022073941e-01
            -4.84373860041621071004236398493958e-02 2.74702066635209907197179290960776e-01
            -2.13680275176096334810438293061452e-01 1.79299040090122208113143642549403e-01
            -2.78939788801403354412400403816719e-01 3.41602719510477354841687113416271e-17
            -2.13680275176096473588316371206020e-01 -1.79299040090122069335265564404835e-01
            -4.84373860041621140393175437566242e-02 -2.74702066635209907197179290960776e-01
            1.39469894400701482917170892505965e-01 -2.41568943228281485247066484589595e-01
            2.62117661180258532116482683704817e-01 -9.54030265450876990840356484113727e-02
            1.15755928666872190402337139403244e-01 8.41016050452375457657794299848319e-02
            -4.42148303514368554156810375843634e-02 1.36079255471613980166267765525845e-01
            -1.43082196630870628339948780194391e-01 1.75225154118967907894541584194896e-17
            -4.42148303514368901101505571205053e-02 -1.36079255471613980166267765525845e-01
            1.15755928666872176524549331588787e-01 -8.41016050452375735213550456137455e-02
            -0.00000000000000000000000000000000e+00 0.00000000000000000000000000000000e+00
            ];
        
    case   21
        
        % DEGREE.             :          21
        % CARDIN.             :         253
        % LEBESGUE CONST.     : 2.38793e+01
        % ABS.DET.VAND.MATRIX : 7.50287e+250
        % CONDITIONING VAND.  : 4.53959e+02
        % POINTS OUT DISK     : 0.00000e+00
        
        pts=[
            9.97332283663551644181666233635042e-01 7.29953146609075287365442363807233e-02
            9.76075877555927173823135944985552e-01 2.17430175581556972552732531767106e-01
            9.34016108732548033799503173213452e-01 3.57230889801132767136238044258789e-01
            8.72049408143807602833419423404848e-01 4.89417847811085493514582367424737e-01
            7.91496488429254130281265133817215e-01 6.11173714097849263282569154398516e-01
            6.94074195220633960445866250665858e-01 7.19903473757995793214092827838613e-01
            5.81858915557952771635541466821451e-01 8.13289740735565369611492769763572e-01
            4.57242323304638598191473874976509e-01 8.89342148882518834795973816653714e-01
            3.22880404771446305467463844252052e-01 9.46439773157609298692705124267377e-01
            1.81636850979436492714569340023445e-01 9.83365676829466073272101311886217e-01
            3.65220230576588505977397858259792e-02 9.99332848370239390511926558247069e-01
            -1.09371208377874187811507056267146e-01 9.94000975239945905315153140691109e-01
            -2.52933382391680783296550316663343e-01 9.67483697057425207077585582737811e-01
            -3.91104720490155877143934048945084e-01 9.20346183569159537185555564064998e-01
            -5.20940340487930142465700100729009e-01 8.53593089037346541836370761302533e-01
            -6.39673021558891052862350079522002e-01 7.68647139778532273446387534932001e-01
            -7.44772182743781874236788098642137e-01 6.67318811222239460789751319680363e-01
            -8.33997817889877812724819250433939e-01 5.51767740770446102338553373556351e-01
            -9.05448237493146623755535529198823e-01 4.24456698875815052751647726836381e-01
            -9.57600599908405847315862047253177e-01 2.88099099365237754089008603841648e-01
            -9.89343368075110141113270856294548e-01 1.45601167735005254666447171985055e-01
            -1.00000000000000000000000000000000e+00 1.22464679914735320717376402945840e-16
            -9.89343368075110141113270856294548e-01 -1.45601167735005004866266631324834e-01
            -9.57600599908405958338164509768831e-01 -2.88099099365237532044403678810340e-01
            -9.05448237493146734777837991714478e-01 -4.24456698875814830707042801805073e-01
            -8.33997817889878145791726637980901e-01 -5.51767740770445547227041060978081e-01
            -7.44772182743781985259090561157791e-01 -6.67318811222239238745146394649055e-01
            -6.39673021558890830817745154490694e-01 -7.68647139778532384468689997447655e-01
            -5.20940340487930808599514875822933e-01 -8.53593089037346208769463373755571e-01
            -3.91104720490155877143934048945084e-01 -9.20346183569159537185555564064998e-01
            -2.52933382391680838807701547921170e-01 -9.67483697057425207077585582737811e-01
            -1.09371208377874645778504714144219e-01 -9.94000975239945905315153140691109e-01
            3.65220230576583787529543201344495e-02 -9.99332848370239390511926558247069e-01
            1.81636850979435798825178949300607e-01 -9.83365676829466184294403774401871e-01
            3.22880404771446249956312612994225e-01 -9.46439773157609298692705124267377e-01
            4.57242323304638376146868949945201e-01 -8.89342148882518945818276279169368e-01
            5.81858915557952549590936541790143e-01 -8.13289740735565480633795232279226e-01
            6.94074195220633516356656400603242e-01 -7.19903473757996237303302677901229e-01
            7.91496488429254241303567596332869e-01 -6.11173714097849152260266691882862e-01
            8.72049408143807602833419423404848e-01 -4.89417847811085549025733598682564e-01
            9.34016108732547922777200710697798e-01 -3.57230889801132989180842969290097e-01
            9.76075877555927284845438407501206e-01 -2.17430175581556500707947066075576e-01
            9.97332283663551644181666233635042e-01 -7.29953146609081116036321645879070e-02
            9.65281718155124868196992338198470e-01 7.79255964025198644140601800245349e-02
            9.40281428694058618589224352035671e-01 2.31758557193166292442754183866782e-01
            8.90928344136920236095988911984023e-01 3.79589093089677254155844821070787e-01
            8.18500683449757349130493366828887e-01 5.17588470864139837956940937147010e-01
            7.24874284999867835033171559189213e-01 6.42182579119932706035456249082927e-01
            6.12474023327420624696060258429497e-01 7.50144495899503715996559094492113e-01
            4.84211006168591195919503888944746e-01 8.38678064268047251950122245034436e-01
            3.43407178294331816292839221205213e-01 9.05490311309360862424000515602529e-01
            1.93709284885738047821135410231363e-01 9.48850834919933161515359643090051e-01
            3.89944227494083833773785841003701e-02 9.67636620314484940941213153564604e-01
            -1.16730374453303545334570401337260e-01 9.61361125519016312956921410659561e-01
            -2.69431916273318361465527459586156e-01 9.30186882552364258103239080810454e-01
            -4.15155312987927072043703446979634e-01 8.74921287932288516131507094542030e-01
            -5.50126405167197796153288891218835e-01 7.96995691529768790495324992662063e-01
            -6.70849512420740090590243198676035e-01 6.98428325359197854638182434428018e-01
            -7.74197969683616538105752624687739e-01 5.81772032429339280845681514620082e-01
            -8.57495106199165468829903602454579e-01 4.50048149450345158495423447675421e-01
            -9.18583569885605855098731353791663e-01 3.06668255800000455479903394007124e-01
            -9.55881201621752163433143323345575e-01 1.55345815409856979893987727336935e-01
            -9.68422012337182613883612702920800e-01 1.18597491763256918298986870214200e-16
            -9.55881201621752274455445785861230e-01 -1.55345815409856757849382802305627e-01
            -9.18583569885605966121033816307317e-01 -3.06668255800000233435298468975816e-01
            -8.57495106199165579852206064970233e-01 -4.50048149450344991961969753901940e-01
            -7.74197969683616760150357549719047e-01 -5.81772032429339058801076589588774e-01
            -6.70849512420740312634848123707343e-01 -6.98428325359197632593577509396710e-01
            -5.50126405167198018197893816250144e-01 -7.96995691529768679473022530146409e-01
            -4.15155312987926905510249753206153e-01 -8.74921287932288627153809557057684e-01
            -2.69431916273318361465527459586156e-01 -9.30186882552364258103239080810454e-01
            -1.16730374453304003301568059214333e-01 -9.61361125519016312956921410659561e-01
            3.89944227494079323492748301305255e-02 -9.67636620314485051963515616080258e-01
            1.93709284885737798020954869571142e-01 -9.48850834919933272537662105605705e-01
            3.43407178294331649759385527431732e-01 -9.05490311309360973446302978118183e-01
            4.84211006168590640807991576366476e-01 -8.38678064268047585017029632581398e-01
            6.12474023327419958562245483335573e-01 -7.50144495899504160085768944554729e-01
            7.24874284999867501966264171642251e-01 -6.42182579119933039102363636629889e-01
            8.18500683449757127085888441797579e-01 -5.17588470864140171023848324693972e-01
            8.90928344136920125073686449468369e-01 -3.79589093089677420689298514844268e-01
            9.40281428694058618589224352035671e-01 -2.31758557193166347953905415124609e-01
            9.65281718155124868196992338198470e-01 -7.79255964025197533917577175088809e-02
            9.08880013336691550129842198657570e-01 8.18006817674291203390524174210441e-02
            8.79667861879084189702382445830153e-01 2.42772904084457064044499929877929e-01
            8.22182461547555698544442748243455e-01 3.95942205509999700652201681805309e-01
            7.38271440407905932268306514743017e-01 5.36385598668119079057703402213519e-01
            6.30631767721781533175828826642828e-01 6.59589117345504516443099873868050e-01
            5.02723071135532273423507376719499e-01 7.61592899079671759032805766764795e-01
            3.58656441401066172769418471943936e-01 8.39118458396693966960810939781368e-01
            2.03062298536466928622346017618838e-01 8.89674060031878988219489201583201e-01
            4.09415663166898813329908080049790e-02 9.11634805351384525096136712818407e-01
            -1.22495061531338572669014297389367e-01 9.04294857931280282592467756330734e-01
            -2.81994597312477446315881479677046e-01 8.67890129720977121507985430071130e-01
            -4.32430594710065785424291107119643e-01 8.03590698639064293651301795762265e-01
            -5.68967916988594168969939346425235e-01 7.13463201306262839729299685131991e-01
            -6.87218142266747600288567809911910e-01 6.00404409644000658374807244399562e-01
            -7.83380611007476912455160800163867e-01 4.68048126241386530654864372991142e-01
            -8.54364582342712064466638821613742e-01 3.20648390950093176154922502973932e-01
            -8.97888573027932679337936860974878e-01 1.62942752543288993383185925267753e-01
            -9.12553686190856749860245145100635e-01 1.11755595084375102981835186675280e-16
            -8.97888573027932679337936860974878e-01 -1.62942752543288771338581000236445e-01
            -8.54364582342712064466638821613742e-01 -3.20648390950093009621468809200451e-01
            -7.83380611007477134499765725195175e-01 -4.68048126241386031054503291670699e-01
            -6.87218142266747711310870272427564e-01 -6.00404409644000436330202319368254e-01
            -5.68967916988594279992241808940889e-01 -7.13463201306262728706997222616337e-01
            -4.32430594710065951957744800893124e-01 -8.03590698639064182628999333246611e-01
            -2.81994597312477668360486404708354e-01 -8.67890129720977010485682967555476e-01
            -1.22495061531338794713619222420675e-01 -9.04294857931280171570165293815080e-01
            4.09415663166896592883858829736710e-02 -9.11634805351384525096136712818407e-01
            2.03062298536466734333316708216444e-01 -8.89674060031878988219489201583201e-01
            3.58656441401066006235964778170455e-01 -8.39118458396694077983113402297022e-01
            5.02723071135532051378902451688191e-01 -7.61592899079671981077410691796103e-01
            6.30631767721781422153526364127174e-01 -6.59589117345504627465402336383704e-01
            7.38271440407905821246004052227363e-01 -5.36385598668119301102308327244828e-01
            8.22182461547555587522140285727801e-01 -3.95942205509999867185655375578790e-01
            8.79667861879084189702382445830153e-01 -2.42772904084457258333529239280324e-01
            9.08880013336691439107539736141916e-01 -8.18006817674293562614451502668089e-02
            8.37010145540218464255133312690305e-01 8.51156125932771151498812400859606e-02
            8.02742851837285553706635710113915e-01 2.51862194599602740030519498759531e-01
            7.35611171461854063124974345555529e-01 4.08297508766469363639117773345788e-01
            6.38363483296131684063823286123807e-01 5.48017074951516414138552590884501e-01
            5.14981119119741093115294461313169e-01 6.65300757698776057402767492021667e-01
            3.70515367418876084837364714985597e-01 7.55346949256328059618681436404586e-01
            2.10880673042174865416953366548114e-01 8.14469147961827788506639080878813e-01
            4.26124991337004169200675107731513e-02 8.40246884053708842365892905945657e-01
            -1.27400235496064329066001619139570e-01 8.31624813987614119881186525162775e-01
            -2.92197189515727595576777275709901e-01 7.88955926325099921037065087148221e-01
            -4.45031556264905314712621020589722e-01 7.13987090340450714087694450427080e-01
            -5.79646278811609794168191456265049e-01 6.09787538987342614404951746109873e-01
            -6.90530214598221503408126409340184e-01 4.80623214141098820118003231982584e-01
            -7.73143762265326772720186454534996e-01 3.31782118437088768825304896381567e-01
            -8.24104713464754556895286441431381e-01 1.69357823821520647733507303200895e-01
            -8.41326720866742983062636085378472e-01 1.03032807574659553462689530974119e-16
            -8.24104713464754556895286441431381e-01 -1.69357823821520453444477993798500e-01
            -7.73143762265326772720186454534996e-01 -3.31782118437088546780699971350259e-01
            -6.90530214598221725452731334371492e-01 -4.80623214141098653584549538209103e-01
            -5.79646278811610238257401306327665e-01 -6.09787538987342281338044358562911e-01
            -4.45031556264905536757225945621030e-01 -7.13987090340450603065391987911426e-01
            -2.92197189515727984154835894514690e-01 -7.88955926325099698992460162116913e-01
            -1.27400235496064551110606544170878e-01 -8.31624813987614119881186525162775e-01
            4.26124991337005834535212045466324e-02 -8.40246884053708842365892905945657e-01
            2.10880673042174476838894747743325e-01 -8.14469147961827899528941543394467e-01
            3.70515367418875529725852402407327e-01 -7.55346949256328281663286361435894e-01
            5.14981119119740649026084611250553e-01 -6.65300757698776390469674879568629e-01
            6.38363483296131795086125748639461e-01 -5.48017074951516192093947665853193e-01
            7.35611171461853952102671883039875e-01 -4.08297508766469807728327623408404e-01
            8.02742851837285442684333247598261e-01 -2.51862194599603295142031811337802e-01
            8.37010145540218464255133312690305e-01 -8.51156125932769486164275463124795e-02
            7.52717886232716182348667643964291e-01 8.79801029086347691210434618369618e-02
            7.12138670152147601477565785899060e-01 2.59197278605298953024771435593721e-01
            6.33167874033452426907331300753867e-01 4.16441061921636546117042598780245e-01
            5.20062833936218216202007624815451e-01 5.51234399798027574490788538241759e-01
            3.78921071848235480050703927190625e-01 6.56310548499600576732859735784587e-01
            2.17351576696850457004472900734982e-01 7.26004825651906715577865725208540e-01
            4.40646017863794148272660322618322e-02 7.56559994733973506519930651847972e-01
            -1.31597907212091913553564381800243e-01 7.46328818671676330609443539287895e-01
            -3.00165938969911172407023514097091e-01 6.95862862814774496555969562905375e-01
            -4.52551947262804787897039204835892e-01 6.07882759906139935601743218285264e-01
            -5.80540762940055632412850172840990e-01 4.87131540066377155540067178662866e-01
            -6.77232475819831925001324179902440e-01 3.40118932812337015914039284325554e-01
            -7.37414410633068562184178063034778e-01 1.74770425853879196598228418224608e-01
            -7.57842143696470738056802929349942e-01 9.28088955536851376390406013968813e-17
            -7.37414410633068562184178063034778e-01 -1.74770425853879002309199108822213e-01
            -6.77232475819831925001324179902440e-01 -3.40118932812336849380585590552073e-01
            -5.80540762940055521390547710325336e-01 -4.87131540066377211051218409920693e-01
            -4.52551947262804954430492898609373e-01 -6.07882759906139713557138293253956e-01
            -3.00165938969911227918174745354918e-01 -6.95862862814774496555969562905375e-01
            -1.31597907212092107842593691202637e-01 -7.46328818671676219587141076772241e-01
            4.40646017863788874713293353124755e-02 -7.56559994733973506519930651847972e-01
            2.17351576696850457004472900734982e-01 -7.26004825651906715577865725208540e-01
            3.78921071848235480050703927190625e-01 -6.56310548499600576732859735784587e-01
            5.20062833936218327224310087331105e-01 -5.51234399798027463468486075726105e-01
            6.33167874033452093840423913206905e-01 -4.16441061921637045717403680100688e-01
            7.12138670152147379432960860867752e-01 -2.59197278605299508136283748171991e-01
            7.52717886232716182348667643964291e-01 -8.79801029086346164653775758779375e-02
            6.57687865711685359926264027308207e-01 9.03971164459601711493874631742074e-02
            6.08910165433634187337474941159599e-01 2.64487008750374397170190832184744e-01
            5.14972383764024099761513753037434e-01 4.18961109563328104599122525542043e-01
            3.82841456232533683401442203830811e-01 5.42362781499513668670431343343807e-01
            2.22316929275401198307093864059425e-01 6.25539887076509759644693531299708e-01
            4.53041727061900545425743302985211e-02 6.62323560883609219196443973487476e-01
            -1.35068587099840015097740320015873e-01 6.49985726108650241350517262617359e-01
            -3.05423927698345587522510413691634e-01 5.89441423515052909110067957954016e-01
            -4.53127372800962824328507849713787e-01 4.85180947054429934084396336402278e-01
            -5.67224433582730225289481040817918e-01 3.44936819305923236811395327094942e-01
            -6.39253053004786631063893764803652e-01 1.79110305650444806557786137091171e-01
            -6.63871197873605822792342223692685e-01 8.13007737522030478590203176131445e-17
            -6.39253053004786631063893764803652e-01 -1.79110305650444917580088599606825e-01
            -5.67224433582730558356388428364880e-01 -3.44936819305922792722185477032326e-01
            -4.53127372800962768817356618455960e-01 -4.85180947054429989595547567660105e-01
            -3.05423927698346031611720263754250e-01 -5.89441423515052798087765495438362e-01
            -1.35068587099839904075437857500219e-01 -6.49985726108650241350517262617359e-01
            4.53041727061898949480145404322684e-02 -6.62323560883609219196443973487476e-01
            2.22316929275401059529215785914857e-01 -6.25539887076509759644693531299708e-01
            3.82841456232533572379139741315157e-01 -5.42362781499513890715036268375115e-01
            5.14972383764023877716908828006126e-01 -4.18961109563328326643727450573351e-01
            6.08910165433633965292870016128290e-01 -2.64487008750374674725946988473879e-01
            6.57687865711685359926264027308207e-01 -9.03971164459600046159337694007263e-02
            5.52953347641184422833759981585899e-01 9.22715939741211854663305302892695e-02
            4.93032272469049959173759134500870e-01 2.66815722973969604581157000211533e-01
            3.79683500390960826376129944037530e-01 4.12446228317079999214911367744207e-01
            2.25190129648990849942080672008160e-01 5.13381785059412010241430834867060e-01
            4.62939141746728580195657798412867e-02 5.58684459451402326557456490263576e-01
            -1.37618965224560768634276541888539e-01 5.43445003779258972720356268837349e-01
            -3.06618694363452404250125482576550e-01 4.69314849529576860742707822282682e-01
            -4.42391530288819889715767885718378e-01 3.44327149163166867928964620659826e-01
            -5.30224379495536690676260604959680e-01 1.82026259398721773630214215700107e-01
            -5.60599189904978034704186029557604e-01 6.86536003521730563067060363125722e-17
            -5.30224379495536690676260604959680e-01 -1.82026259398721884652516678215761e-01
            -4.42391530288820111760372810749686e-01 -3.44327149163166590373208464370691e-01
            -3.06618694363452348738974251318723e-01 -4.69314849529576916253859053540509e-01
            -1.37618965224560879656579004404193e-01 -5.43445003779258861698053806321695e-01
            4.62939141746728372028840681196016e-02 -5.58684459451402326557456490263576e-01
            2.25190129648990405852870821945544e-01 -5.13381785059412232286035759898368e-01
            3.79683500390960881887281175295357e-01 -4.12446228317079999214911367744207e-01
            4.93032272469049792640305440727388e-01 -2.66815722973969937648064387758495e-01
            5.52953347641184422833759981585899e-01 -9.22715939741211021996036834025290e-02
            4.39081398077247886391205611289479e-01 9.33296322685660539875129870779347e-02
            3.63160235420416976914737006154610e-01 2.63851355513371743644057687561144e-01
            2.24445368852231208478542612283491e-01 3.88750782375601511287044331766083e-01
            4.69218589873307487247977576316771e-02 4.46431667275104249181794102696585e-01
            -1.38714866568185796191770009500033e-01 4.26920461198367517940965853995294e-01
            -3.00366531509061895910406292387052e-01 3.33590828929801519464604098175187e-01
            -4.10082094407747788089579898951342e-01 1.82580311761732450026585183877614e-01
            -4.48890737704462305934782762051327e-01 2.54320793525852780336654270973028e-16
            -4.10082094407747732578428667693515e-01 -1.82580311761732533293312030764355e-01
            -3.00366531509062173466162448676187e-01 -3.33590828929801297419999173143879e-01
            -1.38714866568185879458496856386773e-01 -4.26920461198367462429814622737467e-01
            4.69218589873305405579806404148258e-02 -4.46431667275104304692945333954412e-01
            2.24445368852231208478542612283491e-01 -3.88750782375601511287044331766083e-01
            3.63160235420416921403585774896783e-01 -2.63851355513371854666360150076798e-01
            4.39081398077247886391205611289479e-01 -9.33296322685659152096349089333671e-02
            3.16068733301655135914387528828229e-01 9.28061536868369507669029871976818e-02
            2.15719143713332450751352098450297e-01 2.48953163001887245453502828240744e-01
            4.68802501946612437677686102688313e-02 3.26059302082832125346811835697736e-01
            -1.36842791520795509230268294231792e-01 2.99643916577416458135729726564023e-01
            -2.77119213813361353615505322522949e-01 1.78093704741414560199785910299397e-01
            -3.29412243750983879664318010327406e-01 1.86629788033269677327262164777398e-16
            -2.77119213813361409126656553780776e-01 -1.78093704741414476933059063412657e-01
            -1.36842791520795786786024450520927e-01 -2.99643916577416291602276032790542e-01
            4.68802501946611674399356672893191e-02 -3.26059302082832180857963066955563e-01
            2.15719143713332284217898404676816e-01 -2.48953163001887384231380906385311e-01
            3.16068733301655135914387528828229e-01 -9.28061536868369924002664106410521e-02
            1.82624108502567300549301876344543e-01 8.79471354371886004930303215587628e-02
            4.51044299472197901534897823694337e-02 1.97615419532740449470864518843882e-01
            -1.26379804321080924101039499873878e-01 1.58475262100209096649550133406592e-01
            -2.02697468257412305447928702051286e-01 2.48232805696712219300800987472859e-17
            -1.26379804321080951856615115502791e-01 -1.58475262100209041138398902148765e-01
            4.51044299472195611699909534308972e-02 -1.97615419532740477226440134472796e-01
            1.82624108502567356060453107602370e-01 -8.79471354371884755929400512286520e-02
            3.45931313785685715100903792063036e-02 5.99170611405859462883505273111950e-02
            -6.91862627571371291423929505981505e-02 8.47287352304957159035157885381293e-18
            3.45931313785685715100903792063036e-02 -5.99170611405859462883505273111950e-02
            ];
        
    case   22
        
        % DEGREE.             :          22
        % CARDIN.             :         276
        % LEBESGUE CONST.     : 2.73082e+01
        % ABS.DET.VAND.MATRIX : 1.00108e+278
        % CONDITIONING VAND.  : 5.90091e+02
        % POINTS OUT DISK     : 0.00000e+00
        
        pts=[
            9.97564050259824197652847033168655e-01 6.97564737441253024385900971537922e-02
            9.78147600733805466788339799677487e-01 2.07911690817759259308772357144335e-01
            9.39692620785908427905042117345147e-01 3.42020143325668712908083080037613e-01
            8.82947592858926988412804348627105e-01 4.69471562785890805802324621254229e-01
            8.09016994374947451262869435595348e-01 5.87785252292473137103456792829093e-01
            7.19339800338651191857763933512615e-01 6.94658370458997254104360763449222e-01
            6.15661475325658291701813595864223e-01 7.88010753606722014197316639183555e-01
            5.00000000000000111022302462515654e-01 8.66025403784438596588302061718423e-01
            3.74606593415911959255026886239648e-01 9.27183854566787424289486807538196e-01
            2.41921895599667896581408399470092e-01 9.70295726275996472942608761513839e-01
            1.04528463267653456969519254471379e-01 9.94521895368273289861349439888727e-01
            -3.48994967025007332694919170990033e-02 9.99390827019095762118183756683720e-01
            -1.73648177666930303431058746355120e-01 9.84807753012208020315654266596539e-01
            -3.09016994374947340240566973079694e-01 9.51056516295153642204240895807743e-01
            -4.38371146789077514860366591165075e-01 8.98794046299166926594637061498361e-01
            -5.59192903470746682792480442003580e-01 8.29037572555041735178349426860223e-01
            -6.69130606358858237570075289113447e-01 7.43144825477394244117590460518841e-01
            -7.66044443118977902429378445958719e-01 6.42787609686539473941024880332407e-01
            -8.48048096156425956770874563517282e-01 5.29919264233204900804707904171664e-01
            -9.13545457642600755576722804107703e-01 4.06736643075800430313648803348769e-01
            -9.61261695938318672105538098549005e-01 2.75637355816999662927457848127233e-01
            -9.90268068741570250956840482103871e-01 1.39173100960065743159077555901604e-01
            -1.00000000000000000000000000000000e+00 1.22464679914735320717376402945840e-16
            -9.90268068741570250956840482103871e-01 -1.39173100960065521114472630870296e-01
            -9.61261695938318894150143023580313e-01 -2.75637355816998996793643073033309e-01
            -9.13545457642601088643630191654665e-01 -4.06736643075799819690985259512672e-01
            -8.48048096156426067793177026032936e-01 -5.29919264233204789782405441656010e-01
            -7.66044443118978124473983370990027e-01 -6.42787609686539251896419955301099e-01
            -6.69130606358858459614680214144755e-01 -7.43144825477394022072985535487533e-01
            -5.59192903470747237903992754581850e-01 -8.29037572555041402111442039313260e-01
            -4.38371146789077736904971516196383e-01 -8.98794046299166815572334598982707e-01
            -3.09016994374947562285171898111003e-01 -9.51056516295153531181938433292089e-01
            -1.73648177666930331186634361984034e-01 -9.84807753012208020315654266596539e-01
            -3.48994967025016492034872328531492e-02 -9.99390827019095651095881294168066e-01
            1.04528463267652985124733788779849e-01 -9.94521895368273400883651902404381e-01
            2.41921895599667396981047318149649e-01 -9.70295726275996361920306298998185e-01
            3.74606593415911959255026886239648e-01 -9.27183854566787424289486807538196e-01
            5.00000000000000111022302462515654e-01 -8.66025403784438596588302061718423e-01
            6.15661475325658513746418520895531e-01 -7.88010753606721792152711714152247e-01
            7.19339800338650858790856545965653e-01 -6.94658370458997587171268150996184e-01
            8.09016994374947118195962048048386e-01 -5.87785252292473248125759255344747e-01
            8.82947592858926988412804348627105e-01 -4.69471562785890805802324621254229e-01
            9.39692620785908427905042117345147e-01 -3.42020143325668601885780617521959e-01
            9.78147600733805355766037337161833e-01 -2.07911690817759814420284669722605e-01
            9.97564050259824308675149495684309e-01 -6.97564737441247612048655923899787e-02
            9.67878119190277108607745049084770e-01 7.43083824285684646504535066924291e-02
            9.45191876411910492095103109022602e-01 2.21183421782444128433908758779580e-01
            9.00351137157934244825696623593103e-01 3.62874109196114458253390466779820e-01
            8.34406930351213271812582661368651e-01 4.96059335048060823236681926573510e-01
            7.48904932307579485062376534187933e-01 6.17617350526876385252705858874833e-01
            6.45849237393042563404321754205739e-01 7.24698938777534107380517980345758e-01
            5.27655383750442408263836568949046e-01 8.14794198129584201772956930653891e-01
            3.97093735132696912248917442411766e-01 8.85791372065015236714202728762757e-01
            2.57224545924483682934891248805798e-01 9.36026347001195246910754121927312e-01
            1.11326231373216288922378680581460e-01 9.64321657702810197676512871112209e-01
            -3.71814756857012720936417338180036e-02 9.70014086069007741564007574197603e-01
            -1.84817680468103207047647629224230e-01 9.52970206403562669628115600062301e-01
            -3.28121915464535174322691091219895e-01 9.13589512800110470358561087778071e-01
            -4.63735250865717374413321749671013e-01 8.52795055339188201593003668676829e-01
            -5.88479025030380187288869819894899e-01 7.72011804576686500034554683224997e-01
            -6.99429349620023121936185361846583e-01 6.73133251441770719125656796677504e-01
            -7.93985643063400026164799783146009e-01 5.58477025414347738596632098051487e-01
            -8.69931585984395794319823380646994e-01 4.30730571254389293933684257353889e-01
            -9.25487069849738941407224501745077e-01 2.92888157574530849647231889321120e-01
            -9.59349921204270095209665214497363e-01 1.48180693721616824065634432372462e-01
            -9.70726423513061043024663376854733e-01 5.49968831138795317753449819283006e-16
            -9.59349921204270095209665214497363e-01 -1.48180693721616574265453891712241e-01
            -9.25487069849738941407224501745077e-01 -2.92888157574531016180685583094601e-01
            -8.69931585984395905342125843162648e-01 -4.30730571254389071889079332322581e-01
            -7.93985643063400359231707170692971e-01 -5.58477025414347183485119785473216e-01
            -6.99429349620023343980790286877891e-01 -6.73133251441770608103354334161850e-01
            -5.88479025030380076266567357379245e-01 -7.72011804576686611056857145740651e-01
            -4.63735250865717152368716824639705e-01 -8.52795055339188312615306131192483e-01
            -3.28121915464535174322691091219895e-01 -9.13589512800110470358561087778071e-01
            -1.84817680468103900937038019947067e-01 -9.52970206403562558605813137546647e-01
            -3.71814756857015080160344666637684e-02 -9.70014086069007741564007574197603e-01
            1.11326231373216275044590872767003e-01 -9.64321657702810197676512871112209e-01
            2.57224545924483294356832630001009e-01 -9.36026347001195357933056584442966e-01
            3.97093735132696690204312517380458e-01 -8.85791372065015347736505191278411e-01
            5.27655383750442630308441493980354e-01 -8.14794198129584090750654468138237e-01
            6.45849237393042230337414366658777e-01 -7.24698938777534440447425367892720e-01
            7.48904932307578929950864221609663e-01 -6.17617350526877051386520633968757e-01
            8.34406930351212938745675273821689e-01 -4.96059335048061322837043007893953e-01
            9.00351137157934133803394161077449e-01 -3.62874109196114624786844160553301e-01
            9.45191876411910492095103109022602e-01 -2.21183421782444017411606296263926e-01
            9.67878119190277108607745049084770e-01 -7.43083824285688671062999333116750e-02
            9.15451315632558326740308984881267e-01 7.79163898215975425642909613088705e-02
            8.89115448039824451953450079599861e-01 2.31507656791639121474091211894120e-01
            8.37201347815406116126268898369744e-01 3.78438869980714909235786080898833e-01
            7.61202489102995594194567274826113e-01 5.14483085902361803043447707750602e-01
            6.63305220696975172955944799468853e-01 6.35726560159594167309649037633790e-01
            5.46325868768278155584994237869978e-01 7.38681338745469484585726149816765e-01
            4.13629716288123061573855920869391e-01 8.20385600129365899491062918968964e-01
            2.69034189964087511182100342921331e-01 8.78488861469842619023040697356919e-01
            1.16699039824101680196122288180050e-01 9.11319597726475860710593224212062e-01
            -3.89933292182161883587809825257864e-02 9.17933328391933311962702646269463e-01
            -1.93563931173902192828251145328977e-01 8.98139788476558953433936949295457e-01
            -3.42566051250677183759307808941230e-01 8.52508402085710548234942507406231e-01
            -4.81713169741409763524586651328718e-01 7.82351901124996862435523325984832e-01
            -6.07002277391642364179347168828826e-01 6.89688560393437732898291869787499e-01
            -7.14829034687582187679311118699843e-01 5.77184135492160299563124681299087e-01
            -8.02091462141507061112122300983174e-01 4.48075173889284250616782401266391e-01
            -8.66279178593870491376094378210837e-01 3.06075905342028276034938016891829e-01
            -9.05545620308618071092610080086160e-01 1.55271390269080572510418392084830e-01
            -9.18761163249847578882167908886913e-01 1.12515791775482456036508765224801e-16
            -9.05545620308618071092610080086160e-01 -1.55271390269080350465813467053522e-01
            -8.66279178593870491376094378210837e-01 -3.06075905342028053990333091860521e-01
            -8.02091462141507394179029688530136e-01 -4.48075173889283695505270088688121e-01
            -7.14829034687582076657008656184189e-01 -5.77184135492160521607729606330395e-01
            -6.07002277391642586223952093860134e-01 -6.89688560393437621875989407271845e-01
            -4.81713169741410263124947732649161e-01 -7.82351901124996529368615938437870e-01
            -3.42566051250677405803912733972538e-01 -8.52508402085710437212640044890577e-01
            -1.93563931173901998539221835926583e-01 -8.98139788476558953433936949295457e-01
            -3.89933292182166185702030247739458e-02 -9.17933328391933200940400183753809e-01
            1.16699039824101041817883128715039e-01 -9.11319597726475860710593224212062e-01
            2.69034189964087122604041724116541e-01 -8.78488861469842730045343159872573e-01
            4.13629716288123061573855920869391e-01 -8.20385600129365899491062918968964e-01
            5.46325868768278377629599162901286e-01 -7.38681338745469484585726149816765e-01
            6.63305220696975061933642336953199e-01 -6.35726560159594278331951500149444e-01
            7.61202489102995261127659887279151e-01 -5.14483085902362358154960020328872e-01
            8.37201347815406005103966435854090e-01 -3.78438869980715186791542237187969e-01
            8.89115448039824451953450079599861e-01 -2.31507656791639065962939980636293e-01
            9.15451315632558215718006522365613e-01 -7.79163898215979450201373879281164e-02
            8.48545631322156657105892918480095e-01 8.10262835621184118739535051645362e-02
            8.17876981342095965565874848834937e-01 2.40150349686497593948431017452094e-01
            7.57648126298642088372048419842031e-01 3.90594756467573744895815934796701e-01
            6.70035893937816595666845387313515e-01 5.26922051065200069963623263902264e-01
            5.58206818608584676155714987544343e-01 6.44205009855316923506052262382582e-01
            4.26202694461158548833168424607720e-01 7.38204721129480878616391237301286e-01
            2.78794494475616772000137189024827e-01 8.05523790408384843253486451430945e-01
            1.21309935067756419213580443283718e-01 8.43729131130164899943224554590415e-01
            -4.05590814634059770860119442659197e-02 8.51439902738091669576192543900106e-01
            -2.00962187114824497591314411693020e-01 8.28377417856035358489918962732190e-01
            -3.54101995722042428571540995108080e-01 7.75375214776351295853373812860809e-01
            -4.94443635600114284045503154629841e-01 6.94348931214233022757298385840841e-01
            -6.16914794227271245929955512110610e-01 5.88227068169537625763609867135528e-01
            -7.17089044835235944752582781802630e-01 4.60845146270518146724981534134713e-01
            -7.91345829005572709569094058679184e-01 3.16807080064964885490752521945979e-01
            -8.37001313084201337133549714053515e-01 1.61318780553068141792039114079671e-01
            -8.52405388922316875621731924184132e-01 1.04389553111967007427557292462579e-16
            -8.37001313084201559178154639084823e-01 -1.61318780553067558924951185872487e-01
            -7.91345829005572820591396521194838e-01 -3.16807080064964663446147596914670e-01
            -7.17089044835236277819490169349592e-01 -4.60845146270517647124620452814270e-01
            -6.16914794227271356952257974626264e-01 -5.88227068169537514741307404619874e-01
            -4.94443635600114450578956848403323e-01 -6.94348931214232911734995923325187e-01
            -3.54101995722042262038087301334599e-01 -7.75375214776351406875676275376463e-01
            -2.00962187114824525346890027321933e-01 -8.28377417856035358489918962732190e-01
            -4.05590814634063795418583708851656e-02 -8.51439902738091669576192543900106e-01
            1.21309935067756016757734016664472e-01 -8.43729131130165010965527017106069e-01
            2.78794494475616772000137189024827e-01 -8.05523790408384954275788913946599e-01
            4.26202694461158548833168424607720e-01 -7.38204721129480878616391237301286e-01
            5.58206818608584121044202674966073e-01 -6.44205009855317367595262112445198e-01
            6.70035893937816262599937999766553e-01 -5.26922051065200403030530651449226e-01
            7.57648126298641977349745957326377e-01 -3.90594756467573966940420859828009e-01
            8.17876981342095965565874848834937e-01 -2.40150349686497704970733479967748e-01
            8.48545631322156546083590455964440e-01 -8.10262835621190780077682802584604e-02
            7.70008849103553827397661279974272e-01 8.37435089805133731077901870776259e-02
            7.34004091122840263139437411155086e-01 2.47314773535836612827765179645212e-01
            6.63678117628176855724575489148265e-01 3.99321874151252587115124015326728e-01
            5.62319292978468388000123923120555e-01 5.32657127745742586810706598043907e-01
            4.34667043162092925356887462839950e-01 6.41085926052718968470855998020852e-01
            2.86690245505178575857740952415043e-01 7.19538258973301148024859230645234e-01
            1.25308130601764045053414520225488e-01 7.64345782613628399460026230372023e-01
            -4.19332532186042078459209392349294e-02 7.73413346968264692193884002335835e-01
            -2.07213884723934593790062308471533e-01 7.46316962805860906193800019536866e-01
            -3.62805425281265137016362132271752e-01 6.84323626934383422160124155197991e-01
            -5.01432587381712591145799251535209e-01 5.90332078838538221177145715046208e-01
            -6.16613318998484150057493025087751e-01 4.68737258843184567691508846110082e-01
            -7.02961897135368829481194552499801e-01 3.25224805588368526265696800692240e-01
            -7.56440758248236977401290914713172e-01 1.66505201885650822024587114356109e-01
            -7.74549290228936260227499133179663e-01 9.48549309060721046795513117411152e-17
            -7.56440758248236977401290914713172e-01 -1.66505201885650627735557804953714e-01
            -7.02961897135368718458892089984147e-01 -3.25224805588368692799150494465721e-01
            -6.16613318998484483124400412634714e-01 -4.68737258843184123602298996047466e-01
            -5.01432587381712480123496789019555e-01 -5.90332078838538332199448177561862e-01
            -3.62805425281265636616723213592195e-01 -6.84323626934383200115519230166683e-01
            -2.07213884723934954612545311647409e-01 -7.46316962805860906193800019536866e-01
            -4.19332532186047352018576361842861e-02 -7.73413346968264581171581539820181e-01
            1.25308130601763878519960826452007e-01 -7.64345782613628510482328692887677e-01
            2.86690245505178242790833564868080e-01 -7.19538258973301259047161693160888e-01
            4.34667043162092869845736231582123e-01 -6.41085926052718968470855998020852e-01
            5.62319292978468388000123923120555e-01 -5.32657127745742586810706598043907e-01
            6.63678117628176855724575489148265e-01 -3.99321874151252587115124015326728e-01
            7.34004091122840263139437411155086e-01 -2.47314773535836529561038332758471e-01
            7.70008849103553827397661279974272e-01 -8.37435089805139420970903074703529e-02
            6.81429673573651029094833120325347e-01 8.60845871172937343596132109269092e-02
            6.38612941059985339542492965847487e-01 2.52844750146336449958539560611825e-01
            5.55669808805414389141219544399064e-01 4.03717747625741307793134637904586e-01
            4.37811898852995429187728859687923e-01 5.29223674251806386337193544022739e-01
            2.92444657136111230144592809665482e-01 6.21476531076105787043672989966581e-01
            1.28702042075151235067664856615011e-01 6.74679731822094619353435973607702e-01
            -4.31273956223912277585519348122034e-02 6.85490323719217253817248547420604e-01
            -2.12246980441512494985900616484287e-01 6.53229037520001609706810086208861e-01
            -3.68030306889703173744976538728224e-01 5.79922968485055312370946012379136e-01
            -5.00688935635224652287433855235577e-01 4.70178206532707476661414602858713e-01
            -6.01887437149688619975052006338956e-01 3.30890418669424757336372522331658e-01
            -6.65267137400886388043375063716667e-01 1.70811568871308327999258835916407e-01
            -6.86845656727803399732579237024765e-01 8.41143335019966107045152837590821e-17
            -6.65267137400886499065677526232321e-01 -1.70811568871307856154473370224878e-01
            -6.01887437149688619975052006338956e-01 -3.30890418669424868358674984847312e-01
            -5.00688935635224985354341242782539e-01 -4.70178206532707199105658446569578e-01
            -3.68030306889702785166917919923435e-01 -5.79922968485055534415550937410444e-01
            -2.12246980441512800297232388402335e-01 -6.53229037520001609706810086208861e-01
            -4.31273956223910959195677605748642e-02 -6.85490323719217253817248547420604e-01
            1.28702042075150902000757469068049e-01 -6.74679731822094730375738436123356e-01
            2.92444657136110619521929265829385e-01 -6.21476531076106120110580377513543e-01
            4.37811898852995151631972703398787e-01 -5.29223674251806608381798469054047e-01
            5.55669808805414389141219544399064e-01 -4.03717747625741474326588331678067e-01
            6.38612941059985339542492965847487e-01 -2.52844750146336449958539560611825e-01
            6.81429673573651029094833120325347e-01 -8.60845871172939980375815594015876e-02
            5.83807152521080174878420621098485e-01 8.79947698978704451189258861631970e-02
            5.31933325024091741006770917010726e-01 2.56165588229498253358684678460122e-01
            4.32794887247764881177403140100068e-01 4.01574969882767141005075473003672e-01
            2.95200724450394524911445159887080e-01 5.11302653179223298707256617490202e-01
            1.31376681818564822190609220342594e-01 5.75598851925969823284390258777421e-01
            -4.41207555299163098339043642681645e-02 5.88750566705137257095259428751888e-01
            -2.15697870128818108836910028003331e-01 5.49589209943247003486987978249090e-01
            -3.68109282392262038285934977466241e-01 4.61594440045376641634788938972633e-01
            -4.87812569494175396478397033206420e-01 3.32584978475638892714272287776112e-01
            -5.64171569066329592345709897927009e-01 1.74023882043202821057192863918317e-01
            -5.90401448900788938800587857258506e-01 7.23033244608310783997440477649020e-17
            -5.64171569066329703368012360442663e-01 -1.74023882043202432479134245113528e-01
            -4.87812569494175340967245801948593e-01 -3.32584978475639003736574750291766e-01
            -3.68109282392262204819388671239722e-01 -4.61594440045376475101335245199152e-01
            -2.15697870128817970059031949858763e-01 -5.49589209943247003486987978249090e-01
            -4.41207555299167122897507908874104e-02 -5.88750566705137257095259428751888e-01
            1.31376681818564683412731142198027e-01 -5.75598851925969823284390258777421e-01
            2.95200724450394080822235309824464e-01 -5.11302653179223631774164005037164e-01
            4.32794887247765047710856833873549e-01 -4.01574969882767029982773010488017e-01
            5.31933325024091741006770917010726e-01 -2.56165588229498364380987140975776e-01
            5.83807152521080063856118158582831e-01 -8.79947698978709308414991596691834e-02
            4.77749165364121874954861368678394e-01 8.93067966978506738717769053437223e-02
            4.13226493282184137445511851183255e-01 2.55859012333463420318935277464334e-01
            2.92895293515442634024736889841734e-01 3.87856050589711731646502812509425e-01
            1.33006961370591814119990203835187e-01 4.67470980029250804399509888753528e-01
            -4.48446979243730947661816799154622e-02 4.83951363269717493853505629886058e-01
            -2.16639832271601773250324640684994e-01 4.35071433233530702189284511405276e-01
            -3.59176556827799753346397437780979e-01 3.27432695325119704765626238440746e-01
            -4.53204497118395277510671803611331e-01 1.75572357545852819615816997611546e-01
            -4.86024658780340401698083496739855e-01 5.95208542682028375396150752739747e-17
            -4.53204497118395388532974266126985e-01 -1.75572357545852514304485225693497e-01
            -3.59176556827799642324094975265325e-01 -3.27432695325119760276777469698573e-01
            -2.16639832271602272850685722005437e-01 -4.35071433233530424633528355116141e-01
            -4.48446979243731086439694877299189e-02 -4.83951363269717493853505629886058e-01
            1.33006961370591703097687741319533e-01 -4.67470980029250804399509888753528e-01
            2.92895293515442523002434427326079e-01 -3.87856050589711842668805275025079e-01
            4.13226493282183970912058157409774e-01 -2.55859012333463586852388971237815e-01
            4.77749165364121874954861368678394e-01 -8.93067966978505489716866350136115e-02
            3.63460783086254679563609215620090e-01 8.95850371110291504583855726195907e-02
            2.80196297858462284313674217628432e-01 2.48232258947683553929053346109868e-01
            1.32742217522739319734981222609349e-01 3.50012461782439499025088025518926e-01
            -4.51215051303048703124076723725011e-02 3.71609027730266272548931283381535e-01
            -2.12648434731080776538547638665477e-01 3.08074443799350561334904341492802e-01
            -3.31460170626412586880604749239865e-01 1.73963717493526154322935894924740e-01
            -3.74338375959315627916623725468526e-01 -1.20396404204668710152476793679784e-16
            -3.31460170626412808925209674271173e-01 -1.73963717493525765744877276119951e-01
            -2.12648434731080859805274485552218e-01 -3.08074443799350505823753110234975e-01
            -4.51215051303051339903760208471795e-02 -3.71609027730266272548931283381535e-01
            1.32742217522739319734981222609349e-01 -3.50012461782439499025088025518926e-01
            2.80196297858462117780220523854950e-01 -2.48232258947683692706931424254435e-01
            3.63460783086254679563609215620090e-01 -8.95850371110291782139611882485042e-02
            2.40412740367426380760917936640908e-01 8.75030814321118566301294094955665e-02
            1.27920947259518830163571578850679e-01 2.21565580005825296661114975904638e-01
            -4.44264787540858824277378857914300e-02 2.51955081267679736889419928047573e-01
            -1.95986261613340456699816627406108e-01 1.64451999835567935770441749809834e-01
            -2.55841894519037604815991926443530e-01 3.13315957210534153481624289073760e-17
            -1.95986261613340567722119089921762e-01 -1.64451999835567796992563671665266e-01
            -4.44264787540858893666317896986584e-02 -2.51955081267679736889419928047573e-01
            1.27920947259518635874542269448284e-01 -2.21565580005825407683417438420292e-01
            2.40412740367426380760917936640908e-01 -8.75030814321118288745537938666530e-02
            1.05938207306452675249275330315868e-01 7.69686129487861248055224905328942e-02
            -4.04647944838324655214556457849540e-02 1.24537831818071223488608723073412e-01
            -1.30946825645240405577851561247371e-01 1.60363610884950212969470935782250e-17
            -4.04647944838324932770312614138675e-02 -1.24537831818071209610820915258955e-01
            1.05938207306452661371487522501411e-01 -7.69686129487861525610981061618077e-02
            -0.00000000000000000000000000000000e+00 0.00000000000000000000000000000000e+00
            ];
        
    case   23
        
        % DEGREE.             :          23
        % CARDIN.             :         300
        % LEBESGUE CONST.     : 3.18585e+01
        % ABS.DET.VAND.MATRIX : 3.22677e+306
        % CONDITIONING VAND.  : 6.23600e+02
        % POINTS OUT DISK     : 0.00000e+00
        
        pts=[
            9.97766878623153163907488760742126e-01 6.67926337451215518248304192638898e-02
            9.79961705036586860906311358121457e-01 1.99185985103836088461193298826402e-01
            9.44669091607918787190101284068078e-01 3.28024857839569083939323945742217e-01
            8.92518835859881232153156815911643e-01 4.51010119216101790229345169791486e-01
            8.24441560341760304453373464639299e-01 5.65947094330595201761013868235750e-01
            7.41652105647957582412743704480818e-01 6.70784730139223461797826075780904e-01
            6.45627851558802423603822262521135e-01 7.63652196547331962861449028423522e-01
            5.38082353163372717474999262776691e-01 8.42892271416797012051347337546758e-01
            4.20934762428334996453571648089564e-01 9.07090913734340698049152251769556e-01
            2.96275580885634159944430621180800e-01 9.55102497206912426364056045713369e-01
            1.66329354583129945810426875141275e-01 9.86070253990028566803971443732735e-01
            3.34149770076746441271886567392357e-02 9.99441563730254611819248111714842e-01
            -1.00095691624098329097769521922601e-01 9.94977815088504025098359306866769e-01
            -2.31820150267528085619161970498681e-01 9.72758663765037168147387092176359e-01
            -3.59407772837512906605184070940595e-01 9.33180611041602547928164312907029e-01
            -4.80581755186683723390927980290144e-01 8.76949928206671613928335773380240e-01
            -5.93179744729355196142250861157663e-01 8.05070053127562967887342892936431e-01
            -6.95192427674642177137798171315808e-01 7.18823683877929275887197491101688e-01
            -7.84799385278660999176736368099228e-01 6.19749888960244854629877409024630e-01
            -8.60401579260139159899267724540550e-01 5.09616642591917745619412016822025e-01
            -9.20649886676428663712101752025774e-01 3.90389275163495086395926136901835e-01
            -9.64469175054376570699332660296932e-01 2.64195401871286206230138304817956e-01
            -9.91077488154780028573043182404945e-01 1.33286955373779020250779581147071e-01
            -1.00000000000000000000000000000000e+00 -3.21624529935327320103979552447107e-16
            -9.91077488154780139595345644920599e-01 -1.33286955373778326361389190424234e-01
            -9.64469175054376570699332660296932e-01 -2.64195401871285984185533379786648e-01
            -9.20649886676428774734404214541428e-01 -3.90389275163494864351321211870527e-01
            -8.60401579260139270921570187056204e-01 -5.09616642591917523574807091790717e-01
            -7.84799385278661110199038830614882e-01 -6.19749888960244632585272483993322e-01
            -6.95192427674642399182403096347116e-01 -7.18823683877929164864895028586034e-01
            -5.93179744729354974097645936126355e-01 -8.05070053127563078909645355452085e-01
            -4.80581755186683556857474286516663e-01 -8.76949928206671613928335773380240e-01
            -3.59407772837513350694393921003211e-01 -9.33180611041602436905861850391375e-01
            -2.31820150267528751752976745592605e-01 -9.72758663765037057125084629660705e-01
            -1.00095691624098787064767179799674e-01 -9.94977815088504025098359306866769e-01
            3.34149770076741792212970949549344e-02 -9.99441563730254611819248111714842e-01
            1.66329354583129696010246334481053e-01 -9.86070253990028566803971443732735e-01
            2.96275580885633715855220771118184e-01 -9.55102497206912537386358508229023e-01
            4.20934762428334774408966723058256e-01 -9.07090913734340809071454714285210e-01
            5.38082353163372495430394337745383e-01 -8.42892271416797123073649800062412e-01
            6.45627851558802312581519800005481e-01 -7.63652196547332073883751490939176e-01
            7.41652105647957471390441241965163e-01 -6.70784730139223461797826075780904e-01
            8.24441560341760304453373464639299e-01 -5.65947094330595201761013868235750e-01
            8.92518835859880788063946965849027e-01 -4.51010119216102622896613638658891e-01
            9.44669091607918787190101284068078e-01 -3.28024857839569028428172714484390e-01
            9.79961705036586860906311358121457e-01 -1.99185985103835977438890836310748e-01
            9.97766878623152941862883835710818e-01 -6.67926337451222595920086178011843e-02
            9.70127364734027719528342004196020e-01 7.10041712374835654042470878266613e-02
            9.49450784241560041820662263489794e-01 2.11499183076431285233098833487020e-01
            9.08538308672171779356574461417040e-01 3.47486457022458117283036926892237e-01
            8.48261916412420990951659405254759e-01 4.76067660425740279972472990266397e-01
            7.69906294114452660615199874882819e-01 5.94502308172021320942235433903988e-01
            6.75141455830416958860951126553118e-01 7.00266171364929079778960385738173e-01
            5.65987149562343194730829054606147e-01 7.91105076882461233367394015658647e-01
            4.44769809840062702033236519127968e-01 8.65082951163497093638454771280522e-01
            3.14072973808244559901226011788822e-01 9.20623084254439505436096169432858e-01
            1.76682217617566333922596299998986e-01 9.56541734644469121562337932118680e-01
            3.55257867052407236285738179049076e-02 9.72073358660695330257794921635650e-01
            -1.06387814672604441579295553310658e-01 9.66886926702444693404459030716680e-01
            -2.46033944485931327372796317831671e-01 9.41092978562482196380756249709520e-01
            -3.80436287924427185558329256309662e-01 8.95241267463242840207726658263709e-01
            -5.06730292380359048642901598213939e-01 8.30309043021348114343993529473664e-01
            -6.22224220414112405563855645596050e-01 7.47680222868681410020030853047501e-01
            -7.24456519464456660806206400593510e-01 6.49115896850752327473799141444033e-01
            -8.11248285567761517889096012368100e-01 5.36716792454157154423910469631664e-01
            -8.80749702913079635102633346832590e-01 4.12878501447378642996710595980403e-01
            -9.31479469454596031852133819484152e-01 2.80240422001351074943187313692761e-01
            -9.62356368292973995970385203690967e-01 1.41629504499835079389669090232928e-01
            -9.72722311936408234878115308674751e-01 1.19124126577213559980538038989644e-16
            -9.62356368292973995970385203690967e-01 -1.41629504499834829589488549572707e-01
            -9.31479469454596142874436281999806e-01 -2.80240422001350852898582388661453e-01
            -8.80749702913079746124935809348244e-01 -4.12878501447378476463256902206922e-01
            -8.11248285567761850956003399915062e-01 -5.36716792454156599312398157053394e-01
            -7.24456519464456771828508863109164e-01 -6.49115896850752105429194216412725e-01
            -6.22224220414112183519250720564742e-01 -7.47680222868681521042333315563155e-01
            -5.06730292380359714776716373307863e-01 -8.30309043021347781277086141926702e-01
            -3.80436287924427185558329256309662e-01 -8.95241267463242840207726658263709e-01
            -2.46033944485931382883947549089498e-01 -9.41092978562482196380756249709520e-01
            -1.06387814672604885668505403373274e-01 -9.66886926702444693404459030716680e-01
            3.55257867052402656615761600278347e-02 -9.72073358660695330257794921635650e-01
            1.76682217617565640033205909276148e-01 -9.56541734644469232584640394634334e-01
            3.14072973808244504390074780530995e-01 -9.20623084254439505436096169432858e-01
            4.44769809840062479988631594096660e-01 -8.65082951163497204660757233796176e-01
            5.65987149562342972686224129574839e-01 -7.91105076882461344389696478174301e-01
            6.75141455830416625794043739006156e-01 -7.00266171364929523868170235800790e-01
            7.69906294114452771637502337398473e-01 -5.94502308172021209919932971388334e-01
            8.48261916412420990951659405254759e-01 -4.76067660425740335483624221524224e-01
            9.08538308672171668334271998901386e-01 -3.47486457022458339327641851923545e-01
            9.49450784241560152842964726005448e-01 -2.11499183076430813388313367795490e-01
            9.70127364734027719528342004196020e-01 -7.10041712374841343935472082193883e-02
            9.21192318874608395695702256489312e-01 7.43663321283248857085368399566505e-02
            8.97333921695811942420561990729766e-01 2.21172947445687523293500476029294e-01
            8.50235047292910661731468735524686e-01 3.62251299601009546513807890733005e-01
            7.81115531773039606378006283193827e-01 4.93947533378515768465177870893967e-01
            6.91765534281352567624878702190472e-01 6.12850785500217098977771001955261e-01
            5.84499172819491041863670943712350e-01 7.15881524193164975322645204869332e-01
            4.62094589804889932516118733474286e-01 8.00371307444768920191791039542295e-01
            3.27721999641459871277504589670571e-01 8.64131894249252519024651064682985e-01
            1.84861581831759630434319774394680e-01 9.05511918900274825894314290053444e-01
            3.72133461559370076754404976782098e-02 9.23439660495300906895010939479107e-01
            -1.11398695638053435441605643063667e-01 9.17450799944029005139611854247050e-01
            -2.57125569730059733153382239834173e-01 8.87700445588933129137387822993333e-01
            -3.96193026627904010261715939122951e-01 8.34959115980668409306986177398358e-01
            -5.24999292246704274411683854850708e-01 7.60592783852343634620751799957361e-01
            -6.40208351965751987222574825864285e-01 6.66527498143245633599462962592952e-01
            -7.38836351654857059756409398687538e-01 5.55199500343019680670408888545353e-01
            -8.18328877928976350375478432397358e-01 4.29492127116785249452135531100794e-01
            -8.76627116113112170303622860956239e-01 2.92661133400057782427694519356010e-01
            -9.12221172460950691096570608351612e-01 1.48250370056087293901825319153431e-01
            -9.24189179609780087076842391979881e-01 1.13180532061573541957467335510632e-16
            -9.12221172460950691096570608351612e-01 -1.48250370056087071857220394122123e-01
            -8.76627116113112281325925323471893e-01 -2.92661133400057560383089594324701e-01
            -8.18328877928976461397780894913012e-01 -4.29492127116785027407530606069486e-01
            -7.38836351654857281801014323718846e-01 -5.55199500343019458625803963514045e-01
            -6.40208351965752098244877288379939e-01 -6.66527498143245411554858037561644e-01
            -5.24999292246704496456288779882016e-01 -7.60592783852343523598449337441707e-01
            -3.96193026627903843728262245349470e-01 -8.34959115980668520329288639914012e-01
            -2.57125569730059733153382239834173e-01 -8.87700445588933129137387822993333e-01
            -1.11398695638053865653027685311827e-01 -9.17450799944029005139611854247050e-01
            3.72133461559365774640184554300504e-02 -9.23439660495301017917313401994761e-01
            1.84861581831759380634139233734459e-01 -9.05511918900274936916616752569098e-01
            3.27721999641459704744050895897090e-01 -8.64131894249252630046953527198639e-01
            4.62094589804889432915757652153843e-01 -8.00371307444769253258698427089257e-01
            5.84499172819490486752158631134080e-01 -7.15881524193165419411855054931948e-01
            6.91765534281352345580273777159164e-01 -6.12850785500217432044678389502224e-01
            7.81115531773039384333401358162519e-01 -4.93947533378516101532085258440929e-01
            8.50235047292910550709166273009032e-01 -3.62251299601009713047261584506487e-01
            8.97333921695811942420561990729766e-01 -2.21172947445687578804651707287121e-01
            9.21192318874608395695702256489312e-01 -7.43663321283247746862343774409965e-02
            8.58678255267109058479491068283096e-01 7.72824417624152493200284652630216e-02
            8.31079629620002258150179841322824e-01 2.29363404020796857185615635899012e-01
            7.76769420862311710251901786250528e-01 3.74072437753112552183409889039467e-01
            6.97493203790098159622345974639757e-01 5.06758475548216291706182801135583e-01
            5.95798981248751191586165987246204e-01 6.23156878976937722569573452346958e-01
            4.74955289225034604783104441594332e-01 7.19526507580152463461331535654608e-01
            3.38846143411111633270138554507867e-01 7.92769962201358757702962520852452e-01
            1.91846203744420185088870312029030e-01 8.40533137944115771311714979674434e-01
            3.86801692378008279971091099014302e-02 8.61280887040379194985462163458578e-01
            -1.15729077734270699440166652038897e-01 8.54346359762890750211283830140019e-01
            -2.66418696925760423166451573706581e-01 8.19952437524096522381000795576256e-01
            -4.08545399988022250870045581905288e-01 7.59204569284164909603873638843652e-01
            -5.37541117742394214396028928604210e-01 6.74055241511840042001324491138803e-01
            -6.49259821682220739091917494079098e-01 5.67241223662824478601862665527733e-01
            -7.40110780740419915701977515709586e-01 4.42195606157652298939808588329470e-01
            -8.07173970340443247550865635275841e-01 3.02937458030816453291578227435821e-01
            -8.48293924388769715605462806706782e-01 1.53942650745099496312207065784605e-01
            -8.62149013728675250867183876835043e-01 1.05582803005086962201417871753188e-16
            -8.48293924388769715605462806706782e-01 -1.53942650745099302023177756382211e-01
            -8.07173970340443247550865635275841e-01 -3.02937458030816286758124533662340e-01
            -7.40110780740420248768884903256549e-01 -4.42195606157651799339447507009027e-01
            -6.49259821682220850114219956594752e-01 -5.67241223662824256557257740496425e-01
            -5.37541117742394436440633853635518e-01 -6.74055241511839819956719566107495e-01
            -4.08545399988022417403499275678769e-01 -7.59204569284164798581571176327998e-01
            -2.66418696925760645211056498737889e-01 -8.19952437524096411358698333060602e-01
            -1.15729077734270921484771577070205e-01 -8.54346359762890639188981367624365e-01
            3.86801692378006198302919926845789e-02 -8.61280887040379306007764625974232e-01
            1.91846203744419990799841002626636e-01 -8.40533137944115771311714979674434e-01
            3.38846143411111466736684860734385e-01 -7.92769962201358868725264983368106e-01
            4.74955289225034327227348285305197e-01 -7.19526507580152574483633998170262e-01
            5.95798981248750969541561062214896e-01 -6.23156878976937833591875914862612e-01
            6.97493203790098048600043512124103e-01 -5.06758475548216513750787726166891e-01
            7.76769420862311710251901786250528e-01 -3.74072437753112774228014814070775e-01
            8.31079629620002258150179841322824e-01 -2.29363404020797023719069329672493e-01
            8.58678255267108947457188605767442e-01 -7.72824417624154574868455824798730e-02
            7.85255039463315762660045038501266e-01 7.98526327094162685638067955551378e-02
            7.53106605884138025075458244828042e-01 2.36288721962839343149198612081818e-01
            6.90125899373794871038967357890215e-01 3.83051123176357866118024730894831e-01
            5.98891357456738382403216292004799e-01 5.14131366400440326103193910967093e-01
            4.83138132998656322225627945954329e-01 6.24163011076218077199939671118045e-01
            3.47605176609289190370333244572976e-01 7.08641348742495624790649344504345e-01
            1.97841223447663389078954310207337e-01 7.64107826329432526790697011165321e-01
            3.99776273527339132130009602406062e-02 7.88291639727584758645662077469751e-01
            -1.19522657503188772798452532697411e-01 7.80202700774954904794356025377056e-01
            -2.74129670717614459807265347990324e-01 7.40172171582673565914944902033312e-01
            -4.17513783003992611231325327025843e-01 6.69838906719259941091593191231368e-01
            -5.43804831958400458624680595676182e-01 5.72082358312030359037692051060731e-01
            -6.47832447198077088224010822159471e-01 4.50904690938682906065082534041721e-01
            -7.25337725932383658999924591626041e-01 3.11266932539254304046494326030370e-01
            -7.73147592943454475822306903864956e-01 1.58885869349357056190541470641620e-01
            -7.89304706658435217825342533615185e-01 9.66619482561193282691623319453351e-17
            -7.73147592943454475822306903864956e-01 -1.58885869349356861901512161239225e-01
            -7.25337725932383770022227054141695e-01 -3.11266932539254137513040632256889e-01
            -6.47832447198077199246313284675125e-01 -4.50904690938682739531628840268240e-01
            -5.43804831958400791691587983223144e-01 -5.72082358312030025970784663513768e-01
            -4.17513783003992833275930252057151e-01 -6.69838906719259830069290728715714e-01
            -2.74129670717614792874172735537286e-01 -7.40172171582673454892642439517658e-01
            -1.19522657503188967087481842099805e-01 -7.80202700774954904794356025377056e-01
            3.99776273527340658686668461996305e-02 -7.88291639727584758645662077469751e-01
            1.97841223447663028256471307031461e-01 -7.64107826329432637812999473680975e-01
            3.47605176609288690769972163252532e-01 -7.08641348742495957857556732051307e-01
            4.83138132998655989158720558407367e-01 -6.24163011076218299244544596149353e-01
            5.98891357456738493425518754520454e-01 -5.14131366400439993036286523420131e-01
            6.90125899373794648994362432858907e-01 -3.83051123176358254696083349699620e-01
            7.53106605884137914053155782312388e-01 -2.36288721962839842749559693402261e-01
            7.85255039463315762660045038501266e-01 -7.98526327094161020303531017816567e-02
            7.02421345530939378321022559248377e-01 8.21012804336729296039720793487504e-02
            6.64553628978377886049599965190282e-01 2.41877740021715109675071175843186e-01
            5.90859654274296652864961743034655e-01 3.88614508037467165646461353389896e-01
            4.85312282669966843506870191049529e-01 5.14400967335803316338171953248093e-01
            3.53601600288497019963784850915545e-01 6.12455937337338496284644406841835e-01
            2.02828164109111475088553788737045e-01 6.77493249228707239417701657657744e-01
            4.11202091024901253413226243083045e-02 7.06006724691565112905777823470999e-01
            -1.22804547020415433244977521098917e-01 6.96459194883271348608388962020399e-01
            -2.80108878226678625900092356459936e-01 6.49365369607076914348908758256584e-01
            -4.22312467304260585887476509014959e-01 5.67264089173404095767239141423488e-01
            -5.41749081957962341782319981575711e-01 4.54581454861556044644288476774818e-01
            -6.31979863376786688000663616548991e-01 3.17392216654098002770467701338930e-01
            -6.88140446779078263084272748528747e-01 1.63092281892904145124134629440960e-01
            -7.07203200576993928905267239315435e-01 8.66074135933379197354657892695769e-17
            -6.88140446779078263084272748528747e-01 -1.63092281892903950835105320038565e-01
            -6.31979863376786799022966079064645e-01 -3.17392216654097836237014007565449e-01
            -5.41749081957962341782319981575711e-01 -4.54581454861556100155439708032645e-01
            -4.22312467304260696909778971530613e-01 -5.67264089173403984744936678907834e-01
            -2.80108878226678681411243587717763e-01 -6.49365369607076914348908758256584e-01
            -1.22804547020415613656219022686855e-01 -6.96459194883271237586086499504745e-01
            4.11202091024896326798554468950897e-02 -7.06006724691565112905777823470999e-01
            2.02828164109111475088553788737045e-01 -6.77493249228707239417701657657744e-01
            3.53601600288497019963784850915545e-01 -6.12455937337338496284644406841835e-01
            4.85312282669966899018021422307356e-01 -5.14400967335803205315869490732439e-01
            5.90859654274296319798054355487693e-01 -3.88614508037467665246822434710339e-01
            6.64553628978377664004995040158974e-01 -2.41877740021715609275432257163629e-01
            7.02421345530939378321022559248377e-01 -8.21012804336727908260940012041829e-02
            6.11135490065265019055118500546087e-01 8.39986396889170205959374015947105e-02
            5.65810366525960839467757068632636e-01 2.45766124229231358588876332760265e-01
            4.78521676511619531435570706889848e-01 3.89306259640670393462613674273598e-01
            3.55743222841418793578327495197300e-01 5.03973330732193414149833188275807e-01
            2.06580921750025847671849987818860e-01 5.81263005407887556330592815356795e-01
            4.20974587372669808993386197926156e-02 6.15443062073791069543915455142269e-01
            -1.25508180206976044379629797731468e-01 6.03978522290348873724497025250457e-01
            -2.83805451586987000922590596019290e-01 5.47719658526518937691207611351274e-01
            -4.21054170946341510539667751800152e-01 4.50838933340488190459893758088583e-01
            -5.27075228641268100915340255596675e-01 3.20521546919477817727539559200522e-01
            -5.94005527836600877300554657267639e-01 1.66432543651959280461838375231309e-01
            -6.16881154426766498133360983047169e-01 7.55461531223063652654112435298120e-17
            -5.94005527836600877300554657267639e-01 -1.66432543651959363728565222118050e-01
            -5.27075228641268433982247643143637e-01 -3.20521546919477429149480940395733e-01
            -4.21054170946341455028516520542325e-01 -4.50838933340488245971044989346410e-01
            -2.83805451586987389500649214824080e-01 -5.47719658526518826668905148835620e-01
            -1.25508180206975933357327335215814e-01 -6.03978522290348873724497025250457e-01
            4.20974587372668421214605416480481e-02 -6.15443062073791069543915455142269e-01
            2.06580921750025708893971909674292e-01 -5.81263005407887556330592815356795e-01
            3.55743222841418682556025032681646e-01 -5.03973330732193525172135650791461e-01
            4.78521676511619420413268244374194e-01 -3.89306259640670559996067368047079e-01
            5.65810366525960728445454606116982e-01 -2.45766124229231608389056873420486e-01
            6.11135490065265019055118500546087e-01 -8.39986396889168679402715156356862e-02
            5.12015793543675989951680094236508e-01 8.54403244174892911866336930870602e-02
            4.56530937569606498627194923756178e-01 2.47062188358603496141085997805931e-01
            3.51573870702503787910586652287748e-01 3.81911030626224723416584083679481e-01
            2.08518319714108946172359537740704e-01 4.75373886765281472577271415502764e-01
            4.28665732895953943693001519932295e-02 5.17322606087472047775577266293112e-01
            -1.27430431494262419445107070714585e-01 5.03211393952792129802276122063631e-01
            -2.83918371738845654039806731816498e-01 4.34569419154050284870294262873358e-01
            -4.09639350958078019004915404366329e-01 3.18835104750669784401395645545563e-01
            -4.90969550291569856170781349646859e-01 1.68550059511172217741048484640487e-01
            -5.19095580673469059185265450651059e-01 6.35708741323300594968014521009717e-17
            -4.90969550291569856170781349646859e-01 -1.68550059511172301007775331527228e-01
            -4.09639350958078241049520329397637e-01 -3.18835104750669562356790720514255e-01
            -2.83918371738845598528655500558671e-01 -4.34569419154050395892596725389012e-01
            -1.27430431494262530467409533230239e-01 -5.03211393952792018779973659547977e-01
            4.28665732895953804915123441787728e-02 -5.17322606087472047775577266293112e-01
            2.08518319714108529838725303307001e-01 -4.75373886765281639110725109276245e-01
            3.51573870702503843421737883545575e-01 -3.81911030626224723416584083679481e-01
            4.56530937569606332093741229982697e-01 -2.47062188358603829207993385352893e-01
            5.12015793543675989951680094236508e-01 -8.54403244174891940421190383858630e-02
            4.05374167689062092634344480757136e-01 8.61649392738340069719527036795625e-02
            3.35281291386923252506591097699129e-01 2.43596117037157222640075815434102e-01
            2.07215233869075976524953830448794e-01 3.58907313163506713760142474711756e-01
            4.33197799239638456358925111544522e-02 4.12160174273306811887351841505733e-01
            -1.28066057517847275981637267250335e-01 3.94146796893617756829542031482561e-01
            -2.77308110171214650119253519733320e-01 3.07981857619783805368740559060825e-01
            -3.78601071310887105081377512760810e-01 1.68564057236149533736124794813804e-01
            -4.14430467738151842027605198381934e-01 2.34797193534094540361995656637671e-16
            -3.78601071310887049570226281502983e-01 -1.68564057236149589247276026071631e-01
            -2.77308110171214872163858444764628e-01 -3.07981857619783638835286865287344e-01
            -1.28066057517847359248364114137075e-01 -3.94146796893617701318390800224734e-01
            4.33197799239636513468632017520576e-02 -4.12160174273306867398503072763560e-01
            2.07215233869075976524953830448794e-01 -3.58907313163506713760142474711756e-01
            3.35281291386923196995439866441302e-01 -2.43596117037157333662378277949756e-01
            4.05374167689062092634344480757136e-01 -8.61649392738338681940746255349950e-02
            2.91065956340834819382479281557607e-01 8.54646759741110872976577184090274e-02
            1.98654571776392452342463457171107e-01 2.29259597165097334103833759400004e-01
            4.31717642990763622590222325925424e-02 3.00266216127072049779656026657904e-01
            -1.26017773306086294793360025323636e-01 2.75940433048403432891859665687662e-01
            -2.55197558285604420014180959697114e-01 1.64005512178798745770436084967514e-01
            -3.03353921649225699574969894456444e-01 1.71866344285774568604496643857040e-16
            -2.55197558285604475525332190954941e-01 -1.64005512178798662503709238080774e-01
            -1.26017773306086544593540565983858e-01 -2.75940433048403266358405971914181e-01
            4.31717642990762859311892896130303e-02 -3.00266216127072105290807257915731e-01
            1.98654571776392285809009763397626e-01 -2.29259597165097472881711837544572e-01
            2.91065956340834819382479281557607e-01 -8.54646759741111150532333340379409e-02
            1.67807205179241192283257078088354e-01 8.08116908673498224313647142480477e-02
            4.14449570361046862321252604033361e-02 1.81582221120856174279012407168921e-01
            -1.16126189078271935262165470703621e-01 1.45617635268072892484880753727339e-01
            -1.86251946274147872628645927761681e-01 2.28092849839599991922404089995515e-17
            -1.16126189078271976895528894146992e-01 -1.45617635268072836973729522469512e-01
            4.14449570361044780653081431864848e-02 -1.81582221120856202034588022797834e-01
            1.67807205179241247794408309346181e-01 -8.08116908673497114090622517323936e-02
            3.17249362483302335680157568731374e-02 5.49492014489915137076536666427273e-02
            -6.34498724966604532582437059318181e-02 7.77036832593429047261767340750737e-18
            3.17249362483302335680157568731374e-02 -5.49492014489915137076536666427273e-02
            ];
        
    case   24
        
        % DEGREE.             :          24
        % CARDIN.             :         325
        % LEBESGUE CONST.     : 3.69015e+01
        % ABS.DET.VAND.MATRIX : Inf
        % CONDITIONING VAND.  : 8.78540e+02
        % POINTS OUT DISK     : 0.00000e+00
        
        pts=[
            9.97945392750336335296879042289220e-01 6.40702199807129113562353950328543e-02
            9.81559156991065329123102856101468e-01 1.91158628701372290681348431462538e-01
            9.49055747010668637742014652758371e-01 3.15108218023620656467187473026570e-01
            9.00968867902419145998749172576936e-01 4.33883739117558120401696442058892e-01
            8.38088104891840601773367325222353e-01 5.45534901210548706096403748233570e-01
            7.61445958369134534571287531434791e-01 6.48228395307788307633245494798757e-01
            6.72300890261316785867506951035466e-01 7.40277997075315496999792230781168e-01
            5.72116660122169662372471066191792e-01 8.20172254596955863092944127856754e-01
            4.62538290240835203714908629990532e-01 8.86599306373000106695769773068605e-01
            3.45365054421307826615361591393594e-01 9.38468422049760331304923965944909e-01
            2.22520933956314448387558968533995e-01 9.74927912181823619341969333618181e-01
            9.60230259076818581931433982390445e-02 9.95379112949198008308826501888689e-01
            -3.20515775716552070440101829262858e-02 9.99486216200687893618237467308063e-01
            -1.59599895033379179931642966039362e-01 9.87181783414450175762056005623890e-01
            -2.84527586631032336494939727344899e-01 9.58667853036660688736958491062978e-01
            -4.04783343122393668434000346678658e-01 9.14412623015812497939691638748627e-01
            -5.18392568310525048147496818273794e-01 8.55142763005346195903655370784691e-01
            -6.23489801858733483364005678595277e-01 7.81831482468029914656426626606844e-01
            -7.18349350097727490371823932946427e-01 6.95682550603486493656646416638978e-01
            -8.01413621867956504907226644718321e-01 5.98110530491216096926621048623929e-01
            -8.71318704123389187188308824261185e-01 4.90717552003938128901694426531321e-01
            -9.26916757346021635832755691808416e-01 3.75267004879374477255282727128360e-01
            -9.67294863039029451101669110357761e-01 2.53654583909507347350142936193151e-01
            -9.91790013823246052737658828846179e-01 1.27877161684506052141685472633981e-01
            -1.00000000000000000000000000000000e+00 1.22464679914735320717376402945840e-16
            -9.91790013823246163759961291361833e-01 -1.27877161684505830097080547602673e-01
            -9.67294863039029451101669110357761e-01 -2.53654583909507125305538011161843e-01
            -9.26916757346021746855058154324070e-01 -3.75267004879374255210677802097052e-01
            -8.71318704123389520255216211808147e-01 -4.90717552003937518279030882695224e-01
            -8.01413621867956726951831569749629e-01 -5.98110530491215985904318586108275e-01
            -7.18349350097727601394126395462081e-01 -6.95682550603486382634343954123324e-01
            -6.23489801858733705408610603626585e-01 -7.81831482468029692611821701575536e-01
            -5.18392568310525603259009130852064e-01 -8.55142763005345862836747983237728e-01
            -4.04783343122394112523210196741275e-01 -9.14412623015812386917389176232973e-01
            -2.84527586631032336494939727344899e-01 -9.58667853036660688736958491062978e-01
            -1.59599895033378763598008731605660e-01 -9.87181783414450175762056005623890e-01
            -3.20515775716552278606918946479709e-02 -9.99486216200687893618237467308063e-01
            9.60230259076811920593286231451202e-02 -9.95379112949198230353431426919997e-01
            2.22520933956314226342954043502687e-01 -9.74927912181823619341969333618181e-01
            3.45365054421307826615361591393594e-01 -9.38468422049760331304923965944909e-01
            4.62538290240834981670303704959224e-01 -8.86599306373000217718072235584259e-01
            5.72116660122169662372471066191792e-01 -8.20172254596955863092944127856754e-01
            6.72300890261316452800599563488504e-01 -7.40277997075315830066699618328130e-01
            7.61445958369133757415170293825213e-01 -6.48228395307789195811665194923989e-01
            8.38088104891840823817972250253661e-01 -5.45534901210548373029496360686608e-01
            9.00968867902419034976446710061282e-01 -4.33883739117558342446301367090200e-01
            9.49055747010668415697409727727063e-01 -3.15108218023621378112153479378321e-01
            9.81559156991065107078497931070160e-01 -1.91158628701372595992680203380587e-01
            9.97945392750336335296879042289220e-01 -6.40702199807137995346550951580866e-02
            9.72139253519955337523583693837281e-01 6.79785987637945149364426811189333e-02
            9.53217668742200818776666437770473e-01 2.02612670190956273286175814973831e-01
            9.15742786311406709032212347665336e-01 3.33303116461347526122693807337782e-01
            8.60444012187041584738267374632414e-01 4.57506196696494393805210165737662e-01
            7.88397674106013135464365859661484e-01 5.72804439218529415356329081987496e-01
            7.01006072087573484097333675890695e-01 6.76953694886568202448984266084153e-01
            5.99970184258537653221310392837040e-01 7.67926816907054998750936647411436e-01
            4.87256559248879062007375750908977e-01 8.43953116940253211808453670528252e-01
            3.65059039559562037435824777276139e-01 9.03552829534651658072164082113886e-01
            2.35756060913721365857043110736413e-01 9.45565914078268177078712142247241e-01
            1.01864358710739302815717621797376e-01 9.69174633669636853561257794353878e-01
            -3.40100173655562068586455382046552e-02 9.73919471436432315769593515142333e-01
            -1.69222427139652964456217887345701e-01 9.59708074508696551419006937067024e-01
            -3.01141114857134017945838877494680e-01 9.26817051562403904085840622428805e-01
            -4.27198433316862302699945530548575e-01 8.75886588946219402096460271422984e-01
            -5.44940820203093090334789394546533e-01 8.07907990182424984304532245005248e-01
            -6.52076553885066578786222635244485e-01 7.24204381371447492021786729310406e-01
            -7.46520359171753522531389535288326e-01 6.26404958047349191829766823502723e-01
            -8.26433994821485162773910815303680e-01 5.16413274739937921964383349404670e-01
            -8.90262032816752313379993211128749e-01 3.96370194451107771271836099913344e-01
            -9.36762133001294516887469399080146e-01 2.68612219191700474230088957483531e-01
            -9.65029223818099746168286401371006e-01 1.35626012627596964632559206620499e-01
            -9.74513118497757901970146576786647e-01 1.19343437129538449925686157056338e-16
            -9.65029223818099746168286401371006e-01 -1.35626012627596742587954281589191e-01
            -9.36762133001294738932074324111454e-01 -2.68612219191699808096274182389607e-01
            -8.90262032816752535424598136160057e-01 -3.96370194451107160649172556077247e-01
            -8.26433994821485273796213277819334e-01 -5.16413274739937810942080886889016e-01
            -7.46520359171753744575994460319635e-01 -6.26404958047348969785161898471415e-01
            -6.52076553885066800830827560275793e-01 -7.24204381371447269977181804279098e-01
            -5.44940820203093645446301707124803e-01 -8.07907990182424651237624857458286e-01
            -4.27198433316862524744550455579883e-01 -8.75886588946219291074157808907330e-01
            -3.01141114857134239990443802525988e-01 -9.26817051562403793063538159913151e-01
            -1.69222427139652992211793502974615e-01 -9.59708074508696551419006937067024e-01
            -3.40100173655571019759591422371159e-02 -9.73919471436432204747291052626679e-01
            1.01864358710738844848719963920303e-01 -9.69174633669636964583560256869532e-01
            2.35756060913720949523408876302710e-01 -9.45565914078268288101014604762895e-01
            3.65059039559562037435824777276139e-01 -9.03552829534651658072164082113886e-01
            4.87256559248879062007375750908977e-01 -8.43953116940253211808453670528252e-01
            5.99970184258537875265915317868348e-01 -7.67926816907054776706331722380128e-01
            7.01006072087573151030426288343733e-01 -6.76953694886568535515891653631115e-01
            7.88397674106013024442063397145830e-01 -5.72804439218529637400934007018805e-01
            8.60444012187041584738267374632414e-01 -4.57506196696494393805210165737662e-01
            9.15742786311406709032212347665336e-01 -3.33303116461347415100391344822128e-01
            9.53217668742200707754363975254819e-01 -2.02612670190956828397688127552101e-01
            9.72139253519955448545886156352935e-01 -6.79785987637939875805059841695765e-02
            9.26338475922698911801944632316008e-01 7.11191960664923489288113955808512e-02
            9.04625887175155241060053867840907e-01 2.11690614521513831292054419463966e-01
            8.61709634357573417418052486027591e-01 3.47300184392795807664100493639125e-01
            7.98595638061868395851661261986010e-01 4.74769332299897095506224786731764e-01
            7.16763236868268927004521628987277e-01 5.91110289453715020968616045138333e-01
            6.18130512902825834942177607445046e-01 6.93596122424586680743630040524295e-01
            5.05009333618068767535191909701098e-01 7.79824650150639286927400917193154e-01
            3.80051163579367246025952908894396e-01 8.47774749025884788444784589955816e-01
            2.46184916382794216627161176802474e-01 8.95853726324520760471159519511275e-01
            1.06548303402868041467321802429069e-01 9.22934651568518726882928149279905e-01
            -3.55857115026672610191837975435192e-02 9.28382770822887337658357864711434e-01
            -1.76885627491630281760137677338207e-01 9.12070384789915755696654287021374e-01
            -3.14039494293495424770412682846654e-01 8.74379841972479532330453366739675e-01
            -4.43832541516653356072907854468212e-01 8.16194576749197153731074649840593e-01
            -5.63222530141679667003984377515735e-01 7.38878402421357494134213084180374e-01
            -6.69411060025465021183777025726158e-01 6.44243544585055172291276903706603e-01
            -7.59909162028758133899941640265752e-01 5.34508164099187110807065437256824e-01
            -8.32595637343236161242998605303001e-01 4.12244365274946122923438451834954e-01
            -8.85766776593727600541683386836667e-01 2.80317907930781651248963726175134e-01
            -9.18176293341968596806168534385506e-01 1.41821036411161449652951205280260e-01
            -9.29064535984413075730969922005897e-01 5.26365126704496295874822652829970e-16
            -9.18176293341968596806168534385506e-01 -1.41821036411161227608346280248952e-01
            -8.85766776593727600541683386836667e-01 -2.80317907930781762271266188690788e-01
            -8.32595637343236272265301067818655e-01 -4.12244365274945900878833526803646e-01
            -7.59909162028758466966849027812714e-01 -5.34508164099186555695553124678554e-01
            -6.69411060025465132206079488241812e-01 -6.44243544585055061268974441190949e-01
            -5.63222530141679667003984377515735e-01 -7.38878402421357605156515546696028e-01
            -4.43832541516653189539454160694731e-01 -8.16194576749197153731074649840593e-01
            -3.14039494293495424770412682846654e-01 -8.74379841972479532330453366739675e-01
            -1.76885627491630920138376836803218e-01 -9.12070384789915644674351824505720e-01
            -3.55857115026674900026826264820556e-02 -9.28382770822887337658357864711434e-01
            1.06548303402868027589533994614612e-01 -9.22934651568518726882928149279905e-01
            2.46184916382793800293526942368771e-01 -8.95853726324520871493461982026929e-01
            3.80051163579367023981347983863088e-01 -8.47774749025884788444784589955816e-01
            5.05009333618068989579796834732406e-01 -7.79824650150639175905098454677500e-01
            6.18130512902825501875270219898084e-01 -6.93596122424587013810537428071257e-01
            7.16763236868268260870706853893353e-01 -5.91110289453715576080128357716603e-01
            7.98595638061868062784753874439048e-01 -4.74769332299897595106585868052207e-01
            8.61709634357573306395750023511937e-01 -3.47300184392796029708705418670434e-01
            9.04625887175155241060053867840907e-01 -2.11690614521513720269751956948312e-01
            9.26338475922698911801944632316008e-01 -7.11191960664927375068700143856404e-02
            8.67768398952579400607021398172947e-01 7.38579755067950011193644854756712e-02
            8.42804282056660691857530309789581e-01 2.19449167037932019175272557731660e-01
            7.93594220455865362318093048088485e-01 3.58727205583480424078146597821615e-01
            7.21553898025915074754266242962331e-01 4.87685315557371268369024619460106e-01
            6.28755783679634361327259739482542e-01 6.02613606929095269038043625187129e-01
            5.17869510209664207778246236557607e-01 7.00205802005301691792737983632833e-01
            3.92085073813605800019388425425859e-01 7.77654351019310241532878080761293e-01
            2.55021063711427020681554722614237e-01 8.32731200226206058623290573450504e-01
            1.10620561921952201278607219592232e-01 8.63851888952473667693254810728831e-01
            -3.69622920276666960814893059250608e-02 8.70121131644753798006775014073355e-01
            -1.83481808132725687787711876808316e-01 8.51358573605170754206028504995629e-01
            -3.24722886682293154780865052089212e-01 8.08103979467620137100425381504465e-01
            -4.56622279003482567372174116826500e-01 7.41601705151998080722819395305123e-01
            -5.75385479727832493956896087183850e-01 6.53764900009978555672773836704437e-01
            -6.77595887802118879150725661020260e-01 5.47120469001429077238185527676251e-01
            -7.60313095880065126230817895702785e-01 4.24736378239439493764706412548549e-01
            -8.21157480488111546357288261788199e-01 2.90133395191077780861377277688007e-01
            -8.58378659460175996720465718681226e-01 1.47183802607611990964642245671712e-01
            -8.70905847245662556588285951875150e-01 1.06655205818811443850904158478466e-16
            -8.58378659460175996720465718681226e-01 -1.47183802607611768920037320640404e-01
            -8.21157480488111546357288261788199e-01 -2.90133395191077558816772352656699e-01
            -7.60313095880065348275422820734093e-01 -4.24736378239438938653194099970278e-01
            -6.77595887802118768128423198504606e-01 -5.47120469001429299282790452707559e-01
            -5.75385479727832716001501012215158e-01 -6.53764900009978555672773836704437e-01
            -4.56622279003483066972535198146943e-01 -7.41601705151997747655912007758161e-01
            -3.24722886682293321314318745862693e-01 -8.08103979467620137100425381504465e-01
            -1.83481808132725521254258183034835e-01 -8.51358573605170754206028504995629e-01
            -3.69622920276670985373357325443067e-02 -8.70121131644753686984472551557701e-01
            1.10620561921951590655943675756134e-01 -8.63851888952473667693254810728831e-01
            2.55021063711426632103496103809448e-01 -8.32731200226206169645593035966158e-01
            3.92085073813605800019388425425859e-01 -7.77654351019310241532878080761293e-01
            5.17869510209664429822851161588915e-01 -7.00205802005301580770435521117179e-01
            6.28755783679634139282654814451234e-01 -6.02613606929095491082648550218437e-01
            7.21553898025914741687358855415368e-01 -4.87685315557371712458234469522722e-01
            7.93594220455865251295790585572831e-01 -3.58727205583480646122751522852923e-01
            8.42804282056660691857530309789581e-01 -2.19449167037931963664121326473833e-01
            8.67768398952579289584718935657293e-01 -7.38579755067953758196352964660036e-02
            7.98937266369790233255798739264719e-01 7.62892590612434112751216730430315e-02
            7.70061591952442170416759381623706e-01 2.26110484591531185616375410063483e-01
            7.13353885226024941879074958706042e-01 3.67759488083559682447543082162156e-01
            6.30863710462119975375117064686492e-01 4.96116705488248099786829925506026e-01
            5.25572477502748824917944148182869e-01 6.06542972537123192822150485881139e-01
            4.01285685840694739123790668600122e-01 6.95047196226205921121277242491487e-01
            2.62495383952701333285517648619134e-01 7.58430603315867313263254345656605e-01
            1.14217814963605682199165869405988e-01 7.94402352330030647742376004316611e-01
            -3.81878834498892427706806529386085e-02 8.01662330535846234802477283665212e-01
            -1.89213372257944961729592137089639e-01 7.79948143405267080296994208765682e-01
            -3.33400196801966253179472232659464e-01 7.30044598236954889181049566104775e-01
            -4.65537069567823980076326506605255e-01 6.53755339175711491783715700876201e-01
            -5.80848219694497069909289166389499e-01 5.53837658813735700391589489299804e-01
            -6.75166001776135615841667458880693e-01 4.33902842452286663377236664018710e-01
            -7.45081525425725477163041432504542e-01 2.98285646841782603466697310068412e-01
            -7.88067861455450047181159334286349e-01 1.51887630778744425752435631693515e-01
            -8.02571371681389256202976412168937e-01 9.82866461416914098419260924269644e-17
            -7.88067861455450269225764259317657e-01 -1.51887630778743898396498934744159e-01
            -7.45081525425725588185343895020196e-01 -2.98285646841782436933243616294931e-01
            -6.75166001776135948908574846427655e-01 -4.33902842452286219288026813956094e-01
            -5.80848219694497069909289166389499e-01 -5.53837658813735700391589489299804e-01
            -4.65537069567824146609780200378736e-01 -6.53755339175711380761413238360547e-01
            -3.33400196801966086646018538885983e-01 -7.30044598236955000203352028620429e-01
            -1.89213372257944989485167752718553e-01 -7.79948143405267080296994208765682e-01
            -3.81878834498896174709514639289409e-02 -8.01662330535846234802477283665212e-01
            1.14217814963605307498895058415656e-01 -7.94402352330030758764678466832265e-01
            2.62495383952701333285517648619134e-01 -7.58430603315867424285556808172259e-01
            4.01285685840694739123790668600122e-01 -6.95047196226205921121277242491487e-01
            5.25572477502748269806431835604599e-01 -6.06542972537123525889057873428101e-01
            6.30863710462119753330512139655184e-01 -4.96116705488248432853737313052989e-01
            7.13353885226024830856772496190388e-01 -3.67759488083559848980996775935637e-01
            7.70061591952442170416759381623706e-01 -2.26110484591531268883102256950224e-01
            7.98937266369790122233496276749065e-01 -7.62892590612440357755730246935855e-02
            7.21259745084585013330524816410616e-01 7.84417244166641935976258537266403e-02
            6.87534441027060849727092772809556e-01 2.31657325397984337200796289835125e-01
            6.21660790646758831812235257530119e-01 3.74040887312319436652785498154117e-01
            5.26718972622158054797125714685535e-01 4.98934713052518352682795921282377e-01
            4.07148360843837153755231383911450e-01 6.00498906136486709783639525994658e-01
            2.68539944225360260876556139919558e-01 6.73984437776111278139978821855038e-01
            1.17374898275616576515112399192731e-01 7.15955206185225789816684027755400e-01
            -3.92784674646646653206616406350804e-02 7.24448704880178429021952979383059e-01
            -1.94095215721179797929707433468138e-01 6.99067787301838938773812515137251e-01
            -3.39836287411910520361857379612047e-01 6.40999236947306982870031788479537e-01
            -4.69686992004166026237754749672604e-01 5.52958274692601947641890092199901e-01
            -5.77575654869904475674502464244142e-01 4.39061598082252591002117014795658e-01
            -6.58457522043161103120212374051334e-01 3.04634889127494035143683959176997e-01
            -7.08550647308652470357515085197520e-01 1.55963791334495727181064239630359e-01
            -7.25512731803474641978368708805647e-01 8.88496844743777378910575563631803e-17
            -7.08550647308652470357515085197520e-01 -1.55963791334495560647610545856878e-01
            -6.58457522043160992097909911535680e-01 -3.04634889127494201677137652950478e-01
            -5.77575654869904808741409851791104e-01 -4.39061598082252202424058395990869e-01
            -4.69686992004165859704301055899123e-01 -5.52958274692602058664192554715555e-01
            -3.39836287411910964451067229674663e-01 -6.40999236947306760825426863448229e-01
            -1.94095215721180103241039205386187e-01 -6.99067787301838938773812515137251e-01
            -3.92784674646651649210227219555236e-02 -7.24448704880178317999650516867405e-01
            1.17374898275616423859446513233706e-01 -7.15955206185225900838986490271054e-01
            2.68539944225359927809648752372595e-01 -6.73984437776111500184583746886346e-01
            4.07148360843837042732928921395796e-01 -6.00498906136486820805941988510313e-01
            5.26718972622158054797125714685535e-01 -4.98934713052518352682795921282377e-01
            6.21660790646758831812235257530119e-01 -3.74040887312319436652785498154117e-01
            6.87534441027060849727092772809556e-01 -2.31657325397984253934069442948385e-01
            7.21259745084585013330524816410616e-01 -7.84417244166647209535625506759970e-02
            6.35651115998701166098783232882852e-01 8.03014103926909389441490816352598e-02
            5.95710818619227144843364385451423e-01 2.35858598235171079693373030750081e-01
            5.18339819634770160305947683809791e-01 3.76595922923288695116639246407431e-01
            4.08399623462153138486740999724134e-01 4.93670340751215463992451759622782e-01
            2.72798176958659766011550118491868e-01 5.79725635477232770220723523380002e-01
            1.20055817715339685491926502436399e-01 6.29354636444469761613618175033480e-01
            -4.02300900894470570001715259422781e-02 6.39438970999457123589593265933217e-01
            -1.97988193377991894550405049812980e-01 6.09345003314516797665589820098830e-01
            -3.43305970326957698990355538626318e-01 5.40963648057164459004297896171920e-01
            -4.67052570569240876885430679976707e-01 4.38591557267252740714980063785333e-01
            -5.61452540103459574183375480060931e-01 3.08661145907324629966694828908658e-01
            -6.20574381664975582850729551864788e-01 1.59336419573752025025115131029452e-01
            -6.40703252513556087421875417931005e-01 7.84635187394024839760899531158537e-17
            -6.20574381664975804895334476896096e-01 -1.59336419573751580935905280966836e-01
            -5.61452540103459574183375480060931e-01 -3.08661145907324740988997291424312e-01
            -4.67052570569241154441186836265842e-01 -4.38591557267252463159223907496198e-01
            -3.43305970326957310412296919821529e-01 -5.40963648057164681048902821203228e-01
            -1.97988193377992172106161206102115e-01 -6.09345003314516686643287357583176e-01
            -4.02300900894469321000812556121673e-02 -6.39438970999457123589593265933217e-01
            1.20055817715339380180594730518351e-01 -6.29354636444469872635920637549134e-01
            2.72798176958659210900037805913598e-01 -5.79725635477232992265328448411310e-01
            4.08399623462152860930984843434999e-01 -4.93670340751215686037056684654090e-01
            5.18339819634770049283645221294137e-01 -3.76595922923288806138941708923085e-01
            5.95710818619227144843364385451423e-01 -2.35858598235171051937797415121167e-01
            6.35651115998701166098783232882852e-01 -8.03014103926911887443296222954814e-02
            5.42723759603926492189884811523370e-01 8.18024447597535259157908171800955e-02
            4.94500371859127485496543386034318e-01 2.38138828078240466501469541071856e-01
            4.02338455995506272255823887462611e-01 3.73315531466941741278731115016853e-01
            2.74427002683451881637211045017466e-01 4.75321511616579150949490895072813e-01
            1.22131505879907426015407168051752e-01 5.35093089544986799666048682411201e-01
            -4.10159111863523939689457620261237e-02 5.47319298249976160519736367859878e-01
            -2.00518884548343490070720918083680e-01 5.10913785434275791175195990945213e-01
            -3.42204875055583002119163893439691e-01 4.29111340674522334648344212837401e-01
            -4.53484460672775036016446392750368e-01 3.09180470171735555240388748643454e-01
            -5.24469961875413615004504208627623e-01 1.61777558078045252676346876796742e-01
            -5.48854005366903652252119627519278e-01 6.72152300871782824192566173903577e-17
            -5.24469961875413726026806671143277e-01 -1.61777558078044891853863873620867e-01
            -4.53484460672774980505295161492541e-01 -3.09180470171735721773842442416935e-01
            -3.42204875055583113141466355955345e-01 -4.29111340674522223626041750321747e-01
            -2.00518884548343379048418455568026e-01 -5.10913785434275791175195990945213e-01
            -4.10159111863527686692165730164561e-02 -5.47319298249976160519736367859878e-01
            1.22131505879907301115316897721641e-01 -5.35093089544986799666048682411201e-01
            2.74427002683451437548001194954850e-01 -4.75321511616579428505247051361948e-01
            4.02338455995506383278126349978265e-01 -3.73315531466941574745277421243372e-01
            4.94500371859127429985392154776491e-01 -2.38138828078240577523772003587510e-01
            5.42723759603926381167582349007716e-01 -8.18024447597539838827884750571684e-02
            4.42842881132430588042581121044350e-01 8.27816813122882327879992203634174e-02
            3.83034496158380810548749195731943e-01 2.37164919166508808556770304676320e-01
            2.71495180010728365260774808120914e-01 3.59517720511108418435242128907703e-01
            1.23288935395900856040185544770793e-01 4.33315661544221908396679054931155e-01
            -4.15681631117179040124653965904145e-02 4.48591921400819382270697133208159e-01
            -2.00811250853955680639728598180227e-01 4.03283356538589321527155107105500e-01
            -3.32933666434813313461660300163203e-01 3.03509139705600561320864017034182e-01
            -4.20091545514516939707760911915102e-01 1.62744331753169935161906778375851e-01
            -4.50513733564872898007536150544183e-01 5.51720201782145113411866562895996e-17
            -4.20091545514517050730063374430756e-01 -1.62744331753169657606150622086716e-01
            -3.32933666434813202439357837647549e-01 -3.03509139705600616832015248292009e-01
            -2.00811250853956152484514063871757e-01 -4.03283356538589099482550182074192e-01
            -4.15681631117179178902532044048712e-02 -4.48591921400819382270697133208159e-01
            1.23288935395900758895670890069596e-01 -4.33315661544221908396679054931155e-01
            2.71495180010728254238472345605260e-01 -3.59517720511108529457544591423357e-01
            3.83034496158380644015295501958462e-01 -2.37164919166509002845799614078715e-01
            4.42842881132430588042581121044350e-01 -8.27816813122881078879089500333066e-02
            3.36064736215245296602205371527816e-01 8.28325180227388740972216396585281e-02
            2.59076355167445648852719841670478e-01 2.29521622429263383313724489198648e-01
            1.22736703359326376761018195793440e-01 3.23630089172645518669213515750016e-01
            -4.17204480507933142541254767365899e-02 3.43598802651945867125959921395406e-01
            -1.96619947598379779529764732615149e-01 2.84853171258141635302507665983285e-01
            -3.06476186678414086461685883477912e-01 1.60851111181948780437522827924113e-01
            -3.46122424828859909240463821333833e-01 -1.11321462185657724266946633169086e-16
            -3.06476186678414252995139577251393e-01 -1.60851111181948447370615440377151e-01
            -1.96619947598379862796491579501890e-01 -2.84853171258141579791356434725458e-01
            -4.17204480507935571154121134895831e-02 -3.43598802651945867125959921395406e-01
            1.22736703359326376761018195793440e-01 -3.23630089172645518669213515750016e-01
            2.59076355167445482319266147896997e-01 -2.29521622429263522091602567343216e-01
            3.36064736215245296602205371527816e-01 -8.28325180227389018527972552874417e-02
            2.21807857763696381070417373848613e-01 8.07314579523370490221623185789213e-02
            1.18021495996312203446976241139055e-01 2.04419227450899521070226683150395e-01
            -4.09884354105690407177320366827189e-02 2.32456968558535009838905693868583e-01
            -1.80819422353127284841534105908067e-01 1.51725510606197988572318990918575e-01
            -2.36042991992624351382801251020283e-01 2.89069294604931726475925034244022e-17
            -1.80819422353127395863836568423721e-01 -1.51725510606197849794440912774007e-01
            -4.09884354105690476566259405899473e-02 -2.32456968558535009838905693868583e-01
            1.18021495996312023035734739551117e-01 -2.04419227450899604336953530037135e-01
            2.21807857763696381070417373848613e-01 -8.07314579523370212665867029500077e-02
            9.75523821750290953680462280317442e-02 7.08759543583907525299281360275927e-02
            -3.72616943073417125620316880940663e-02 1.14679703136962476972549040965532e-01
            -1.20581375735374751734241272060899e-01 1.47669595831111022399788610999993e-17
            -3.72616943073417403176073037229799e-02 -1.14679703136962463094761233151075e-01
            9.75523821750290814902584202172875e-02 -7.08759543583907802855037516565062e-02
            -0.00000000000000000000000000000000e+00 0.00000000000000000000000000000000e+00
            ];
        
    case   25
        
        % DEGREE.             :          25
        % CARDIN.             :         351
        % LEBESGUE CONST.     : 4.28325e+01
        % ABS.DET.VAND.MATRIX : Inf
        % CONDITIONING VAND.  : 9.03984e+02
        % POINTS OUT DISK     : 0.00000e+00
        
        pts=[
            9.98103328737044104279618750297232e-01 6.15609061339428345616120452632458e-02
            9.82973099683901785361683778319275e-01 1.83749517816570340222881441150093e-01
            9.52942000427156599151601312769344e-01 3.03152674113043529846578394426615e-01
            9.08465271819523634277970813855063e-01 4.17960344886783408124841798780835e-01
            8.50217135729614215122751375020016e-01 5.26432162877355724894812283309875e-01
            7.79080574525670477292749183106935e-01 6.26923805894106456193526355491485e-01
            6.96133945962926548034488405392040e-01 7.17911923064441959141390725562815e-01
            6.02634636379256405369631011126330e-01 7.98017227280239271891559837968089e-01
            4.99999999999999888977697537484346e-01 8.66025403784438707610604524234077e-01
            3.89785873292679385659909030437120e-01 9.20905517944953566633614627789939e-01
            2.73662990072082779047235590041964e-01 9.61825643172819044757204665074823e-01
            1.53391654878685446128372404928086e-01 9.88165472081259377290507472935133e-01
            3.07950585561703252257537144487287e-02 9.99525719713365901064605623105308e-01
            -9.22683594633018910879940222002915e-02 9.95734176295034578707543460041052e-01
            -2.13933083206497426376202497522172e-01 9.76848317759600681675635769352084e-01
            -3.32354799479659512861928760685259e-01 9.43154434471277558493795822869288e-01
            -4.45738355776538197616787329025101e-01 8.95163291355062340493020656140288e-01
            -5.52364972960505795640528958756477e-01 8.33602385221119401848000052268617e-01
            -6.50618300204242161477452555118361e-01 7.59404916654706885204006994172232e-01
            -7.39008917220658978486369505844777e-01 6.73695643646557429384813531214604e-01
            -8.16196912356221604412098713510204e-01 5.77773831408251226093852892518044e-01
            -8.81012194285784477898459954303689e-01 4.73093556836010120658642108537606e-01
            -9.32472229404355812398819125519367e-01 3.61241666187152921096981117443647e-01
            -9.69796936035009493615177689207485e-01 2.43913720108377002349087092625268e-01
            -9.92420509671935735518388810305623e-01 1.22888290664714336375418213265220e-01
            -1.00000000000000000000000000000000e+00 1.22464679914735320717376402945840e-16
            -9.92420509671935735518388810305623e-01 -1.22888290664714086575237672604999e-01
            -9.69796936035009271570572764176177e-01 -2.43913720108377141126965170769836e-01
            -9.32472229404355923421121588035021e-01 -3.61241666187152699052376192412339e-01
            -8.81012194285784588920762416819343e-01 -4.73093556836009898614037183506298e-01
            -8.16196912356221715434401176025858e-01 -5.77773831408251004049247967486735e-01
            -7.39008917220659089508671968360431e-01 -6.73695643646557207340208606183296e-01
            -6.50618300204242050455150092602707e-01 -7.59404916654707218270914381719194e-01
            -5.52364972960506017685133883787785e-01 -8.33602385221119290825697589752963e-01
            -4.45738355776538031083333635251620e-01 -8.95163291355062451515323118655942e-01
            -3.32354799479659734906533685716568e-01 -9.43154434471277447471493360353634e-01
            -2.13933083206497870465412347584788e-01 -9.76848317759600570653333306836430e-01
            -9.22683594633019188435696378292050e-02 -9.95734176295034578707543460041052e-01
            3.07950585561700823644670776957355e-02 -9.99525719713365901064605623105308e-01
            1.53391654878685640417401714330481e-01 -9.88165472081259377290507472935133e-01
            2.73662990072082779047235590041964e-01 -9.61825643172819044757204665074823e-01
            3.89785873292679774237967649241909e-01 -9.20905517944953455611312165274285e-01
            5.00000000000000111022302462515654e-01 -8.66025403784438596588302061718423e-01
            6.02634636379256183325026086095022e-01 -7.98017227280239715980769688030705e-01
            6.96133945962926770079093330423348e-01 -7.17911923064441737096785800531507e-01
            7.79080574525670366270446720591281e-01 -6.26923805894106567215828818007139e-01
            8.50217135729613882055843987473054e-01 -5.26432162877356168984022133372491e-01
            9.08465271819523745300273276370717e-01 -4.17960344886783352613690567523008e-01
            9.52942000427156488129298850253690e-01 -3.03152674113043751891183319457923e-01
            9.82973099683901785361683778319275e-01 -1.83749517816570062667125284860958e-01
            9.98103328737044104279618750297232e-01 -6.15609061339429039505510843355296e-02
            9.74007051130584833309455916605657e-01 6.52021004356291566939063386598718e-02
            9.56625872228504259275894128222717e-01 1.94442768279947220122494400129654e-01
            9.22173681973618153406846431607846e-01 3.20213600317874935718975848431000e-01
            8.71265280517212858946152209682623e-01 4.40270213072129101838925180345541e-01
            8.04809129489320151940034975268645e-01 5.52470193443916346431876718270360e-01
            7.23991140479408490371326934109675e-01 6.54811330125434798432593197503593e-01
            6.30253512415973049520800941536436e-01 7.45467343108096480719382270763163e-01
            5.25268995492491730381345860223519e-01 8.22820473692545073518544995749835e-01
            4.10911040900593382829697475244757e-01 8.85490353430971266490701054863166e-01
            2.89220369049160819230337438057177e-01 9.32358636834765941436842240364058e-01
            1.62368552860287812533712781259965e-01 9.62588958276258011004244963260135e-01
            3.26192659990409833392632776849496e-02 9.75641856953154418263807201583404e-01
            -9.77121124367237026131505217563245e-02 9.71284403579337096701351583760697e-01
            -2.26299815911211926744428524216346e-01 9.49594357013491929819792858324945e-01
            -3.50849193809622816875304351924569e-01 9.10958776650432899835152511514025e-01
            -4.69137659532728901190523629338713e-01 8.56067115337033057720361739484360e-01
            -5.79054352607396127794459061988164e-01 7.85898916069837194520175671641482e-01
            -6.78637807041732044055493133782875e-01 7.01706332027084211944156777462922e-01
            -7.66110953732180188779921081732027e-01 6.04991781865576228049974361056229e-01
            -8.39912832303771894615351811808068e-01 4.97481139024155971650742458223249e-01
            -8.98726446484998664487875430495478e-01 3.81092933471302353076737290393794e-01
            -9.41502265937475879553630875307135e-01 2.57904115492394114816931960376678e-01
            -9.67476955149695894142780616675736e-01 1.30112992462662252490801506610296e-01
            -9.76186995177315219862634876335505e-01 -3.13965683452883665242650449587506e-16
            -9.67476955149696005165083079191390e-01 -1.30112992462661558601411115887458e-01
            -9.41502265937475879553630875307135e-01 -2.57904115492393892772327035345370e-01
            -8.98726446484998775510177893011132e-01 -3.81092933471302131032132365362486e-01
            -8.39912832303772005637654274323722e-01 -4.97481139024155749606137533191941e-01
            -7.66110953732180299802223544247681e-01 -6.04991781865576006005369436024921e-01
            -6.78637807041732155077795596298529e-01 -7.01706332027083989899551852431614e-01
            -5.79054352607395905749854136956856e-01 -7.85898916069837305542478134157136e-01
            -4.69137659532728734657069935565232e-01 -8.56067115337033057720361739484360e-01
            -3.50849193809623260964514201987186e-01 -9.10958776650432788812850048998371e-01
            -2.26299815911212592878243299310270e-01 -9.49594357013491818797490395809291e-01
            -9.77121124367241605801481796333974e-02 -9.71284403579337096701351583760697e-01
            3.26192659990405323111595237151050e-02 -9.75641856953154418263807201583404e-01
            1.62368552860287590489107856228657e-01 -9.62588958276258011004244963260135e-01
            2.89220369049160375141127587994561e-01 -9.32358636834766052459144702879712e-01
            4.10911040900593160785092550213449e-01 -8.85490353430971377513003517378820e-01
            5.25268995492491508336740935192211e-01 -8.22820473692545184540847458265489e-01
            6.30253512415972938498498479020782e-01 -7.45467343108096591741684733278817e-01
            7.23991140479408379349024471594021e-01 -6.54811330125434798432593197503593e-01
            8.04809129489320151940034975268645e-01 -5.52470193443916346431876718270360e-01
            8.71265280517212414856942359620007e-01 -4.40270213072129934506193649212946e-01
            9.22173681973618153406846431607846e-01 -3.20213600317874880207824617173173e-01
            9.56625872228504259275894128222717e-01 -1.94442768279947109100191937613999e-01
            9.74007051130584833309455916605657e-01 -6.52021004356298644610845371971664e-02
            9.31093503360810315072626508481335e-01 6.81472608175162086752152390545234e-02
            9.11248861854865754850152370636351e-01 2.02989341902105130399647237027239e-01
            8.71982532923397002377896569669247e-01 3.33505057584041364471261204016628e-01
            8.14131410195332749779595360450912e-01 4.56912691978453022745298994777841e-01
            7.38928489913382335885216889437288e-01 5.70582025612414778237280188477598e-01
            6.47976591759788833613242786668707e-01 6.72090393986557455008323813672177e-01
            5.43214197537537746285352113773115e-01 7.59274322462762385477219595486531e-01
            4.26874135796223075356436993388343e-01 8.30275636969955654898001284891507e-01
            3.01435992968036803318909733206965e-01 8.83581067758364535613679890957428e-01
            1.69573265287902397169261803355766e-01 9.18054502116969373126664777373662e-01
            3.40963778628182306862370865019329e-02 9.32961198643477263026113632804481e-01
            -1.02107214659977740822682790167164e-01 9.27983446981689996668762887566118e-01
            -2.36134569175759922998736328736413e-01 9.03227339266154061192537483293563e-01
            -3.65129125314644698008237355679739e-01 8.59220508952504236077629684587009e-01
            -4.86341588066459384886996986097074e-01 7.96900885226407673656012775609270e-01
            -5.97188524230692685534904740052298e-01 7.17596702671357888903003185987473e-01
            -6.95307423809937041880857577780262e-01 6.22998192254541449663918228907278e-01
            -7.78607052808809374511156420339830e-01 5.15121556988268336496616939257365e-01
            -8.45312024255868488253895520756487e-01 3.96266000063194789859721822722349e-01
            -8.94000637494570815633210258965846e-01 2.68964721324077948860775677530910e-01
            -9.23635179264480243865875763731310e-01 1.35930926513098571106752388004679e-01
            -9.33584040757787336772821618069429e-01 1.14331070724907636738370245699994e-16
            -9.23635179264480243865875763731310e-01 -1.35930926513098349062147462973371e-01
            -8.94000637494570926655512721481500e-01 -2.68964721324077726816170752499602e-01
            -8.45312024255868599276197983272141e-01 -3.96266000063194567815116897691041e-01
            -7.78607052808809707578063807886792e-01 -5.15121556988267892407407089194749e-01
            -6.95307423809937152903160040295916e-01 -6.22998192254541227619313303875970e-01
            -5.97188524230692463490299815020990e-01 -7.17596702671357999925305648503127e-01
            -4.86341588066459995509660529933171e-01 -7.96900885226407451611407850577962e-01
            -3.65129125314644698008237355679739e-01 -8.59220508952504236077629684587009e-01
            -2.36134569175759978509887559994240e-01 -9.03227339266154061192537483293563e-01
            -1.02107214659978171034104832415323e-01 -9.27983446981689996668762887566118e-01
            3.40963778628177865970272364393168e-02 -9.32961198643477263026113632804481e-01
            1.69573265287901731035447028261842e-01 -9.18054502116969484148967239889316e-01
            3.01435992968036747807758501949138e-01 -8.83581067758364535613679890957428e-01
            4.26874135796222908822983299614862e-01 -8.30275636969955765920303747407161e-01
            5.43214197537537524240747188741807e-01 -7.59274322462762496499522058002185e-01
            6.47976591759788389524032936606091e-01 -6.72090393986557899097533663734794e-01
            7.38928489913382446907519351952942e-01 -5.70582025612414667214977725961944e-01
            8.14131410195332749779595360450912e-01 -4.56912691978453078256450226035668e-01
            8.71982532923397002377896569669247e-01 -3.33505057584041586515866129047936e-01
            9.11248861854865865872454833152005e-01 -2.02989341902104714066013002593536e-01
            9.31093503360810315072626508481335e-01 -6.81472608175167499089397438183369e-02
            8.76132051668074618433479372470174e-01 7.07286912924070115815666781600157e-02
            8.53440691740858237146483133983565e-01 2.10354237924819387206554210933973e-01
            8.08645666189317879890552376309643e-01 3.44531720288975051857960352208465e-01
            7.42907142645494289467933413106948e-01 4.69786012071829961467273051312077e-01
            6.57927714338314983955058323772391e-01 5.82873092909260037686181021854281e-01
            5.55908303823296923162899929593550e-01 6.80864066809485302123050587397302e-01
            4.39491160244448453298105050635058e-01 7.61221019020780098607303898461396e-01
            3.11691426469351329231471936509479e-01 8.21862746690435574947741770301946e-01
            1.75819048472669103855281491632923e-01 8.61218660925441970022120585781522e-01
            3.53930494740407677878302195040305e-02 8.78269464219822659778458273649449e-01
            -1.05949610914852124232687913263362e-01 8.72573549724627861579051568696741e-01
            -2.44548232033819340491831439976522e-01 8.44278438633357164455617294152034e-01
            -3.76813182398385682070340862992452e-01 7.94116959460536397941154973523226e-01
            -4.99318869269688880851987278219895e-01 7.23388268168129511259678565693321e-01
            -6.08892459707038757876773615862476e-01 6.33924200708537721737911851960234e-01
            -7.02696055274465658513349808345083e-01 5.28041829435653142787998604035238e-01
            -7.78300192119534828272264803672442e-01 4.08483452147992753822336453595199e-01
            -8.33746762810984032299188584147487e-01 2.78345568016181987847090795185068e-01
            -8.67599730292648030349766941071721e-01 1.40998679880950161802388720388990e-01
            -8.78982320488897128640815026301425e-01 1.07644288529384079457226019136170e-16
            -8.67599730292648141372069403587375e-01 -1.40998679880949939757783795357682e-01
            -8.33746762810984143321491046663141e-01 -2.78345568016181765802485870153760e-01
            -7.78300192119534828272264803672442e-01 -4.08483452147992531777731528563891e-01
            -7.02696055274465880557954733376391e-01 -5.28041829435652920743393679003930e-01
            -6.08892459707038979921378540893784e-01 -6.33924200708537610715609389444580e-01
            -4.99318869269689047385440971993376e-01 -7.23388268168129400237376103177667e-01
            -3.76813182398385515536887169218971e-01 -7.94116959460536508963457436038880e-01
            -2.44548232033819340491831439976522e-01 -8.44278438633357164455617294152034e-01
            -1.05949610914852540566322147697065e-01 -8.72573549724627861579051568696741e-01
            3.53930494740403583930898889775563e-02 -8.78269464219822770800760736165103e-01
            1.75819048472668881810676566601614e-01 -8.61218660925442081044423048297176e-01
            3.11691426469351162698018242735998e-01 -8.21862746690435685970044232817600e-01
            4.39491160244447953697743969314615e-01 -7.61221019020780320651908823492704e-01
            5.55908303823296368051387617015280e-01 -6.80864066809485746212260437459918e-01
            6.57927714338314650888150936225429e-01 -5.82873092909260370753088409401244e-01
            7.42907142645494067423328488075640e-01 -4.69786012071830239023029207601212e-01
            8.08645666189317768868249913793989e-01 -3.44531720288975162880262814724119e-01
            8.53440691740858237146483133983565e-01 -2.10354237924819442717705442191800e-01
            8.76132051668074618433479372470174e-01 -7.07286912924069144370520234588184e-02
            8.11481746121753277911636814678786e-01 7.30346790561375164285706773625861e-02
            7.85400055111995287759896200441290e-01 2.16756642490414208612747870574822e-01
            7.34074960101620099806041253032163e-01 3.53511869087089480867547308662324e-01
            6.59156091874689709086965194728691e-01 4.78904933340770944116826512981788e-01
            5.63051404499467889053221369977109e-01 5.88905598992588319440244504221482e-01
            4.48849781703394345999669212687877e-01 6.79978354139643026421424565342022e-01
            3.20221757608543100559472804889083e-01 7.49196045496596241264342097565532e-01
            1.81301542744813609653320440884272e-01 7.94333959510729381570115492650075e-01
            3.65541471218595176440047112009779e-02 8.13941326486028682296591796330176e-01
            -1.09368128866443564684018951993494e-01 8.07387949514912883763884110521758e-01
            -2.51775223204582954128483152089757e-01 7.74884459525370106192099228792358e-01
            -3.86090054707583396620407256705221e-01 7.17475545429624883553287872928195e-01
            -5.07995634176326982256455266906414e-01 6.37006376962926501583694971486693e-01
            -6.13573815982443315775185510574374e-01 5.36063299410046711912514183495659e-01
            -6.99431230492666533571366471733199e-01 4.17890706339776096811533534491900e-01
            -7.62808349760922044247024587093620e-01 2.86286762126126637095779869923717e-01
            -8.01668181027060722243504642392509e-01 1.45481325820210949384403420481249e-01
            -8.14761737340213176850056697730906e-01 9.97795353701428562893065073099674e-17
            -8.01668181027060722243504642392509e-01 -1.45481325820210755095374111078854e-01
            -7.62808349760922044247024587093620e-01 -2.86286762126126470562326176150236e-01
            -6.99431230492666755615971396764508e-01 -4.17890706339775652722323684429284e-01
            -6.13573815982443426797487973090028e-01 -5.36063299410046489867909258464351e-01
            -5.07995634176327093278757729422068e-01 -6.37006376962926279539090046455385e-01
            -3.86090054707583563153860950478702e-01 -7.17475545429624772530985410412541e-01
            -2.51775223204583176173088077121065e-01 -7.74884459525370106192099228792358e-01
            -1.09368128866443772850836069210345e-01 -8.07387949514912883763884110521758e-01
            3.65541471218593164160814978913550e-02 -8.13941326486028793318894258845830e-01
            1.81301542744813415364291131481878e-01 -7.94333959510729381570115492650075e-01
            3.20221757608542934026019111115602e-01 -7.49196045496596352286644560081186e-01
            4.48849781703394068443913056398742e-01 -6.79978354139643137443727027857676e-01
            5.63051404499467667008616444945801e-01 -5.88905598992588430462546966737136e-01
            6.59156091874689598064662732213037e-01 -4.78904933340771110650280206755269e-01
            7.34074960101619988783738790516509e-01 -3.53511869087089647401001002435805e-01
            7.85400055111995287759896200441290e-01 -2.16756642490414402901777179977216e-01
            8.11481746121753166889334352163132e-01 -7.30346790561377245953877945794375e-02
            7.38478625533172783335089661704842e-01 7.50959363326821893735996127361432e-02
            7.08245223836290405117210866592359e-01 2.22213372541188725062255571174319e-01
            6.49016179460270015155742839851882e-01 3.60233367168896367882524600645411e-01
            5.63216336440983011968341997999232e-01 4.83505365419085897382700522939558e-01
            4.54358350432692459364147907763254e-01 5.86982597199549815947250408498803e-01
            3.26898880172848238512273155720322e-01 6.66428692483137408153481828776421e-01
            1.86056131349739778402252454725385e-01 7.18591118794418948212410214182455e-01
            3.75962226485061640213203304483613e-02 7.41334340271385339171672512748046e-01
            -1.12402879825326387774886427450838e-01 7.33727246754554918162227750144666e-01
            -2.57800195192331993432333092641784e-01 6.96081273546302115029504875565181e-01
            -3.92643140277927071846164608359686e-01 6.29937651212986615689715108601376e-01
            -5.11411229066933370468461816926720e-01 5.38004307424480465726901456946507e-01
            -6.09242082049671784815814135072287e-01 4.24045004077193699032477525179274e-01
            -6.82130492610391381269607791182352e-01 2.92725248439814400569503050064668e-01
            -7.27092400656711768114348615199560e-01 1.49421286737552810874873898683290e-01
            -7.42287060390416808530744674499147e-01 9.09039472555622037327755474108245e-17
            -7.27092400656711768114348615199560e-01 -1.49421286737552644341420204909809e-01
            -6.82130492610391492291910253698006e-01 -2.92725248439814234036049356291187e-01
            -6.09242082049672006860419060103595e-01 -4.24045004077193532499023831405793e-01
            -5.11411229066933703535369204473682e-01 -5.38004307424480132659994069399545e-01
            -3.92643140277927238379618302133167e-01 -6.29937651212986504667412646085722e-01
            -2.57800195192332326499240480188746e-01 -6.96081273546301892984899950533872e-01
            -1.12402879825326568186127929038776e-01 -7.33727246754554918162227750144666e-01
            3.75962226485063097380923125001573e-02 -7.41334340271385339171672512748046e-01
            1.86056131349739445335345067178423e-01 -7.18591118794418948212410214182455e-01
            3.26898880172847738911912074399879e-01 -6.66428692483137630198086753807729e-01
            4.54358350432692126297240520216292e-01 -5.86982597199550037991855333530111e-01
            5.63216336440983122990644460514886e-01 -4.83505365419085675338095597908250e-01
            6.49016179460269793111137914820574e-01 -3.60233367168896700949431988192373e-01
            7.08245223836290294094908404076705e-01 -2.22213372541189169151465421236935e-01
            7.38478625533172783335089661704842e-01 -7.50959363326820367179337267771189e-02
            6.57994712760665234618784324993612e-01 7.69085517972174642631344454457576e-02
            6.22522047480154494536463971599005e-01 2.26579495457227747534645345695026e-01
            5.53489057486162505661297927872511e-01 3.64035479869222466930978043819778e-01
            4.54617329137788850346169056138024e-01 4.81866217334395552374104454429471e-01
            3.31237062902287437982096207633731e-01 5.73719422296649850245842117146822e-01
            1.89999720868205573820475251523021e-01 6.34643264701154397045002042432316e-01
            3.85194447025239417037312250613468e-02 6.61353324434333478265557459963020e-01
            -1.15037424697456994171496091894369e-01 6.52409655262330190339525870513171e-01
            -2.62392596755670892694212170681567e-01 6.08294412705189468937305719009601e-01
            -3.95602116004994119879967229280737e-01 5.31385860907972129574261543893954e-01
            -5.07484622782697458731604456261266e-01 4.25830159805102248515851215415751e-01
            -5.92008502188686502876180384191684e-01 2.97317844565111122356881878658896e-01
            -6.44617050005994340899917460774304e-01 1.52777047366758955693200050518499e-01
            -6.62474125804574764941889952751808e-01 8.11296817684513501089088386669622e-17
            -6.44617050005994340899917460774304e-01 -1.52777047366758816915321972373931e-01
            -5.92008502188686502876180384191684e-01 -2.97317844565110955823428184885415e-01
            -5.07484622782697347709301993745612e-01 -4.25830159805102304027002446673578e-01
            -3.95602116004994286413420923054218e-01 -5.31385860907972018551959081378300e-01
            -2.62392596755670948205363401939394e-01 -6.08294412705189468937305719009601e-01
            -1.15037424697457160704949785667850e-01 -6.52409655262330079317223407997517e-01
            3.85194447025234767978396632770455e-02 -6.61353324434333478265557459963020e-01
            1.89999720868205573820475251523021e-01 -6.34643264701154397045002042432316e-01
            3.31237062902287437982096207633731e-01 -5.73719422296649850245842117146822e-01
            4.54617329137788961368471518653678e-01 -4.81866217334395496862953223171644e-01
            5.53489057486162283616693002841203e-01 -3.64035479869222911020187893882394e-01
            6.22522047480154272491859046567697e-01 -2.26579495457228219379430811386555e-01
            6.57994712760665234618784324993612e-01 -7.69085517972173393630441751156468e-02
            5.70627606218485183831035101320595e-01 7.84309592070605576807906800240744e-02
            5.28306767112858732815539042348973e-01 2.29476012174557847389522180492349e-01
            4.46803831933113793084544340672437e-01 3.63501879101971070440413313917816e-01
            3.32163500530413102751481346786022e-01 4.70568474566837480210779176559299e-01
            1.92888121840275733598346619146469e-01 5.42735158980611087642387246887665e-01
            3.93071135576870747674327333243127e-02 5.74649659500935605649374338099733e-01
            -1.17189123519396087846899945361656e-01 5.63945023623343977270394589140778e-01
            -2.64993979409613000797207860159688e-01 5.11415165220426182202118070563301e-01
            -3.93145444113810305086786911488161e-01 4.20955983581814685567934475329821e-01
            -4.92139109748818803780068265041336e-01 2.99276422386425711152924122870900e-01
            -5.54633069000377010304703162546502e-01 1.55400898041167301322218463610625e-01
            -5.75992430801636645654184576414991e-01 7.05387286714327601769608776257330e-17
            -5.54633069000376899282400700030848e-01 -1.55400898041167384588945310497365e-01
            -4.92139109748819025824673190072645e-01 -2.99276422386425322574865504066111e-01
            -3.93145444113810249575635680230334e-01 -4.20955983581814741079085706587648e-01
            -2.64993979409613333864115247706650e-01 -5.11415165220426071179815608047647e-01
            -1.17189123519395976824597482846002e-01 -5.63945023623343977270394589140778e-01
            3.93071135576869359895546551797452e-02 -5.74649659500935605649374338099733e-01
            1.92888121840275594820468541001901e-01 -5.42735158980611087642387246887665e-01
            3.32163500530413047240330115528195e-01 -4.70568474566837646744232870332780e-01
            4.46803831933113626551090646898956e-01 -3.63501879101971236973867007691297e-01
            5.28306767112858621793236579833319e-01 -2.29476012174558097189702721152571e-01
            5.70627606218485183831035101320595e-01 -7.84309592070604050251247940650501e-02
            4.76766518881121814654733270799625e-01 7.95582608158849624580000181595096e-02
            4.25101468765590628784423188335495e-01 2.30053410414644970982678273685451e-01
            3.27370078380397000472612489829771e-01 3.55618703348522136042930696930853e-01
            1.94163060332544740171911712423025e-01 4.42647191781866011783819203628809e-01
            3.99154619473657476524941500883870e-02 4.81707988606790593610895712117781e-01
            -1.18657596092016412447911477556772e-01 4.68568250396604824015156509631197e-01
            -2.64372262432523985609122973983176e-01 4.04651871670427543126180580657092e-01
            -3.81438091980155546956154921645066e-01 2.96885183828041299136657471535727e-01
            -4.57169185639923647546112306372379e-01 1.56946379669619939800639940585825e-01
            -4.83358904324800331409051068476401e-01 5.91943935020738405748881830017320e-17
            -4.57169185639923647546112306372379e-01 -1.56946379669620023067366787472565e-01
            -3.81438091980155769000759846676374e-01 -2.96885183828041077092052546504419e-01
            -2.64372262432523930097971742725349e-01 -4.04651871670427598637331811914919e-01
            -1.18657596092016523470213940072426e-01 -4.68568250396604768504005278373370e-01
            3.99154619473657337747063422739302e-02 -4.81707988606790593610895712117781e-01
            1.94163060332544351593853093618236e-01 -4.42647191781866178317272897402290e-01
            3.27370078380397055983763721087598e-01 -3.55618703348522136042930696930853e-01
            4.25101468765590462250969494562014e-01 -2.30053410414645276294010045603500e-01
            4.76766518881121870165884502057452e-01 -7.95582608158848791912731712727691e-02
            3.76575292567856489966970912064426e-01 8.00435493981061924051445544137096e-02
            3.11462003403741083396027988783317e-01 2.26290391330568330108263808142510e-01
            1.92494104307647462270836058451096e-01 3.33409568818308355009349952524644e-01
            4.02422258227235485339434717388940e-02 3.82879202926519224270407448784681e-01
            -1.18967899096093607247404122517764e-01 3.66145544500374120477914630100713e-01
            -2.57607393471762702308325287958723e-01 2.86101995102267969706133499130374e-01
            -3.51704229226464659685547076151124e-01 1.56588811595950810895416793755430e-01
            -3.84988208615294813519369654386537e-01 2.18116567104576774888290937804377e-16
            -3.51704229226464604174395844893297e-01 -1.56588811595950866406568025013257e-01
            -2.57607393471762924352930212990032e-01 -2.86101995102267803172679805356893e-01
            -1.18967899096093690514130969404505e-01 -3.66145544500374120477914630100713e-01
            4.02422258227233681227019701509562e-02 -3.82879202926519224270407448784681e-01
            1.92494104307647462270836058451096e-01 -3.33409568818308355009349952524644e-01
            3.11462003403741027884876757525490e-01 -2.26290391330568441130566270658164e-01
            3.76575292567856489966970912064426e-01 -8.00435493981060675050542840835988e-02
            2.69831011992089919715454016113654e-01 7.92295337372477398441006357643346e-02
            1.84161572219427027707894239938469e-01 2.12533784059301567026523116510361e-01
            4.00221344905854134466061111652380e-02 2.78360059634485901280953612513258e-01
            -1.16824048156127680009319647069788e-01 2.55808983073917528550111910590203e-01
            -2.36579420952550356638255379948532e-01 1.52040361847284005714087129490508e-01
            -2.81222499186848606811395256954711e-01 1.59327700803686818713081316791187e-16
            -2.36579420952550384393830995577446e-01 -1.52040361847283950202935898232681e-01
            -1.16824048156127915931712379915552e-01 -2.55808983073917417527809448074549e-01
            4.00221344905853440576670720929542e-02 -2.78360059634485956792104843771085e-01
            1.84161572219426861174440546164988e-01 -2.12533784059301705804401194654929e-01
            2.69831011992089919715454016113654e-01 -7.92295337372477675996762513932481e-02
            1.55282269457979155147242522616580e-01 7.47799997217942630234333023508952e-02
            3.83515533750806367208063818452501e-02 1.68029134140869562674680537384120e-01
            -1.07458664628371822202801411094697e-01 1.34748903382176404841530370504188e-01
            -1.72350316409375925452707178919809e-01 2.11068263322775768239603510471886e-17
            -1.07458664628371849958377026723610e-01 -1.34748903382176377085954754875274e-01
            3.83515533750804493706709763500839e-02 -1.68029134140869618185831768641947e-01
            1.55282269457979210658393753874407e-01 -7.47799997217941520011308398352412e-02
            2.93096173566358489392946751195268e-02 5.07657464120958926145910083960189e-02
            -5.86192347132716840008015424245968e-02 7.17878581600755828862824885247960e-18
            2.93096173566358489392946751195268e-02 -5.07657464120958926145910083960189e-02
            ];
        
    case   26
        
        % DEGREE.             :          26
        % CARDIN.             :         378
        % LEBESGUE CONST.     : 5.01980e+01
        % ABS.DET.VAND.MATRIX : Inf
        % CONDITIONING VAND.  : 1.28209e+03
        % POINTS OUT DISK     : 0.00000e+00
        
        pts=[
            9.98243731764321240440551719075302e-01 5.92406278937142732887721763290756e-02
            9.84230577947596829702092691150028e-01 1.76890275122572965260658861552656e-01
            9.56400984276522425631128498935141e-01 2.92056770636975826516135157362442e-01
            9.15145617243018461017811659985455e-01 4.03123429287972234735804022420780e-01
            8.61043611767355554498237779625924e-01 5.08531118649220514882358656905126e-01
            7.94854441413353263179430996387964e-01 6.06800145818593317237343853776110e-01
            7.17507257044331159256955743330764e-01 6.96551029062997040242066759674344e-01
            6.30087843581711104512521615106380e-01 7.76523862718042412467411850229837e-01
            5.33823377964790624083946113387356e-01 8.45596003501826065651414410240250e-01
            4.30065202276520508473112158753793e-01 9.02797829965743536817512904235628e-01
            3.20269853862837516889072730918997e-01 9.47326353854191394177064466930460e-01
            2.05978618741098601363503917127673e-01 9.78556492299503921650227766804164e-01
            8.87958953229349007285620132279291e-02 9.96049842615216896035690297139809e-01
            -2.96333278225595457555652245673627e-02 9.99560836508794348098660975665553e-01
            -1.47646564002481162081181764733628e-01 9.89040187322164032757143559138058e-01
            -2.63587166069067457829788736489718e-01 9.64635581908358741287656812346540e-01
            -3.75827582114238112342974318380584e-01 9.26689607431833484163519187859492e-01
            -4.82792202730744746119739829737227e-01 8.75734942195636856254736812843475e-01
            -5.82979479114471899059424231381854e-01 8.12486878005681423253747652779566e-01
            -6.74983001518210334879199763236102e-01 7.37833279041727463365418770990800e-01
            -7.57511242161619802182315197569551e-01 6.52822118190521938352333108923631e-01
            -8.29405685450201768382783029665006e-01 5.58646765803652467496931421919726e-01
            -8.89657090994747212775450861954596e-01 4.56629237393713249826276978637907e-01
            -9.37419661134120896228694164165063e-01 3.48201635434398637514163965533953e-01
            -9.72022914080410638248963550722692e-01 2.34886045780984042963268620951567e-01
            -9.92981096013516917331287459091982e-01 1.18273170921365827767957057403692e-01
            -1.00000000000000000000000000000000e+00 1.22464679914735320717376402945840e-16
            -9.92981096013516917331287459091982e-01 -1.18273170921366022056986366806086e-01
            -9.72022914080410860293568475754000e-01 -2.34886045780983376829453845857643e-01
            -9.37419661134121007250996626680717e-01 -3.48201635434398415469559040502645e-01
            -8.89657090994747323797753324470250e-01 -4.56629237393713027781672053606599e-01
            -8.29405685450201879405085492180660e-01 -5.58646765803652356474628959404072e-01
            -7.57511242161620246271525047632167e-01 -6.52822118190521383240820796345361e-01
            -6.74983001518210778968409613298718e-01 -7.37833279041727019276208920928184e-01
            -5.82979479114472121104029156413162e-01 -8.12486878005681312231445190263912e-01
            -4.82792202730744579586286135963746e-01 -8.75734942195636967277039275359130e-01
            -3.75827582114238334387579243411892e-01 -9.26689607431833373141216725343838e-01
            -2.63587166069067513340939967747545e-01 -9.64635581908358741287656812346540e-01
            -1.47646564002481633925967230425158e-01 -9.89040187322163921734841096622404e-01
            -2.96333278225597886168518613203560e-02 -9.99560836508794348098660975665553e-01
            8.87958953229342068391716225050914e-02 -9.96049842615217007057992759655463e-01
            2.05978618741099017697138151561376e-01 -9.78556492299503810627925304288510e-01
            3.20269853862837683422526424692478e-01 -9.47326353854191172132459541899152e-01
            4.30065202276520064383902308691177e-01 -9.02797829965743647839815366751282e-01
            5.33823377964790624083946113387356e-01 -8.45596003501826065651414410240250e-01
            6.30087843581710549401009302528109e-01 -7.76523862718042856556621700292453e-01
            7.17507257044330937212350818299456e-01 -6.96551029062997262286671684705652e-01
            7.94854441413353263179430996387964e-01 -6.06800145818593317237343853776110e-01
            8.61043611767355221431330392078962e-01 -5.08531118649220847949266044452088e-01
            9.15145617243018461017811659985455e-01 -4.03123429287972345758106484936434e-01
            9.56400984276522314608826036419487e-01 -2.92056770636975548960379001073306e-01
            9.84230577947596718679790228634374e-01 -1.76890275122573270571990633470705e-01
            9.98243731764321240440551719075302e-01 -5.92406278937142455331965607001621e-02
            9.75609164232314030051895770156989e-01 6.26361865305006815241029016760876e-02
            9.59589688727790601774358947295696e-01 1.86880075140342105655122395546641e-01
            9.27813777063645650500234296487179e-01 3.08055398082957621053168395519606e-01
            8.80803188830912131557226985023590e-01 4.24172459905702181615083645738196e-01
            8.19329836588693405374783651495818e-01 5.33324621663675779714708369283471e-01
            7.44403111081284540873070909583475e-01 6.33719607878486579366494879650418e-01
            6.57253307070055470262559538241476e-01 7.23708935652057072651643920835340e-01
            5.59311421927484730964863501867512e-01 8.01814982710234214202671410021139e-01
            4.52185658699863435305843495370937e-01 8.66755249919681003412108566408278e-01
            3.37635019457737994841295403602999e-01 9.17463419888188691508901229099138e-01
            2.17540422530540039636193228034244e-01 9.53106865866777841489465572522022e-01
            9.38738178796204442155826086491288e-02 9.73100323457896099199615491670556e-01
            -3.13341922656009755354666879156866e-02 9.77115500640646117425092143093934e-01
            -1.56027695840101510160735642784857e-01 9.65086468316692758229180526541313e-01
            -2.78159228962526039463654115024838e-01 9.37210742864234891413843797636218e-01
            -3.95723395235512920287135329999728e-01 8.93946042924535722029588669101940e-01
            -5.06789794299096540974858271511039e-01 8.36002773674488164346030316664837e-01
            -6.09534718951248999374570303189103e-01 7.64332361993249609355416396283545e-01
            -7.02271100369718737077562309423229e-01 6.80111634059190617307422144222073e-01
            -7.83476209735450290772007519990439e-01 5.84723491896580682691819674801081e-01
            -8.51816661397694629975774205377093e-01 4.79734206162582443866426729073282e-01
            -9.06170307029531607589944997016573e-01 3.66867698026362654140086760889972e-01
            -9.45644661272374120741801561962347e-01 2.47977232431154409608708988344006e-01
            -9.69591556320881786668053337052697e-01 1.25014987535127714002314291974471e-01
            -9.77617784820406177104246125963982e-01 1.19723649096983634111476864377417e-16
            -9.69591556320881897690355799568351e-01 -1.25014987535127519713284982572077e-01
            -9.45644661272374120741801561962347e-01 -2.47977232431154187564104063312698e-01
            -9.06170307029531718612247459532227e-01 -3.66867698026362432095481835858664e-01
            -8.51816661397694963042681592924055e-01 -4.79734206162581888754914416495012e-01
            -7.83476209735450512816612445021747e-01 -5.84723491896580571669517212285427e-01
            -7.02271100369718848099864771938883e-01 -6.80111634059190506285119681706419e-01
            -6.09534718951249221419175228220411e-01 -7.64332361993249387310811471252237e-01
            -5.06789794299097096086370584089309e-01 -8.36002773674487831279122929117875e-01
            -3.95723395235513308865193948804517e-01 -8.93946042924535722029588669101940e-01
            -2.78159228962526039463654115024838e-01 -9.37210742864234891413843797636218e-01
            -1.56027695840101093827101408351155e-01 -9.65086468316692758229180526541313e-01
            -3.13341922656009963521483996373718e-02 -9.77115500640646117425092143093934e-01
            9.38738178796197642039800257407478e-02 -9.73100323457896099199615491670556e-01
            2.17540422530539817591588303002936e-01 -9.53106865866777841489465572522022e-01
            3.37635019457737994841295403602999e-01 -9.17463419888188691508901229099138e-01
            4.52185658699863213261238570339628e-01 -8.66755249919681114434411028923932e-01
            5.59311421927484730964863501867512e-01 -8.01814982710234214202671410021139e-01
            6.57253307070055137195652150694514e-01 -7.23708935652057405718551308382303e-01
            7.44403111081283763716953671973897e-01 -6.33719607878487467544914579775650e-01
            8.19329836588693627419388576527126e-01 -5.33324621663675446647800981736509e-01
            8.80803188830912020534924522507936e-01 -4.24172459905702403659688570769504e-01
            9.27813777063645428455629371455871e-01 -3.08055398082958342698134401871357e-01
            9.59589688727790601774358947295696e-01 -1.86880075140342438722029783093603e-01
            9.75609164232314030051895770156989e-01 -6.26361865305015558247347939868632e-02
            9.35224594505027706503597073606215e-01 6.53972743448988508285779630568868e-02
            9.17021511575196290877443061617669e-01 1.94918939477870090115629864158109e-01
            8.80969648019062745447627094108611e-01 3.20646729170912081485766975674778e-01
            8.27770712352360105157345060433727e-01 4.40133495010890829490790565614589e-01
            7.58460161344948424755330051993951e-01 5.51053563014912706208292547671590e-01
            6.74387046032603687528705904696835e-01 6.51248000228986767545791281008860e-01
            5.77187753973129380469231364259031e-01 7.38766635902224466647680856112856e-01
            4.68754158823907363107252876943676e-01 8.11906019342218288059598307881970e-01
            3.51196797173130459412959680776112e-01 8.69242575645124748717762486194260e-01
            2.26803789345814854616634193007485e-01 9.09660313961873745469688401499297e-01
            9.79963037443691703520798341742193e-02 9.32372548990625715781277449423214e-01
            -3.27185684403169113609877172166307e-02 9.36937212911330474796045564289670e-01
            -1.62796610907132627277249525832303e-01 9.23265459732999560493738044897327e-01
            -2.89706002521041061648077175050275e-01 8.91623394579860728548226234124741e-01
            -4.10976596331571186748732316118549e-01 8.42626894257803904508818959584460e-01
            -5.24247998173456464243713526229840e-01 7.77229619912905178580331266857684e-01
            -6.27315509054155229229365886567393e-01 6.96704455101990638432596369966632e-01
            -7.18173037111929923881348258873913e-01 6.02618730562087701052575994253857e-01
            -7.95052143912042930118388994742418e-01 4.96803717900439589794103767417255e-01
            -8.56456465089317386940592768951319e-01 3.81318985975713287128741058040760e-01
            -9.01190835378418153567281478899531e-01 2.58412313732887366501955739295227e-01
            -9.28384551146259839882191045035142e-01 1.30475939742900670648140248886193e-01
            -9.37508317647814504169900828856044e-01 1.14811656038141600854028382675188e-16
            -9.28384551146259839882191045035142e-01 -1.30475939742900476359110939483799e-01
            -9.01190835378418375611886403930839e-01 -2.58412313732886755879292195459129e-01
            -8.56456465089317720007500156498281e-01 -3.81318985975712676506077514204662e-01
            -7.95052143912043041140691457258072e-01 -4.96803717900439478771801304901601e-01
            -7.18173037111930145925953183905222e-01 -6.02618730562087479007971069222549e-01
            -6.27315509054155451273970811598701e-01 -6.96704455101990416387991444935324e-01
            -5.24247998173457019355225838808110e-01 -7.77229619912904845513423879310722e-01
            -4.10976596331571408793337241149857e-01 -8.42626894257803793486516497068806e-01
            -2.89706002521041228181530868823756e-01 -8.91623394579860617525923771609087e-01
            -1.62796610907132655032825141461217e-01 -9.23265459732999560493738044897327e-01
            -3.27185684403177717838318017129495e-02 -9.36937212911330363773743101774016e-01
            9.79963037443687262628699841116031e-02 -9.32372548990625826803579911938868e-01
            2.26803789345814438282999958573782e-01 -9.09660313961873856491990864014952e-01
            3.51196797173130459412959680776112e-01 -8.69242575645124748717762486194260e-01
            4.68754158823907363107252876943676e-01 -8.11906019342218288059598307881970e-01
            5.77187753973129602513836289290339e-01 -7.38766635902224244603075931081548e-01
            6.74387046032603354461798517149873e-01 -6.51248000228987100612698668555822e-01
            7.58460161344948313733027589478297e-01 -5.51053563014912928252897472702898e-01
            8.27770712352360105157345060433727e-01 -4.40133495010890829490790565614589e-01
            8.80969648019062745447627094108611e-01 -3.20646729170911970463464513159124e-01
            9.17021511575196179855140599102015e-01 -1.94918939477870617471566561107466e-01
            9.35224594505027706503597073606215e-01 -6.53972743448983512282168817364436e-02
            8.83462221054755025839710924628889e-01 6.78273919842827116566397194219462e-02
            8.62754615381087441861041043011937e-01 2.01892359372568136466341570667282e-01
            8.21824772759790489473630259453785e-01 3.31225140973189391413455950896605e-01
            7.61632054011381121050305864628172e-01 4.52794286002810519864425486957771e-01
            6.83587325446339710843801640294259e-01 5.63750316739166423829487939656246e-01
            5.89519889354586101859467817121185e-01 6.61492517863767615082792872271966e-01
            4.81634606710249268957113599753939e-01 7.43729895024701770367414610518608e-01
            3.62460217099187353984035553366994e-01 8.08534873802485010152452105103293e-01
            2.34790067206354535755963297560811e-01 8.54388480420719353958247666014358e-01
            1.01616637137038001714728352453676e-01 8.80215945203987937262013474537525e-01
            -3.39386007805030989747940850520536e-02 8.85411894268115173822764063515933e-01
            -1.68698346660773157434931590614724e-01 8.69854538970920132534558888437459e-01
            -2.99503946277403176878806334570982e-01 8.33908530534765990438472726964392e-01
            -4.23289427241063997975345500890398e-01 7.78416412930972634320880843006307e-01
            -5.37153362793676758535355020285351e-01 7.04678874363234397648625417787116e-01
            -6.38426878792483942781643690977944e-01 6.14424260238540131950912837055512e-01
            -7.24736209857925861577143678005086e-01 5.09768062215708916973255782068009e-01
            -7.94058338422225173935942166281166e-01 3.93163332873915472021053574280813e-01
            -8.44768412546546443309125606901944e-01 2.67343188239345663781421080784639e-01
            -8.75677831073281232043825639266288e-01 1.35256745862024935211920251276752e-01
            -8.86062103429771097395928336482029e-01 5.02001931271315534166716379724611e-16
            -8.75677831073281232043825639266288e-01 -1.35256745862024713167315326245443e-01
            -8.44768412546546443309125606901944e-01 -2.67343188239345830314874774558120e-01
            -7.94058338422225284958244628796820e-01 -3.93163332873915305487599880507332e-01
            -7.24736209857926194644051065552048e-01 -5.09768062215708361861743469489738e-01
            -6.38426878792484164826248616009252e-01 -6.14424260238540020928610374539858e-01
            -5.37153362793676647513052557769697e-01 -7.04678874363234508670927880302770e-01
            -4.23289427241063775930740575859090e-01 -7.78416412930972634320880843006307e-01
            -2.99503946277403176878806334570982e-01 -8.33908530534765990438472726964392e-01
            -1.68698346660773768057595134450821e-01 -8.69854538970920021512256425921805e-01
            -3.39386007805033140805051061761333e-02 -8.85411894268115173822764063515933e-01
            1.01616637137037987836940544639219e-01 -8.80215945203987937262013474537525e-01
            2.34790067206354147177904678756022e-01 -8.54388480420719464980550128530012e-01
            3.62460217099187187450581859593512e-01 -8.08534873802485121174754567618947e-01
            4.81634606710249491001718524785247e-01 -7.43729895024701659345112148002954e-01
            5.89519889354585879814862892089877e-01 -6.61492517863767948149700259818928e-01
            6.83587325446339155732289327715989e-01 -5.63750316739166978941000252234517e-01
            7.61632054011380899005700939596863e-01 -4.52794286002811019464786568278214e-01
            8.21824772759790378451327796938131e-01 -3.31225140973189613458060875927913e-01
            8.62754615381087441861041043011937e-01 -2.01892359372568025444039108151628e-01
            8.83462221054755025839710924628889e-01 -6.78273919842830724791227225978218e-02
            8.22547770500463570897409226745367e-01 7.00091328056208078711719622333476e-02
            7.98884568752121215773343010368990e-01 2.08013363131351963764004153745191e-01
            7.52238912486253186173712492745835e-01 3.40033427728771042719557726741186e-01
            6.83952712306096222150131325179245e-01 4.62271349707736867173935024766251e-01
            5.95990437862461530649227370304288e-01 5.71210566610938719200873947556829e-01
            4.90882603638582493132958006754052e-01 6.63717095513204791146222305542324e-01
            3.71652970655728109861115626699757e-01 7.37129692004229841728601968497969e-01
            2.41731558373968896669126138476713e-01 7.89336409344945200139420649065869e-01
            1.04855969277330859923402783806523e-01 8.18835355329989300621207348740427e-01
            -3.50361351446329127856671448171255e-02 8.24777898991968294595267252589110e-01
            -1.73920313748616633953147925240046e-01 8.06993084169288943385822676646058e-01
            -3.07801121581970649199178069466143e-01 7.65992547603669082789679123379756e-01
            -4.32827051559502740119000918639358e-01 7.02955800082612491941347343527013e-01
            -5.45401335309897095093845109659014e-01 6.19696294061582664269849374250043e-01
            -6.42285415653137459202071113395505e-01 5.18609253938603353972780496405903e-01
            -7.20692113994149230471464306901908e-01 4.02602769809302762915592666104203e-01
            -7.78365812376378807257992775703315e-01 2.75014137009605807993040116343764e-01
            -8.13647343503607012316081181779737e-01 1.39513848205121610002166221420339e-01
            -8.25521721962225729640749705140479e-01 1.01097253442765099254319134762962e-16
            -8.13647343503607012316081181779737e-01 -1.39513848205121387957561296389031e-01
            -7.78365812376378807257992775703315e-01 -2.75014137009605641459586422570283e-01
            -7.20692113994149563538371694448870e-01 -4.02602769809302263315231584783760e-01
            -6.42285415653137348179768650879851e-01 -5.18609253938603464995082958921557e-01
            -5.45401335309897206116147572174668e-01 -6.19696294061582553247546911734389e-01
            -4.32827051559503184208210768701974e-01 -7.02955800082612269896742418495705e-01
            -3.07801121581970815732631763239624e-01 -7.65992547603668971767376660864102e-01
            -1.73920313748616467419694231466565e-01 -8.06993084169288943385822676646058e-01
            -3.50361351446332944248318597146863e-02 -8.24777898991968183572964790073456e-01
            1.04855969277330290934102663413796e-01 -8.18835355329989300621207348740427e-01
            2.41731558373968508091067519671924e-01 -7.89336409344945311161723111581523e-01
            3.71652970655728109861115626699757e-01 -7.37129692004229841728601968497969e-01
            4.90882603638582715177562931785360e-01 -6.63717095513204680123919843026670e-01
            5.95990437862461308604622445272980e-01 -5.71210566610938941245478872588137e-01
            6.83952712306095889083223937632283e-01 -4.62271349707737311263144874828868e-01
            7.52238912486253186173712492745835e-01 -3.40033427728771264764162651772494e-01
            7.98884568752121215773343010368990e-01 -2.08013363131351908252852922487364e-01
            8.22547770500463459875106764229713e-01 -7.00091328056211686936549654092232e-02
            7.53745411341151916317926406918559e-01 7.19739601249409638450416082378069e-02
            7.26503088310768707636100316449301e-01 2.13320553929583517360768496473611e-01
            6.73003050783500533782444108510390e-01 3.46957187113928866573075993073871e-01
            5.95178929508571208373268746072426e-01 4.68053883567843109769768261685385e-01
            4.95843490997626867855530008455389e-01 5.72233893167116813849304435279919e-01
            3.78586976814413556091665213898523e-01 6.55731878926464561985198997717816e-01
            2.47647342890380206537059848415083e-01 7.15530006088663794727722233801614e-01
            1.07757088755430552318159698188538e-01 7.49467014535571851574502488801954e-01
            -3.60277873254969821514848149490717e-02 7.56316332359904586191134967521066e-01
            -1.78510525302996436725067042061710e-01 7.35830407369766903435959193302551e-01
            -3.14541427791408978453802092190017e-01 6.88749654269859346022997215186479e-01
            -4.39203983549742937864124314728542e-01 6.16775694144918396055743414763128e-01
            -5.47992563007772104377579580614110e-01 5.22509853440183302808463849942200e-01
            -6.36975263458003482242020254489034e-01 4.09359145245975830640361436962849e-01
            -7.02936018264001649669125981745310e-01 2.81413130967728797315885458374396e-01
            -7.43490833888006963370287394354818e-01 1.43296112921547230678598339181917e-01
            -7.57173953628826890138725502765737e-01 9.27270658709289312478789627556083e-17
            -7.43490833888007185414892319386126e-01 -1.43296112921546731078237257861474e-01
            -7.02936018264001649669125981745310e-01 -2.81413130967728630782431764600915e-01
            -6.36975263458003815308927642035997e-01 -4.09359145245975442062302818158059e-01
            -5.47992563007772104377579580614110e-01 -5.22509853440183191786161387426546e-01
            -4.39203983549743104397578008502023e-01 -6.16775694144918285033440952247474e-01
            -3.14541427791408811920348398416536e-01 -6.88749654269859457045299677702133e-01
            -1.78510525302996436725067042061710e-01 -7.35830407369766903435959193302551e-01
            -3.60277873254973360350739142177190e-02 -7.56316332359904586191134967521066e-01
            1.07757088755430191495676695012662e-01 -7.49467014535571962596804951317608e-01
            2.47647342890380206537059848415083e-01 -7.15530006088663905750024696317269e-01
            3.78586976814413556091665213898523e-01 -6.55731878926464561985198997717816e-01
            4.95843490997626423766320158392773e-01 -5.72233893167117146916211822826881e-01
            5.95178929508570986328663821041118e-01 -4.68053883567843498347826880490175e-01
            6.73003050783500533782444108510390e-01 -3.46957187113929033106529686847352e-01
            7.26503088310768707636100316449301e-01 -2.13320553929583600627495343360351e-01
            7.53745411341151805295623944402905e-01 -7.19739601249415467121295364449907e-02
            6.77885430895830309871996632864466e-01 7.37244834732408288457961020867515e-02
            6.46188261562684496119857158191735e-01 2.17726175511391950578854448394850e-01
            5.84276047305537171716594002646161e-01 3.51547233567894079619975400419207e-01
            4.95043734452568662263161058945116e-01 4.68930333699448809170462482143193e-01
            3.82663726778191271016282826167298e-01 5.64386772605850128847748692351161e-01
            2.52390788539851362859423034024076e-01 6.33453113296046366187397325120401e-01
            1.10316337541601583449590862073819e-01 6.72899890441088666115376781817758e-01
            -3.69163827922900159017594035049115e-02 6.80882616583618593963933562918101e-01
            -1.82422934096427152850239394865639e-01 6.57028028321374080178429721854627e-01
            -3.19399591750744060725253348209662e-01 6.02451539689027315560565511987079e-01
            -4.41441479481946064122865891476977e-01 5.19705086637616386902038811967941e-01
            -5.42842054259537576399452518671751e-01 4.12657801345748198595941858002334e-01
            -6.18859937905563595172964141966077e-01 2.86315095899157434633508501065080e-01
            -6.65940618668544703773193305096356e-01 1.46584614784696087852466916956473e-01
            -6.81882656242422502401723249931820e-01 8.35065412361377729577980792361199e-17
            -6.65940618668544703773193305096356e-01 -1.46584614784695921319013223182992e-01
            -6.18859937905563484150661679450423e-01 -2.86315095899157545655810963580734e-01
            -5.42842054259537909466359906218713e-01 -4.12657801345747810017883239197545e-01
            -4.41441479481945897589412197703496e-01 -5.19705086637616497924341274483595e-01
            -3.19399591750744504814463198272279e-01 -6.02451539689027093515960586955771e-01
            -1.82422934096427458161571166783688e-01 -6.57028028321373969156127259338973e-01
            -3.69163827922904808076509652892128e-02 -6.80882616583618482941631100402446e-01
            1.10316337541601430793924976114795e-01 -6.72899890441088777137679244333412e-01
            2.52390788539851029792515646477113e-01 -6.33453113296046477209699787636055e-01
            3.82663726778191215505131594909471e-01 -5.64386772605850128847748692351161e-01
            4.95043734452568662263161058945116e-01 -4.68930333699448809170462482143193e-01
            5.84276047305537171716594002646161e-01 -3.51547233567894079619975400419207e-01
            6.46188261562684496119857158191735e-01 -2.17726175511391895067703217137023e-01
            6.77885430895830309871996632864466e-01 -7.37244834732413284461571834071947e-02
            5.95546148839159128485221117443871e-01 7.52349748188244071833707948826486e-02
            5.58125794042070855205395218945341e-01 2.20977634293724162217742446046032e-01
            4.85636342962233513720349264985998e-01 3.52835456307059591729569092422025e-01
            3.82632574408545478306109544064384e-01 4.62523328962585356105563505479950e-01
            2.55586593980596799013937925337814e-01 5.43149159817577720232861793192569e-01
            1.12481167871107359812477000104991e-01 5.89646931398353557618463582912227e-01
            -3.76918636925221289812881764191843e-02 5.99095017709651234127932184492238e-01
            -1.85496576839372206979561497064424e-01 5.70899760740900874544934140430996e-01
            -3.21645857854716721302423820816330e-01 5.06832772182350455025812152598519e-01
            -4.37584946690330933716239769637468e-01 4.10919616547036181675167654248071e-01
            -5.26028964000532117673003540403442e-01 2.89186870147435659550438913356629e-01
            -5.81420646903377580372307420475408e-01 1.49283449141560720097032799458248e-01
            -6.00279532245722169392365685780533e-01 7.35130407758394053546990268875389e-17
            -5.81420646903377691394609882991062e-01 -1.49283449141560331518974180653458e-01
            -5.26028964000532117673003540403442e-01 -2.89186870147435770572741375872283e-01
            -4.37584946690331155760844694668776e-01 -4.10919616547035904119411497958936e-01
            -3.21645857854716388235516433269368e-01 -5.06832772182350677070417077629827e-01
            -1.85496576839372484535317653353559e-01 -5.70899760740900763522631677915342e-01
            -3.76918636925220179589857139035303e-02 -5.99095017709651234127932184492238e-01
            1.12481167871107082256720843815856e-01 -5.89646931398353668640766045427881e-01
            2.55586593980596299413576844017371e-01 -5.43149159817577942277466718223877e-01
            3.82632574408545200750353387775249e-01 -4.62523328962585522639017199253431e-01
            4.85636342962233458209198033728171e-01 -3.52835456307059702751871554937679e-01
            5.58125794042070855205395218945341e-01 -2.20977634293724134462166830417118e-01
            5.95546148839159128485221117443871e-01 -7.52349748188246431057635277284135e-02
            5.07124318925776029765017938188976e-01 7.64366924262316616012213899011840e-02
            4.62064097710802867968737928094924e-01 2.22518341719724566107885266319499e-01
            3.75947453679330800824232028389815e-01 3.48828259845761212698533881848562e-01
            2.56426228570223790903526150941616e-01 4.44143256276897491208188739619800e-01
            1.14120407744683100004223774703860e-01 4.99994175297254650480738291662419e-01
            -3.83255121181331689927951344998291e-02 5.11418417654152634987951842049370e-01
            -1.87366042040513824940006770702894e-01 4.77400889279719409241664607179700e-01
            -3.19758276885262204825011167486082e-01 4.00964196853487830907170064165257e-01
            -4.23738585592669692037048889687867e-01 2.88900075934428013368915344472043e-01
            -4.90067861424013817561728956206935e-01 1.51165915451493576560082487958425e-01
            -5.12852457140447470784749839367578e-01 6.28063120071904103547016255583247e-17
            -4.90067861424013928584031418722589e-01 -1.51165915451493215737599484782550e-01
            -4.23738585592669636525897658430040e-01 -2.88900075934428124391217806987697e-01
            -3.19758276885262315847313630001736e-01 -4.00964196853487719884867601649603e-01
            -1.87366042040513713917704308187240e-01 -4.77400889279719409241664607179700e-01
            -3.83255121181335159374903298612480e-02 -5.11418417654152634987951842049370e-01
            1.14120407744682988981921312188206e-01 -4.99994175297254650480738291662419e-01
            2.56426228570223402325467532136827e-01 -4.44143256276897713252793664651108e-01
            3.75947453679330911846534490905469e-01 -3.48828259845761101676231419332908e-01
            4.62064097710802812457586696837097e-01 -2.22518341719724677130187728835153e-01
            5.07124318925775918742715475673322e-01 -7.64366924262320918126434321493434e-02
            4.12841698298062664829188861403964e-01 7.71734882889851397935743193556846e-02
            3.57085139308087218257270478716237e-01 2.21097757640466935358247724252578e-01
            2.53102253577491442815272648658720e-01 3.35161549677635228761118924012408e-01
            1.14936506013252878743990947896236e-01 4.03959917236579535426699294475839e-01
            -3.87520535732413518026362453383626e-02 4.18201259553549586911458391114138e-01
            -1.87206933592127505727731318074802e-01 3.75962204434636571015460049238754e-01
            -3.10378479879967694721187854156597e-01 2.82947370328333724920355507492786e-01
            -3.91631692593489011411378442062414e-01 1.51718925993686193365306280611549e-01
            -4.19992875116136588076187763363123e-01 5.14342930175670751374192587105554e-17
            -3.91631692593489122433680904578068e-01 -1.51718925993685915809550124322413e-01
            -3.10378479879967583698885391640943e-01 -2.82947370328333780431506738750613e-01
            -1.87206933592127949816941168137419e-01 -3.75962204434636348970855124207446e-01
            -3.87520535732413656804240531528194e-02 -4.18201259553549586911458391114138e-01
            1.14936506013252795477264101009496e-01 -4.03959917236579535426699294475839e-01
            2.53102253577491331792970186143066e-01 -3.35161549677635284272270155270235e-01
            3.57085139308087051723816784942755e-01 -2.21097757640467129647277033654973e-01
            4.12841698298062664829188861403964e-01 -7.71734882889850287712718568400305e-02
            3.12666418671381451943602769460995e-01 7.70653507159836936857288947066991e-02
            2.41038310192586563429628654375847e-01 2.13541309037075049959142347688612e-01
            1.14191229675205091487200093069987e-01 3.01097526909521018279036752574029e-01
            -3.88156854072665008503761896463402e-02 3.19675929985554718726348255586345e-01
            -1.82930394742652158157625308376737e-01 2.65020430014485164349480328382924e-01
            -2.85137955192736658460717080743052e-01 1.49651943369506795766810114400869e-01
            -3.22023846393035273472094104363350e-01 -1.03570768224126015031787113326496e-16
            -2.85137955192736824994170774516533e-01 -1.49651943369506462699902726853907e-01
            -1.82930394742652241424352155263477e-01 -2.65020430014485108838329097125097e-01
            -3.88156854072667298338750185848767e-02 -3.19675929985554718726348255586345e-01
            1.14191229675205091487200093069987e-01 -3.01097526909521018279036752574029e-01
            2.41038310192586452407326191860193e-01 -2.13541309037075160981444810204266e-01
            3.12666418671381451943602769460995e-01 -7.70653507159837075635167025211558e-02
            2.05997400910796796269508490695443e-01 7.49769222677315050340496327407891e-02
            1.09608927618539603310310326378385e-01 1.89848231598450073454031894470972e-01
            -3.80667810739717255019698427531694e-02 2.15887443436183407152739732737246e-01
            -1.67930619836825001378599608869990e-01 1.40910521168451957629841331254283e-01
            -2.19217855237079151109469421498943e-01 2.68464444732036828715390880455905e-17
            -1.67930619836825112400902071385644e-01 -1.40910521168451818851963253109716e-01
            -3.80667810739717324408637466603977e-02 -2.15887443436183407152739732737246e-01
            1.09608927618539422899068824790447e-01 -1.89848231598450184476334356986627e-01
            2.05997400910796796269508490695443e-01 -7.49769222677314772784740171118756e-02
            9.04551673507041631427938455090043e-02 6.57195259581285773364811575447675e-02
            -3.45507994699091949830638270668715e-02 1.06336426724783050801192985090893e-01
            -1.11808735761589894686096613440895e-01 1.36926210367143272382149476577926e-17
            -3.45507994699092227386394426957850e-02 -1.06336426724783036923405177276436e-01
            9.04551673507041492650060376945476e-02 -6.57195259581286050920567731736810e-02
            -0.00000000000000000000000000000000e+00 0.00000000000000000000000000000000e+00
            ];
        
    case   27
        
        % DEGREE.             :          27
        % CARDIN.             :         406
        % LEBESGUE CONST.     : 5.90104e+01
        % ABS.DET.VAND.MATRIX : Inf
        % CONDITIONING VAND.  : 1.35813e+03
        % POINTS OUT DISK     : 0.00000e+00
        
        pts=[
            9.98369103926135648130468780436786e-01 5.70888108627679788376063640953362e-02
            9.85353835847692982596868205291685e-01 1.70522192632623775798705878514738e-01
            9.59492973614497368650688713387353e-01 2.81732556841429671035115234190016e-01
            9.21123653114850116097045429341961e-01 3.89270106317391451078435693489155e-01
            8.70746077119777139863288084598025e-01 4.91732924645603752811240383380209e-01
            8.09016994374947451262869435595348e-01 5.87785252292473026081154330313439e-01
            7.36741137876404827977694367291406e-01 6.76174900274019496926314332085894e-01
            6.54860733945285100610078643512679e-01 7.55749574354258268904516171460273e-01
            5.64443218866769180763753865903709e-01 8.25471896962774009942620523361256e-01
            4.66667323225673835729310212627752e-01 8.84432930997814281681712600402534e-01
            3.62807705350640885555435488640796e-01 9.31864029211452171708174319064710e-01
            2.54218334193487105476805254511419e-01 9.67146854701957048305871467164252e-01
            1.42314838273285115821664703616989e-01 9.89821441880932684220795181317953e-01
            2.85560507936964760866693779917114e-02 9.99592192828189229913959934492595e-01
            -8.55750084788397258339642803548486e-02 9.96331730862691444805534501938382e-01
            -1.98590466645745422624713683035225e-01 9.80082561092393445001391683035763e-01
            -3.09016994374947340240566973079694e-01 9.51056516295153642204240895807743e-01
            -4.15415013001886324062184030481149e-01 9.09631995354518441132540829130448e-01
            -5.16397461638961829955007942771772e-01 8.56349030251589038442716628196649e-01
            -6.10647879635437873524494989396771e-01 7.91902245922275316303284853347577e-01
            -6.96937568655293326891353444807464e-01 7.17131804758963653512182645499706e-01
            -7.74141610639082489164763956068782e-01 6.33012453808870390048468834720552e-01
            -8.41253532831181094486794336262392e-01 5.40640817455597777474451959278667e-01
            -8.97398428691358329700733520439826e-01 4.41221101243221336396516107924981e-01
            -9.41844363639524617681786367029417e-01 3.36049393215430369785678976768395e-01
            -9.74011916942333466629122540325625e-01 2.26496767425764439218838219858299e-01
            -9.93481735348550221154084738373058e-01 1.13991409890540504323830361954606e-01
            -1.00000000000000000000000000000000e+00 1.22464679914735320717376402945840e-16
            -9.93481735348550221154084738373058e-01 -1.13991409890540254523649821294384e-01
            -9.74011916942333577651425002841279e-01 -2.26496767425764217174233294826990e-01
            -9.41844363639524728704088829545071e-01 -3.36049393215430147741074051737087e-01
            -8.97398428691358329700733520439826e-01 -4.41221101243221502929969801698462e-01
            -8.41253532831181427553701723809354e-01 -5.40640817455597222362939646700397e-01
            -7.74141610639082600187066418584436e-01 -6.33012453808870168003863909689244e-01
            -6.96937568655293548935958369838772e-01 -7.17131804758963431467577720468398e-01
            -6.10647879635438428636007301975042e-01 -7.91902245922274872214075003284961e-01
            -5.16397461638962385066520255350042e-01 -8.56349030251588705375809240649687e-01
            -4.15415013001886379573335261738976e-01 -9.09631995354518441132540829130448e-01
            -3.09016994374947562285171898111003e-01 -9.51056516295153531181938433292089e-01
            -1.98590466645745866713923533097841e-01 -9.80082561092393333979089220520109e-01
            -8.55750084788404058455668632632296e-02 -9.96331730862691333783232039422728e-01
            2.85560507936962297559357892851040e-02 -9.99592192828189229913959934492595e-01
            1.42314838273284866021484162956767e-01 -9.89821441880932795243097643833607e-01
            2.54218334193486439342990479417494e-01 -9.67146854701957270350476392195560e-01
            3.62807705350641107600040413672104e-01 -9.31864029211452282730476781580364e-01
            4.66667323225673613684705287596444e-01 -8.84432930997814392704015062918188e-01
            5.64443218866768847696846478356747e-01 -8.25471896962774120964922985876910e-01
            6.54860733945285211632381106028333e-01 -7.55749574354257935837608783913311e-01
            7.36741137876404938999996829807060e-01 -6.76174900274019385904011869570240e-01
            8.09016994374947784329776823142311e-01 -5.87785252292472581991944480250822e-01
            8.70746077119776917818683159566717e-01 -4.91732924645604196900450233442825e-01
            9.21123653114849783030138041794999e-01 -3.89270106317392117212250468583079e-01
            9.59492973614497368650688713387353e-01 -2.81732556841429782057417696705670e-01
            9.85353835847692982596868205291685e-01 -1.70522192632624108865613266061700e-01
            9.98369103926135648130468780436786e-01 -5.70888108627685478269064844880631e-02
            9.77091142226830022821104648755863e-01 6.02649188306433186701482895841764e-02
            9.62279436502538998432498829060933e-01 1.79881201753133102005932641986874e-01
            9.32880555414515755252580220258096e-01 2.96770669017845989401394035667181e-01
            8.89340156032485396053743897937238e-01 4.09161395451611009654868666984839e-01
            8.32318266428440534099308933946304e-01 5.15349652206490427275298316089902e-01
            7.62679280323864450252813185215928e-01 6.13725733552429320027954418037552e-01
            6.81478853762028768947800472233212e-01 7.02798358375278597875990271859337e-01
            5.89947902438454185869431967148557e-01 7.81217276478358146896141533943592e-01
            4.89473942273691120519174546643626e-01 8.47793736999069014181884540448664e-01
            3.81580056086322561004209319435176e-01 9.01518508660223871764571867970517e-01
            2.67901805209976751065426014974946e-01 9.41577178687456717298687181028072e-01
            1.50162436050711306512184251005237e-01 9.67362498476714405271081886894535e-01
            3.01467574280757100169125806132797e-02 9.78483588864099473880742152687162e-01
            -9.03259153072568377051965171631309e-02 9.74771865455554498147705544397468e-01
            -2.09429339239699807695416211572592e-01 9.56283594194430319745947599585634e-01
            -3.25358027869782184815505843289429e-01 9.23299038427140006390914095391054e-01
            -4.36354620449070584875528311386006e-01 8.76318210396510477444564912730129e-01
            -5.40736521777759215900971412338549e-01 8.16053291565867033874326352815842e-01
            -6.36921408632756813616992985771503e-01 7.43417836674006848873830222146353e-01
            -7.23451216174815781023710314912023e-01 6.59512925176584663411460951465415e-01
            -7.99014240725228419570669302629540e-01 5.65610470003943488492836877412628e-01
            -8.62465023856516244116221514559584e-01 4.63133936657608935583141374081606e-01
            -9.12841716374575673498270589334425e-01 3.53636764924285029731976237599156e-01
            -9.49380658972005742057831412239466e-01 2.38778820312178008400394446653081e-01
            -9.71527958524776580340187592810253e-01 1.20301232181865946913035259058233e-01
            -9.78947884547382463082954018318560e-01 1.19886539334302462271718391419620e-16
            -9.71527958524776580340187592810253e-01 -1.20301232181865697112854718398012e-01
            -9.49380658972005742057831412239466e-01 -2.38778820312178202689423756055476e-01
            -9.12841716374575784520573051850079e-01 -3.53636764924284863198522543825675e-01
            -8.62465023856516355138523977075238e-01 -4.63133936657608769049687680308125e-01
            -7.99014240725228530592971765145194e-01 -5.65610470003943377470534414896974e-01
            -7.23451216174815892046012777427677e-01 -6.59512925176584441366856026434107e-01
            -6.36921408632756591572388060740195e-01 -7.43417836674006959896132684662007e-01
            -5.40736521777759437945576337369857e-01 -8.16053291565866922852023890300188e-01
            -4.36354620449070418342074617612525e-01 -8.76318210396510588466867375245783e-01
            -3.25358027869782406860110768320737e-01 -9.23299038427139895368611632875400e-01
            -2.09429339239700251784626061635208e-01 -9.56283594194430208723645137069980e-01
            -9.03259153072568654607721327920444e-02 -9.74771865455554498147705544397468e-01
            3.01467574280754706250728958139007e-02 -9.78483588864099473880742152687162e-01
            1.50162436050711473045637944778719e-01 -9.67362498476714405271081886894535e-01
            2.67901805209976751065426014974946e-01 -9.41577178687456717298687181028072e-01
            3.81580056086322949582267938239966e-01 -9.01518508660223760742269405454863e-01
            4.89473942273691342563779471674934e-01 -8.47793736999068903159582077933010e-01
            5.89947902438453852802524579601595e-01 -7.81217276478358368940746458974900e-01
            6.81478853762028990992405397264520e-01 -7.02798358375278375831385346828029e-01
            7.62679280323864339230510722700274e-01 -6.13725733552429431050256880553206e-01
            8.32318266428440201032401546399342e-01 -5.15349652206490871364508166152518e-01
            8.89340156032485507076046360452892e-01 -4.09161395451610954143717435727012e-01
            9.32880555414515644230277757742442e-01 -2.96770669017846211445998960698489e-01
            9.62279436502538998432498829060933e-01 -1.79881201753132824450176485697739e-01
            9.77091142226830022821104648755863e-01 -6.02649188306433880590873286564602e-02
            9.39036341616019010203331163211260e-01 6.28610868757917551352676355236326e-02
            9.22279215853697209581696370150894e-01 1.87461503042869959134719692883664e-01
            8.89063995635265946759773214580491e-01 3.08716664247102701157388082719990e-01
            8.39983407352406286072721286473097e-01 4.24462769264212336217667598248227e-01
            7.75913295265766578268085140734911e-01 5.32634326108092470697386033862131e-01
            6.97996992043382169512710788694676e-01 6.31301010784232174977148588368436e-01
            6.07624915962127754021082637336804e-01 7.18702113967128686233820644702064e-01
            5.06409758860627778886964733828790e-01 7.93277960899912648606857601407683e-01
            3.96157707615189869088112573081162e-01 8.53697743827333876964758019312285e-01
            2.78836212692208817998107406310737e-01 8.98883270291681357733182267111260e-01
            1.56538878947982351697021385916742e-01 9.28028203502733739505003995873267e-01
            3.14481052004546499101245160545659e-02 9.40612451436883545419220808980754e-01
            -9.42038607293947949372636685438920e-02 9.36411447891619452832401293562725e-01
            -2.18174756532797109453980510807014e-01 9.15500159874730545794818681315519e-01
            -3.38252318637216109475929215477663e-01 8.78251749816275517623864743654849e-01
            -4.52293760102207398343665545326076e-01 8.25330916476178955143438997765770e-01
            -5.58264008703136860312099543079967e-01 7.57682033379112440663050165312598e-01
            -6.54272022843239042799723392818123e-01 6.76512296446575067676576509256847e-01
            -7.38604537235711511300451093120500e-01 5.83270181557074773870397166319890e-01
            -8.09756636163346255052886135672452e-01 4.79619596459761654561049226686009e-01
            -8.66458608735155455526921741693513e-01 3.67410188301224571727487955286051e-01
            -9.07698606907300309387665038229898e-01 2.48644336628343176620603571791435e-01
            -9.32740701935405036593351724150125e-01 1.25441420877835357883256506283942e-01
            -9.41138017040435204130233159958152e-01 -3.02693072334896030312933538887253e-16
            -9.32740701935405147615654186665779e-01 -1.25441420877834719505017346818931e-01
            -9.07698606907300309387665038229898e-01 -2.48644336628342982331574262389040e-01
            -8.66458608735155566549224204209168e-01 -3.67410188301224405194034261512570e-01
            -8.09756636163346366075188598188106e-01 -4.79619596459761432516444301654701e-01
            -7.38604537235711622322753555636154e-01 -5.83270181557074551825792241288582e-01
            -6.54272022843239153822025855333777e-01 -6.76512296446574956654274046741193e-01
            -5.58264008703136638267494618048659e-01 -7.57682033379112551685352627828252e-01
            -4.52293760102207231810211851552594e-01 -8.25330916476178955143438997765770e-01
            -3.38252318637216498053987834282452e-01 -8.78251749816275406601562281139195e-01
            -2.18174756532797720076644054643111e-01 -9.15500159874730434772516218799865e-01
            -9.42038607293952251486857107920514e-02 -9.36411447891619452832401293562725e-01
            3.14481052004542127598085698991781e-02 -9.40612451436883545419220808980754e-01
            1.56538878947982101896840845256520e-01 -9.28028203502733739505003995873267e-01
            2.78836212692208373908897556248121e-01 -8.98883270291681468755484729626914e-01
            3.96157707615189702554658879307681e-01 -8.53697743827333987987060481827939e-01
            5.06409758860627556842359808797482e-01 -7.93277960899912759629160063923337e-01
            6.07624915962127642998780174821150e-01 -7.18702113967128797256123107217718e-01
            6.97996992043382058490408326179022e-01 -6.31301010784232174977148588368436e-01
            7.75913295265766578268085140734911e-01 -5.32634326108092470697386033862131e-01
            8.39983407352405841983511436410481e-01 -4.24462769264213113373784835857805e-01
            8.89063995635265946759773214580491e-01 -3.08716664247102645646236851462163e-01
            9.22279215853697209581696370150894e-01 -1.87461503042869848112417230368010e-01
            9.39036341616019010203331163211260e-01 -6.28610868757924351468702184320136e-02
            8.90209112327640883499668689182727e-01 6.51549090837257871555721067124978e-02
            8.71235850635123876273269161174539e-01 1.94076063482767485757207737151475e-01
            8.33693709382633207916057926922804e-01 3.18860823533874404578369876617217e-01
            7.78382834132168910379334647586802e-01 4.36849618721645849284129781153752e-01
            7.06482080161706660348386321857106e-01 5.45527722722927155274419419583865e-01
            6.19523887211616663961422091233544e-01 6.42578850432445336515741018956760e-01
            5.19361618192144325334425047913101e-01 7.25934525558408871859228383982554e-01
            4.08130057970694570812497659062501e-01 7.93818166603481367715744454471860e-01
            2.88199914138689394782488761848072e-01 8.44782951614985511135103024571436e-01
            1.62127289495162474342038194663473e-01 8.77742654682924006159794316772604e-01
            3.25992031533755763361703827740712e-02 8.91994796959399316449434991227463e-01
            -9.76236786065115963451077618628915e-02 8.87235618775648271494560503924731e-01
            -2.25765881146272467949742690507264e-01 8.63566553752009413713608410034794e-01
            -3.49096275892884500002821823727572e-01 8.21492066916409191534853562188800e-01
            -4.64986289602416169586263094970491e-01 7.61908902908118634833556370722363e-01
            -5.70965927835121456190847766265506e-01 6.86086973422651347220835305051878e-01
            -6.64776418598642782065155643067556e-01 5.95642291248730137986910904146498e-01
            -7.44418354151459515932742760924157e-01 4.92502527761337738354541215812787e-01
            -8.08194304907627669720682206389029e-01 3.78865927953084213886114639535663e-01
            -8.54744997201410061649085037061013e-01 2.57154458658675366677925921976566e-01
            -8.83078283845559863785013021697523e-01 1.29962188536726974685819868682302e-01
            -8.92590290026098687192757097363938e-01 1.09310784163046943517663694451873e-16
            -8.83078283845559863785013021697523e-01 -1.29962188536726752641214943650994e-01
            -8.54744997201410172671387499576667e-01 -2.57154458658675200144472228203085e-01
            -8.08194304907627780742984668904683e-01 -3.78865927953083991841509714504355e-01
            -7.44418354151459737977347685955465e-01 -4.92502527761337238754180134492344e-01
            -6.64776418598642893087458105583210e-01 -5.95642291248729915942305979115190e-01
            -5.70965927835121234146242841234198e-01 -6.86086973422651458243137767567532e-01
            -4.64986289602416780208926638806588e-01 -7.61908902908118301766648983175401e-01
            -3.49096275892884500002821823727572e-01 -8.21492066916409191534853562188800e-01
            -2.25765881146272523460893921765091e-01 -8.63566553752009413713608410034794e-01
            -9.76236786065119988009541884821374e-02 -8.87235618775648271494560503924731e-01
            3.25992031533751530636422444331401e-02 -8.91994796959399316449434991227463e-01
            1.62127289495161863719374650827376e-01 -8.77742654682924006159794316772604e-01
            2.88199914138689339271337530590245e-01 -8.44782951614985511135103024571436e-01
            4.08130057970694348767892734031193e-01 -7.93818166603481478738046916987514e-01
            5.19361618192144103289820122881792e-01 -7.25934525558408982881530846498208e-01
            6.19523887211616330894514703686582e-01 -6.42578850432445780604950869019376e-01
            7.06482080161706660348386321857106e-01 -5.45527722722927044252116957068210e-01
            7.78382834132168910379334647586802e-01 -4.36849618721645904795281012411579e-01
            8.33693709382633096893755464407150e-01 -3.18860823533874571111823570390698e-01
            8.71235850635123876273269161174539e-01 -1.94076063482767069423573502717772e-01
            8.90209112327640883499668689182727e-01 -6.51549090837263006337209958473977e-02
            8.32712132528664827901820899569429e-01 6.72234730425945309351121181862254e-02
            8.11145325699725416868091087962966e-01 1.99929366486845672135075346886879e-01
            7.68570281010193867565760683646658e-01 3.27457194357150649377530271522119e-01
            7.06089669753887316794305206713034e-01 4.46504052898953507355628289587912e-01
            6.25321706942789323768749909504550e-01 5.53986691008458653762147605448263e-01
            5.28358240388249189578573350445367e-01 6.47121364816661048813273282576120e-01
            4.17710572941464075569228953099810e-01 7.23495935193321559886214799917070e-01
            2.96244421068761643045519349470851e-01 7.81132340883399445274903882818762e-01
            1.67105694300410806407697350550734e-01 8.18537829254532778300301743001910e-01
            3.36390178262610459181125577288185e-02 8.34743617806107840451090851274785e-01
            -1.00698891539826168584070842371148e-01 8.29329985127147950585424496239284e-01
            -2.32428752509724945163327447517077e-01 8.02437141460387581837210291269002e-01
            -3.58138830878827252313101325853495e-01 7.54761597330635192193426519224886e-01
            -4.74573301649837575588719573715935e-01 6.87538124288040730647253440110944e-01
            -5.78716573190000249660158715414582e-01 6.02507774973541909702134944382124e-01
            -6.67871389470367615714962994388770e-01 5.01872790769997467741347918490646e-01
            -7.39728687580148203117857974575600e-01 3.88239564907154499628916255460354e-01
            -7.92427401243199991398569181910716e-01 2.64551138246074180049305368811474e-01
            -8.24602661457010555068336543627083e-01 1.34010976066738174417025675211335e-01
            -8.35421145882928373183062831230927e-01 1.02309583224554227563401809791175e-16
            -8.24602661457010666090639006142737e-01 -1.34010976066737952372420750180027e-01
            -7.92427401243200102420871644426370e-01 -2.64551138246074013515851675037993e-01
            -7.39728687580148203117857974575600e-01 -3.88239564907154277584311330429045e-01
            -6.67871389470367726737265456904424e-01 -5.01872790769997356719045455974992e-01
            -5.78716573190000471704763640445890e-01 -6.02507774973541687657530019350816e-01
            -4.74573301649837797633324498747243e-01 -6.87538124288040619624950977595290e-01
            -3.58138830878827085779647632080014e-01 -7.54761597330635303215728981740540e-01
            -2.32428752509724945163327447517077e-01 -8.02437141460387581837210291269002e-01
            -1.00698891539826571039917268990393e-01 -8.29329985127147950585424496239284e-01
            3.36390178262606573400539389240294e-02 -8.34743617806107951473393313790439e-01
            1.67105694300410584363092425519426e-01 -8.18537829254532889322604205517564e-01
            2.96244421068761421000914424439543e-01 -7.81132340883399556297206345334416e-01
            4.17710572941463631480019103037193e-01 -7.23495935193321781930819724948378e-01
            5.28358240388248634467061037867097e-01 -6.47121364816661492902483132638736e-01
            6.25321706942788990701842521957587e-01 -5.53986691008458875806752530479571e-01
            7.06089669753887094749700281681726e-01 -4.46504052898953784911384445877047e-01
            7.68570281010193756543458221131004e-01 -3.27457194357150815910983965295600e-01
            8.11145325699725416868091087962966e-01 -1.99929366486845727646226578144706e-01
            8.32712132528664827901820899569429e-01 -6.72234730425944337905974634850281e-02
            7.67742754297485840986325911217136e-01 6.90980985410594855666843727703963e-02
            7.43066870473522156359535983938258e-01 2.05073425881963949946040770555555e-01
            6.94508206035082120699541974317981e-01 3.34457524580045240103487458327436e-01
            6.23627476411419134905145256198011e-01 4.53091883245555993031672414872446e-01
            5.32702846573496313631324028392555e-01 5.57163495978311273937322312121978e-01
            4.24656708937339311127345808927203e-01 6.43327415514671985263817077793647e-01
            3.02961755267232124566589845926501e-01 7.08814262584830712121686246973695e-01
            1.71529361505073585369984812132316e-01 7.51519236041194971242873634764692e-01
            3.45838729293132390862908209783200e-02 7.70069762899108112286228333687177e-01
            -1.03473169778100657079100699320406e-01 7.63869613961932647505648219521390e-01
            -2.38204499670838731884003891536850e-01 7.33118067118008642779614092432894e-01
            -3.65279740948840858649759866239037e-01 6.78803502385356916093428480962757e-01
            -4.80614590799575303048385421789135e-01 6.02671634564657776600427041557850e-01
            -5.80502092251008794399069756764220e-01 5.07169404529177803020445480797207e-01
            -6.61731778818782534479225887480425e-01 3.95366332531754072210361528050271e-01
            -7.21692861540599306380272537353449e-01 2.70855861298257727387550630737678e-01
            -7.58458141881636738190763935563155e-01 1.37639859821690441199493193380476e-01
            -7.70845953481160583997677804291015e-01 9.44014029566392811061321695895720e-17
            -7.58458141881636738190763935563155e-01 -1.37639859821690246910463883978082e-01
            -7.21692861540599306380272537353449e-01 -2.70855861298257560854096936964197e-01
            -6.61731778818782756523830812511733e-01 -3.95366332531753628121151677987655e-01
            -5.80502092251009016443674681795528e-01 -5.07169404529177691998143018281553e-01
            -4.80614590799575469581839115562616e-01 -6.02671634564657665578124579042196e-01
            -3.65279740948841025183213560012518e-01 -6.78803502385356805071126018447103e-01
            -2.38204499670838898417457585310331e-01 -7.33118067118008531757311629917240e-01
            -1.03473169778100851368130008722801e-01 -7.63869613961932536483345757005736e-01
            3.45838729293130517361554154831538e-02 -7.70069762899108223308530796202831e-01
            1.71529361505073391080955502729921e-01 -7.51519236041194971242873634764692e-01
            3.02961755267231958033136152153020e-01 -7.08814262584830712121686246973695e-01
            4.24656708937339033571589652638067e-01 -6.43327415514672207308422002824955e-01
            5.32702846573496202609021565876901e-01 -5.57163495978311384959624774637632e-01
            6.23627476411419023882842793682357e-01 -4.53091883245556159565126108645927e-01
            6.94508206035082009677239511802327e-01 -3.34457524580045406636941152100917e-01
            7.43066870473522156359535983938258e-01 -2.05073425881964116479494464329036e-01
            7.67742754297485729964023448701482e-01 -6.90980985410596659779258743583341e-02
            6.96091245403394509594363626092672e-01 7.07855610699765908089275967540743e-02
            6.67593188029330986132947600708576e-01 2.09458714022774661334125312350807e-01
            6.11763787098477673787044750497444e-01 3.39556602613126423673151066395803e-01
            5.30888704844619918610248987533851e-01 4.55753003996290095845012046993361e-01
            4.28278976637649022585208058444550e-01 5.53290823847141233216007094597444e-01
            3.08135456806489849146402093538200e-01 6.28176852360779136574819858651608e-01
            1.75376835169293865401840548656764e-01 6.77345246731120509409151964064222e-01
            3.54382652943641338061375734014291e-02 6.98783047115602573562398447393207e-01
            -1.05951151325536688241335525617615e-01 6.91612587447650084548911308957031e-01
            -2.43002915361437921148990426445380e-01 6.56127427188562317716957750235451e-01
            -3.70106111490811906516995577476337e-01 5.93780332968675272908853912667837e-01
            -4.82057119930130117957389757066267e-01 5.07123802150824309897814146097517e-01
            -5.74272653240202601843122920399765e-01 3.99705563288401455324105882027652e-01
            -6.42977396652449240121995899244212e-01 2.75923331701542040583774451079080e-01
            -6.85358569899108371892282320914092e-01 1.40844766495206635825709895470936e-01
            -6.99681082767885209605651652964298e-01 8.56862198435644902495911275809078e-17
            -6.85358569899108371892282320914092e-01 -1.40844766495206469292256201697455e-01
            -6.42977396652449351144298361759866e-01 -2.75923331701541874050320757305599e-01
            -5.74272653240202712865425382915419e-01 -3.99705563288401288790652188254171e-01
            -4.82057119930130451024297144613229e-01 -5.07123802150823976830906758550555e-01
            -3.70106111490812073050449271249818e-01 -5.93780332968675272908853912667837e-01
            -2.43002915361438226460322198363428e-01 -6.56127427188562095672352825204143e-01
            -1.05951151325536868652577027205552e-01 -6.91612587447650084548911308957031e-01
            3.54382652943642725840156515459967e-02 -6.98783047115602573562398447393207e-01
            1.75376835169293532334933161109802e-01 -6.77345246731120620431454426579876e-01
            3.08135456806489405057192243475583e-01 -6.28176852360779358619424783682916e-01
            4.28278976637648745029451902155415e-01 -5.53290823847141455260612019628752e-01
            5.30888704844619918610248987533851e-01 -4.55753003996289818289255890704226e-01
            6.11763787098477562764742287981790e-01 -3.39556602613126812251209685200593e-01
            6.67593188029330875110645138192922e-01 -2.09458714022775077667759546784509e-01
            6.96091245403394509594363626092672e-01 -7.07855610699764381532617107950500e-02
            6.18314484941876352230849533953005e-01 7.22705983344565372483714327245252e-02
            5.84980991013920648136092950153397e-01 2.12915668340611902165093738403812e-01
            5.20111020443718707895186526002362e-01 3.42082399555358240839098016294884e-01
            4.27201730135676083222051602206193e-01 4.52807380065346487540978159813676e-01
            3.11261883978972864195355896299588e-01 5.39121397511190036944128678442212e-01
            1.78541829089827464027706582783139e-01 5.96371240870832930447420494601829e-01
            3.61965379806194059719715028222708e-02 6.21470556270186991199011572462041e-01
            -1.08100117860248090551067434716970e-01 6.13066233119357706371488347940613e-01
            -2.46569068366597421437802495347569e-01 5.71611350654783856306551115267212e-01
            -3.71745416575278708748442113574129e-01 4.99340752320327485591633376316167e-01
            -4.76880873153672502073874284178601e-01 4.00150564778745609917365300134406e-01
            -5.56307558424338099989370221010176e-01 2.79388156714828861382216018682811e-01
            -6.05743559225503491738606953731505e-01 1.43563860805486498417593566045980e-01
            -6.22523767957945617368409330083523e-01 7.62371739822847757972292304540150e-17
            -6.05743559225503491738606953731505e-01 -1.43563860805486359639715487901412e-01
            -5.56307558424338211011672683525831e-01 -2.79388156714828694848762324909330e-01
            -4.76880873153672391051571821662947e-01 -4.00150564778745665428516531392233e-01
            -3.71745416575278875281895807347610e-01 -4.99340752320327319058179682542686e-01
            -2.46569068366597476948953726605396e-01 -5.71611350654783856306551115267212e-01
            -1.08100117860248257084521128490451e-01 -6.13066233119357595349185885424959e-01
            3.61965379806189757605494605741114e-02 -6.21470556270187102221314034977695e-01
            1.78541829089827464027706582783139e-01 -5.96371240870832930447420494601829e-01
            3.11261883978972864195355896299588e-01 -5.39121397511190036944128678442212e-01
            4.27201730135676138733202833464020e-01 -4.52807380065346432029826928555849e-01
            5.20111020443718374828279138455400e-01 -3.42082399555358684928307866357500e-01
            5.84980991013920426091488025122089e-01 -2.12915668340612346254303588466428e-01
            6.18314484941876352230849533953005e-01 -7.22705983344564123482811623944144e-02
            5.34807371240558881986260075791506e-01 7.35075812321341615085401599571924e-02
            4.95143155096573972517859374420368e-01 2.15071022671223410771546014075284e-01
            4.18756436268288401159054501476930e-01 3.40683630243248825042456928713364e-01
            3.11312468245209750250523939030245e-01 4.41029291484036245485356175777270e-01
            1.80779878612162298034959917458764e-01 5.08665827750211407831670840096194e-01
            3.68396723953657370675962567929673e-02 5.38576946563476544049819949577795e-01
            -1.09832763792708176797674468616606e-01 5.28544277075715718261506026465213e-01
            -2.48359406341737809498226852156222e-01 4.79311896486427024832721599523211e-01
            -3.68466367891083945718122549806139e-01 3.94531145240763159165453544119373e-01
            -4.61245864555419549102310838861740e-01 2.80489823812485883358647242857842e-01
            -5.19816865505106417977287946996512e-01 1.45645855307598520722578427921690e-01
            -5.39835427544206103434021315479185e-01 6.61107728408354890985352077327709e-17
            -5.19816865505106417977287946996512e-01 -1.45645855307598631744880890437344e-01
            -4.61245864555419771146915763893048e-01 -2.80489823812485494780588624053053e-01
            -3.68466367891083890206971318548312e-01 -3.94531145240763214676604775377200e-01
            -2.48359406341738142565134239703184e-01 -4.79311896486426913810419137007557e-01
            -1.09832763792708079653159813915408e-01 -5.28544277075715718261506026465213e-01
            3.68396723953656052286120825556281e-02 -5.38576946563476544049819949577795e-01
            1.80779878612162187012657454943110e-01 -5.08665827750211407831670840096194e-01
            3.11312468245209694739372707772418e-01 -4.41029291484036412018809869550751e-01
            4.18756436268288290136752038961276e-01 -3.40683630243248991575910622486845e-01
            4.95143155096573861495556911904714e-01 -2.15071022671223660571726554735505e-01
            5.34807371240558881986260075791506e-01 -7.35075812321340366084498896270816e-02
            4.45821884322524786270491858886089e-01 7.43945146014009656143528559368860e-02
            3.97510165516894886650334228761494e-01 2.15121743797310277512835341440223e-01
            3.06122052271779743204405122014578e-01 3.32537194095004262628378910449101e-01
            1.81560864689969542196124052679806e-01 4.13917079566300749604579323204234e-01
            3.73247402119185542335166871907859e-02 4.50442626881357166546138159901602e-01
            -1.10956099021110324298611260473990e-01 4.38155726236326092948303312368807e-01
            -2.47213123263936906948146088325302e-01 3.78387853967003418009795723264688e-01
            -3.56680769694280974668743056099629e-01 2.77615786427861555019092065776931e-01
            -4.27496520255871648164003318015602e-01 1.46759740776501307335522028552077e-01
            -4.51986389555774970006041257875040e-01 5.53523685227648515179375327900261e-17
            -4.27496520255871648164003318015602e-01 -1.46759740776501390602248875438818e-01
            -3.56680769694281196713347981130937e-01 -2.77615786427861332974487140745623e-01
            -2.47213123263936851436994857067475e-01 -3.78387853967003473520946954522515e-01
            -1.10956099021110421443125915175187e-01 -4.38155726236326037437152081110980e-01
            3.73247402119185403557288793763291e-02 -4.50442626881357166546138159901602e-01
            1.81560864689969153618065433875017e-01 -4.13917079566300860626881785719888e-01
            3.06122052271779798715556353272405e-01 -3.32537194095004262628378910449101e-01
            3.97510165516894720116880534988013e-01 -2.15121743797310555068591497729358e-01
            4.45821884322524841781643090143916e-01 -7.43945146014008823476260090501455e-02
            3.51431185319822814161483393036178e-01 7.46990044152018722867225619665987e-02
            2.90665540725935589438932993289200e-01 2.11180876763066432966198249232548e-01
            1.79641183526995013020055580454937e-01 3.11147657000560518003595689151553e-01
            3.75552337073185790727869459715293e-02 3.57314180654933755132418582434184e-01
            -1.11024357198940590296665220648720e-01 3.41697836376644359379639581675292e-01
            -2.40406828120882071209152286428434e-01 2.66998831961442528726280443152064e-01
            -3.28220774433254203206189458796871e-01 1.46133303891867294410644717572723e-01
            -3.59282367053989970528959929652046e-01 2.03552822578341908551126320770238e-16
            -3.28220774433254147695038227539044e-01 -1.46133303891867349921795948830550e-01
            -2.40406828120882265498181595830829e-01 -2.66998831961442417703977980636409e-01
            -1.11024357198940659685604259721003e-01 -3.41697836376644359379639581675292e-01
            3.75552337073184056004393482908199e-02 -3.57314180654933810643569813692011e-01
            1.79641183526995013020055580454937e-01 -3.11147657000560518003595689151553e-01
            2.90665540725935589438932993289200e-01 -2.11180876763066516232925096119288e-01
            3.51431185319822814161483393036178e-01 -7.46990044152017612644200994509447e-02
            2.51369190393970209917995362047805e-01 7.38086538081380583165014286350925e-02
            1.71561248533712323860456194779545e-01 1.97992235347357575792059947161761e-01
            3.72838224578573088074939789748896e-02 2.59314681110076383774298847129103e-01
            -1.08830953813466288493394529268699e-01 2.38306547850328287463383958311169e-01
            -2.20392671211788571117295987278339e-01 1.41637769441706834472327614093956e-01
            -2.61981272720569924317146615067031e-01 1.48426509105371252662710174465079e-16
            -2.20392671211788598872871602907253e-01 -1.41637769441706751205600767207216e-01
            -1.08830953813466496660211646485550e-01 -2.38306547850328176441081495795515e-01
            3.72838224578572463574488438098342e-02 -2.59314681110076383774298847129103e-01
            1.71561248533712185082578116634977e-01 -1.97992235347357686814362409677415e-01
            2.51369190393970209917995362047805e-01 -7.38086538081380860720770442640060e-02
            1.44429347728415563567594404048577e-01 6.95535080769317248794436636671890e-02
            3.56711030671363338306889545492595e-02 1.56285314015863679992790480355325e-01
            -9.99482097615929654388366998318816e-02 1.25331090861429905736201817489928e-01
            -1.60304482067917808407742086274084e-01 1.96316370853449831957727401697317e-17
            -9.99482097615930070722001232752518e-02 -1.25331090861429850225050586232101e-01
            3.56711030671361534194474529613217e-02 -1.56285314015863735503941711613152e-01
            1.44429347728415591323170019677491e-01 -6.95535080769316277349290089659917e-02
            2.72223502435993205961217711319478e-02 4.71504937233490142856062732334976e-02
            -5.44447004871986273144557344494388e-02 6.66755281821841407091027654828808e-18
            2.72223502435993205961217711319478e-02 -4.71504937233490142856062732334976e-02
            ];
        
    case   28
        
        % DEGREE.             :          28
        % CARDIN.             :         435
        % LEBESGUE CONST.     : 6.91126e+01
        % ABS.DET.VAND.MATRIX : Inf
        % CONDITIONING VAND.  : 2.13004e+03
        % POINTS OUT DISK     : 0.00000e+00
        
        pts=[
            9.98481516433316174108369978057453e-01 5.50877603558654407867045676994167e-02
            9.86361303402722322530848941823933e-01 1.64594590280733893417064450659382e-01
            9.62268000309250415291728586453246e-01 2.72103464845334985788838366715936e-01
            9.26494067214801764187370736181038e-01 3.76309371947835424876416254846845e-01
            8.79473751206489073872774042683886e-01 4.75947393037073562815919558488531e-01
            8.21777815225245178432089687703410e-01 5.69808057510266086076455849251943e-01
            7.54106609776896141816848739836132e-01 6.56752024047734472844695119420066e-01
            6.77281571625741207753890193998814e-01 7.35723910673131475945751844847109e-01
            5.92235252664980005299355525494320e-01 8.05765105660978142587680395081406e-01
            5.00000000000000111022302462515654e-01 8.66025403784438596588302061718423e-01
            4.01695424652969368395361016155221e-01 9.15773326655057506862078753329115e-01
            2.98514811001694635450576242874376e-01 9.54405001879507386419732029025909e-01
            1.91710631923738494819531297252979e-01 9.81451493252417872525938946637325e-01
            8.25793454723323938626577955801622e-02 9.96584493006669847048328847449739e-01
            -2.75543423681619374654427900850351e-02 9.99620307024951415542091126553714e-01
            -1.37353557818408134050258695424418e-01 9.90522084637503241744127535639564e-01
            -2.45485487140799124583523393994255e-01 9.69400265939330374465043860254809e-01
            -3.50637555192754135635624379574438e-01 9.36511241197054866702842446102295e-01
            -4.51533358310889143538702228397597e-01 8.92254238618394146520529375266051e-01
            -5.46948158122426697502760362112895e-01 8.37166478262528657161567480216036e-01
            -6.35723748209967798317165943444706e-01 7.71916650916321001041353611071827e-01
            -7.16782513168451096419175883056596e-01 6.97296801093995499698507956054527e-01
            -7.89140509396393463603658346983138e-01 6.14212712689667927890013743308373e-01
            -8.51919408838327174571247724088607e-01 5.23672913987877630681566643033875e-01
            -9.04357160697577433516869405139005e-01 4.26776435496403816483024229455623e-01
            -9.45817241700634636636380037089111e-01 3.24699469204683621725848752248567e-01
            -9.75796382627435621159861511841882e-01 2.18681091206375938229555799807713e-01
            -9.93930677317949484717019004165195e-01 1.10008220994079433663337397319992e-01
            -1.00000000000000000000000000000000e+00 1.22464679914735320717376402945840e-16
            -9.93930677317949484717019004165195e-01 -1.10008220994079183863156856659771e-01
            -9.75796382627435621159861511841882e-01 -2.18681091206375716184950874776405e-01
            -9.45817241700634747658682499604765e-01 -3.24699469204683399681243827217259e-01
            -9.04357160697577655561474330170313e-01 -4.26776435496403205860360685619526e-01
            -8.51919408838327063548945261572953e-01 -5.23672913987877852726171568065183e-01
            -7.89140509396393463603658346983138e-01 -6.14212712689667705845408818277065e-01
            -7.16782513168451318463780808087904e-01 -6.97296801093995388676205493538873e-01
            -6.35723748209968020361770868476015e-01 -7.71916650916320890019051148556173e-01
            -5.46948158122426919547365287144203e-01 -8.37166478262528546139265017700382e-01
            -4.51533358310889365583307153428905e-01 -8.92254238618394035498226912750397e-01
            -3.50637555192754357680229304605746e-01 -9.36511241197054755680539983586641e-01
            -2.45485487140799124583523393994255e-01 -9.69400265939330374465043860254809e-01
            -1.37353557818408161805834311053331e-01 -9.90522084637503241744127535639564e-01
            -2.75543423681619617515714537603344e-02 -9.99620307024951415542091126553714e-01
            8.25793454723314918064502876404731e-02 -9.96584493006669958070631309965393e-01
            1.91710631923738467063955681624066e-01 -9.81451493252417872525938946637325e-01
            2.98514811001694635450576242874376e-01 -9.54405001879507386419732029025909e-01
            4.01695424652968702261546241061296e-01 -9.15773326655057728906683678360423e-01
            5.00000000000000111022302462515654e-01 -8.66025403784438596588302061718423e-01
            5.92235252664979339165540750400396e-01 -8.05765105660978586676890245144023e-01
            6.77281571625741096731587731483160e-01 -7.35723910673131475945751844847109e-01
            7.54106609776896363861453664867440e-01 -6.56752024047734250800090194388758e-01
            8.21777815225244734342879837640794e-01 -5.69808057510266752210270624345867e-01
            8.79473751206489184895076505199540e-01 -4.75947393037073396282465864715050e-01
            9.26494067214801542142765811149729e-01 -3.76309371947836146521382261198596e-01
            9.62268000309250193247123661421938e-01 -2.72103464845335707433804373067687e-01
            9.86361303402722433553151404339587e-01 -1.64594590280733726883610756885901e-01
            9.98481516433316174108369978057453e-01 -5.50877603558661346760949584222544e-02
            9.78427225590903892893379634188022e-01 5.80646202404550282327733157217153e-02
            9.64692252082536838564408299134811e-01 1.73378760732406378419767634113668e-01
            9.37415113986426851155897566059139e-01 2.86259043474605401335963961173547e-01
            8.96978722529219396619737381115556e-01 3.95120876733982939743583528979798e-01
            8.43950716009310375476104582048720e-01 4.98436078999658860322341524806689e-01
            7.79075491399415342996803701680619e-01 5.94754331301539318488380558846984e-01
            7.03263754644811167615614522219403e-01 6.82723536509519002279944288602564e-01
            6.17579736348155994285491487971740e-01 7.61108799813353775753910213097697e-01
            5.23226252304650363278426539181964e-01 8.28809763938873955702035800641170e-01
            4.21527818604877480002102174694301e-01 8.84876055752100931783843407174572e-01
            3.13912058332265764271085117798066e-01 9.28520627414804344823551218723878e-01
            2.01889660864387698868682718966738e-01 9.59130804810920500891313622560119e-01
            8.70331751055676700046248583930719e-02 9.76276888148144839085773583065020e-01
            -2.90450656526616453334543876962925e-02 9.79718184001100556024255183729110e-01
            -1.44715577356696906141664271672198e-01 9.69406384119425812428971767076291e-01
            -2.58354599575101706587787475655205e-01 9.45486243569715112400331236131024e-01
            -3.68366889535738928351804588601226e-01 9.08293548691691654539681621827185e-01
            -4.73208115837474463383216516376706e-01 8.58350403394050442962281977088423e-01
            -5.71406537477834430838186108303489e-01 7.96357899960045578779954666970298e-01
            -6.61583663870583094102073573594680e-01 7.23186277248647035875706023944076e-01
            -7.42473605831865168802607968245866e-01 6.39862704448547869873209492652677e-01
            -8.12940845889484231534538594132755e-01 5.47556861874336830986464974557748e-01
            -8.71996178459125692583597810880747e-01 4.47564521218854427520028593789903e-01
            -9.18810596122397793550362621317618e-01 3.41289355758988721678548472482362e-01
            -9.52726927073777041243829444283620e-01 2.30223235859761871102691088708525e-01
            -9.73269060372220717880509255337529e-01 1.15925286384619977142484970045189e-01
            -9.80148629495130041533457188052125e-01 1.20033588179987593592571709684951e-16
            -9.73269060372220717880509255337529e-01 -1.15925286384620171431514279447583e-01
            -9.52726927073777263288434369314928e-01 -2.30223235859761232724451929243514e-01
            -9.18810596122397904572665083833272e-01 -3.41289355758988499633943547451054e-01
            -8.71996178459125803605900273396401e-01 -4.47564521218854205475423668758594e-01
            -8.12940845889484342556841056648409e-01 -5.47556861874336719964162512042094e-01
            -7.42473605831865612891817818308482e-01 -6.39862704448547314761697180074407e-01
            -6.61583663870583538191283423657296e-01 -7.23186277248646591786496173881460e-01
            -5.71406537477834652882791033334797e-01 -7.96357899960045467757652204454644e-01
            -4.73208115837474296849762822603225e-01 -8.58350403394050553984584439604077e-01
            -3.68366889535739150396409513632534e-01 -9.08293548691691543517379159311531e-01
            -2.58354599575101762098938706913032e-01 -9.45486243569715112400331236131024e-01
            -1.44715577356697377986449737363728e-01 -9.69406384119425701406669304560637e-01
            -2.90450656526618812558471205420574e-02 -9.79718184001100556024255183729110e-01
            8.70331751055669899930222754846909e-02 -9.76276888148144950108076045580674e-01
            2.01889660864388115202316953400441e-01 -9.59130804810920389869011160044465e-01
            3.13912058332265986315690042829374e-01 -9.28520627414804344823551218723878e-01
            4.21527818604877035912892324631684e-01 -8.84876055752101042806145869690226e-01
            5.23226252304650363278426539181964e-01 -8.28809763938873955702035800641170e-01
            6.17579736348155439173979175393470e-01 -7.61108799813354219843120063160313e-01
            7.03263754644810945571009597188095e-01 -6.82723536509519224324549213633873e-01
            7.79075491399415342996803701680619e-01 -5.94754331301539318488380558846984e-01
            8.43950716009310042409197194501758e-01 -4.98436078999659193389248912353651e-01
            8.96978722529219396619737381115556e-01 -3.95120876733983050765885991495452e-01
            9.37415113986426962178200028574793e-01 -2.86259043474605179291359036142239e-01
            9.64692252082536727542105836619157e-01 -1.73378760732406683731099406031717e-01
            9.78427225590903892893379634188022e-01 -5.80646202404550004771977000928018e-02
            9.42485144711574296394474004046060e-01 6.05095539183792205384371243326314e-02
            9.27009564691818499504449846426724e-01 1.80535096552674828584983401924546e-01
            8.96312513248385678288343569874996e-01 2.97596257892737636741031792553258e-01
            8.50898035117311324349032020109007e-01 4.09770896905694348433257800934371e-01
            7.91511834773956590716181835887255e-01 5.15217109120187477522279095865088e-01
            7.19129031986139422016890421218704e-01 6.12203470646872749405531521915691e-01
            6.34938150374504850503853958798572e-01 6.99137468110815119004541884351056e-01
            5.40321601887533642383232290740125e-01 7.74591647677076333700085797318025e-01
            4.36832987635565994644082365994109e-01 8.37327053803222032257735918392427e-01
            3.26171587803522455839555505008320e-01 8.86313572855074505163486264791572e-01
            2.10154459517244956989756587972806e-01 9.20746847544108071303980977972969e-01
            9.06866008157281577872765865322435e-02 9.40061484451887974245209989021532e-01
            -3.02703293640167216127512261891752e-02 9.43940337774370363810305661900202e-01
            -1.50730221572472650182206166391552e-01 9.32319716847236801271492367959581e-01
            -2.68715127709870493788457679329440e-01 9.05390431944841367339904536493123e-01
            -3.82287738879302951833238921608427e-01 8.63594661180781097975511784170521e-01
            -4.89583195945252513947565375929116e-01 8.07618689955495572263544090674259e-01
            -5.88839710469038712936651336349314e-01 7.38381642168964735795100295945304e-01
            -6.78427493226275935001012840075418e-01 6.57020388231681740087708476494299e-01
            -7.56875515300877932389767011045478e-01 5.64870877683943617419970451010158e-01
            -8.22895662339192757173123027314432e-01 4.63446202941333484925934271814185e-01
            -8.75403885352076471804139146115631e-01 3.54411754359088504440222777702729e-01
            -9.13538000769326008487780654832022e-01 2.39557874568508688550849683451816e-01
            -9.36671847470064156127023125009146e-01 1.20770461100449283398106103959435e-01
            -9.44425568331034970270820849691518e-01 1.15658774928952192757312889886448e-16
            -9.36671847470064267149325587524800e-01 -1.20770461100449061353501178928127e-01
            -9.13538000769326008487780654832022e-01 -2.39557874568508466506244758420507e-01
            -8.75403885352076582826441608631285e-01 -3.54411754359088282395617852671421e-01
            -8.22895662339193090240030414861394e-01 -4.63446202941332874303270727978088e-01
            -7.56875515300878154434371936076786e-01 -5.64870877683943506397667988494504e-01
            -6.78427493226276046023315302591072e-01 -6.57020388231681629065406013978645e-01
            -5.88839710469038934981256261380622e-01 -7.38381642168964513750495370913995e-01
            -4.89583195945253013547926457249559e-01 -8.07618689955495350218939165642951e-01
            -3.82287738879303395922448771671043e-01 -8.63594661180780986953209321654867e-01
            -2.68715127709870493788457679329440e-01 -9.05390431944841367339904536493123e-01
            -1.50730221572472261604147547586763e-01 -9.32319716847236801271492367959581e-01
            -3.02703293640167424294329379108603e-02 -9.43940337774370363810305661900202e-01
            9.06866008157275055312496192527760e-02 -9.40061484451887974245209989021532e-01
            2.10154459517244762700727278570412e-01 -9.20746847544108071303980977972969e-01
            3.26171587803522455839555505008320e-01 -8.86313572855074505163486264791572e-01
            4.36832987635565772599477440962801e-01 -8.37327053803222143280038380908081e-01
            5.40321601887533642383232290740125e-01 -7.74591647677076333700085797318025e-01
            6.34938150374504517436946571251610e-01 -6.99137468110815341049146809382364e-01
            7.19129031986138755883075646124780e-01 -6.12203470646873637583951222040923e-01
            7.91511834773956812760786760918563e-01 -5.15217109120187144455371708318125e-01
            8.50898035117311213326729557593353e-01 -4.09770896905694570477862725965679e-01
            8.96312513248385456243738644843688e-01 -2.97596257892738302874846567647182e-01
            9.27009564691818499504449846426724e-01 -1.80535096552675161651890789471508e-01
            9.42485144711574296394474004046060e-01 -6.05095539183800601445994971072651e-02
            8.96326061758505265864016564592021e-01 6.26772239606543102308222614738042e-02
            8.78880094522159871495148308895295e-01 1.86811731011854303963204415595101e-01
            8.44327725957230601494529764750041e-01 3.07310160214103122999773631818243e-01
            7.93341478615097295268299149029190e-01 4.21827146707910605183400321038789e-01
            7.26913741804277813152168619126314e-01 5.28133747612316239994356692477595e-01
            6.46337455861364151843417857890017e-01 6.24160825862681956088806600746466e-01
            5.53180946538068041284930131951114e-01 7.08039323610047177659509998193244e-01
            4.49257399324409112395528609340545e-01 7.78136641306136134232929180143401e-01
            3.36589567855617777247800859186100e-01 8.33088414396511933723843412735732e-01
            2.17370403313475957229883306354168e-01 8.71825069124685603227931096625980e-01
            9.39203711260060136734040270312107e-02 8.93592640568664942080090440867934e-01
            -3.13577142525925320337698565253959e-02 8.97967447710538491101317504217150e-01
            -1.56025457392136052137132651296270e-01 8.84864339905559016408176375989569e-01
            -2.77656342479868756267791241043597e-01 8.54538354242586284392757534078555e-01
            -3.93882962690639437663975286341156e-01 8.07579751537252366055952279566554e-01
            -5.02443099067865883711192509508692e-01 7.44902527576598139091856864979491e-01
            -6.01223752042291059716205836593872e-01 6.67726623230731841651675040338887e-01
            -6.88302268565094355068367804051377e-01 5.77554179691456059941856437944807e-01
            -7.61983764362504478739879232307430e-01 4.76140301002627885917917183178361e-01
            -8.20834112930283743558845799270784e-01 3.65458892956348979641489904679474e-01
            -8.63707859174839720495242545439396e-01 2.47664243262004063472758730313217e-01
            -8.89770514393685818532730991137214e-01 1.25049090786465089131240802089451e-01
            -8.98514798648818002746452293649781e-01 1.10036327215180357483192918039926e-16
            -8.89770514393685818532730991137214e-01 -1.25049090786464894842211492687056e-01
            -8.63707859174839942539847470470704e-01 -2.47664243262003452850095186477120e-01
            -8.20834112930283965603450724302093e-01 -3.65458892956348424529977592101204e-01
            -7.61983764362504589762181694823084e-01 -4.76140301002627774895614720662707e-01
            -6.88302268565094577112972729082685e-01 -5.77554179691455837897251512913499e-01
            -6.01223752042291170738508299109526e-01 -6.67726623230731730629372577823233e-01
            -5.02443099067866327800402359571308e-01 -7.44902527576597917047251939948183e-01
            -3.93882962690639604197428980114637e-01 -8.07579751537252255033649817050900e-01
            -2.77656342479868922801244934817078e-01 -8.54538354242586173370455071562901e-01
            -1.56025457392136079892708266925183e-01 -8.84864339905559016408176375989569e-01
            -3.13577142525933577621444214855728e-02 -8.97967447710538380079015041701496e-01
            9.39203711260055973397697925975081e-02 -8.93592640568665053102392903383588e-01
            2.17370403313475568651824687549379e-01 -8.71825069124685714250233559141634e-01
            3.36589567855617777247800859186100e-01 -8.33088414396511933723843412735732e-01
            4.49257399324409112395528609340545e-01 -7.78136641306136134232929180143401e-01
            5.53180946538068263329535056982422e-01 -7.08039323610046955614905073161935e-01
            6.46337455861363818776510470343055e-01 -6.24160825862682289155713988293428e-01
            7.26913741804277702129866156610660e-01 -5.28133747612316351016659154993249e-01
            7.93341478615097295268299149029190e-01 -4.21827146707910605183400321038789e-01
            8.44327725957230601494529764750041e-01 -3.07310160214103011977471169302589e-01
            8.78880094522159760472845846379641e-01 -1.86811731011854803563565496915544e-01
            8.96326061758505376886319027107675e-01 -6.26772239606538245082489879678178e-02
            8.41940232885492023662266092287609e-01 6.46395610839857193141710922645871e-02
            8.22205867422106773112489008781267e-01 1.92403586726099973258641284701298e-01
            7.83199693295725474229129758896306e-01 3.15657835369072492515130079482333e-01
            7.25835982167770232820203091250733e-01 4.31513331890168994053880169303739e-01
            6.51459290807853586002806878241245e-01 5.37254521645500249249494117975701e-01
            5.61812945822691478525712227565236e-01 6.30402920769277841372968396171927e-01
            4.58998181558017248615755079299561e-01 7.08775209734962663432611407188233e-01
            3.45424888946442076864684622705681e-01 7.70534408514470636752946575143142e-01
            2.23755129706521727062096260851831e-01 8.14232933833079819407885224791244e-01
            9.68407398723343942892327618210402e-02 8.38846529294474563265282540669432e-01
            -3.23435148260556512567198694796389e-02 8.43798273082555838620066879229853e-01
            -1.60769664950014712356818336047581e-01 8.28972100519834609322344931570115e-01
            -2.85427510389594962791903753895895e-01 7.94715524525099747954470785771264e-01
            -4.03395176902782370831346270279028e-01 7.41831490205140720028964551602257e-01
            -5.11907602371266423624263097735820e-01 6.71559554501987787666905660444172e-01
            -6.08421347512931864898177991562989e-01 5.85546832028792541002815141837345e-01
            -6.90674211942915783346563785016770e-01 4.85809388099323613552371625701198e-01
            -7.56738258233274119213263020355953e-01 3.74684983865750109721659555361839e-01
            -8.05065001132250324111794270720566e-01 2.54778281178629162351256809415645e-01
            -8.34521702746140014994580269558355e-01 1.28899791520739132044681696243060e-01
            -8.44417922955456257128048491722438e-01 4.78408258837525237170582921788721e-16
            -8.34521702746140014994580269558355e-01 -1.28899791520738910000076771211752e-01
            -8.05065001132250324111794270720566e-01 -2.54778281178629328884710503189126e-01
            -7.56738258233274230235565482871607e-01 -3.74684983865749887677054630330531e-01
            -6.90674211942916005391168710048078e-01 -4.85809388099323169463161775638582e-01
            -6.08421347512932086942782916594297e-01 -5.85546832028792429980512679321691e-01
            -5.11907602371266312601960635220166e-01 -6.71559554501987898689208122959826e-01
            -4.03395176902782204297892576505546e-01 -7.41831490205140831051267014117911e-01
            -2.85427510389594962791903753895895e-01 -7.94715524525099747954470785771264e-01
            -1.60769664950015295223906264254765e-01 -8.28972100519834498300042469054461e-01
            -3.23435148260558524846430827892618e-02 -8.43798273082555838620066879229853e-01
            9.68407398723343804114449540065834e-02 -8.38846529294474563265282540669432e-01
            2.23755129706521338484037642047042e-01 -8.14232933833079930430187687306898e-01
            3.45424888946441910331230928932200e-01 -7.70534408514470636752946575143142e-01
            4.58998181558017470660360004330869e-01 -7.08775209734962552410308944672579e-01
            5.61812945822691145458804840018274e-01 -6.30402920769278174439875783718890e-01
            6.51459290807853030891294565662974e-01 -5.37254521645500804361006430553971e-01
            7.25835982167770010775598166219424e-01 -4.31513331890169493654241250624182e-01
            7.83199693295725363206827296380652e-01 -3.15657835369072714559735004513641e-01
            8.22205867422106773112489008781267e-01 -1.92403586726099862236338822185644e-01
            8.41940232885492023662266092287609e-01 -6.46395610839860801366540954404627e-02
            7.80463373128469584116828627884388e-01 6.64272227083290422999795055147843e-02
            7.58010862869650026141243870370090e-01 1.97370677871408412018539024757047e-01
            7.13751760192974593621784151764587e-01 3.22636137984016024837785607815022e-01
            6.48959318900106052474541229457827e-01 4.38619943828961300624769137357362e-01
            5.65497499559739047469975048443303e-01 5.41985452483268681511674458306516e-01
            4.65767346755744104935814675627626e-01 6.29759026460061877017437836911995e-01
            3.52637915406059931910931481979787e-01 6.99415579844972490342058790702140e-01
            2.29363733276379933023747526021907e-01 7.48951220420483898543295708805090e-01
            9.94911741418362943756292793295870e-02 7.76940897996552526372227021056460e-01
            -3.32435649296428450960583234063961e-02 7.82579400509992528789382504328387e-01
            -1.65021947164502802429808525630506e-01 7.65704518509487952471204152971040e-01
            -2.92052948434142756184428435517475e-01 7.26801711626172908253806781431194e-01
            -4.10682118116797167939324708640925e-01 6.66990142783918327218373178766342e-01
            -5.17496710988281538590172203839757e-01 5.87990481919666407861768675502390e-01
            -6.09423865688523358485895187186543e-01 4.92075405442161217806074091640767e-01
            -6.83819005348144992595393887313548e-01 3.82004215469521013481823956681183e-01
            -7.38541917250030044428399378375616e-01 2.60943459731146465419016067244229e-01
            -7.72018322852515481713453482370824e-01 1.32375835754868304006137691430922e-01
            -7.83285166916756203647764777997509e-01 9.59247672484205779235874727130556e-17
            -7.72018322852515481713453482370824e-01 -1.32375835754868109717108382028528e-01
            -7.38541917250030044428399378375616e-01 -2.60943459731146298885562373470748e-01
            -6.83819005348145214639998812344857e-01 -3.82004215469520569392614106618566e-01
            -6.09423865688523247463592724670889e-01 -4.92075405442161384339527785414248e-01
            -5.17496710988281760634777128871065e-01 -5.87990481919666296839466212986736e-01
            -4.10682118116797556517383327445714e-01 -6.66990142783917994151465791219380e-01
            -2.92052948434142922717882129290956e-01 -7.26801711626172797231504318915540e-01
            -1.65021947164502663651930447485938e-01 -7.65704518509487952471204152971040e-01
            -3.32435649296432059185413265822717e-02 -7.82579400509992417767080041812733e-01
            9.94911741418357531419047745657736e-02 -7.76940897996552526372227021056460e-01
            2.29363733276379572201264522846031e-01 -7.48951220420484009565598171320744e-01
            3.52637915406059931910931481979787e-01 -6.99415579844972490342058790702140e-01
            4.65767346755744271469268369401107e-01 -6.29759026460061877017437836911995e-01
            5.65497499559738936447672585927648e-01 -5.41985452483268903556279383337824e-01
            6.48959318900105719407633841910865e-01 -4.38619943828961744713978987419978e-01
            7.13751760192974593621784151764587e-01 -3.22636137984016246882390532846330e-01
            7.58010862869650026141243870370090e-01 -1.97370677871408384262963409128133e-01
            7.80463373128469473094526165368734e-01 -6.64272227083293753668868930617464e-02
            7.12647917571202271780350656626979e-01 6.80496252854488892225504059751984e-02
            6.86890965044140600070932123344392e-01 2.01689385096961243393209883834061e-01
            6.36307983363430529344384467549389e-01 3.28039565034502156315454612922622e-01
            5.62727173279686132545407417637762e-01 4.42533540392946067587587322122999e-01
            4.68807936982264750191973234905163e-01 5.41033200591695684344983874325408e-01
            3.57944760375138504304715070247767e-01 6.19978511272806787069100664666621e-01
            2.34144527512078065578648988775967e-01 6.76516183218263345011678211449180e-01
            1.01881701367115398704221718162444e-01 7.08602797656488925248652321897680e-01
            -3.40633949154388743219001867146289e-02 7.15078660740827820596621222648537e-01
            -1.68777351354439109076821523558465e-01 6.95709717906715319202248792862520e-01
            -2.97391254570390617395503340958385e-01 6.51196013213464208746472650091164e-01
            -4.15256663000811654384847315668594e-01 5.83146387928015430546224706631619e-01
            -5.18113613689701324460656906012446e-01 4.94020332809753937031160830883891e-01
            -6.02244588447991557877969626133563e-01 3.87039095706325830814620303499396e-01
            -6.64608874646801406349538865470095e-01 2.66069257263542968683367462290335e-01
            -7.02952464494342788015046608052216e-01 1.35482982626567799444572415268340e-01
            -7.15889520750276897587127677979879e-01 8.76711810129959357128019406519258e-17
            -7.02952464494342899037349070567871e-01 -1.35482982626567327599786949576810e-01
            -6.64608874646801406349538865470095e-01 -2.66069257263542802149913768516853e-01
            -6.02244588447991779922574551164871e-01 -3.87039095706325442236561684694607e-01
            -5.18113613689701435482959368528100e-01 -4.94020332809753881520009599626064e-01
            -4.15256663000811820918301009442075e-01 -5.83146387928015319523922244115965e-01
            -2.97391254570390506373200878442731e-01 -6.51196013213464319768775112606818e-01
            -1.68777351354439109076821523558465e-01 -6.95709717906715319202248792862520e-01
            -3.40633949154392143277014781688194e-02 -7.15078660740827820596621222648537e-01
            1.01881701367115065637314330615482e-01 -7.08602797656489036270954784413334e-01
            2.34144527512078065578648988775967e-01 -6.76516183218263345011678211449180e-01
            3.57944760375138504304715070247767e-01 -6.19978511272806787069100664666621e-01
            4.68807936982264361613914616100374e-01 -5.41033200591696017411891261872370e-01
            5.62727173279685910500802492606454e-01 -4.42533540392946345143343478412135e-01
            6.36307983363430418322082005033735e-01 -3.28039565034502322848908306696103e-01
            6.86890965044140600070932123344392e-01 -2.01689385096961298904361115091888e-01
            7.12647917571202160758048194111325e-01 -6.80496252854494443340627185534686e-02
            6.39028596108989876967143572983332e-01 6.94985480223503371277615769940894e-02
            6.09148329184206582809224528318737e-01 2.05245969203614209153130332197179e-01
            5.50784963406511396399878321972210e-01 3.31396316979427729698670646030223e-01
            4.66667504893447271374640195062966e-01 4.42050941293835264467304568825057e-01
            3.60729192515244767580639972948120e-01 5.32035754897676849139998012105934e-01
            2.37923584016731221035811927322356e-01 5.97143167917773998176755867461907e-01
            1.03992933162665987523176625018095e-01 6.34328830082999339801119731419021e-01
            -3.48003116662412778636870314130647e-02 6.41853981159401953959786624182016e-01
            -1.71966332599403942671401068764681e-01 6.19366753446253803794263603776926e-01
            -3.01091398947069377456386973790359e-01 5.67918624718663500594573179114377e-01
            -4.16137766119024865574260729772504e-01 4.89915252295444691998937969401595e-01
            -5.11725993851162685999156565230805e-01 3.89003987176585797058692151040304e-01
            -5.83386482853413212978921364992857e-01 2.69903327964228112456623875914374e-01
            -6.27768468304943816349350527161732e-01 1.38182289112267153718960344122024e-01
            -6.42796697893075252849826028977986e-01 7.87198918577242863257638865915692e-17
            -6.27768468304943816349350527161732e-01 -1.38182289112266987185506650348543e-01
            -5.83386482853413101956618902477203e-01 -2.69903327964228223478926338430028e-01
            -5.11725993851162908043761490262114e-01 -3.89003987176585408480633532235515e-01
            -4.16137766119024754551958267256850e-01 -4.89915252295444747510089200659422e-01
            -3.01091398947069766034445592595148e-01 -5.67918624718663278549968254083069e-01
            -1.71966332599404247982732840682729e-01 -6.19366753446253803794263603776926e-01
            -3.48003116662417219528968814756809e-02 -6.41853981159401953959786624182016e-01
            1.03992933162665834867510739059071e-01 -6.34328830082999450823422193934675e-01
            2.37923584016730943480055771033221e-01 -5.97143167917774109199058329977561e-01
            3.60729192515244712069488741690293e-01 -5.32035754897676960162300474621588e-01
            4.66667504893447271374640195062966e-01 -4.42050941293835264467304568825057e-01
            5.50784963406511396399878321972210e-01 -3.31396316979427729698670646030223e-01
            6.09148329184206582809224528318737e-01 -2.05245969203614125886403485310439e-01
            6.39028596108989765944841110467678e-01 -6.94985480223507950947592348711623e-02
            5.59993091613543159112964531232137e-01 7.07435791976534222857964095965144e-02
            5.24806666156938383949182025389746e-01 2.07785658335287032327798328878998e-01
            4.56644707761787949085174886931782e-01 3.31771800377518688573985627954244e-01
            3.59790082956206680453448143452988e-01 4.34911500030701336783067745273001e-01
            2.40328524023122241937144849543984e-01 5.10724110644344309051234631624538e-01
            1.05766240059181185206860220660019e-01 5.54446047074313996816385952115525e-01
            -3.54417257486996303827986309897824e-02 5.63330099256681648967060027644038e-01
            -1.74422757582239906781751415110193e-01 5.36818049519570461569628605502658e-01
            -3.02444166074858522552659678694909e-01 4.76575747452461340181173454766395e-01
            -4.11461895301157898341415375398356e-01 3.86388438449920212924837414902868e-01
            -4.94625960394688535259888340078760e-01 2.71922922822296853073709144155146e-01
            -5.46710857289587015550580417766469e-01 1.40371489891194328736290231063322e-01
            -5.64443900359095751539939556096215e-01 6.91244415873014205907656067577941e-17
            -5.46710857289587126572882880282123e-01 -1.40371489891193940158231612258533e-01
            -4.94625960394688535259888340078760e-01 -2.71922922822296908584860375412973e-01
            -4.11461895301158120386020300429664e-01 -3.86388438449919935369081258613733e-01
            -3.02444166074858244996903522405773e-01 -4.76575747452461562225778379797703e-01
            -1.74422757582240156581931955770415e-01 -5.36818049519570350547326142987004e-01
            -3.54417257486995193604961684741284e-02 -5.63330099256681648967060027644038e-01
            1.05766240059180921528891872185341e-01 -5.54446047074314107838688414631179e-01
            2.40328524023121770092359383852454e-01 -5.10724110644344420073537094140192e-01
            3.59790082956206458408843218421680e-01 -4.34911500030701558827672670304310e-01
            4.56644707761787893574023655673955e-01 -3.31771800377518799596288090469898e-01
            5.24806666156938383949182025389746e-01 -2.07785658335287004572222713250085e-01
            5.59993091613543159112964531232137e-01 -7.07435791976536443304013346278225e-02
            4.75807706666434571118884377938230e-01 7.17164726107643035746264104091097e-02
            4.33530103881393236164853988157120e-01 2.08777094518270256440217735871556e-01
            3.52731448850965412233904316963162e-01 3.27286955374639254578994496114319e-01
            2.40591056653662038744556639358052e-01 4.16715933970824736753968409175286e-01
            1.07073093256218845881200252279086e-01 4.69117873105947047474018063439871e-01
            -3.59587843595696177168008489388740e-02 4.79836630525728335960877757315757e-01
            -1.75795566182484541695174584674533e-01 4.47919797594928892348065119222156e-01
            -3.00012140483950084934861024521524e-01 3.76203324984164644284589940070873e-01
            -3.97571319521823562936901907960419e-01 2.71059536007458024009508790186374e-01
            -4.59804542107184188726165530169965e-01 1.41830917731307931672901645470120e-01
            -4.81182113307323966466810816200450e-01 5.89278134868773331716015683225621e-17
            -4.59804542107184299748467992685619e-01 -1.41830917731307626361569873552071e-01
            -3.97571319521823562936901907960419e-01 -2.71059536007458135031811252702028e-01
            -3.00012140483950195957163487037178e-01 -3.76203324984164533262287477555219e-01
            -1.75795566182484430672872122158878e-01 -4.47919797594928892348065119222156e-01
            -3.59587843595699438448143325786077e-02 -4.79836630525728335960877757315757e-01
            1.07073093256218748736685597577889e-01 -4.69117873105947047474018063439871e-01
            2.40591056653661650166498020553263e-01 -4.16715933970824958798573334206594e-01
            3.52731448850965523256206779478816e-01 -3.27286955374639143556692033598665e-01
            4.33530103881393180653702756899293e-01 -2.08777094518270339706944582758297e-01
            4.75807706666434515607733146680403e-01 -7.17164726107647060304728370283556e-02
            3.86604449207235689733863637229661e-01 7.22688964229177555065319893401465e-02
            3.34391376092592507163203663367312e-01 2.07046374351058909413225705975492e-01
            2.37016894710064596196730235533323e-01 3.13861092139523789601440739716054e-01
            1.07631968340990327726025554966327e-01 3.78287130270196392256565331990714e-01
            -3.62892517618600418671803709003143e-02 3.91623395296528231668276021082420e-01
            -1.75309407328585326046876957661880e-01 3.52068750727917656462295781238936e-01
            -2.90653056012624866344395968553727e-01 2.64965270493207172286531658755848e-01
            -3.66742398917977163730341771952226e-01 1.42076762255140764956706789234886e-01
            -3.93301148659670807283816884591943e-01 4.81654992807043175886754322187530e-17
            -3.66742398917977274752644234467880e-01 -1.42076762255140515156526248574664e-01
            -2.90653056012624810833244737295900e-01 -2.64965270493207227797682890013675e-01
            -1.75309407328585742380511192095582e-01 -3.52068750727917434417690856207628e-01
            -3.62892517618600488060742748075427e-02 -3.91623395296528231668276021082420e-01
            1.07631968340990244459298708079587e-01 -3.78287130270196392256565331990714e-01
            2.37016894710064485174427773017669e-01 -3.13861092139523845112591970973881e-01
            3.34391376092592396140901200851658e-01 -2.07046374351059103702255015377887e-01
            3.86604449207235689733863637229661e-01 -7.22688964229176583620173346389493e-02
            2.92297717441566795582019722132827e-01 7.20449167641221549507335453199630e-02
            2.25335832945062541909919673344120e-01 1.99630128097074005522060247130867e-01
            1.06752224712014606722298992735887e-01 2.81482482886830531754185358295217e-01
            -3.62870316987847774115039101161528e-02 2.98850593078867243779228601852083e-01
            -1.71013366453530712973929439613130e-01 2.47755633936606434186700198551989e-01
            -2.66562599888253703994678289745934e-01 1.39902844838530993065717211720766e-01
            -3.01045554116149194356921725557186e-01 -9.68236348317266256345555207867217e-17
            -2.66562599888253870528131983519415e-01 -1.39902844838530687754385439802718e-01
            -1.71013366453530796240656286499870e-01 -2.47755633936606406431124582923076e-01
            -3.62870316987849855783210273330042e-02 -2.98850593078867243779228601852083e-01
            1.06752224712014606722298992735887e-01 -2.81482482886830531754185358295217e-01
            2.25335832945062430887617210828466e-01 -1.99630128097074116544362709646521e-01
            2.92297717441566795582019722132827e-01 -7.20449167641221688285213531344198e-02
            1.92284858135953223845504567179887e-01 6.99859648615863694232075431500562e-02
            1.02312636005982754427989789292042e-01 1.77210683818662950717026660640840e-01
            -3.55328055894777172785126140297507e-02 2.01516554339615544533259594572883e-01
            -1.56752052546475451055840721892309e-01 1.31530589478029230621203282680654e-01
            -2.04625272011965453344828347326256e-01 2.50593684394109974451460478397819e-17
            -1.56752052546475534322567568779050e-01 -1.31530589478029119598900820164999e-01
            -3.55328055894777242174065179369791e-02 -2.01516554339615544533259594572883e-01
            1.02312636005982587894536095518561e-01 -1.77210683818663061739329123156494e-01
            1.92284858135953223845504567179887e-01 -6.99859648615863416676319275211426e-02
            8.43182474881407489908369257136656e-02 6.12607926870154459453310380467883e-02
            -3.22067046686443092529117393496563e-02 9.91220447453519948322053778611007e-02
            -1.04223085638992851720274757099105e-01 1.27636468225053077345676450651255e-17
            -3.22067046686443300695934510713414e-02 -9.91220447453519809544175700466440e-02
            8.43182474881407351130491178992088e-02 -6.12607926870154737009066536757018e-02
            -0.00000000000000000000000000000000e+00 0.00000000000000000000000000000000e+00
            ];
        
    case   29
        
        % DEGREE.             :          29
        % CARDIN.             :         465
        % LEBESGUE CONST.     : 8.15662e+01
        % ABS.DET.VAND.MATRIX : Inf
        % CONDITIONING VAND.  : 2.41223e+03
        % POINTS OUT DISK     : 0.00000e+00
        
        pts=[
            9.98582695676761944447719088202575e-01 5.32221748421786503002728352385020e-02
            9.87268354721344554292272732709534e-01 1.59063496019072048159870291783591e-01
            9.64767868814515927589070543035632e-01 2.63102564227521262818498826163705e-01
            9.31336177452338431770328952552518e-01 3.64160575252822193981216969405068e-01
            8.87352075056571543143490998772904e-01 4.61092501449325842255433371974505e-01
            8.33313919082514953373674870817922e-01 5.52800065361193304624976008199155e-01
            7.69833983429906276718668323155725e-01 6.38244183644820051171109298593365e-01
            6.97631521134984722287697422871133e-01 7.16456740298315075676782726077363e-01
            6.17524614946191929831798006489407e-01 7.86551555802642465842211549897911e-01
            5.30420908119742517961014982574852e-01 8.47734427889670905109653631370747e-01
            4.37307320458855453004787250392837e-01 8.99312130171219248353509101434611e-01
            3.39238866118030391039184223700431e-01 9.40700266671033236143273370544193e-01
            2.37326699871114765727497797342949e-01 9.71429893264709964917358320235508e-01
            1.32725527283722194438198016541719e-01 9.91152831004007084381157710595289e-01
            2.66205214377748175524907026101573e-02 9.99645611123452626500807127740700e-01
            -7.97861055530829782478363654263376e-02 9.96812007030750124592088923236588e-01
            -1.85288724087114387018004890705924e-01 9.82684124592520968910491774295224e-01
            -2.88691947339620835766282880285871e-01 9.57422038362005567435630837280769e-01
            -3.88824175473320599039084299874958e-01 9.21311977870412968094626648962731e-01
            -4.84550870332650096550253238092409e-01 8.74763084531961276901768087554956e-01
            -5.74787410214406824238153603801038e-01 8.18302775908169133245451121183578e-01
            -6.58511379065038537916620953183156e-01 7.52570769856138577225124208780471e-01
            -7.34774150863067077033008445141604e-01 6.78311836269616219574629667476984e-01
            -8.02711637930963783915672138391528e-01 5.96367358538501313169888362608617e-01
            -8.61554081393805959443454867141554e-01 5.07665800338840234040560517314589e-01
            -9.10634772854913010498023595573613e-01 4.13212185768378537087386348503060e-01
            -9.49397608468381282165182710741647e-01 3.14076712021948811770499787598965e-01
            -9.77403389817866674604829313466325e-01 2.11382623629624344374633437837474e-01
            -9.94334800210137093046114387107082e-01 1.06293485647365917867723794643098e-01
            -1.00000000000000000000000000000000e+00 1.22464679914735320717376402945840e-16
            -9.94334800210137204068416849622736e-01 -1.06293485647365237856121211734717e-01
            -9.77403389817866563582526850950671e-01 -2.11382623629624538663662747239869e-01
            -9.49397608468381393187485173257301e-01 -3.14076712021948534214743631309830e-01
            -9.10634772854913343564930983120576e-01 -4.13212185768377870953571573409135e-01
            -8.61554081393806070465757329657208e-01 -5.07665800338840011995955592283281e-01
            -8.02711637930963672893369675875874e-01 -5.96367358538501424192190825124271e-01
            -7.34774150863067632144520757719874e-01 -6.78311836269615775485419817414368e-01
            -6.58511379065038759961225878214464e-01 -7.52570769856138466202821746264817e-01
            -5.74787410214406602193548678769730e-01 -8.18302775908169244267753583699232e-01
            -4.84550870332649930016799544318928e-01 -8.74763084531961387924070550070610e-01
            -3.88824175473321265172899074968882e-01 -9.21311977870412746050021723931422e-01
            -2.88691947339620835766282880285871e-01 -9.57422038362005567435630837280769e-01
            -1.85288724087114192728975581303530e-01 -9.82684124592520968910491774295224e-01
            -7.97861055530838803040438733660267e-02 -9.96812007030749902547483998205280e-01
            2.66205214377747932663620389348580e-02 -9.99645611123452626500807127740700e-01
            1.32725527283721944638017475881497e-01 -9.91152831004007195403460173110943e-01
            2.37326699871113877549078097217716e-01 -9.71429893264710186961963245266816e-01
            3.39238866118030168994579298669123e-01 -9.40700266671033347165575833059847e-01
            4.37307320458855230960182325361529e-01 -8.99312130171219248353509101434611e-01
            5.30420908119742295916410057543544e-01 -8.47734427889671016131956093886402e-01
            6.17524614946191707787193081458099e-01 -7.86551555802642576864514012413565e-01
            6.97631521134984500243092497839825e-01 -7.16456740298315297721387651108671e-01
            7.69833983429906609785575710702688e-01 -6.38244183644819718104201911046403e-01
            8.33313919082514731329069945786614e-01 -5.52800065361193748714185858261772e-01
            8.87352075056571321098886073741596e-01 -4.61092501449326286344643222037121e-01
            9.31336177452338542792631415068172e-01 -3.64160575252821805403158350600279e-01
            9.64767868814515816566768080519978e-01 -2.63102564227521817930011138741975e-01
            9.87268354721344443269970270193880e-01 -1.59063496019071742848538519865542e-01
            9.98582695676761944447719088202575e-01 -5.32221748421784282556679102071939e-02
            9.79660723076195227854157110414235e-01 5.60190269404783544593406929834600e-02
            9.66889347352912653654755104071228e-01 1.67326787135205601320109281004989e-01
            9.41513090320202361560575354815228e-01 2.76453186766284664255266534382827e-01
            9.03862770296469220099311314697843e-01 3.81975596327205124680403969250619e-01
            8.54429216781966038851692246680614e-01 4.82518369833613458563803533252212e-01
            7.93856871745631353931571538851131e-01 5.76770778472498468758544731826987e-01
            7.22935388338476481173699994542403e-01 6.63504097956770788613312106463127e-01
            6.42589336557144008565956028178334e-01 7.41587626825435441979550432733959e-01
            5.53866150060053574755158933839994e-01 8.10003426866322651100915663846536e-01
            4.57922471267821096230221655787318e-01 8.67859593497417924901071728527313e-01
            3.56009072760449185590658771616290e-01 9.14401883107081703272456252307165e-01
            2.49454551543938030100378000497585e-01 9.49023545772993193381239507289138e-01
            1.39648008756482200354298583988566e-01 9.71273235175293625509596040501492e-01
            2.80209406107813571717990441811708e-02 9.80860892586109200941280050756177e-01
            -8.39714233482871941216529876328423e-02 9.77661528228657816796953738958109e-01
            -1.94869091386269371879436107519723e-01 9.61716850710135795488042731449241e-01
            -3.03226342804165049926723440876231e-01 9.33234723286238909700784915912664e-01
            -4.07630575118683113888806701652356e-01 8.92586454045737553997241775505245e-01
            -5.06720719495908689111729472642764e-01 8.40301955341697603962813900579931e-01
            -5.99204984365039439175859570241300e-01 7.77062835573562038504746851685923e-01
            -6.83877695897052051421383112028707e-01 7.03693513379277324482075073319720e-01
            -7.59635015806903290958018715173239e-01 6.21150470077563077175852868094807e-01
            -8.25489331573679097076023936097044e-01 5.30509780471173253424410631851060e-01
            -8.80582131480163621262136075529270e-01 4.32953084566195856019987786567071e-01
            -9.24195196625997250627904122666223e-01 3.29752183087490768897964699135628e-01
            -9.55759964009417095631704341940349e-01 2.22252457611270132220582240734075e-01
            -9.74864938615489950990422585164197e-01 1.11855331458758755491800229719956e-01
            -9.81261057882932496987393733434146e-01 1.20169821366427902997540822942078e-16
            -9.74864938615489950990422585164197e-01 -1.11855331458758505691619689059735e-01
            -9.55759964009417206654006804456003e-01 -2.22252457611269910175977315702767e-01
            -9.24195196625997361650206585181877e-01 -3.29752183087490546853359774104320e-01
            -8.80582131480163621262136075529270e-01 -4.32953084566195967042290249082725e-01
            -8.25489331573679319120628861128353e-01 -5.30509780471172698312898319272790e-01
            -7.59635015806903401980321177688893e-01 -6.21150470077562855131247943063499e-01
            -6.83877695897052273465988037060015e-01 -7.03693513379277102437470148288412e-01
            -5.99204984365039994287371882819571e-01 -7.77062835573561594415537001623306e-01
            -5.06720719495909244223241785221035e-01 -8.40301955341697270895906513032969e-01
            -4.07630575118683169399957932910183e-01 -8.92586454045737553997241775505245e-01
            -3.03226342804165271971328365907539e-01 -9.33234723286238798678482453397010e-01
            -1.94869091386269815968645957582339e-01 -9.61716850710135684465740268933587e-01
            -8.39714233482878602554677627267665e-02 -9.77661528228657705774651276442455e-01
            2.80209406107811177799593593817917e-02 -9.80860892586109200941280050756177e-01
            1.39648008756481950554118043328344e-01 -9.71273235175293736531898503017146e-01
            2.49454551543937363966563225403661e-01 -9.49023545772993415425844432320446e-01
            3.56009072760449352124112465389771e-01 -9.14401883107081592250153789791511e-01
            4.57922471267820874185616730756010e-01 -8.67859593497418035923374191042967e-01
            5.53866150060053241688251546293031e-01 -8.10003426866322762123218126362190e-01
            6.42589336557144230610560953209642e-01 -7.41587626825435330957247970218305e-01
            7.22935388338476592196002457058057e-01 -6.63504097956770677591009643947473e-01
            7.93856871745631686998478926398093e-01 -5.76770778472498024669334881764371e-01
            8.54429216781965816807087321649306e-01 -4.82518369833613902653013383314828e-01
            9.03862770296468887032403927150881e-01 -3.81975596327205790814218744344544e-01
            9.41513090320202361560575354815228e-01 -2.76453186766284775277568996898481e-01
            9.66889347352912653654755104071228e-01 -1.67326787135205934387016668551951e-01
            9.79660723076195227854157110414235e-01 -5.60190269404789165097469094689586e-02
            9.45667260203114312666627938597230e-01 5.83267601291050097334078827771009e-02
            9.31331908498561289455608402931830e-01 1.74096106158783292539027343082125e-01
            9.02878514408643417787914131622529e-01 2.87226332682893326087025798187824e-01
            8.60738402383970702125282059569145e-01 3.96002500785932576299330776237184e-01
            8.05550373567572641775313968537375e-01 4.98775674639779342811607421026565e-01
            7.38151022220726593658923775365110e-01 5.93987917690014355365235587669304e-01
            6.59562053806735049121812153316569e-01 6.80195909386012487196637721353909e-01
            5.70974796977571030787146355578443e-01 7.56092824449250189289273293979932e-01
            4.73732144245886721556360043905443e-01 8.20528143012424160396278693951899e-01
            3.69308195103393133162938966052025e-01 8.72525091327863711043733019323554e-01
            2.59285910175177214398445357801393e-01 9.11295448661877616203241814218927e-01
            1.45333115150209413179993589437800e-01 9.36251495917608034247336945554707e-01
            2.91772182439844242340942770397305e-02 9.47014924857452200512852868996561e-01
            -8.74209755492005441412928234967694e-02 9.43422572870317277526908128493233e-01
            -2.02693956465095498353790048895462e-01 9.25528896350486074418029147636844e-01
            -3.14894303615821713471234488679329e-01 8.93605145194190209068096919509117e-01
            -4.22321174109310859545729499586741e-01 8.48135250927678385757246815046528e-01
            -5.23346086093803397609747207752662e-01 7.89808490798573292757112085382687e-01
            -6.16437604882739575984373914252501e-01 7.19509039035406749995615882653510e-01
            -7.00184557943547725145094773324672e-01 6.38302563667593081397910736995982e-01
            -7.73317426834770005328323350113351e-01 5.47420072084384701227577352256048e-01
            -8.34727591811557090295536909252405e-01 4.48239250217672802190094216712168e-01
            -8.83484137370935895816614902287256e-01 3.42263578227593678882101357885404e-01
            -9.18847963981912374542559973633615e-01 2.31099539275865045739877245978278e-01
            -9.40282992080963997416631627856987e-01 1.16432266878613840943579305076128e-01
            -9.47464288491773665157325012842193e-01 1.16030910820787504197335073435358e-16
            -9.40282992080963997416631627856987e-01 -1.16432266878613605021186572230363e-01
            -9.18847963981912374542559973633615e-01 -2.31099539275865240028906555380672e-01
            -8.83484137370936006838917364802910e-01 -3.42263578227593456837496432854095e-01
            -8.34727591811557201317839371768059e-01 -4.48239250217672580145489291680860e-01
            -7.73317426834770116350625812629005e-01 -5.47420072084384479182972427224740e-01
            -7.00184557943547836167397235840326e-01 -6.38302563667592859353305811964674e-01
            -6.16437604882739353939768989221193e-01 -7.19509039035406861017918345169164e-01
            -5.23346086093803619654352132783970e-01 -7.89808490798573181734809622867033e-01
            -4.22321174109310693012275805813260e-01 -8.48135250927678496779549277562182e-01
            -3.14894303615821935515839413710637e-01 -8.93605145194190098045794456993463e-01
            -2.02693956465095914687424283329165e-01 -9.25528896350485963395726685121190e-01
            -8.74209755492005580190806313112262e-02 -9.43422572870317277526908128493233e-01
            2.91772182439841952505954481011941e-02 -9.47014924857452200512852868996561e-01
            1.45333115150209579713447283211281e-01 -9.36251495917608034247336945554707e-01
            2.59285910175177214398445357801393e-01 -9.11295448661877616203241814218927e-01
            3.69308195103393466229846353598987e-01 -8.72525091327863600021430556807900e-01
            4.73732144245886943600964968936751e-01 -8.20528143012424160396278693951899e-01
            5.70974796977570697720238968031481e-01 -7.56092824449250300311575756495586e-01
            6.59562053806735271166417078347877e-01 -6.80195909386012265152032796322601e-01
            7.38151022220726482636621312849456e-01 -5.93987917690014466387538050184958e-01
            8.05550373567572419730709043506067e-01 -4.98775674639779786900817271089181e-01
            8.60738402383970813147584522084799e-01 -3.96002500785932520788179544979357e-01
            9.02878514408643306765611669106875e-01 -2.87226332682893548131630723219132e-01
            9.31331908498561289455608402931830e-01 -1.74096106158783042738846802421904e-01
            9.45667260203114312666627938597230e-01 -5.83267601291050791223469218493847e-02
            9.01964344086333857930526392010506e-01 6.03794086338589261475640057597047e-02
            8.85868768998181232987576549930964e-01 1.80060753924090821698200670653023e-01
            8.53964844740635276032492129161255e-01 2.96528910794828848285220601610490e-01
            8.06821897597890025366496047354303e-01 4.07705502227532878833926588413306e-01
            7.45281194578544692319610476261005e-01 5.11606579314264009461510340770474e-01
            6.70440930985906180517019947728841e-01 6.06378024872947118950605727150105e-01
            5.83636633096783485896708043583203e-01 6.90328640212410360454953206499340e-01
            4.86417325663440203165066577639664e-01 7.61960324613094042156546947808238e-01
            3.80517889530192443547917946489179e-01 8.19994808969881971982829327316722e-01
            2.67828102643642429470105525979307e-01 8.63396466534564588357625325443223e-01
            1.50358916920450641496742605340842e-01 8.91390793699695982432729124411708e-01
            3.02065727627449515102497912266699e-02 9.03478231033816303607864028890617e-01
            -9.04848084015191095330621351422451e-02 8.99443077931341483655103274941212e-01
            -2.09561486016232950690962866246991e-01 8.79357341794979929794351392047247e-01
            -3.24898533948383749780930429551518e-01 8.43579453061924611212418767536292e-01
            -4.34437759845236082245634179344052e-01 7.92747869004211236365620152355405e-01
            -5.36224433625628771338256228773389e-01 7.27769680443571820305237451975700e-01
            -6.28442169684579443611482929554768e-01 6.49804424694233162540513148996979e-01
            -7.09445340337437335698211882117903e-01 5.60243393592073202214010052557569e-01
            -7.77788442084901388007267541979672e-01 4.60684805858850632276357828231994e-01
            -8.32251890657210391388787229516311e-01 3.52905286851250943325197795275017e-01
            -8.71863784524328111480429015500704e-01 2.38828164639309170613756805323646e-01
            -8.95917248501772567337297914491501e-01 1.20489148171434745648866737610660e-01
            -9.03983047955029372921842423238559e-01 -2.90743122868040784328540221319300e-16
            -8.95917248501772678359600377007155e-01 -1.20489148171434107270627578145650e-01
            -8.71863784524328111480429015500704e-01 -2.38828164639308976324727495921252e-01
            -8.32251890657210502411089692031965e-01 -3.52905286851250721280592870243709e-01
            -7.77788442084901499029570004495326e-01 -4.60684805858850465742904134458513e-01
            -7.09445340337437446720514344633557e-01 -5.60243393592072980169405127526261e-01
            -6.28442169684579554633785392070422e-01 -6.49804424694232940495908223965671e-01
            -5.36224433625628549293651303742081e-01 -7.27769680443571931327539914491354e-01
            -4.34437759845235971223331716828397e-01 -7.92747869004211236365620152355405e-01
            -3.24898533948384138358989048356307e-01 -8.43579453061924500190116305020638e-01
            -2.09561486016233561313626410083089e-01 -8.79357341794979818772048929531593e-01
            -9.04848084015195258666963695759478e-02 -8.99443077931341483655103274941212e-01
            3.02065727627445317071686048393531e-02 -9.03478231033816303607864028890617e-01
            1.50358916920450419452137680309534e-01 -8.91390793699695982432729124411708e-01
            2.67828102643641985380895675916690e-01 -8.63396466534564699379927787958877e-01
            3.80517889530192277014464252715698e-01 -8.19994808969881971982829327316722e-01
            4.86417325663440036631612883866183e-01 -7.61960324613094153178849410323892e-01
            5.83636633096783374874405581067549e-01 -6.90328640212410360454953206499340e-01
            6.70440930985906069494717485213187e-01 -6.06378024872947118950605727150105e-01
            7.45281194578544692319610476261005e-01 -5.11606579314264009461510340770474e-01
            8.06821897597889581277286197291687e-01 -4.07705502227533600478892594765057e-01
            8.53964844740635276032492129161255e-01 -2.96528910794828848285220601610490e-01
            8.85868768998181232987576549930964e-01 -1.80060753924090738431473823766282e-01
            9.01964344086333857930526392010506e-01 -6.03794086338595784035909730391722e-02
            8.50438287899740519293345641926862e-01 6.22440599204216044038062705112679e-02
            8.32312672281778520577688595949439e-01 1.85405555689099360572313912598474e-01
            7.96447757073959872187174369173590e-01 3.04615453930160318130049290630268e-01
            7.43607940677058598666349098493811e-01 4.17333002628887395069057220098330e-01
            6.74919412039716060114358242572052e-01 5.21155822929364243023542258015368e-01
            5.91846147896233021334921886591474e-01 6.13871111668898516988690516882343e-01
            4.96158710644161615732627979014069e-01 6.93502803435676162813194878253853e-01
            3.89896511880765017643568626226624e-01 7.58353686972267126975566498003900e-01
            2.75324345885544830014879380541970e-01 8.07041578286965211042058854218340e-01
            1.54884119462197988870144627071568e-01 8.38528779505890553558344890916487e-01
            3.11428069346125595273644393046197e-02 8.52144195601573284370999772363575e-01
            -9.32622604541928218457869093072077e-02 8.47597637618341392951037960301619e-01
            -2.15679604678711500653776056424249e-01 8.24986007546099853193766193726333e-01
            -3.33500112581696261937480585402227e-01 7.84791233022652301443145006487612e-01
            -4.44212644591296279550363124144496e-01 7.27869995882798881403630275599426e-01
            -5.45457555301313568030252554308390e-01 6.55435473472357421620415607321775e-01
            -6.35076985216338485429332649800926e-01 5.69031481879294309678130048268940e-01
            -7.11160851780524683185547019093065e-01 4.70499572174106817090688537064125e-01
            -7.72087559471078765938045762595721e-01 3.61939780945963962555111947949626e-01
            -8.16558561291493067990643339726375e-01 2.45665871668788643455982878549548e-01
            -8.43626035046305622344675612112042e-01 1.24156020849850376452927491754963e-01
            -8.52713084525632769583580738981254e-01 1.04427234955538266255024765916625e-16
            -8.43626035046305622344675612112042e-01 -1.24156020849850154408322566723655e-01
            -8.16558561291493179012945802242029e-01 -2.45665871668788476922529184776067e-01
            -7.72087559471078876960348225111375e-01 -3.61939780945963740510507022918318e-01
            -7.11160851780524905230151944124373e-01 -4.70499572174106373001478687001509e-01
            -6.35076985216338596451635112316580e-01 -5.69031481879294087633525123237632e-01
            -5.45457555301313345985647629277082e-01 -6.55435473472357532642718069837429e-01
            -4.44212644591296834661875436722767e-01 -7.27869995882798548336722888052464e-01
            -3.33500112581696261937480585402227e-01 -7.84791233022652301443145006487612e-01
            -2.15679604678711528409351672053162e-01 -8.24986007546099853193766193726333e-01
            -9.32622604541932243016333359264536e-02 -8.47597637618341392951037960301619e-01
            3.11428069346121570715180126853738e-02 -8.52144195601573284370999772363575e-01
            1.54884119462197406003056698864384e-01 -8.38528779505890664580647353432141e-01
            2.75324345885544774503728149284143e-01 -8.07041578286965211042058854218340e-01
            3.89896511880764795598963701195316e-01 -7.58353686972267237997868960519554e-01
            4.96158710644161393688023053982761e-01 -6.93502803435676162813194878253853e-01
            5.91846147896232577245712036528857e-01 -6.13871111668898850055597904429305e-01
            6.74919412039716171136660705087706e-01 -5.21155822929364132001239795499714e-01
            7.43607940677058598666349098493811e-01 -4.17333002628887450580208451356157e-01
            7.96447757073959761164871906657936e-01 -3.04615453930160540174654215661576e-01
            8.32312672281778631599991058465093e-01 -1.85405555689098971994255293793685e-01
            8.50438287899740519293345641926862e-01 -6.22440599204220970652734479244828e-02
            7.92167555248693422420558363228338e-01 6.39503763848972422989547226279683e-02
            7.71650831674218884437266297027236e-01 1.90194847997909644021774511202239e-01
            7.31148756888910011930704513360979e-01 3.11513372952532063830943798166118e-01
            6.71710313354945354191727346915286e-01 4.24763865178128030564153050363529e-01
            5.94874925538276921876956748747034e-01 5.27013196413800621975553895026678e-01
            5.02632589623585146476614227140089e-01 6.15613162689647497316514090925921e-01
            3.97372333658390641808466625661822e-01 6.88269071418545097529317899898160e-01
            2.81820342981524973868800998388906e-01 7.43099172728806989240979419264477e-01
            1.58969353454850859108660188212525e-01 7.78683395797424404705111555813346e-01
            3.20011411764546671587794435254182e-02 7.94100127938452304832139816426206e-01
            -9.57958838489860187159763427189318e-02 7.88950083887474673538520164584043e-01
            -2.21111845801999634675283346041397e-01 7.63366647080218174714616452547489e-01
            -3.40701127093449296356908462257707e-01 7.18012415091629829788644201471470e-01
            -4.51466428155244070552498669712804e-01 6.54062038706732740145355364802526e-01
            -5.50538985872219055472953641583445e-01 5.73171799082308530692841941345250e-01
            -6.35352873039923826681274476868566e-01 4.77436710934942776241030060191406e-01
            -7.03711454531399827061477481038310e-01 3.69336262760324329779137997320504e-01
            -7.53844278993127780985616936959559e-01 2.51670199383623893751860123302322e-01
            -7.84452932605109842789659069239860e-01 1.27486010039159325391011634565075e-01
            -7.94744667316781505661538176354952e-01 9.73281512968924519940507721902942e-17
            -7.84452932605109953811961531755514e-01 -1.27486010039159131101982325162680e-01
            -7.53844278993127892007919399475213e-01 -2.51670199383623671707255198271014e-01
            -7.03711454531399827061477481038310e-01 -3.69336262760324163245684303547023e-01
            -6.35352873039924048725879401899874e-01 -4.77436710934942609707576366417925e-01
            -5.50538985872219277517558566614753e-01 -5.73171799082308308648237016313942e-01
            -4.51466428155244237085952363486285e-01 -6.54062038706732629123052902286872e-01
            -3.40701127093449185334605999742053e-01 -7.18012415091629940810946663987124e-01
            -2.21111845801999634675283346041397e-01 -7.63366647080218174714616452547489e-01
            -9.57958838489864072940349615237210e-02 -7.88950083887474673538520164584043e-01
            3.20011411764542924585086325350858e-02 -7.94100127938452415854442278941860e-01
            1.58969353454850664819630878810131e-01 -7.78683395797424515727414018329000e-01
            2.81820342981524807335347304615425e-01 -7.43099172728807100263281881780131e-01
            3.97372333658390197719256775599206e-01 -6.88269071418545430596225287445122e-01
            5.02632589623584591365101914561819e-01 -6.15613162689647830383421478472883e-01
            5.94874925538276699832351823715726e-01 -5.27013196413800844020158820057986e-01
            6.71710313354945132147122421883978e-01 -4.24763865178128252608757975394838e-01
            7.31148756888909900908402050845325e-01 -3.11513372952532174853246260681772e-01
            7.71650831674218884437266297027236e-01 -1.90194847997909699532925742460066e-01
            7.92167555248693422420558363228338e-01 -6.39503763848971590322278757412278e-02
            7.27868873940481608819652592501370e-01 6.55093843543084475289361989780446e-02
            7.04474569439530129422166737640509e-01 1.94422627548476917302977540202846e-01
            6.58437872633185761195306895388057e-01 3.17086967521766516231451760177151e-01
            5.91238440835924583538485421740916e-01 4.29559871458880637717925310425926e-01
            5.05036119077587275505436537059722e-01 5.28226367684266784330304744798923e-01
            4.02601520906993470827472947348724e-01 6.09915233826177516363031827495433e-01
            2.87226978592813986246312651928747e-01 6.72000922512989040669140194950160e-01
            1.62620724855516290974222215481859e-01 7.12487948626032263632623653393239e-01
            3.27877072165842289863668668203900e-02 7.30075025833197943647689953650115e-01
            -9.80991343101042106988884938800766e-02 7.24196891002352516331086462741951e-01
            -2.25832988943829332528778763844457e-01 6.95042472223504792516735051322030e-01
            -3.46308385496897519484349459162331e-01 6.43548816504542431360391674388666e-01
            -4.55653145596606745648671221715631e-01 5.71370972309394264954107711673714e-01
            -5.50352838684184053619219412212260e-01 4.80828794938620129872930419878685e-01
            -6.27363738704627582620787507039495e-01 3.74832384471268487136086378086475e-01
            -6.84210651966500882359412116784370e-01 2.56788552753897003633198892202927e-01
            -7.19066471903771153861839593446348e-01 1.30491325664690321906036274413054e-01
            -7.30810903784190335485959622019436e-01 8.94985234101293067800129685000127e-17
            -7.19066471903771153861839593446348e-01 -1.30491325664690155372582580639573e-01
            -6.84210651966500882359412116784370e-01 -2.56788552753896837099745198429446e-01
            -6.27363738704627915687694894586457e-01 -3.74832384471268098558027759281686e-01
            -5.50352838684184164641521874727914e-01 -4.80828794938619963339476726105204e-01
            -4.55653145596606912182124915489112e-01 -5.71370972309394153931805249158060e-01
            -3.46308385496897686017803152935812e-01 -6.43548816504542431360391674388666e-01
            -2.25832988943829499062232457617938e-01 -6.95042472223504681494432588806376e-01
            -9.80991343101043911101299954680144e-02 -7.24196891002352516331086462741951e-01
            3.27877072165840555140192691396805e-02 -7.30075025833197943647689953650115e-01
            1.62620724855516124440768521708378e-01 -7.12487948626032263632623653393239e-01
            2.87226978592813819712858958155266e-01 -6.72000922512989040669140194950160e-01
            4.02601520906993248782868022317416e-01 -6.09915233826177627385334290011087e-01
            5.05036119077587164483134074544068e-01 -5.28226367684266895352607207314577e-01
            5.91238440835924472516182959225262e-01 -4.29559871458880804251379004199407e-01
            6.58437872633185650173004432872403e-01 -3.17086967521766682764905453950632e-01
            7.04474569439530129422166737640509e-01 -1.94422627548477083836431233976327e-01
            7.27868873940481497797350129985716e-01 -6.55093843543086418179655083804391e-02
            6.58054873914941440560255614400376e-01 6.69176401405646437137164639352704e-02
            6.31114030058699038150393789692316e-01 1.98013304371850357155082633653365e-01
            5.78335303659103683315834132372402e-01 3.21002280656577154704933718676330e-01
            5.01879461976191709737804558244534e-01 4.30849385855057220862107669745455e-01
            4.04876616151641555152451701360405e-01 5.23057466573977780655013702926226e-01
            2.91298074090860781293343961806386e-01 5.93851513154716958986512054252671e-01
            1.65793754650729513455686969791714e-01 6.40333209012312054575488673435757e-01
            3.35018194152586767931012445842498e-02 6.60599588056985487227734665793832e-01
            -1.00161684243369922264754734442249e-01 6.53820942349450207053962458303431e-01
            -2.29724556780576349979128281120211e-01 6.20274790441429524356919955607736e-01
            -3.49882478971696886382858338038204e-01 5.61334515733543315540998719370691e-01
            -4.55716171364270172805532865822897e-01 4.79413139997521053903284382613492e-01
            -5.42892790156814020186004654533463e-01 3.77864533981347727742416964247241e-01
            -6.07843314333143314165397441684036e-01 2.60846109546780613452909847183037e-01
            -6.47908661802116925265693225810537e-01 1.33148614739251824889976205668063e-01
            -6.61448552530876421329253389558289e-01 8.10040852657587724496071399747515e-17
            -6.47908661802116925265693225810537e-01 -1.33148614739251658356522511894582e-01
            -6.07843314333143425187699904199690e-01 -2.60846109546780446919456153409556e-01
            -5.42892790156814131208307117049117e-01 -3.77864533981347616720114501731587e-01
            -4.55716171364270450361289022112032e-01 -4.79413139997520776347528226324357e-01
            -3.49882478971697052916312031811685e-01 -5.61334515733543315540998719370691e-01
            -2.29724556780576655290460053038260e-01 -6.20274790441429413334617493092082e-01
            -1.00161684243370088798208428215730e-01 -6.53820942349450207053962458303431e-01
            3.35018194152588086320854188215890e-02 -6.60599588056985487227734665793832e-01
            1.65793754650729208144355197873665e-01 -6.40333209012312054575488673435757e-01
            2.91298074090860337204134111743770e-01 -5.93851513154717181031116979283979e-01
            4.04876616151641222085544313813443e-01 -5.23057466573978002699618627957534e-01
            5.01879461976191820760107020760188e-01 -4.30849385855056998817502744714147e-01
            5.78335303659103461271229207341094e-01 -3.21002280656577487771841106223292e-01
            6.31114030058699038150393789692316e-01 -1.98013304371850773488716868087067e-01
            6.58054873914941440560255614400376e-01 -6.69176401405645049358383857907029e-02
            5.83103011681512795050252861983608e-01 6.81549673687621010431669787976716e-02
            5.51667777391173452805617216654355e-01 2.00790650174180573817039885398117e-01
            4.90491990427794122275884092232445e-01 3.22601657055986312805373472656356e-01
            4.02873653301332734777417954319390e-01 4.27021125103577370296648041403387e-01
            2.93536293245438228982635564534576e-01 5.08419773766535909587105379614513e-01
            1.68374315641644511920560489670606e-01 5.62409380826187299540208641701611e-01
            3.41352350995424366764119383788056e-02 5.86079352591256541593622841901379e-01
            -1.01944084802351869756265045907639e-01 5.78153634757145096223496238962980e-01
            -2.32527572705308938072477076275391e-01 5.39059504823785395899449213175103e-01
            -3.50575438976203745955473323192564e-01 4.70904537455023419756372504707542e-01
            -4.49723692588821555293776555117802e-01 3.77362984582964411384153891049209e-01
            -5.24627225527336538135614318889566e-01 2.63477695535270339810551831760677e-01
            -5.71247968942977246697978443989996e-01 1.35388255722610068021438678442792e-01
            -5.87072586490876346942968666553497e-01 7.18956563913209433432179155043526e-17
            -5.71247968942977246697978443989996e-01 -1.35388255722609901487984984669311e-01
            -5.24627225527336649157916781405220e-01 -2.63477695535270173277098137987196e-01
            -4.49723692588821499782625323859975e-01 -3.77362984582964466895305122307036e-01
            -3.50575438976203856977775785708218e-01 -4.70904537455023308734070042191888e-01
            -2.32527572705308965828052691904304e-01 -5.39059504823785395899449213175103e-01
            -1.01944084802352022411930931866664e-01 -5.78153634757145096223496238962980e-01
            3.41352350995420342205655117595597e-02 -5.86079352591256652615925304417033e-01
            1.68374315641644511920560489670606e-01 -5.62409380826187299540208641701611e-01
            2.93536293245438228982635564534576e-01 -5.08419773766535909587105379614513e-01
            4.02873653301332790288569185577217e-01 -4.27021125103577259274345578887733e-01
            4.90491990427793900231279167201137e-01 -3.22601657055986701383432091461145e-01
            5.51667777391173341783314754138701e-01 -2.00790650174180990150674119831820e-01
            5.83103011681512795050252861983608e-01 -6.81549673687619900208645162820176e-02
            5.03284555732262162131007698917529e-01 6.91748699677648681838348920791759e-02
            4.65958242607242167920844622130971e-01 2.02394226251758624357535154558718e-01
            3.94073938245164678839671523746802e-01 3.20602928666635478283097882012953e-01
            2.92962972651754083308617282455089e-01 4.15033978523114632785961930494523e-01
            1.70124283593184544294274473941186e-01 4.78683856846649213867550543000107e-01
            3.46682546873198701997687010134541e-02 5.06831943340800838981863307708409e-01
            -1.03358960071991412554837097559357e-01 4.97390623199225723194416559636011e-01
            -2.33720513598542595223861439990287e-01 4.51060115945658701708254056939040e-01
            -3.46748085831694863312435472835205e-01 3.71276543355129218237919985767803e-01
            -4.34058938805652161363468621857464e-01 2.63957088021118890797112044310779e-01
            -4.89177625975911412048446891276399e-01 1.37061142991910578370351458943333e-01
            -5.08016246466269638659696283866651e-01 6.22140470149769978297521771257672e-17
            -4.89177625975911356537295660018572e-01 -1.37061142991910661637078305830073e-01
            -4.34058938805652383408073546888772e-01 -2.63957088021118557730204656763817e-01
            -3.46748085831694807801284241577378e-01 -3.71276543355129273749071217025630e-01
            -2.33720513598542900535193211908336e-01 -4.51060115945658590685951594423386e-01
            -1.03358960071991315410322442858160e-01 -4.97390623199225723194416559636011e-01
            3.46682546873197522385723345905717e-02 -5.06831943340800838981863307708409e-01
            1.70124283593184433271972011425532e-01 -4.78683856846649213867550543000107e-01
            2.92962972651754027797466051197262e-01 -4.15033978523114743808264393010177e-01
            3.94073938245164567817369061231147e-01 -3.20602928666635644816551575786434e-01
            4.65958242607242056898542159615317e-01 -2.02394226251758846402140079590026e-01
            5.03284555732262162131007698917529e-01 -6.91748699677647294059568139346084e-02
            4.18764391731101359717115428793477e-01 6.98794176569590835823575503127358e-02
            3.73384772088007355073102644382743e-01 2.02065733776862432868881569447694e-01
            2.87543118727497160058703684626380e-01 3.12355092269134493321303125412669e-01
            1.70541706761671574277272611652734e-01 3.88795929825417607705873024315224e-01
            3.50594546409882107385058702675451e-02 4.23104695594685553672320565965492e-01
            -1.04222033393535529199880329542793e-01 4.11563502450486728978518158328370e-01
            -2.32209446938398872406494888309680e-01 3.55423017750057856911638509700424e-01
            -3.35033363806676809382167903095251e-01 2.60766934120064353130885592690902e-01
            -4.01551217128233939313020073313965e-01 1.37852706962282661740104572345444e-01
            -4.24554765364840824837244781519985e-01 5.19929634466807919670641703717000e-17
            -4.01551217128233939313020073313965e-01 -1.37852706962282717251255803603271e-01
            -3.35033363806676975915621596868732e-01 -2.60766934120064186597431898917421e-01
            -2.32209446938398816895343657051853e-01 -3.55423017750057912422789740958251e-01
            -1.04222033393535626344394984243991e-01 -4.11563502450486728978518158328370e-01
            3.50594546409881968607180624530884e-02 -4.23104695594685553672320565965492e-01
            1.70541706761671213454789608476858e-01 -3.88795929825417774239326718088705e-01
            2.87543118727497215569854915884207e-01 -3.12355092269134493321303125412669e-01
            3.73384772088007244050800181867089e-01 -2.02065733776862710424637725736829e-01
            4.18764391731101415228266660051304e-01 -6.98794176569590141934185112404521e-02
            3.29557923170118227673697219870519e-01 7.00496990201536356979161723756988e-02
            2.72574364314263295483442561817355e-01 1.98036867718339087973689061072946e-01
            1.68460221608111165858545632545429e-01 2.91781662879560921286525854156935e-01
            3.52177761728484153835871950377623e-02 3.35074757775716047802916364162229e-01
            -1.04114142706152129624896929271927e-01 3.20430382993839468763752620361629e-01
            -2.25443780463965959270922212454025e-01 2.50380683973685902454775487058214e-01
            -3.07792140487111731683711468576803e-01 1.37037890057376959829227303089283e-01
            -3.36920443216222276205940033833031e-01 1.90883587645430454603295195948770e-16
            -3.07792140487111676172560237318976e-01 -1.37037890057377015340378534347110e-01
            -2.25443780463966153559951521856419e-01 -2.50380683973685735921321793284733e-01
            -1.04114142706152199013835968344210e-01 -3.20430382993839468763752620361629e-01
            3.52177761728482557890274051715096e-02 -3.35074757775716103314067595420056e-01
            1.68460221608111165858545632545429e-01 -2.91781662879560921286525854156935e-01
            2.72574364314263239972291330559528e-01 -1.98036867718339143484840292330773e-01
            3.29557923170118227673697219870519e-01 -7.00496990201535246756137098600448e-02
            2.35375859670418963176530269265641e-01 6.91125881973782690836927145028312e-02
            1.60645687311413626341405347375257e-01 1.85395006165680414911278717227106e-01
            3.49116442992209521922752912814758e-02 2.42815819614896233336054365281598e-01
            -1.01906599104083200879600212829246e-01 2.23144325990980163521015811056714e-01
            -2.06370217329462729560773937009799e-01 1.32626085527393439145171782911348e-01
            -2.45312749695015153150734477094375e-01 1.38982892548609080542659261111276e-16
            -2.06370217329462757316349552638712e-01 -1.32626085527393383634020551653521e-01
            -1.01906599104083409046417330046097e-01 -2.23144325990980052498713348541060e-01
            3.49116442992208897422301561164204e-02 -2.42815819614896261091629980910511e-01
            1.60645687311413487563527269230690e-01 -1.85395006165680498178005564113846e-01
            2.35375859670418963176530269265641e-01 -6.91125881973782968392683301317447e-02
            1.35060083487510529387520819000201e-01 6.50415082216108803025989004709118e-02
            3.33570858977933690225903262671636e-02 1.46146942368981569426722444404732e-01
            -9.34644777335106313742585371073801e-02 1.17200748058181286603840476345795e-01
            -1.49905383303586492438341792876599e-01 1.83581147837694277313421573176427e-17
            -9.34644777335106730076219605507504e-02 -1.17200748058181258848264860716881e-01
            3.33570858977932094280305364009109e-02 -1.46146942368981624937873675662559e-01
            1.35060083487510557143096434629115e-01 -6.50415082216107831580842457697145e-02
            2.54256866845566434354175555654365e-02 4.40385811549795710972965423479764e-02
            -5.08513733691132729930473033164162e-02 6.22749716287315297809194667249766e-18
            2.54256866845566434354175555654365e-02 -4.40385811549795710972965423479764e-02
            ];
        
    case   30
        
        % DEGREE.             :          30
        % CARDIN.             :         496
        % LEBESGUE CONST.     : 9.69641e+01
        % ABS.DET.VAND.MATRIX : Inf
        % CONDITIONING VAND.  : 2.40515e+03
        % POINTS OUT DISK     : 0.00000e+00
        
        pts=[
            9.98674089884830529229020612547174e-01 5.14787547703465311887960353942617e-02
            9.88087896091077166893512639944674e-01 1.53890576704061782242760614280996e-01
            9.67027724791320375530290220922325e-01 2.54671120241228732261618006305071e-01
            9.35716819040493641423950066382531e-01 3.52752086549094789891256596092717e-01
            8.94487082228795582494740301626734e-01 4.47093792985113869242752571153687e-01
            8.43775559823185639096720933594042e-01 5.36696193991600400963193351344671e-01
            7.84119806576710431933463496534387e-01 6.20609481827422815314321269397624e-01
            7.16152188314393312040806449658703e-01 6.97944154766343527462879592349054e-01
            6.40593178698175114149648834427353e-01 7.67880446036599995096594284405001e-01
            5.58243722026864785945576841186266e-01 8.29677013552618802805227460339665e-01
            4.69976743027319954215670350095024e-01 8.82678798325547409042712843074696e-01
            3.76727893635185273613075196408317e-01 9.26323968251494878067830995860277e-01
            2.79485634851609487938617348845582e-01 9.60149873671601761238036942813778e-01
            1.79280758810735768582489413347503e-01 9.83797951573516349377257483865833e-01
            7.71754621266463047835060251600225e-02 9.97017526448526703042318786174292e-01
            -2.57479136549885363749456956838912e-02 9.99668467514313041633045031630900e-01
            -1.28398355146550846583863858541008e-01 9.91722674136101489672512343531707e-01
            -2.29687742131795408218053466953279e-01 9.73264373700382545706588643952273e-01
            -3.28542381910834735414539409248391e-01 9.44489228783661260990811570081860e-01
            -4.23914390709860644523843120623496e-01 9.05702263080471525746872885065386e-01
            -5.14792801509830422190816534566693e-01 8.57314628076332518880064981203759e-01
            -6.00214280548368006584780687262537e-01 7.99839244739719457122362200607313e-01
            -6.79273338897293132987442731973715e-01 7.33885366432199148789550235960633e-01
            -7.51131930870519992637923678557854e-01 6.60152120671231634752018635481363e-01
            -8.15028337516811252072557181236334e-01 5.79421098204563778111264582548756e-01
            -8.70285241030155254371436512883520e-01 4.92548067953864410206676893722033e-01
            -9.16316904487004757484669426048640e-01 4.00453905651266373055818803550210e-01
            -9.52635380803382503245302359573543e-01 3.04114832327518014309930549643468e-01
            -9.78855685095357808123139875533525e-01 2.04552066126201248508209573628847e-01
            -9.94699875614589057448711173492484e-01 1.02820997137360675699468970378803e-01
            -1.00000000000000000000000000000000e+00 1.22464679914735320717376402945840e-16
            -9.94699875614589057448711173492484e-01 -1.02820997137360439777076237533038e-01
            -9.78855685095357919145442338049179e-01 -2.04552066126200582374394798534922e-01
            -9.52635380803382614267604822089197e-01 -3.04114832327517792265325624612160e-01
            -9.16316904487004757484669426048640e-01 -4.00453905651266539589272497323691e-01
            -8.70285241030155143349134050367866e-01 -4.92548067953864576740130587495514e-01
            -8.15028337516811696161767031298950e-01 -5.79421098204563222999752269970486e-01
            -7.51131930870519992637923678557854e-01 -6.60152120671231412707413710450055e-01
            -6.79273338897293244009745194489369e-01 -7.33885366432198926744945310929324e-01
            -6.00214280548367895562478224746883e-01 -7.99839244739719679166967125638621e-01
            -5.14792801509830977302328847144963e-01 -8.57314628076332185813157593656797e-01
            -4.23914390709860866568448045654804e-01 -9.05702263080471414724570422549732e-01
            -3.28542381910834735414539409248391e-01 -9.44489228783661260990811570081860e-01
            -2.29687742131796296396473167078511e-01 -9.73264373700382323661983718920965e-01
            -1.28398355146550652294834549138614e-01 -9.91722674136101489672512343531707e-01
            -2.57479136549890012808372574681925e-02 -9.99668467514313041633045031630900e-01
            7.71754621266460688611132923142577e-02 -9.97017526448526703042318786174292e-01
            1.79280758810735546537884488316195e-01 -9.83797951573516349377257483865833e-01
            2.79485634851609487938617348845582e-01 -9.60149873671601761238036942813778e-01
            3.76727893635185273613075196408317e-01 -9.26323968251494878067830995860277e-01
            4.69976743027319565637611731290235e-01 -8.82678798325547631087317768106004e-01
            5.58243722026864452878669453639304e-01 -8.29677013552619135872134847886628e-01
            6.40593178698175003127346371911699e-01 -7.67880446036600217141199209436309e-01
            7.16152188314393201018503987143049e-01 -6.97944154766343638485182054864708e-01
            7.84119806576709876821951183956116e-01 -6.20609481827423481448136044491548e-01
            8.43775559823185750119023396109696e-01 -5.36696193991600289940890888829017e-01
            8.94487082228795360450135376595426e-01 -4.47093792985114368843113652474131e-01
            9.35716819040493863468554991413839e-01 -3.52752086549094290290895514772274e-01
            9.67027724791320264507987758406671e-01 -2.54671120241228954306222931336379e-01
            9.88087896091076833826605252397712e-01 -1.53890576704062670421180314406229e-01
            9.98674089884830529229020612547174e-01 -5.14787547703464132275996689713793e-02
            9.80734224128302134460000161197968e-01 5.41086149541995103939839850681892e-02
            9.68829439185171947812591497495305e-01 1.61669039574526801628095995511103e-01
            9.45164377261472066216185794473859e-01 2.67267021057104092740530631999718e-01
            9.10026300151413614081263858679449e-01 3.69620742953549463738482927510631e-01
            8.63841736511812285925770993344486e-01 4.67487769732066238415058023747406e-01
            8.07171304381984922038384411280276e-01 5.59680128261750731155643734382465e-01
            7.40702906040185515834650686883833e-01 6.45078728197131523458551782823633e-01
            6.65243377801805646498678470379673e-01 7.22646946219001717892638225748669e-01
            5.81708696119472623564661262207665e-01 7.91443209237269074129983437160263e-01
            4.91112858869731994104768091347069e-01 8.50632423812779148164509024354629e-01
            3.94555576792421536236332713087904e-01 8.99496113060420210416623376659118e-01
            2.93208924491999867179004013451049e-01 9.37441137985233430285347822064068e-01
            1.88303113039580194421063197296462e-01 9.64006897386324612675423395558028e-01
            8.11115568770168215984028847742593e-02 9.78870918931495914705465111183003e-01
            -2.70645837094067760741911143895777e-02 9.81852773534526046539383514755173e-01
            -1.34912196912254866987268542288803e-01 9.72916265519861545030266825051513e-01
            -2.41122158801493319257858161108743e-01 9.52169871989085869756763713667169e-01
            -3.44405224315613767149812929346808e-01 9.19865426055853308007215218822239e-01
            -4.43507676950223528322680976998527e-01 8.76395059933030906584860986185959e-01
            -5.37226547178078273070411796652479e-01 8.22286444978831410068664808932226e-01
            -6.24424214869557792084719949343707e-01 7.58196386481326478623543607682223e-01
            -7.04042218459978497158147092704894e-01 6.84902850931981888038535544183105e-01
            -7.75114103239158636071692853874993e-01 6.03295522566312136802935128798708e-01
            -8.36777152802405610465541485609720e-01 5.14365003802459530568569334718632e-01
            -8.88282861259001577103333602281054e-01 4.19190790669745183549821376800537e-01
            -9.29006019079765765766865115438122e-01 3.18928169189193255750325306507875e-01
            -9.58452302293805402655380021315068e-01 2.14794191766231740148285211944312e-01
            -9.76264272911894326334447669069050e-01 1.08052903823151219553366786385595e-01
            -9.82225717739463766164931257662829e-01 1.20287958126984602507518876150635e-16
            -9.76264272911894326334447669069050e-01 -1.08052903823150969753186245725374e-01
            -9.58452302293805402655380021315068e-01 -2.14794191766231518103680286913004e-01
            -9.29006019079765876789167577953776e-01 -3.18928169189193089216871612734394e-01
            -8.88282861259001799147938527312363e-01 -4.19190790669744572927157832964440e-01
            -8.36777152802405499443239023094065e-01 -5.14365003802459752613174259749940e-01
            -7.75114103239158858116297778906301e-01 -6.03295522566312025780632666283054e-01
            -7.04042218459978719202752017736202e-01 -6.84902850931981777016233081667451e-01
            -6.24424214869558014129324874375015e-01 -7.58196386481326367601241145166568e-01
            -5.37226547178078495115016721683787e-01 -8.22286444978831299046362346416572e-01
            -4.43507676950223750367285902029835e-01 -8.76395059933030795562558523670305e-01
            -3.44405224315613989194417854378116e-01 -9.19865426055853196984912756306585e-01
            -2.41122158801493319257858161108743e-01 -9.52169871989085869756763713667169e-01
            -1.34912196912254894742844157917716e-01 -9.72916265519861545030266825051513e-01
            -2.70645837094068003603197780648770e-02 -9.81852773534526046539383514755173e-01
            8.11115568770159334199831846490270e-02 -9.78870918931496025727767573698657e-01
            1.88303113039580166665487581667549e-01 -9.64006897386324612675423395558028e-01
            2.93208924491999867179004013451049e-01 -9.37441137985233430285347822064068e-01
            3.94555576792420870102517937993980e-01 -8.99496113060420432461228301690426e-01
            4.91112858869731994104768091347069e-01 -8.50632423812779148164509024354629e-01
            5.81708696119471957430846487113740e-01 -7.91443209237269518219193287222879e-01
            6.65243377801805646498678470379673e-01 -7.22646946219001828914940688264323e-01
            7.40702906040185737879255611915141e-01 -6.45078728197131301413946857792325e-01
            8.07171304381984477949174561217660e-01 -5.59680128261751397289458509476390e-01
            8.63841736511812396948073455860140e-01 -4.67487769732066071881604329973925e-01
            9.10026300151413392036658933648141e-01 -3.69620742953550185383448933862383e-01
            9.45164377261471844171580869442550e-01 -2.67267021057104814385496638351469e-01
            9.68829439185172058834893960010959e-01 -1.61669039574526662850217917366535e-01
            9.80734224128302134460000161197968e-01 -5.41086149542001904055865679765702e-02
            9.48469057278173210967509021429578e-01 5.62867571345630271495430463346565e-02
            9.35154630783802010007832450355636e-01 1.68070128715613109626758614467690e-01
            9.08712683157457901117481924302410e-01 2.77494164103761709050388617470162e-01
            8.69514401382350587965675003943034e-01 3.83022789702603005945746872384916e-01
            8.18110043410909315575452183111338e-01 4.83174614930329371365047563813278e-01
            7.55221213749310615881427111162338e-01 5.76543727696251839809349348797696e-01
            6.81730733711988889922395173925906e-01 6.61819430324756430294996789598372e-01
            5.98670248545548955299011595343472e-01 7.37804638877584295642009237781167e-01
            5.07205745390898576907545702852076e-01 8.03432687588285010527044960326748e-01
            4.08621185379665907699830995625234e-01 8.57782302511417293899853575567249e-01
            3.04300479634387444072274320205906e-01 9.00090534189285640387367948278552e-01
            1.95708062189920400930631672054005e-01 9.29763467789920250439195115177426e-01
            8.43683325496695640799416082700191e-02 9.46384560369441074634266897191992e-01
            -2.81557435419126853015647782285669e-02 9.49720488221915681847917767299805e-01
            -1.40284574712317700040387080662185e-01 9.39724422232739553528801934589865e-01
            -2.50444117961341750078219092756626e-01 9.16536685256753580475219678191934e-01
            -3.57087974774465854999050407059258e-01 8.80482782292954513359006796235917e-01
            -4.58719099168250432629889701274806e-01 8.32068831107824036230624642485054e-01
            -5.53910812934379159777620316162938e-01 7.71974457451311657507631025509909e-01
            -6.41326833074385538324690969602671e-01 7.01043254601063092756874084443552e-01
            -7.19740030283783194242630543158157e-01 6.20270941161981781419854087289423e-01
            -7.88049655157600725807753860863158e-01 5.30791383359657142904097781865858e-01
            -8.45296790299153277814525608846452e-01 4.33860678044025060984267838648520e-01
            -8.90677811418321918601748166111065e-01 3.30839519842989593367832412695861e-01
            -9.23555668455018241580489757325267e-01 2.23174099992530794445144692872418e-01
            -9.43468828365598977114814260858111e-01 1.12375804981836496798663915797079e-01
            -9.50137754035104031835601290367777e-01 1.16358315922814529845820077810224e-16
            -9.43468828365598977114814260858111e-01 -1.12375804981836691087693225199473e-01
            -9.23555668455018463625094682356576e-01 -2.23174099992530156066905533407407e-01
            -8.90677811418322029624050628626719e-01 -3.30839519842989426834378718922380e-01
            -8.45296790299153388836828071362106e-01 -4.33860678044024838939662913617212e-01
            -7.88049655157600725807753860863158e-01 -5.30791383359657031881795319350203e-01
            -7.19740030283783638331840393220773e-01 -6.20270941161981226308341774711153e-01
            -6.41326833074385982413900819665287e-01 -7.01043254601062759689966696896590e-01
            -5.53910812934379381822225241194246e-01 -7.71974457451311657507631025509909e-01
            -4.58719099168250266096436007501325e-01 -8.32068831107824147252927105000708e-01
            -3.57087974774466021532504100832739e-01 -8.80482782292954402336704333720263e-01
            -2.50444117961341805589370324014453e-01 -9.16536685256753580475219678191934e-01
            -1.40284574712318144129596930724801e-01 -9.39724422232739442506499472074211e-01
            -2.81557435419129177545105591207175e-02 -9.49720488221915681847917767299805e-01
            8.43683325496689118239146409905516e-02 -9.46384560369441185656569359707646e-01
            1.95708062189920817264265906487708e-01 -9.29763467789920139416892652661772e-01
            3.04300479634387610605728013979387e-01 -9.00090534189285640387367948278552e-01
            4.08621185379665463610621145562618e-01 -8.57782302511417404922156038082903e-01
            5.07205745390898576907545702852076e-01 -8.03432687588285010527044960326748e-01
            5.98670248545548400187499282765202e-01 -7.37804638877584739731219087843783e-01
            6.81730733711988667877790248894598e-01 -6.61819430324756652339601714629680e-01
            7.55221213749310615881427111162338e-01 -5.76543727696251839809349348797696e-01
            8.18110043410908982508544795564376e-01 -4.83174614930329704431954951360240e-01
            8.69514401382350587965675003943034e-01 -3.83022789702603116968049334900570e-01
            9.08712683157458012139784386818064e-01 -2.77494164103761542516934923696681e-01
            9.35154630783801898985529987839982e-01 -1.68070128715613414938090386385738e-01
            9.48469057278173210967509021429578e-01 -5.62867571345629993939674307057430e-02
            9.06968735135388670620670836797217e-01 5.82293247685658071910452804331726e-02
            8.92076333578969649096279681543820e-01 1.73731850402834175906008340461995e-01
            8.62536063287965393264755675772903e-01 2.86381703856564251431393586244667e-01
            8.18832974683869285748016864090459e-01 3.94329177650419082645782964391401e-01
            7.61684671273323510298780547600472e-01 4.95801777249072650466388267886941e-01
            6.92029526618379242641765358712291e-01 5.89133325372476202019811353238765e-01
            6.11011276268549785584127675974742e-01 6.72791320580733764877834346407326e-01
            5.19960237654709445109801890794188e-01 7.45402100905375730732771444309037e-01
            4.20371466313655350877098726414260e-01 8.05773399340904750154379598825471e-01
            3.13880207117527842974880059045972e-01 8.52913920836064098907058905751910e-01
            2.02235043598216812643642015245860e-01 8.86049619331173432534853873221437e-01
            8.72691862541128404728851819527335e-02 9.04636407573028766826439550641226e-01
            -2.91296287155969925442011714267210e-02 9.08369091012558249609298854920780e-01
            -1.45050135987128570036475139204413e-01 8.97186379090880725684087337867822e-01
            -2.58588924035878964247103795059957e-01 8.71271891628587091815916210180148e-01
            -3.67881689101036912781239607284078e-01 8.31051143793363533696094691549661e-01
            -4.71133847001794281439401856914628e-01 7.77184559152702125750522554881172e-01
            -5.66650000159980238301216104446212e-01 7.10556625537180130969261426798766e-01
            -6.52861775981424141690467877197079e-01 6.32261371774735847495207963220309e-01
            -7.28353579490590985479059327190043e-01 5.43584403767559454223601278499700e-01
            -7.91885837360943978247007635218324e-01 4.45981794878721915509345308237243e-01
            -8.42415351674696055717106446536491e-01 3.41056177247807901231624327920144e-01
            -8.79112429203779077724334456434008e-01 2.30530426615491446096228855822119e-01
            -9.01374504949710830814524342713412e-01 1.16219372751506649921182656726160e-01
            -9.08836036244211609158583087264560e-01 1.11300314273624172060452448215981e-16
            -9.01374504949710830814524342713412e-01 -1.16219372751506441754365539509308e-01
            -8.79112429203779077724334456434008e-01 -2.30530426615491224051623930790811e-01
            -8.42415351674696166739408909052145e-01 -3.41056177247807734698170634146663e-01
            -7.91885837360944311313915022765286e-01 -4.45981794878721360397832995658973e-01
            -7.28353579490591207523664252221351e-01 -5.43584403767559454223601278499700e-01
            -6.52861775981424252712770339712733e-01 -6.32261371774735736472905500704655e-01
            -5.66650000159980460345821029477520e-01 -7.10556625537179908924656501767458e-01
            -4.71133847001794781039762938235071e-01 -7.77184559152701792683615167334210e-01
            -3.67881689101037301359298226088868e-01 -8.31051143793363422673792229034007e-01
            -2.58588924035878964247103795059957e-01 -8.71271891628587091815916210180148e-01
            -1.45050135987128181458416520399624e-01 -8.97186379090880725684087337867822e-01
            -2.91296287155970098914359311947919e-02 -9.08369091012558249609298854920780e-01
            8.72691862541122159724338303021796e-02 -9.04636407573028766826439550641226e-01
            2.02235043598216618354612705843465e-01 -8.86049619331173432534853873221437e-01
            3.13880207117527842974880059045972e-01 -8.52913920836064098907058905751910e-01
            4.20371466313655184343645032640779e-01 -8.05773399340904861176682061341126e-01
            5.19960237654709445109801890794188e-01 -7.45402100905375730732771444309037e-01
            6.11011276268549563539522750943433e-01 -6.72791320580734097944741733954288e-01
            6.92029526618378465485648121102713e-01 -5.89133325372476979175928590848343e-01
            7.61684671273323621321083010116126e-01 -4.95801777249072317399480880339979e-01
            8.18832974683869174725714401574805e-01 -3.94329177650419304690387889422709e-01
            8.62536063287965171220150750741595e-01 -2.86381703856564917565208361338591e-01
            8.92076333578969649096279681543820e-01 -1.73731850402834508972915728008957e-01
            9.06968735135388670620670836797217e-01 -5.82293247685666190416320375788928e-02
            8.58026083442135378831494563200977e-01 5.99990285794849767531111695006985e-02
            8.41325581718138426623454506625421e-01 1.78829272895038693391711603908334e-01
            8.08249634539662809018523148552049e-01 2.94178808828973514799542954278877e-01
            7.59442027595205404466582876921166e-01 4.03802488872487708171377107646549e-01
            6.95852745436109976218119754776126e-01 5.05566612788622138374705627938965e-01
            6.18719481107866897673375206068158e-01 5.97490457660324603139656574057881e-01
            5.29543545862837805593414941540686e-01 6.77784830408991179062638821051223e-01
            4.30060647844444310372580275725340e-01 7.44886892402564115833740743255476e-01
            3.22207108502494787849457225092920e-01 7.97490578331803035005975743843010e-01
            2.08082174298698352465919469977962e-01 8.34572017285901135430492558953119e-01
            8.99071572621424619509156173080555e-02 8.55409461235128287803775037900778e-01
            -3.00178003226450190732421674510988e-02 8.59597333035254429489668837049976e-01
            -1.49358495568894383831448635646666e-01 8.47054120525323139823115070612403e-01
            -2.65792097591665665845539479050785e-01 8.18023963069147930227131837455090e-01
            -3.77052358768845241598910433822311e-01 7.73071899660298211820474989508511e-01
            -4.80973724673290137232584129378665e-01 7.13072871080813297517408955172868e-01
            -5.75533484126472649755612565058982e-01 6.39194690174109125813117771031102e-01
            -6.58891138970768230898045203502988e-01 5.52875311696349847068177041364834e-01
            -7.29424227272560066204221129737562e-01 4.55794844162766610295989266887773e-01
            -7.85759902698252243880006062681787e-01 3.49842848446506426984825566250947e-01
            -8.26801655406564917072387288499158e-01 2.37081559625576920868894603700028e-01
            -8.51750654365332593442872166633606e-01 1.19705747922812230643607733782119e-01
            -8.60121295688888398700555626419373e-01 1.05334479164387127248111563216623e-16
            -8.51750654365332593442872166633606e-01 -1.19705747922812036354578424379724e-01
            -8.26801655406565139116992213530466e-01 -2.37081559625576338001806675492844e-01
            -7.85759902698252576946913450228749e-01 -3.49842848446505871873313253672677e-01
            -7.29424227272560177226523592253216e-01 -4.55794844162766499273686804372119e-01
            -6.58891138970768452942650128534297e-01 -5.52875311696349625023572116333526e-01
            -5.75533484126472871800217490090290e-01 -6.39194690174109014790815308515448e-01
            -4.80973724673290636832945210699108e-01 -7.13072871080813075472804030141560e-01
            -3.77052358768845408132364127595793e-01 -7.73071899660298100798172526992857e-01
            -2.65792097591665832378993172824266e-01 -8.18023963069147819204829374939436e-01
            -1.49358495568894411587024251275579e-01 -8.47054120525323139823115070612403e-01
            -3.00178003226458066377002609215197e-02 -8.59597333035254318467366374534322e-01
            8.99071572621420594950691906888096e-02 -8.55409461235128398826077500416432e-01
            2.08082174298697963887860851173173e-01 -8.34572017285901135430492558953119e-01
            3.22207108502494787849457225092920e-01 -7.97490578331803035005975743843010e-01
            4.30060647844444310372580275725340e-01 -7.44886892402564115833740743255476e-01
            5.29543545862838027638019866571994e-01 -6.77784830408990957018033896019915e-01
            6.18719481107866675628770281036850e-01 -5.97490457660324825184261499089189e-01
            6.95852745436109865195817292260472e-01 -5.05566612788622360419310552970273e-01
            7.59442027595205404466582876921166e-01 -4.03802488872487708171377107646549e-01
            8.08249634539662809018523148552049e-01 -2.94178808828973403777240491763223e-01
            8.41325581718138315601152044109767e-01 -1.78829272895039192992072685228777e-01
            8.58026083442135489853797025716631e-01 -5.99990285794845118472196077163971e-02
            8.02667397994056175392074692354072e-01 6.16244078572465159293614078706014e-02
            7.83853554494414850317696163983783e-01 1.83428799681991744341402750251291e-01
            7.46666848040889452597923536814051e-01 3.00933775909232370526780186992255e-01
            6.91978903514759879911366624583025e-01 4.11385119488801520581944259902230e-01
            6.21071559984366028395186276611639e-01 5.12193944541411760873472758248681e-01
            5.35606825483783022257000538957072e-01 6.00997377649428066170855800010031e-01
            4.37587920953154407843754825080396e-01 6.75713941607098078634408011566848e-01
            3.29312326437707303394830660181469e-01 7.34592343482076914895628760859836e-01
            2.13317930102745106912820460820512e-01 7.76252523437434782671573429979617e-01
            9.23235422860682747314697849105869e-02 7.99718002164548802390697801456554e-01
            -3.08348311119883249087347820704963e-02 8.04438768730473263701696851057932e-01
            -1.53270462203170670933971564409148e-01 7.90304172368039070661893674696330e-01
            -2.72113563566330707299556479483726e-01 7.57645516036053123798410524614155e-01
            -3.84578553632257236216673845774494e-01 7.07228290958744065797247912996681e-01
            -4.88029348354711012270001901924843e-01 6.40234234160264925606043107109144e-01
            -5.80041148786224813882483886118280e-01 5.58233629550443088973565863852855e-01
            -6.58457276310269956631771037791623e-01 4.63148501800843270803653695111279e-01
            -7.21439723360110418681756527803373e-01 3.57207565715498553959861283146893e-01
            -7.67512234758344735752189080812968e-01 2.42893987044875664382814761665941e-01
            -7.95594909887048173935397699096939e-01 1.22887179185318190510756153344119e-01
            -8.05029514642975563276650063926354e-01 4.56092602896445209913418403229718e-16
            -7.95594909887048173935397699096939e-01 -1.22887179185317982343939036127267e-01
            -7.67512234758344735752189080812968e-01 -2.42893987044875803160692839810508e-01
            -7.21439723360110418681756527803373e-01 -3.57207565715498331915256358115585e-01
            -6.58457276310270178676375962822931e-01 -4.63148501800842826714443845048663e-01
            -5.80041148786224924904786348633934e-01 -5.58233629550442977951263401337201e-01
            -4.88029348354710956758850670667016e-01 -6.40234234160265036628345569624798e-01
            -3.84578553632257014172068920743186e-01 -7.07228290958744176819550375512335e-01
            -2.72113563566330707299556479483726e-01 -7.57645516036053123798410524614155e-01
            -1.53270462203171253801059492616332e-01 -7.90304172368038959639591212180676e-01
            -3.08348311119885226672110434265051e-02 -8.04438768730473263701696851057932e-01
            9.23235422860682608536819770961301e-02 -7.99718002164548802390697801456554e-01
            2.13317930102744746090337457644637e-01 -7.76252523437434782671573429979617e-01
            3.29312326437707136861376966407988e-01 -7.34592343482077025917931223375490e-01
            4.37587920953154574377208518853877e-01 -6.75713941607097967612105549051194e-01
            5.35606825483782800212395613925764e-01 -6.00997377649428288215460725041339e-01
            6.21071559984365473283673964033369e-01 -5.12193944541412315984985070826951e-01
            6.91978903514759546844459237036062e-01 -4.11385119488801964671154109964846e-01
            7.46666848040889452597923536814051e-01 -3.00933775909232537060233880765736e-01
            7.83853554494414850317696163983783e-01 -1.83428799681991633319100287735637e-01
            8.02667397994056175392074692354072e-01 -6.16244078572468489962687954175635e-02
            7.41576270030736450777908430609386e-01 6.31174424586802701453436270639941e-02
            7.20242470926468314473822829313576e-01 1.87536553474142775321809040178778e-01
            6.78188607275811539132348571001785e-01 3.06560579293097601460971191045246e-01
            6.16624492168718840723329321917845e-01 4.16765415399231786697242796435603e-01
            5.37321213107318951252011629549088e-01 5.14980669307211647023336809070315e-01
            4.42560181043091527275379348793649e-01 5.98380866982167636258793663728284e-01
            3.35067498337547675646419520489872e-01 6.64566736583348749434208002639934e-01
            2.17935533760691246829566125597921e-01 7.11634231146638485121513895137468e-01
            9.45339606717670866142810837118304e-02 7.38229304549022469217334219138138e-01
            -3.15871823481345473383363753328013e-02 7.43586864950242620864173659356311e-01
            -1.56799619642518817119736240783823e-01 7.27552785092041354175762535305694e-01
            -2.77501217364136520959760900950641e-01 6.90588336258763368924462611175841e-01
            -3.90219610307382669400766417311388e-01 6.33756918342339714556032959080767e-01
            -4.91712095533141491099371478412650e-01 5.58693467763523465841046800051117e-01
            -5.79058919028370810977435212407727e-01 4.67557423327786825240082180243917e-01
            -6.49747271713073559773476972623030e-01 3.62970603102568012410245046339696e-01
            -7.01743578382471255849850422237068e-01 2.47941779485001290161960696423193e-01
            -7.33551999963122147718763699231204e-01 1.25780122298112945200543322243902e-01
            -7.44257466079598417607599003531504e-01 9.11452523575900014208657000369876e-17
            -7.33551999963122147718763699231204e-01 -1.25780122298112750911514012841508e-01
            -7.01743578382471255849850422237068e-01 -2.47941779485001123628507002649712e-01
            -6.49747271713073781818081897654338e-01 -3.62970603102567568321035196277080e-01
            -5.79058919028370810977435212407727e-01 -4.67557423327786936262384642759571e-01
            -4.91712095533141657632825172186131e-01 -5.58693467763523465841046800051117e-01
            -3.90219610307383057978825036116177e-01 -6.33756918342339492511428034049459e-01
            -2.77501217364136687493214594724122e-01 -6.90588336258763257902160148660187e-01
            -1.56799619642518678341858162639255e-01 -7.27552785092041354175762535305694e-01
            -3.15871823481348942830315706942201e-02 -7.43586864950242509841871196840657e-01
            9.45339606717665592583443867624737e-02 -7.38229304549022469217334219138138e-01
            2.17935533760690913762658738050959e-01 -7.11634231146638485121513895137468e-01
            3.35067498337547675646419520489872e-01 -6.64566736583348749434208002639934e-01
            4.42560181043091693808833042567130e-01 -5.98380866982167525236491201212630e-01
            5.37321213107318729207406704517780e-01 -5.14980669307211869067941734101623e-01
            6.16624492168718507656421934370883e-01 -4.16765415399232230786452646498219e-01
            6.78188607275811539132348571001785e-01 -3.06560579293097823505576116076554e-01
            7.20242470926468314473822829313576e-01 -1.87536553474142747566233424549864e-01
            7.41576270030736450777908430609386e-01 -6.31174424586805893344632067964994e-02
            6.75243936889308615789673240215052e-01 6.44779781833822174252901504587498e-02
            6.50838861679211677646605949121295e-01 1.91103532422865651785315321831149e-01
            6.02910774263913928905367356492206e-01 3.10822107085189647257550404901849e-01
            5.33191920598018009869178968074266e-01 4.19306760958353841317602928029373e-01
            4.44202121703710872679948806762695e-01 5.12636575997373444835147893172689e-01
            3.39157700773692227791400455316762e-01 5.87438369518277103686898499290692e-01
            2.21855236870941968652104492321087e-01 6.41008609809047280592153583711479e-01
            9.65343466694946056305681736375846e-02 6.71411128809675794570921425474808e-01
            -3.22755463383755866746405160938593e-02 6.77547100270489366380388673860580e-01
            -1.59918917008460836903793733654311e-01 6.59194754195776555505403848655988e-01
            -2.81782401353186551240526114270324e-01 6.17017392189248559120073878148105e-01
            -3.93461535536122009037995894686901e-01 5.52539414005866369450359343318269e-01
            -4.90919944670750674209358521693503e-01 4.68091221772910792697786064309184e-01
            -5.70635227925538335291832936491119e-01 3.66724993185299941167443193990039e-01
            -6.29726267267512462844081255752826e-01 2.52104367851322008764469728703261e-01
            -6.66057358574652869087628914712695e-01 1.28372033811674002290459384312271e-01
            -6.78315401547384344560498448117869e-01 8.30696785317355814458482906567160e-17
            -6.66057358574652980109931377228349e-01 -1.28372033811673558201249534249655e-01
            -6.29726267267512573866383718268480e-01 -2.52104367851321897742167266187607e-01
            -5.70635227925538557336437861522427e-01 -3.66724993185299552589384575185250e-01
            -4.90919944670750729720509752951330e-01 -4.68091221772910737186634833051357e-01
            -3.93461535536122175571449588460382e-01 -5.52539414005866258428056880802615e-01
            -2.81782401353186440218223651754670e-01 -6.17017392189248670142376340663759e-01
            -1.59918917008460836903793733654311e-01 -6.59194754195776555505403848655988e-01
            -3.22755463383759058637600958263647e-02 -6.77547100270489366380388673860580e-01
            9.65343466694942864414485939050792e-02 -6.71411128809675905593223887990462e-01
            2.21855236870941968652104492321087e-01 -6.41008609809047391614456046227133e-01
            3.39157700773692227791400455316762e-01 -5.87438369518277103686898499290692e-01
            4.44202121703710539613041419215733e-01 -5.12636575997373777902055280719651e-01
            5.33191920598017787824574043042958e-01 -4.19306760958354118873359084318508e-01
            6.02910774263913817883064893976552e-01 -3.10822107085189758279852867417503e-01
            6.50838861679211677646605949121295e-01 -1.91103532422865735052042168717890e-01
            6.75243936889308504767370777699398e-01 -6.44779781833827447812268474081066e-02
            6.04036097346922984385741983714979e-01 6.56928844410248347074343655549455e-02
            5.75792040772884927690711265313439e-01 1.94006927059009209868278844624001e-01
            5.20624588319196446306591496977489e-01 3.13249421390926818808964071649825e-01
            4.41113308748372623391276192705845e-01 4.17844720930330926211837549999473e-01
            3.40976061122705009776012730071670e-01 5.02902065720084889832719454716425e-01
            2.24895151846612767476685235124023e-01 5.64444268852268726810450516495621e-01
            9.82983952231812618816064741622540e-02 5.99593685307667767503403410955798e-01
            -3.28946851100663240075050453015137e-02 6.06706767438597860397919703245861e-01
            -1.62549646527384239469427029689541e-01 5.85450915430239637871068225649651e-01
            -2.84603967134037738606622269799118e-01 5.36820029298321510502489672944648e-01
            -3.93350522552094294947977459742106e-01 4.63088035229023864403075094742235e-01
            -4.83704444713320635962361393467290e-01 3.67702559317801602745134914584924e-01
            -5.51440884638630168801398667710600e-01 2.55123720404920706350537784601329e-01
            -5.93392561680760821651858805125812e-01 1.30615579875555803956999056936183e-01
            -6.07597862047162928789134639373515e-01 7.44092776924833103352316049391872e-17
            -5.93392561680760821651858805125812e-01 -1.30615579875555665179120978791616e-01
            -5.51440884638630168801398667710600e-01 -2.55123720404920817372840247116983e-01
            -4.83704444713320858006966318498598e-01 -3.67702559317801269678227527037961e-01
            -3.93350522552094128414523765968625e-01 -4.63088035229023919914226326000062e-01
            -2.84603967134038071673529657346080e-01 -5.36820029298321288457884747913340e-01
            -1.62549646527384517025183185978676e-01 -5.85450915430239637871068225649651e-01
            -3.28946851100667403411392797352164e-02 -6.06706767438597749375617240730207e-01
            9.82983952231811369815162038321432e-02 -5.99593685307667767503403410955798e-01
            2.24895151846612489920929078834888e-01 -5.64444268852268837832752979011275e-01
            3.40976061122704954264861498813843e-01 -5.02902065720085000855021917232079e-01
            4.41113308748372623391276192705845e-01 -4.17844720930330926211837549999473e-01
            5.20624588319196446306591496977489e-01 -3.13249421390926818808964071649825e-01
            5.75792040772884927690711265313439e-01 -1.94006927059009154357127613366174e-01
            6.04036097346922873363439521199325e-01 -6.56928844410252787966442156175617e-02
            5.28223417941010908727150763297686e-01 6.67301360691667372337931851689063e-02
            4.95033197921938006302866597252432e-01 1.95997508342001108827545863277919e-01
            4.30738221472681037660379388398724e-01 3.12949636337294723187341105585801e-01
            3.39378378423929649709833711312967e-01 4.10237987733263698153507448296295e-01
            2.26694143712436180226887927346979e-01 4.81749577610171619834744660693104e-01
            9.97658822287496444003451756543654e-02 5.22991069774821903948236467840616e-01
            -3.34310365486181829131062670512620e-02 5.31371109598911428584244731609942e-01
            -1.64527360348884210683451101431274e-01 5.06363148360661985414310493069934e-01
            -2.85285825009125582063518322684104e-01 4.49538528237520496055878993502120e-01
            -3.88118732076171979450407434342196e-01 3.64467749098158211307207920981455e-01
            -4.66564711806024545737159314739984e-01 2.56496120864340981793105811448186e-01
            -5.15694714788123897974969622737262e-01 1.32407898029871878842200771941862e-01
            -5.32421722247593320886949186387938e-01 6.52028557947036238700939718552579e-17
            -5.15694714788124008997272085252916e-01 -1.32407898029871518019717768765986e-01
            -4.66564711806024545737159314739984e-01 -2.56496120864341092815408273963840e-01
            -3.88118732076172257006163590631331e-01 -3.64467749098157989262602995950147e-01
            -2.85285825009125304507762166394969e-01 -4.49538528237520662589332687275601e-01
            -1.64527360348884432728056026462582e-01 -5.06363148360661985414310493069934e-01
            -3.34310365486180788296977084428363e-02 -5.31371109598911428584244731609942e-01
            9.97658822287493946001646349941439e-02 -5.22991069774822014970538930356270e-01
            2.26694143712435736137678077284363e-01 -4.81749577610171786368198354466585e-01
            3.39378378423929427665228786281659e-01 -4.10237987733263864686961142069777e-01
            4.30738221472680982149228157140897e-01 -3.12949636337294834209643568101455e-01
            4.95033197921938006302866597252432e-01 -1.95997508342001081071970247649006e-01
            5.28223417941010908727150763297686e-01 -6.67301360691669454006103023857577e-02
            4.47988547723629171315451458212920e-01 6.75234090634038580658327077799186e-02
            4.08182799293024312081712423605495e-01 1.96570475973328162577757893814123e-01
            3.32108217864523602713688887888566e-01 3.08151393457696820554758687649155e-01
            2.26524363845851173238088449579664e-01 3.92351707333232602170625114013092e-01
            1.00812826013677567238424614970427e-01 4.41689850205102818581082146920380e-01
            -3.38563738196112490319578114394972e-02 4.51781911562267934900916088736267e-01
            -1.65517286262778479111190677031118e-01 4.21731167464862166660566344944527e-01
            -2.82471261460850719959836396810715e-01 3.54207758401458350228097060607979e-01
            -3.74326425473413049171966804351541e-01 2.55211435588939716812006963664317e-01
            -4.32921043878201072807598848157795e-01 1.33538456747406109048625921786879e-01
            -4.53048727691702235453874436643673e-01 5.54824674225423980031191680070977e-17
            -4.32921043878201183829901310673449e-01 -1.33538456747405803737294149868831e-01
            -3.74326425473412993660815573093714e-01 -2.55211435588939827834309426179971e-01
            -2.82471261460850830982138859326369e-01 -3.54207758401458239205794598092325e-01
            -1.65517286262778395844463830144377e-01 -4.21731167464862166660566344944527e-01
            -3.38563738196115612821834872647742e-02 -4.51781911562267934900916088736267e-01
            1.00812826013677456216122152454773e-01 -4.41689850205102818581082146920380e-01
            2.26524363845850812415605446403788e-01 -3.92351707333232824215230039044400e-01
            3.32108217864523713735991350404220e-01 -3.08151393457696709532456225133501e-01
            4.08182799293024256570561192347668e-01 -1.96570475973328273600060356329777e-01
            4.47988547723629115804300226955093e-01 -6.75234090634042327661035187702510e-02
            3.63404975307300426301537754625315e-01 6.79321631551589033559679364771000e-02
            3.14325119695566146393872486441978e-01 1.94621874406261802237239066926122e-01
            2.22793914933330727823346251170733e-01 2.95026823081764089096168390824459e-01
            1.01173157415648473644864679954480e-01 3.55586764500012253442662313318579e-01
            -3.41115956308356282900007272473886e-02 3.68122742998252039381412714647013e-01
            -1.64789388668498681944640793517465e-01 3.30941705216041381909519714099588e-01
            -2.73211461636956476350945877129561e-01 2.49065156333110215847170820779866e-01
            -3.44734812794371792143977017985890e-01 1.33550977969718320803593769596773e-01
            -3.69699817242365891267752431303961e-01 4.52751697831224834629008448656201e-17
            -3.44734812794371847655128249243717e-01 -1.33550977969718098758988844565465e-01
            -2.73211461636956365328643414613907e-01 -2.49065156333110243602746436408779e-01
            -1.64789388668499098278275027951167e-01 -3.30941705216041159864914789068280e-01
            -3.41115956308356421677885350618453e-02 -3.68122742998252039381412714647013e-01
            1.01173157415648390378137833067740e-01 -3.55586764500012253442662313318579e-01
            2.22793914933330644556619404283992e-01 -2.95026823081764200118470853340114e-01
            3.14325119695566035371570023926324e-01 -1.94621874406261968770692760699603e-01
            3.63404975307300426301537754625315e-01 -6.79321631551588062114532817759027e-02
            2.74353904982108542931484862492653e-01 6.76221642144683027231266692069767e-02
            2.11502731673683858071299823677691e-01 1.87375069757291984329228284877900e-01
            1.00198831423046239019747360998736e-01 2.64202604933101103945602972089546e-01
            -3.40594135797908162399671994080563e-02 2.80504507305285755158763549843570e-01
            -1.60515057391927395968878045096062e-01 2.32546207499599116852451174963790e-01
            -2.50198635971714933301512928665034e-01 1.31314374041357762035175937853637e-01
            -2.82564722270810642079652552638436e-01 -9.08797459766557825299616705420555e-17
            -2.50198635971715099834966622438515e-01 -1.31314374041357484479419781564502e-01
            -1.60515057391927451480029276353889e-01 -2.32546207499599089096875559334876e-01
            -3.40594135797910105289965088104509e-02 -2.80504507305285755158763549843570e-01
            1.00198831423046239019747360998736e-01 -2.64202604933101103945602972089546e-01
            2.11502731673683774804572976790951e-01 -1.87375069757292067595955131764640e-01
            2.74353904982108542931484862492653e-01 -6.76221642144683304787022848358902e-02
            1.80241196270942205526210955213173e-01 6.56024304311553785318267273396486e-02
            9.59043373780024965835622197118937e-02 1.66111185004927219832637774743489e-01
            -3.33072268320891914927805999013799e-02 1.88894669994710662219716823528870e-01
            -1.46933969438852951583385220146738e-01 1.23292239563555297565677904003678e-01
            -1.91808674756004937655973208165960e-01 2.34897879588637164957868267255682e-17
            -1.46933969438853034850112067033479e-01 -1.23292239563555186543375441488024e-01
            -3.33072268320891984316745038086083e-02 -1.88894669994710662219716823528870e-01
            9.59043373780023439278963337528694e-02 -1.66111185004927303099364621630230e-01
            1.80241196270942205526210955213173e-01 -6.56024304311553646540389195251919e-02
            7.89416583238923691423494233276870e-02 5.73544720035762053966799101090146e-02
            -3.01530303514458211666671161310660e-02 9.28014851085905839722656196499884e-02
            -9.75772559448930820735768065787852e-02 1.19497674162495349050160692567422e-17
            -3.01530303514458454527957798063653e-02 -9.28014851085905700944778118355316e-02
            7.89416583238923691423494233276870e-02 -5.73544720035762262133616218306997e-02
            -0.00000000000000000000000000000000e+00 0.00000000000000000000000000000000e+00
            ];
        
    case   31
        
        % DEGREE.             :          31
        % CARDIN.             :         528
        % LEBESGUE CONST.     : 1.14108e+02
        % ABS.DET.VAND.MATRIX : Inf
        % CONDITIONING VAND.  : 4.34404e+03
        % POINTS OUT DISK     : 0.00000e+00
        
        pts=[
            9.98756921218922344429813620081404e-01 4.98458856606971631442171144499298e-02
            9.88830826225128522999341385002481e-01 1.49042266176174442726676261372631e-01
            9.69077286229077961010602848546114e-01 2.46757397690293617253942670686229e-01
            9.39692620785908427905042117345147e-01 3.42020143325668712908083080037613e-01
            9.00968867902419145998749172576936e-01 4.33883739117558120401696442058892e-01
            8.53290881632155717717580500902841e-01 5.21435203379498002362879560678266e-01
            7.97132507222922503942186267522629e-01 6.03804410325477380894199086469598e-01
            7.33051871829826340309921306470642e-01 6.80172737770919355604348766064504e-01
            6.61685837596859394160730971634621e-01 7.49781202967734206055183676653542e-01
            5.83743672234789845454372425592737e-01 8.11938005715856281341302747023292e-01
            4.99999999999999888977697537484346e-01 8.66025403784438707610604524234077e-01
            4.11287103130611675361194556899136e-01 9.11505852311673026022731392004061e-01
            3.18486650251684377810335035974276e-01 9.47927346167131590348731151607353e-01
            2.22520933956314448387558968533995e-01 9.74927912181823619341969333618181e-01
            1.24343704647485273073748146543949e-01 9.92239206600172063410525424842490e-01
            2.49306917380730345967787542349470e-02 9.99689182000816245476926269475371e-01
            -7.47300935864242676931468167822459e-02 9.97203797181180129349797880422557e-01
            -1.73648177666930303431058746355120e-01 9.84807753012208020315654266596539e-01
            -2.70840468143004997614298190455884e-01 9.62624246950012141255115238891449e-01
            -3.65341024366394873101882012633723e-01 9.30873748644204357383102887979476e-01
            -4.56210657353162574167981802020222e-01 8.89871808811468767430596926715225e-01
            -5.42546263865759326172621967998566e-01 8.40025923150771514080759061471326e-01
            -6.23489801858733483364005678595277e-01 7.81831482468029914656426626606844e-01
            -6.98236818086072741351699733058922e-01 7.15866849259718551756748183834134e-01
            -7.66044443118977902429378445958719e-01 6.42787609686539473941024880332407e-01
            -8.26238774315994684016573046392296e-01 5.63320058063622175481555132137146e-01
            -8.78221573370228658639291552390205e-01 4.78253978621318076580593015023624e-01
            -9.21476211870407735382570990623208e-01 3.88434796274694627005175107115065e-01
            -9.55572805786140566652875349973328e-01 2.94755174410904596804527955100639e-01
            -9.80172487848543827482217238866724e-01 1.98146143199397606338152399985120e-01
            -9.95030775365401409793264519976219e-01 9.95678465958167308036408371663128e-02
            -1.00000000000000000000000000000000e+00 1.22464679914735320717376402945840e-16
            -9.95030775365401409793264519976219e-01 -9.95678465958164810034602965060913e-02
            -9.80172487848543716459914776351070e-01 -1.98146143199397301026820628067071e-01
            -9.55572805786140788697480275004636e-01 -2.94755174410903930670713180006715e-01
            -9.21476211870407624360268528107554e-01 -3.88434796274694793538628800888546e-01
            -8.78221573370228769661594014905859e-01 -4.78253978621317854535988089992316e-01
            -8.26238774315994906061177971423604e-01 -5.63320058063622064459252669621492e-01
            -7.66044443118978124473983370990027e-01 -6.42787609686539251896419955301099e-01
            -6.98236818086072852374002195574576e-01 -7.15866849259718329712143258802826e-01
            -6.23489801858733705408610603626585e-01 -7.81831482468029692611821701575536e-01
            -5.42546263865759215150319505482912e-01 -8.40025923150771514080759061471326e-01
            -4.56210657353163184790645345856319e-01 -8.89871808811468434363689539168263e-01
            -3.65341024366395705769150481501129e-01 -9.30873748644204024316195500432514e-01
            -2.70840468143004609036239571651095e-01 -9.62624246950012252277417701407103e-01
            -1.73648177666930331186634361984034e-01 -9.84807753012208020315654266596539e-01
            -7.47300935864247256601444746593188e-02 -9.97203797181180129349797880422557e-01
            2.49306917380727882660451655283396e-02 -9.99689182000816245476926269475371e-01
            1.24343704647484593062145563635568e-01 -9.92239206600172174432827887358144e-01
            2.22520933956314226342954043502687e-01 -9.74927912181823619341969333618181e-01
            3.18486650251684599854939961005584e-01 -9.47927346167131701371033614123007e-01
            4.11287103130611286783135938094347e-01 -9.11505852311673248067336317035370e-01
            5.00000000000000111022302462515654e-01 -8.66025403784438596588302061718423e-01
            5.83743672234789512387465038045775e-01 -8.11938005715856725430512597085908e-01
            6.61685837596858728026916196540697e-01 -7.49781202967734761166695989231812e-01
            7.33051871829826562354526231501950e-01 -6.80172737770919133559743841033196e-01
            7.97132507222922392919883805006975e-01 -6.03804410325477491916501548985252e-01
            8.53290881632155828739882963418495e-01 -5.21435203379497891340577098162612e-01
            9.00968867902419034976446710061282e-01 -4.33883739117558342446301367090200e-01
            9.39692620785908094838134729798185e-01 -3.42020143325669434553049086389365e-01
            9.69077286229077849988300386030460e-01 -2.46757397690293950320850058233191e-01
            9.88830826225128522999341385002481e-01 -1.49042266176174387215525030114804e-01
            9.98756921218922344429813620081404e-01 -4.98458856606976002945330606053176e-02
            9.81770173181140348717121923982631e-01 5.23261058278907467689045063252706e-02
            9.70646324823541406523474961431930e-01 1.56385441796191210217514822033991e-01
            9.48524665755099638531078198866453e-01 2.58672868220488905155463044138742e-01
            9.15655843212426656663183166529052e-01 3.58029427687414747438765516562853e-01
            8.72412274088646300107541264878819e-01 4.53329370677341580986308144929353e-01
            8.19283925301184212663940797938267e-01 5.43492910756268488015052753326017e-01
            7.56872762270813792540025133348536e-01 6.27498458987578833223608398839133e-01
            6.85885928412904077866585339506855e-01 7.04394198942897675763674669724423e-01
            6.07127732919965024116493168548914e-01 7.73308871162552646794097199745011e-01
            5.21490537617109839452211872412590e-01 8.33461644873389251308992697886424e-01
            4.29944646146006748121948248808621e-01 8.84170965113434959015137337701162e-01
            3.33527310036905610957091994350776e-01 9.24862275021953617049064177990658e-01
            2.33330976234335130126140711581684e-01 9.55074525798259355013897220487706e-01
            1.30490909236702534723661983662168e-01 9.74465400568853667984114963473985e-01
            2.61723280958959594877377696775511e-02 9.82815192974385576363260952348355e-01
            -7.84427959801685947827110112484661e-02 9.80029296530492199934769814717583e-01
            -1.82169131833627151451082681887783e-01 9.66139276557070991735542975220596e-01
            -2.83831418632318588368690370771219e-01 9.41302512530591051209682973421877e-01
            -3.82277782044625757951195055284188e-01 9.05800414911739459888906367268646e-01
            -4.76392785435915899761027958447812e-01 8.60035236652456736017313687625574e-01
            -5.65110068211318594677550208871253e-01 8.04525515509257660440312065475155e-01
            -6.47424428107360894202315648726653e-01 7.39900198803253861257189782918431e-01
            -7.22403210535271345094088246696629e-01 6.66891517195690619601577964203898e-01
            -7.89196875930140873123264100286178e-01 5.86326688221970537817639979039086e-01
            -8.47048625373650110326195772358915e-01 4.99118543586438700998542117304169e-01
            -8.95302975428218683617842543753795e-01 4.06255186414421542995256686481298e-01
            -9.33413185026268243937863644532626e-01 3.08788795648992586695413820052636e-01
            -9.60947450264985736367862045881338e-01 2.07823704443118678630852969035914e-01
            -9.77593796917082147324151719658403e-01 1.04503887623765834291589271742851e-01
            -9.83163615223446862856349071080331e-01 1.20402817442153426020277595474238e-16
            -9.77593796917082258346454182174057e-01 -1.04503887623765168157774496648926e-01
            -9.60947450264985625345559583365684e-01 -2.07823704443118872919882278438308e-01
            -9.33413185026268354960166107048281e-01 -3.08788795648992309139657663763501e-01
            -8.95302975428218905662447468785103e-01 -4.06255186414420932372593142645201e-01
            -8.47048625373650221348498234874569e-01 -4.99118543586438478953937192272861e-01
            -7.89196875930140762100961637770524e-01 -5.86326688221970537817639979039086e-01
            -7.22403210535271900205600559274899e-01 -6.66891517195690175512368114141282e-01
            -6.47424428107361116246920573757961e-01 -7.39900198803253750234887320402777e-01
            -5.65110068211318372632945283839945e-01 -8.04525515509257771462614527990809e-01
            -4.76392785435915733227574264674331e-01 -8.60035236652456847039616150141228e-01
            -3.82277782044626424085009830378112e-01 -9.05800414911739237844301442237338e-01
            -2.83831418632318588368690370771219e-01 -9.41302512530591051209682973421877e-01
            -1.82169131833626957162053372485389e-01 -9.66139276557070991735542975220596e-01
            -7.84427959801694968389185191881552e-02 -9.80029296530492199934769814717583e-01
            2.61723280958959352016091060022518e-02 -9.82815192974385576363260952348355e-01
            1.30490909236702312679057058630860e-01 -9.74465400568853779006417425989639e-01
            2.33330976234334269703296627085365e-01 -9.55074525798259577058502145519014e-01
            3.33527310036905444423638300577295e-01 -9.24862275021953728071366640506312e-01
            4.29944646146006526077343323777313e-01 -8.84170965113434959015137337701162e-01
            5.21490537617109617407606947381282e-01 -8.33461644873389362331295160402078e-01
            6.07127732919964802071888243517606e-01 -7.73308871162552757816399662260665e-01
            6.85885928412903855821980414475547e-01 -7.04394198942897897808279594755732e-01
            7.56872762270814125606932520895498e-01 -6.27498458987578500156701011292171e-01
            8.19283925301184101641638335422613e-01 -5.43492910756268932104262603388634e-01
            8.72412274088646078062936339847511e-01 -4.53329370677342025075517994991969e-01
            9.15655843212426767685485629044706e-01 -3.58029427687414358860706897758064e-01
            9.48524665755099527508775736350799e-01 -2.58672868220489460266975356717012e-01
            9.70646324823541517545777423947584e-01 -1.56385441796190960417334281373769e-01
            9.81770173181140348717121923982631e-01 -5.23261058278905247242995812939625e-02
            9.51150368179666250156856222019996e-01 5.43887458631517120566378764578985e-02
            9.38750668533428256345985118969111e-01 1.62457197110262213657350116591260e-01
            9.14112918288737752448014362016693e-01 2.68407770346777818648575930637890e-01
            8.77558308198617020856602266576374e-01 3.70859237820041709454699230263941e-01
            8.29563383508661988940957598970272e-01 4.68475987972213681054256539937342e-01
            7.70753831460983862555735868227202e-01 5.59985437179480904923423167929286e-01
            7.01896324504142299360864853952080e-01 6.44194619825761094489280367270112e-01
            6.23888525545305272501650506455917e-01 7.20005740433912189146781201998238e-01
            5.37747385541453848389892300474457e-01 7.86430485108640886515729562233901e-01
            4.44595885988433747737502699237666e-01 8.42602905719557093711102879751706e-01
            3.45648399139776518751432377030142e-01 8.87790708859352184489921455678996e-01
            2.42194856807233738216211804683553e-01 9.21404802408259948620639079308603e-01
            1.35583934126911442863416823456646e-01 9.43006975250740286931261380232172e-01
            2.72054675163416991023890290080089e-02 9.52315610027525738523479503783165e-01
            -8.15276639687043530591026296860946e-02 9.49209354448578568330674443132011e-01
            -1.89197957673425232183461730528506e-01 9.33728703305776064347298870416125e-01
            -2.94401766658887731331617487740004e-01 9.06075470561369389344008595799096e-01
            -3.95767598386476238125908366782824e-01 8.66610158394350960087137991649797e-01
            -4.91973994220561261503377181725227e-01 8.15847257503234057907093301764689e-01
            -5.81766756662725259552360057568876e-01 7.54448539932986106393286718230229e-01
            -6.63975299734203106005736572114984e-01 6.83214431864371807279212589492090e-01
            -7.37527909354294464172596690332284e-01 6.03073578834593670983110769157065e-01
            -8.01465714772381931929601250885753e-01 5.15070739422534118467922326090047e-01
            -8.54955188914570118896563144517131e-01 4.20353165222926261623825894275797e-01
            -8.97299014683807460990294657676714e-01 3.20155644667323491248112077300902e-01
            -9.27945175554656387362228997517377e-01 2.15784405668526024779652061624802e-01
            -9.46494151952902762481301124353195e-01 1.08600086942122073252470215720678e-01
            -9.52704129604192040403631835943088e-01 1.16672606285423902214393469497813e-16
            -9.46494151952902762481301124353195e-01 -1.08600086942121837330077482874913e-01
            -9.27945175554656498384531460033031e-01 -2.15784405668525802735047136593494e-01
            -8.97299014683807572012597120192368e-01 -3.20155644667323269203507152269594e-01
            -8.54955188914570118896563144517131e-01 -4.20353165222926428157279588049278e-01
            -8.01465714772382264996508638432715e-01 -5.15070739422533674378712476027431e-01
            -7.37527909354294575194899152847938e-01 -6.03073578834593448938505844125757e-01
            -6.63975299734203328050341497146292e-01 -6.83214431864371585234607664460782e-01
            -5.81766756662725814663872370147146e-01 -7.54448539932985662304076868167613e-01
            -4.91973994220561816614889494303497e-01 -8.15847257503233724840185914217727e-01
            -3.95767598386476293637059598040651e-01 -8.66610158394350960087137991649797e-01
            -2.94401766658887897865071181513485e-01 -9.06075470561369278321706133283442e-01
            -1.89197957673425648517095964962209e-01 -9.33728703305775953324996407900471e-01
            -8.15276639687050053151295969655621e-02 -9.49209354448578457308371980616357e-01
            2.72054675163414631799962961622441e-02 -9.52315610027525738523479503783165e-01
            1.35583934126911220818811898425338e-01 -9.43006975250740397953563842747826e-01
            2.42194856807233099837972645218542e-01 -9.21404802408260170665244004339911e-01
            3.45648399139776685284886070803623e-01 -8.87790708859352073467618993163342e-01
            4.44595885988433525692897774206358e-01 -8.42602905719557204733405342267361e-01
            5.37747385541453515322984912927495e-01 -7.86430485108640997538032024749555e-01
            6.23888525545305383523952968971571e-01 -7.20005740433912078124478739482583e-01
            7.01896324504142410383167316467734e-01 -6.44194619825760983466977904754458e-01
            7.70753831460984195622643255774165e-01 -5.59985437179480460834213317866670e-01
            8.29563383508661766896352673938964e-01 -4.68475987972214125143466389999958e-01
            8.77558308198616687789694879029412e-01 -3.70859237820042375588514005357865e-01
            9.14112918288737752448014362016693e-01 -2.68407770346777929670878393153544e-01
            9.38750668533428256345985118969111e-01 -1.62457197110262518968681888509309e-01
            9.51150368179666250156856222019996e-01 -5.43887458631522532903623812217120e-02
            9.11726368325649905166585540428059e-01 5.62333575736654184273888290590548e-02
            8.97905525944519111725128368561855e-01 1.67847632341307922976270106119046e-01
            8.70473351064564471180062810162781e-01 2.76917508097111575438020736328326e-01
            8.29845687494146666551841917680576e-01 3.81789596704327771625742116157198e-01
            7.76638409199433721319394408055814e-01 4.80874144200391928638538274753955e-01
            7.11658084282859926261721739138011e-01 5.72669129846490099211564483994152e-01
            6.35889748232864815413734049798222e-01 6.55783035230883437627369403344346e-01
            5.50481971789977486686495922185713e-01 7.28955938269594483358559955377132e-01
            4.56729449785178043264011193969054e-01 7.91078612340906817124164263077546e-01
            3.56053374886001250398948059228132e-01 8.41209341030266344318988558370620e-01
            2.49979893764378069409559657287900e-01 8.78588193591193444831333181355149e-01
            1.40116972268759881758981578059320e-01 9.02648544720768830629253898223396e-01
            2.81300203009240308571481392618807e-02 9.13025664021639649092776380712166e-01
            -8.42833541005098135778794699035643e-02 9.09562244943057485180304411187535e-01
            -1.95419078767500614679519799210539e-01 8.92310789387838587671808454615530e-01
            -3.03592449399616215455210976870148e-01 8.61532811837034895319220595411025e-01
            -4.07163667963936548588321784336586e-01 8.17694875056973469185095382272266e-01
            -5.04562700361713245555961293575820e-01 7.61461517483307925857616282883100e-01
            -5.94313076544902840758766160433879e-01 6.93685179495726944587374873663066e-01
            -6.75054272297063717722664932807675e-01 6.15393281290727234278392643318512e-01
            -7.45562333393636755829447793075815e-01 5.27772648238729713554562295030337e-01
            -8.04768429500357651562580940662883e-01 4.32151519821247609431935643442557e-01
            -8.51775056551619669242825239052763e-01 3.29979414874278675906538182971417e-01
            -8.85869641997243051356747400859604e-01 2.22805158360309951692812546752975e-01
            -9.06535346675978570551990287640365e-01 1.12253402760672041371670104581426e-01
            -9.13458899570356308572627312969416e-01 1.11866451751150050076318504366366e-16
            -9.06535346675978570551990287640365e-01 -1.12253402760671819327065179550118e-01
            -8.85869641997243051356747400859604e-01 -2.22805158360310118226266240526456e-01
            -8.51775056551619780265127701568417e-01 -3.29979414874278509373084489197936e-01
            -8.04768429500357762584883403178537e-01 -4.32151519821247442898481949669076e-01
            -7.45562333393636866851750255591469e-01 -5.27772648238729491509957369999029e-01
            -6.75054272297063828744967395323329e-01 -6.15393281290727012233787718287203e-01
            -5.94313076544902618714161235402571e-01 -6.93685179495727055609677336178720e-01
            -5.04562700361713467600566218607128e-01 -7.61461517483307925857616282883100e-01
            -4.07163667963936382054868090563104e-01 -8.17694875056973580207397844787920e-01
            -3.03592449399616437499815901901457e-01 -8.61532811837034784296918132895371e-01
            -1.95419078767501031013154033644241e-01 -8.92310789387838476649505992099876e-01
            -8.42833541005098413334550855324778e-02 -9.09562244943057485180304411187535e-01
            2.81300203009238088125432142305726e-02 -9.13025664021639649092776380712166e-01
            1.40116972268760048292435271832801e-01 -9.02648544720768830629253898223396e-01
            2.49979893764378069409559657287900e-01 -8.78588193591193444831333181355149e-01
            3.56053374886001583465855446775095e-01 -8.41209341030266233296686095854966e-01
            4.56729449785178265308616119000362e-01 -7.91078612340906817124164263077546e-01
            5.50481971789977153619588534638751e-01 -7.28955938269594705403164880408440e-01
            6.35889748232864926436036512313876e-01 -6.55783035230883215582764478313038e-01
            7.11658084282859815239419276622357e-01 -5.72669129846490210233866946509806e-01
            7.76638409199433388252487020508852e-01 -4.80874144200392317216596893558744e-01
            8.29845687494146777574144380196230e-01 -3.81789596704327716114590884899371e-01
            8.70473351064564360157760347647127e-01 -2.76917508097111797482625661359634e-01
            8.97905525944519111725128368561855e-01 -1.67847632341307673176089565458824e-01
            9.11726368325649905166585540428059e-01 -5.62333575736654808774339642241102e-02
            8.65202547363960183801623315957841e-01 5.79184958927200232992049677704927e-02
            8.49762987409221515200385965727037e-01 1.72721930746839835713046795717673e-01
            8.19159386812906231689623837155523e-01 2.84443138654923766139859253598843e-01
            7.73937867552668579129715453746030e-01 3.91088452015127541194772220478626e-01
            7.14905408711025147638906673819292e-01 4.90754782684064028153159142675577e-01
            6.43115445914509864522301541001070e-01 5.81663582629806663604199457040522e-01
            5.59849072749962428652281687391223e-01 6.62192582163654286375731317093596e-01
            4.66592179619121139033666167961201e-01 7.30904739381157964039914531895192e-01
            3.65008937989202697504964589825249e-01 7.86573884208950246943459205795079e-01
            2.56912103213644771315671277989168e-01 8.28206599438752633091098687145859e-01
            1.44230665869878288409822175708541e-01 8.55059948280991743985168795916252e-01
            2.89754288767762949174944253627473e-02 8.66654732089410351214553429599619e-01
            -8.67968753310726093275206949329004e-02 8.62784041672261636790608463343233e-01
            -2.01020287242382189596412445098395e-01 8.43516949591738174341060130245751e-01
            -3.11656487365592815841353058203822e-01 8.09197277562462402578091769100865e-01
            -4.16731170088484814684193224820774e-01 7.60437460944845322607932303071721e-01
            -5.14369275208603315974187353276648e-01 6.98107619821569436169284017523751e-01
            -6.02828448426989904618267246405594e-01 6.23320031684101105717843438469572e-01
            -6.80530133701925721290137971664080e-01 5.37409282814504285497037017194089e-01
            -7.46087742618892324486523648374714e-01 4.41908452561620757048643781672581e-01
            -7.98331398093678368255154964572284e-01 3.38521755503769117279233569206554e-01
            -8.36328810856660775918669514794601e-01 2.29094129699223464369239877669315e-01
            -8.59401916176908531319611483922927e-01 1.15578313722854500444903180778056e-01
            -8.67138973943370139352282421896234e-01 -2.78893164883138445165568452935595e-16
            -8.59401916176908642341913946438581e-01 -1.15578313722853903700027444756415e-01
            -8.36328810856660775918669514794601e-01 -2.29094129699223270080210568266921e-01
            -7.98331398093678479277457427087938e-01 -3.38521755503768950745779875433072e-01
            -7.46087742618892435508826110890368e-01 -4.41908452561620535004038856641273e-01
            -6.80530133701925832312440434179734e-01 -5.37409282814504063452432092162780e-01
            -6.02828448426990015640569708921248e-01 -6.23320031684100994695540975953918e-01
            -5.14369275208603093929582428245340e-01 -6.98107619821569547191586480039405e-01
            -4.16731170088484703661890762305120e-01 -7.60437460944845322607932303071721e-01
            -3.11656487365593204419411677008611e-01 -8.09197277562462291555789306585211e-01
            -2.01020287242382772463500373305578e-01 -8.43516949591738063318757667730097e-01
            -8.67968753310730117833671215521463e-02 -8.62784041672261636790608463343233e-01
            2.89754288767758924616479987435014e-02 -8.66654732089410351214553429599619e-01
            1.44230665869878066365217250677233e-01 -8.55059948280991743985168795916252e-01
            2.56912103213644382737612659184379e-01 -8.28206599438752633091098687145859e-01
            3.65008937989202475460359664793941e-01 -7.86573884208950357965761668310734e-01
            4.66592179619120972500212474187720e-01 -7.30904739381158075062216994410846e-01
            5.59849072749962317629979224875569e-01 -6.62192582163654397398033779609250e-01
            6.43115445914509753499999078485416e-01 -5.81663582629806663604199457040522e-01
            7.14905408711025147638906673819292e-01 -4.90754782684064028153159142675577e-01
            7.73937867552668246062808066199068e-01 -3.91088452015128262839738226830377e-01
            8.19159386812906231689623837155523e-01 -2.84443138654923766139859253598843e-01
            8.49762987409221515200385965727037e-01 -1.72721930746839724690744333202019e-01
            8.65202547363960183801623315957841e-01 -5.79184958927206477996563194210466e-02
            8.12556022587607507112750226951903e-01 5.94714354683488419239800748528069e-02
            7.95237801685470313550752052833559e-01 1.77146776009384471217700252054783e-01
            7.60970467692692054129111056681722e-01 2.91046540573194234546861025592079e-01
            7.10484369340089183531006256089313e-01 3.98743153425201946049583057174459e-01
            6.44855530162596890519921544182580e-01 4.97941248239965217337044123269152e-01
            5.65482714925759522017756353307050e-01 5.86526589849301394075098414759850e-01
            4.74057617383219664919380420542439e-01 6.62611135494268088663716298469808e-01
            3.72528804761393605993191613379167e-01 7.24573275178643338989559197216295e-01
            2.63060187432044789712648480417556e-01 7.71092393470637182950611077103531e-01
            1.47984898919584328957910202007042e-01 8.01177016128033270270236698706867e-01
            2.97555692106677843744577671714069e-02 8.14185941650313438344710448291153e-01
            -8.91079487958359173216393855909701e-02 8.09841907375419278736217165715061e-01
            -2.06072285578541652961703789515013e-01 7.88237498852023876771966115484247e-01
            -3.18644549366584484140219046821585e-01 7.49833176539305146235392385278828e-01
            -4.24425457799683270021517955683521e-01 6.95447461891685825285946975782281e-01
            -5.21160474466133893933772469608812e-01 6.26239491995109420763299112877576e-01
            -6.06787860432211667571777979901526e-01 5.43684314572489113537301363976439e-01
            -6.79482616628054203467002025718102e-01 4.49541449902399081750559162173886e-01
            -7.37695380534364675284564327739645e-01 3.45817389699126342961221780569758e-01
            -7.80185448154582350532848522561835e-01 2.34722832225354505197856269660406e-01
            -8.06047217466523080453555394342402e-01 1.18625565096796101172138548918156e-01
            -8.14729489757219038637003905023448e-01 9.97755861802134541703424838268372e-17
            -8.06047217466523080453555394342402e-01 -1.18625565096795893005321431701304e-01
            -7.80185448154582461555150985077489e-01 -2.34722832225354310908826960258011e-01
            -7.37695380534364675284564327739645e-01 -3.45817389699126176427768086796277e-01
            -6.79482616628054536533909413265064e-01 -4.49541449902398582150198080853443e-01
            -6.06787860432211778594080442417180e-01 -5.43684314572489002514998901460785e-01
            -5.21160474466133671889167544577504e-01 -6.26239491995109531785601575393230e-01
            -4.24425457799683825133030268261791e-01 -6.95447461891685492219039588235319e-01
            -3.18644549366584484140219046821585e-01 -7.49833176539305146235392385278828e-01
            -2.06072285578541708472855020772840e-01 -7.88237498852023876771966115484247e-01
            -8.91079487958362920219101965813024e-02 -8.09841907375419278736217165715061e-01
            2.97555692106673992658461003202319e-02 -8.14185941650313438344710448291153e-01
            1.47984898919583746090822273799859e-01 -8.01177016128033381292539161222521e-01
            2.63060187432044734201497249159729e-01 -7.71092393470637182950611077103531e-01
            3.72528804761393383948586688347859e-01 -7.24573275178643338989559197216295e-01
            4.74057617383219498385926726768957e-01 -6.62611135494268199686018760985462e-01
            5.65482714925759188950848965760088e-01 -5.86526589849301838164308264822466e-01
            6.44855530162596890519921544182580e-01 -4.97941248239965106314741660753498e-01
            7.10484369340089183531006256089313e-01 -3.98743153425202001560734288432286e-01
            7.60970467692691943106808594166068e-01 -2.91046540573194401080314719365560e-01
            7.95237801685470424573054515349213e-01 -1.77146776009384082639641633249994e-01
            8.12556022587607507112750226951903e-01 -5.94714354683493137687655405443365e-02
            7.54439003625215542925275258312467e-01 6.09046128203683048707439695590438e-02
            7.34899429719892971490935451583937e-01 1.81136440980778162801456687702739e-01
            6.96326346609730140180261059867917e-01 2.96676930466379495943129995794152e-01
            6.39718776885771833740079728158889e-01 4.04533643290121147639837317910860e-01
            5.66542826869280813362195203808369e-01 5.01913147244392288115477640531026e-01
            4.78693715228126759342330842628144e-01 5.86293364327876376229653487825999e-01
            3.78446687808800419361432432197034e-01 6.55488891240999849152615297498414e-01
            2.68398089964123010009444669776713e-01 7.07707600183449581088268587336643e-01
            1.51398122572402871188756989795365e-01 7.41597054022842372411616906902054e-01
            3.04770233318314570647444838868978e-02 7.56279533706048279206868301116629e-01
            -9.12334148041909487325540339952568e-02 7.51374770721624174463215695141116e-01
            -2.10580955419491788749297711547115e-01 7.27009795854513196644575145910494e-01
            -3.24474559902513448594874034824898e-01 6.83815649155440907769332170573762e-01
            -4.29964443722702038819249992229743e-01 6.22911036335072720859784567437600e-01
            -5.24318474300401016208184046263341e-01 5.45873354873735006087542842578841e-01
            -6.05092931805539024914253332099179e-01 4.54697840255244900564690624378272e-01
            -6.70195800217603165904733941715676e-01 3.51745890415927242589333445721422e-01
            -7.17940949441683629039800962345907e-01 2.39683906778450084296139266371028e-01
            -7.47091805192249491796019356115721e-01 1.21414235855573093836312636994990e-01
            -7.56893375617601060767469789425377e-01 9.26927049745930478954833017743196e-17
            -7.47091805192249602818321818631375e-01 -1.21414235855572899547283327592595e-01
            -7.17940949441683740062103424861562e-01 -2.39683906778449917762685572597547e-01
            -6.70195800217603165904733941715676e-01 -3.51745890415927076055879751947941e-01
            -6.05092931805539246958858257130487e-01 -4.54697840255244734031236930604791e-01
            -5.24318474300401238252788971294649e-01 -5.45873354873734784042937917547533e-01
            -4.29964443722702205352703686003224e-01 -6.22911036335072609837482104921946e-01
            -3.24474559902513337572571572309243e-01 -6.83815649155441018791634633089416e-01
            -2.10580955419491788749297711547115e-01 -7.27009795854513196644575145910494e-01
            -9.12334148041913095550370371711324e-02 -7.51374770721624174463215695141116e-01
            3.04770233318311066506023365718647e-02 -7.56279533706048390229170763632283e-01
            1.51398122572402676899727680392971e-01 -7.41597054022842483433919369417708e-01
            2.68398089964122843475990976003231e-01 -7.07707600183449692110571049852297e-01
            3.78446687808800030783373813392245e-01 -6.55488891241000071197220222529722e-01
            4.78693715228126259741969761307701e-01 -5.86293364327876709296560875372961e-01
            5.66542826869280591317590278777061e-01 -5.01913147244392510160082565562334e-01
            6.39718776885771722717777265643235e-01 -4.04533643290121425195593474199995e-01
            6.96326346609730029157958597352263e-01 -2.96676930466379606965432458309806e-01
            7.34899429719892971490935451583937e-01 -1.81136440980778190557032303331653e-01
            7.54439003625215542925275258312467e-01 -6.09046128203682216040171226723032e-02
            6.91321991356282805618604925257387e-01 6.22201053867950937270592248751200e-02
            6.69102333732462639659388514701277e-01 1.84660510778380443364099505743070e-01
            6.25377176563247205720585952803958e-01 3.01165775414374281560014878778020e-01
            5.61551882377234079513073083944619e-01 4.07991324228524743222834558764589e-01
            4.79677848645188920073678673361428e-01 5.01703696185590630740591677749762e-01
            3.82386574177438820498764471267350e-01 5.79290898544075338882919368188595e-01
            2.72805080586904558082039784494555e-01 6.38259214781214612166593269648729e-01
            1.54455407241539249829642699296528e-01 6.76713354693854407528874617128167e-01
            3.11414100210984715055850813314464e-02 6.93417370585030834462259008432738e-01
            -9.31734977406579178982326538971392e-02 6.87834381639891412341114573791856e-01
            -2.14493732621620275535789801324427e-01 6.60143829716831498366502728458727e-01
            -3.28919962450092695505077244888525e-01 6.11235711938520331898416770854965e-01
            -4.32774434049172596061794138222467e-01 5.42681975452086073907764784962637e-01
            -5.22719179249921617191887435183162e-01 4.56685993754405106237470590713201e-01
            -5.95863299934804802049370664462913e-01 3.56011748454970189392554402729729e-01
            -6.49855883881827245396323178283637e-01 2.43894992632750218231052485862165e-01
            -6.82961565017685345857501033606241e-01 1.23939251069845310371242419478222e-01
            -6.94116299511227552443415333982557e-01 8.50047304432430326199901266835156e-17
            -6.82961565017685345857501033606241e-01 -1.23939251069845129960000917890284e-01
            -6.49855883881827245396323178283637e-01 -2.43894992632750079453174407717597e-01
            -5.95863299934805135116278052009875e-01 -3.56011748454969800814495783924940e-01
            -5.22719179249921728214189897698816e-01 -4.56685993754404939704016896939720e-01
            -4.32774434049172707084096600738121e-01 -5.42681975452085962885462322446983e-01
            -3.28919962450092806527379707404179e-01 -6.11235711938520220876114308339311e-01
            -2.14493732621620414313667879468994e-01 -6.60143829716831498366502728458727e-01
            -9.31734977406580983094741554850771e-02 -6.87834381639891301318812111276202e-01
            3.11414100210983049721313875579654e-02 -6.93417370585030834462259008432738e-01
            1.54455407241539083296189005523047e-01 -6.76713354693854407528874617128167e-01
            2.72805080586904391548586090721074e-01 -6.38259214781214723188895732164383e-01
            3.82386574177438598454159546236042e-01 -5.79290898544075449905221830704249e-01
            4.79677848645188753540224979587947e-01 -5.01703696185590741762894140265416e-01
            5.61551882377234079513073083944619e-01 -4.07991324228524909756288252538070e-01
            6.25377176563247094698283490288304e-01 -3.01165775414374448093468572551501e-01
            6.69102333732462639659388514701277e-01 -1.84660510778380609897553199516551e-01
            6.91321991356282694596302462741733e-01 -6.22201053867952671994068225558294e-02
            6.23558147039393384503114248218480e-01 6.34096658870624135806437493556587e-02
            5.98029603234629170138703102566069e-01 1.87632998489451530144123125865008e-01
            5.48017657207944597352877735829679e-01 3.04174614087741268519948789617047e-01
            4.75569803905826038459281335235573e-01 4.08263285246279306051064850180410e-01
            3.83652066954723591774012447785935e-01 4.95637609537935341919023812806699e-01
            2.76027569305291042844885396334575e-01 5.62720471860161941535238838696387e-01
            1.57102470536637339737495722147287e-01 6.06765491947585555720934280543588e-01
            3.17455781654575330819056944164913e-02 6.25969461502756785442613818304380e-01
            -9.49109819057635945016571099586145e-02 6.19546167755716470360027869901387e-01
            -2.17681875226195503669757158604625e-01 5.87758581107173383450970050034812e-01
            -3.31540846998332860984248782187933e-01 5.31908089089401459048644937865902e-01
            -4.31826497539962772531652035468142e-01 4.54281217407762893945033511045040e-01
            -5.14433120534847798666078233509324e-01 3.58056019309673567718732556386385e-01
            -5.75978791131710909922958308015950e-01 2.47171965711250440911328496440547e-01
            -6.13943822345007328422639147902373e-01 1.26168662795135916310229617920413e-01
            -6.26773921336162942452574498020113e-01 7.67576676553366861899798367909458e-17
            -6.13943822345007328422639147902373e-01 -1.26168662795135749776775924146932e-01
            -5.75978791131710909922958308015950e-01 -2.47171965711250302133450418295979e-01
            -5.14433120534847909688380696024979e-01 -3.58056019309673401185278862612904e-01
            -4.31826497539963050087408191757277e-01 -4.54281217407762616389277354755905e-01
            -3.31540846998333027517702475961414e-01 -5.31908089089401348026342475350248e-01
            -2.17681875226195781225513314893760e-01 -5.87758581107173161406365125003504e-01
            -9.49109819057637471573229959176388e-02 -6.19546167755716470360027869901387e-01
            3.17455781654576510431020608393737e-02 -6.25969461502756785442613818304380e-01
            1.57102470536637062181739565858152e-01 -6.06765491947585666743236743059242e-01
            2.76027569305290654266826777529786e-01 -5.62720471860162163579843763727695e-01
            3.83652066954723314218256291496800e-01 -4.95637609537935563963628737838008e-01
            4.75569803905826093970432566493400e-01 -4.08263285246279084006459925149102e-01
            5.48017657207944375308272810798371e-01 -3.04174614087741601586856177164009e-01
            5.98029603234629170138703102566069e-01 -1.87632998489451890966606129040883e-01
            6.23558147039393384503114248218480e-01 -6.34096658870622886805534790255479e-02
            5.51414190898349421132706993375905e-01 6.44510754265769508775107965448115e-02
            5.21687309138775923145203705644235e-01 1.89878652120944985126627102545172e-01
            4.63836129509804184767318702142802e-01 3.05069821531215701337913515089895e-01
            3.80979424079451678419871996084112e-01 4.03814597898358496053106136969291e-01
            2.77584019284127625493141522383667e-01 4.80789624769287937677830768734566e-01
            1.59223988159250845475511937365809e-01 5.31845158521149219410517616779543e-01
            3.22801506191155579417184640078631e-02 5.54228782114147167092710333236028e-01
            -9.64039181963014663034883255932073e-02 5.46733788606598269943503964896081e-01
            -2.19890826828532059966647693727282e-01 5.09764235038500990171428384201135e-01
            -3.31523364069817194632605605875142e-01 4.45313159611924191949583473615348e-01
            -4.25283390942474415208351956607657e-01 3.56855136485653090527847552948515e-01
            -4.96116280128919784342400589594035e-01 2.49158960582931549021523665032873e-01
            -5.40203412238702496139808317821007e-01 1.28030560622790862135289557954820e-01
            -5.55168038568255139963980582251679e-01 6.79884761421528038020915074779605e-17
            -5.40203412238702496139808317821007e-01 -1.28030560622790723357411479810253e-01
            -4.96116280128919839853551820851862e-01 -2.49158960582931437999221202517219e-01
            -4.25283390942474359697200725349830e-01 -3.56855136485653146038998784206342e-01
            -3.31523364069817305654908068390796e-01 -4.45313159611924080927281011099694e-01
            -2.19890826828532087722223309356195e-01 -5.09764235038500990171428384201135e-01
            -9.64039181963016050813664037377748e-02 -5.46733788606598158921201502380427e-01
            3.22801506191151693636598452030739e-02 -5.54228782114147278115012795751682e-01
            1.59223988159250845475511937365809e-01 -5.31845158521149219410517616779543e-01
            2.77584019284127625493141522383667e-01 -4.80789624769287937677830768734566e-01
            3.80979424079451733931023227341939e-01 -4.03814597898358440541954905711464e-01
            4.63836129509803962722713777111494e-01 -3.05069821531216089915972133894684e-01
            5.21687309138775812122901243128581e-01 -1.89878652120945401460261336978874e-01
            5.51414190898349421132706993375905e-01 -6.44510754265768398552083340291574e-02
            4.75081469293756997185340651412844e-01 6.52984449615679890532859985796676e-02
            4.39846850069345596256908947907505e-01 1.91052447942413217152335391801898e-01
            3.71990802140739873493657796643674e-01 3.02636964866162372356228615899454e-01
            2.76545898162040726386834421646199e-01 3.91776282577779411120388886047294e-01
            1.60590850029966286660609853242931e-01 4.51859345667838085969236772143631e-01
            3.27255132054240158168134655625181e-02 4.78430068208673009433340439500171e-01
            -9.75669252243035328708842257583456e-02 4.69517821262397938575361422408605e-01
            -2.20623271149127692103419917657448e-01 4.25783585414201193319883032017970e-01
            -3.27316998337128628460135360001004e-01 3.50470928866127184875267630559392e-01
            -4.09735121134096158534987353050383e-01 2.49165446821868585836057263804832e-01
            -4.61765064410003256423209450076683e-01 1.29380503442904526423262723255903e-01
            -4.79548005293228052359211233124370e-01 5.87276929719849741377645592784123e-17
            -4.61765064410003256423209450076683e-01 -1.29380503442904581934413954513730e-01
            -4.09735121134096380579592278081691e-01 -2.49165446821868280524725491886784e-01
            -3.27316998337128572948984128743177e-01 -3.50470928866127240386418861817219e-01
            -2.20623271149127969659176073946583e-01 -4.25783585414201082297580569502315e-01
            -9.75669252243034496041573788716050e-02 -4.69517821262397938575361422408605e-01
            3.27255132054238978556170991396357e-02 -4.78430068208673009433340439500171e-01
            1.60590850029966175638307390727277e-01 -4.51859345667838085969236772143631e-01
            2.76545898162040670875683190388372e-01 -3.91776282577779466631540117305121e-01
            3.71990802140739762471355334128020e-01 -3.02636964866162538889682309672935e-01
            4.39846850069345485234606485391851e-01 -1.91052447942413439196940316833206e-01
            4.75081469293756997185340651412844e-01 -6.52984449615678641531957282495569e-02
            3.94667173028971696169264760101214e-01 6.58583030557480103572842722314817e-02
            3.51898860939126589819636592437746e-01 1.90438140134292166472107510344358e-01
            2.70996846993108109202808009285945e-01 2.94381049777082237639547201979440e-01
            1.60728119726054358151756673578348e-01 3.66423204883902176032250963544357e-01
            3.30420067329440653169925212750968e-02 3.98757720099715551320684880920453e-01
            -9.82247203892403636382724130271527e-02 3.87880648979191278158396016806364e-01
            -2.18847274943679115377648258800036e-01 3.34970690953385885624271622873493e-01
            -3.15754331492621387322827786192647e-01 2.45761460956983229797501167013252e-01
            -3.78444506791079049445869486589800e-01 1.29920163283918116414739074571116e-01
            -4.00124347607169528195925067848293e-01 4.90011001558043062506819883940006e-17
            -3.78444506791079049445869486589800e-01 -1.29920163283918171925890305828943e-01
            -3.15754331492621553856281479966128e-01 -2.45761460956983063264047473239771e-01
            -2.18847274943679059866497027542209e-01 -3.34970690953385885624271622873493e-01
            -9.82247203892404607827870677283499e-02 -3.87880648979191222647244785548537e-01
            3.30420067329440583780986173678684e-02 -3.98757720099715551320684880920453e-01
            1.60728119726054025084849286031385e-01 -3.66423204883902342565704657317838e-01
            2.70996846993108164713959240543772e-01 -2.94381049777082237639547201979440e-01
            3.51898860939126423286182898664265e-01 -1.90438140134292416272288051004580e-01
            3.94667173028971696169264760101214e-01 -6.58583030557479548461330409736547e-02
            3.10148978349858328584787159343250e-01 6.59242004435160039443886148546881e-02
            2.56521402378154572687662948737852e-01 1.86373708171304802716505832904659e-01
            1.58538945511487644468573421363544e-01 2.74597508604290330147534859861480e-01
            3.31436646847800900350655695092428e-02 3.15340905159544160341056340257637e-01
            -9.79824568666669004635139117453946e-02 3.01558994430525195706849217458512e-01
            -2.12166521483191289343395169453288e-01 2.35634793987009233395824026047194e-01
            -2.89665067062934655783834614339867e-01 1.28967196988239302113399276095151e-01
            -3.17077891022975233425995611469261e-01 1.79641712517485332289742541169118e-16
            -2.89665067062934655783834614339867e-01 -1.28967196988239357624550507352978e-01
            -2.12166521483191455876848863226769e-01 -2.35634793987009094617945947902626e-01
            -9.79824568666669698524529508176784e-02 -3.01558994430525140195697986200685e-01
            3.31436646847799443182935874574468e-02 -3.15340905159544160341056340257637e-01
            1.58538945511487644468573421363544e-01 -2.74597508604290330147534859861480e-01
            2.56521402378154517176511717480025e-01 -1.86373708171304858227657064162486e-01
            3.10148978349858328584787159343250e-01 -6.59242004435159067998739601534908e-02
            2.21226591460790711352046855608933e-01 6.49579881953407933803390506000142e-02
            1.50988711784390494674568117261515e-01 1.74250262305214037583667163744394e-01
            3.28129829517042823083805558326276e-02 2.28219309326701785822777424073138e-01
            -9.57806361226893748783695059501042e-02 2.09730338157546020161348110377730e-01
            -1.93964579981764861926762932853308e-01 1.24653466507125984530368612013262e-01
            -2.30566140184862433670787140727043e-01 1.30628143569789512168764421614450e-16
            -1.93964579981764889682338548482221e-01 -1.24653466507125929019217380755435e-01
            -9.57806361226895691673988153524988e-02 -2.09730338157545936894621263490990e-01
            3.28129829517042267972293245748006e-02 -2.28219309326701813578353039702051e-01
            1.50988711784390383652265654745861e-01 -1.74250262305214120850394010631135e-01
            2.21226591460790711352046855608933e-01 -6.49579881953408211359146662289277e-02
            1.26791448656747268719513499490859e-01 6.10595435549274034858768800404505e-02
            3.13149017440070148721176224171359e-02 1.37199548980220187299750023157685e-01
            -8.77424048895539682169086859175877e-02 1.10025495662642802674469066914753e-01
            -1.40727891022400575238293640722986e-01 1.72341961291340395381195252446417e-17
            -8.77424048895540098502721093609580e-02 -1.10025495662642774918893451285840e-01
            3.13149017440068622164517364581116e-02 -1.37199548980220215055325638786599e-01
            1.26791448656747296475089115119772e-01 -6.10595435549273132802561292464816e-02
            2.38433295994562935438132456056337e-02 4.12978582878691727331421645885712e-02
            -4.76866591989125732098386833968107e-02 5.83993145499789667633499239650625e-18
            2.38433295994562935438132456056337e-02 -4.12978582878691727331421645885712e-02
            ];
        
    case   32
        
        % DEGREE.             :          32
        % CARDIN.             :         561
        % LEBESGUE CONST.     : 1.34949e+02
        % ABS.DET.VAND.MATRIX : Inf
        % CONDITIONING VAND.  : 4.52780e+03
        % POINTS OUT DISK     : 0.00000e+00
        
        pts=[
            9.98832226832326641741133244067896e-01 4.83133795255070649932171988893970e-02
            9.89506399451051121829436851840001e-01 1.44489049569221317259604120408767e-01
            9.70941817426052011796855367720127e-01 2.39315664287557738898470915955841e-01
            9.43311813257743159155666035076138e-01 3.31907853128528440578293157159351e-01
            9.06874360850545402357170132745523e-01 4.21401107772529093242752651349292e-01
            8.61969666880049278923081601533340e-01 5.06959853813590322069160265527898e-01
            8.09016994374947451262869435595348e-01 5.87785252292473137103456792829093e-01
            7.48510748171101081283040912239812e-01 6.63122658240795082029706009052461e-01
            6.81015858786797045887340118497377e-01 7.32268666597773565385409710870590e-01
            6.07162507818711283391621691407636e-01 7.94577679713754148060900206473889e-01
            5.27640244106132749735138531832490e-01 8.49467935121520967278740954498062e-01
            4.43191545599241343289520500547951e-01 8.96426937295703774033484023675555e-01
            3.54604887042535565910839068237692e-01 9.35016242685414833424317748722387e-01
            2.62707378198587027107180347229587e-01 9.64875553343551461971117078064708e-01
            1.68357041347038632883581499299908e-01 9.85726080931650816552291871630587e-01
            7.24348001617623887815611283258477e-02 9.97373149691490934465321060997667e-01
            -2.41637452361322946359223351464607e-02 9.99708014080192941541724849230377e-01
            -1.20536680255322881105684018621105e-01 9.92708874098053972723221249907510e-01
            -2.15784196767806024652713858813513e-01 9.76441078829272113281945166818332e-01
            -3.09016994374947340240566973079694e-01 9.51056516295153642204240895807743e-01
            -3.99364583565695319133936891375924e-01 9.16792195316582514408310089493170e-01
            -4.85983413242606021587022269159206e-01 8.73968032626517787875286558119114e-01
            -5.68064746731155700842919031856582e-01 8.22983865893656463263994282897329e-01
            -6.44842212736170705689175974839600e-01 7.64315720545848176215031344327144e-01
            -7.15598960744121104227133400854655e-01 6.98511365248936977323523933591787e-01
            -7.79674354063222274646705045597628e-01 6.26185197538313920162522663304117e-01
            -8.36470138010226738067842688906239e-01 5.48012507354669997639007306133863e-01
            -8.85456025653209799486376141430810e-01 4.64723172043768673056263196485816e-01
            -9.26174648957776347479864398337668e-01 3.77094841688320747685736478160834e-01
            -9.58245829109166225023841434449423e-01 2.85945678398689284716027714239317e-01
            -9.81370126139413434529501500946935e-01 1.92126717353708592606054139650951e-01
            -9.95331634717648627841413144778926e-01 9.65139209145150639423960114982037e-02
            -1.00000000000000000000000000000000e+00 1.22464679914735320717376402945840e-16
            -9.95331634717648627841413144778926e-01 -9.65139209145148141422154708379821e-02
            -9.81370126139413434529501500946935e-01 -1.92126717353708342805873598990729e-01
            -9.58245829109166114001538971933769e-01 -2.85945678398689506760632639270625e-01
            -9.26174648957776680546771785884630e-01 -3.77094841688320081551921703066910e-01
            -8.85456025653209910508678603946464e-01 -4.64723172043768451011658271454507e-01
            -8.36470138010226960112447613937547e-01 -5.48012507354669775594402381102555e-01
            -7.79674354063222385669007508113282e-01 -6.26185197538313698117917738272808e-01
            -7.15598960744121215249435863370309e-01 -6.98511365248936866301221471076133e-01
            -6.44842212736170261599966124776984e-01 -7.64315720545848620304241194389760e-01
            -5.68064746731155922887523956887890e-01 -8.22983865893656352241691820381675e-01
            -4.85983413242606687720837044253130e-01 -8.73968032626517565830681633087806e-01
            -3.99364583565695041578180735086789e-01 -9.16792195316582403386007626977516e-01
            -3.09016994374947562285171898111003e-01 -9.51056516295153531181938433292089e-01
            -2.15784196767806912831133558938745e-01 -9.76441078829271891237340241787024e-01
            -1.20536680255322659061079093589797e-01 -9.92708874098053861700918787391856e-01
            -2.41637452361325409666559238530681e-02 -9.99708014080192941541724849230377e-01
            7.24348001617623610259855126969342e-02 -9.97373149691490934465321060997667e-01
            1.68357041347038827172610808702302e-01 -9.85726080931650816552291871630587e-01
            2.62707378198586583017970497166971e-01 -9.64875553343551572993419540580362e-01
            3.54604887042535565910839068237692e-01 -9.35016242685414833424317748722387e-01
            4.43191545599240732666856956711854e-01 -8.96426937295704107100391411222517e-01
            5.27640244106132416668231144285528e-01 -8.49467935121521189323345879529370e-01
            6.07162507818711061347016766376328e-01 -7.94577679713754370105505131505197e-01
            6.81015858786796601798130268434761e-01 -7.32268666597774009474619560933206e-01
            7.48510748171101303327645837271120e-01 -6.63122658240794859985101084021153e-01
            8.09016994374947118195962048048386e-01 -5.87785252292473248125759255344747e-01
            8.61969666880048834833871751470724e-01 -5.06959853813591099225277503137477e-01
            9.06874360850545624401775057776831e-01 -4.21401107772528815686996495060157e-01
            9.43311813257742826088758647529176e-01 -3.31907853128528662622898082190659e-01
            9.70941817426051789752250442688819e-01 -2.39315664287558654832466231709986e-01
            9.89506399451051121829436851840001e-01 -1.44489049569221067459423579748545e-01
            9.98832226832326530718830781552242e-01 -4.83133795255074466323819137869577e-02
            9.82699374563723027087291939096758e-01 5.06553044967580495816505958828202e-02
            9.72282516726416412566891267488245e-01 1.51428954661046777374622251954861e-01
            9.51559222336289090016236968949670e-01 2.50597420234822898521542811067775e-01
            9.20749163469227083211876561108511e-01 3.47109490812783749724701465311227e-01
            8.80178934413865299291046540020034e-01 4.39942114437415654482066429409315e-01
            8.30278589690879531559630777337588e-01 5.28111242204249542453453614143655e-01
            7.71577085368083337435507473855978e-01 6.10682259425050832923886900971411e-01
            7.04696671994519685533475694683148e-01 6.86779892776018807687421485752566e-01
            6.30346298589843812010258261580020e-01 7.55597488412762530174404673743993e-01
            5.49314097608348927970212116633775e-01 8.16405562701722820051486451120581e-01
            4.62459030538885873529153514027712e-01 8.68559534928162180200672537466744e-01
            3.70701782699397797138374244241277e-01 9.11506560012093403067012786777923e-01
            2.75015003743508568145870185617241e-01 9.44791388803660425743657924613217e-01
            1.76412997332229870561803863893147e-01 9.68061193837378319848596675001318e-01
            7.59409692628229687771934663942375e-02 9.81069309391041199930327820766252e-01
            -2.53360519726669973505916999556575e-02 9.83677846203740546826566060190089e-01
            -1.26344504754376196764553696993971e-01 9.75859153136333978828531598992413e-01
            -2.26013674354862775794927642891707e-01 9.57696110280398693603842730226461e-01
            -3.23287042781580435946153784243506e-01 9.29381250408642611837706226651790e-01
            -4.17133488130429830320622386352625e-01 8.91214718079617496115929498046171e-01
            -5.06558214734455725114514734741533e-01 8.43601088030730639211185462045250e-01
            -5.90613298245393325558438846201170e-01 7.87045076585381808698116401501466e-01
            -6.68407733867574349595486182806781e-01 7.22146191534377313026027422893094e-01
            -7.39116881230417521742026565334527e-01 6.49592377204206705698652513092384e-01
            -8.01991205781503957439326768508181e-01 5.70152722076042395293882236728678e-01
            -8.56364224039295462986842721875291e-01 4.84669306256510334929288319472107e-01
            -9.01659568483838325114732015208574e-01 3.94048275219077648312548944886657e-01
            -9.37397097195860506957387769944035e-01 2.99250234436609752197711031840299e-01
            -9.63197983480560404601078516861890e-01 2.01280066724387113330507759201282e-01
            -9.78788731524812383177902574971085e-01 1.01176280232277884807423617985478e-01
            -9.84004075520824028622257628740044e-01 1.20505744143452745288981784482741e-16
            -9.78788731524812383177902574971085e-01 -1.01176280232277648885030885139713e-01
            -9.63197983480560515623380979377544e-01 -2.01280066724386474952268599736271e-01
            -9.37397097195860617979690232459689e-01 -2.99250234436609530153106106808991e-01
            -9.01659568483838325114732015208574e-01 -3.94048275219077814846002638660138e-01
            -8.56364224039295351964540259359637e-01 -4.84669306256510501462742013245588e-01
            -8.01991205781504401528536618570797e-01 -5.70152722076041840182369924150407e-01
            -7.39116881230417743786631490365835e-01 -6.49592377204206594676350050576730e-01
            -6.68407733867574460617788645322435e-01 -7.22146191534377090981422497861786e-01
            -5.90613298245393214536136383685516e-01 -7.87045076585382030742721326532774e-01
            -5.06558214734456280226027047319803e-01 -8.43601088030730306144278074498288e-01
            -4.17133488130430052365227311383933e-01 -8.91214718079617385093627035530517e-01
            -3.23287042781580435946153784243506e-01 -9.29381250408642611837706226651790e-01
            -2.26013674354863636217771727388026e-01 -9.57696110280398471559237805195153e-01
            -1.26344504754376002475524387591577e-01 -9.75859153136333978828531598992413e-01
            -2.53360519726674518481424058791163e-02 -9.83677846203740546826566060190089e-01
            7.59409692628227328548007335484726e-02 -9.81069309391041199930327820766252e-01
            1.76412997332229648517198938861839e-01 -9.68061193837378319848596675001318e-01
            2.75015003743508568145870185617241e-01 -9.44791388803660425743657924613217e-01
            3.70701782699397797138374244241277e-01 -9.11506560012093403067012786777923e-01
            4.62459030538885484951094895222923e-01 -8.68559534928162402245277462498052e-01
            5.49314097608348594903304729086813e-01 -8.16405562701723153118393838667544e-01
            6.30346298589843700987955799064366e-01 -7.55597488412762752219009598775301e-01
            7.04696671994519574511173232167494e-01 -6.86779892776018918709723948268220e-01
            7.71577085368082782323995161277708e-01 -6.10682259425051499057701676065335e-01
            8.30278589690879642581933239853242e-01 -5.28111242204249431431151151628001e-01
            8.80178934413865077246441614988726e-01 -4.39942114437416154082427510729758e-01
            9.20749163469227305256481486139819e-01 -3.47109490812783250124340383990784e-01
            9.51559222336288978993934506434016e-01 -2.50597420234823120566147736099083e-01
            9.72282516726416301544588804972591e-01 -1.51428954661047665553041952080093e-01
            9.82699374563723027087291939096758e-01 -5.06553044967579316204542294599378e-02
            9.53571104502499378163804522046121e-01 5.26099838830815652590544573286024e-02
            9.41996043035489449835040431935340e-01 1.57191337712276918425757799013809e-01
            9.18986425667685180584953741345089e-01 2.59864601638674252992444735355093e-01
            8.84821557984278084241225315054180e-01 3.59383461323096342621141729978262e-01
            8.39916155197988567593370135000441e-01 4.54539892620794305777565114112804e-01
            7.84815308068171346711494607006898e-01 5.44178825358131779132975225365954e-01
            7.20187866237396723256836139626103e-01 6.27212164319793985534090552391717e-01
            6.46818319302838062867522239685059e-01 7.02631997250727668991032714984613e-01
            5.65597274175258069028870977490442e-01 7.69522829545565056896805344877066e-01
            4.77510644317562626959272620297270e-01 8.27072697112969046351338420208776e-01
            3.83627682090912580648023322282825e-01 8.74583022519788366722082173509989e-01
            2.85087999479509190958737008259050e-01 9.11477094774776119834314158651978e-01
            1.83087734744862867808379292000609e-01 9.37307069818791860349449507339159e-01
            7.88650329276320560811797122369171e-02 9.51759406745012581652076733007561e-01
            -2.63149835559354366987250273268728e-02 9.54658673760808373920383473887341e-01
            -1.31175571786355277259517038146441e-01 9.45969677692058752427328727208078e-01
            -2.34443866270427403453169290514779e-01 9.25797891180612175787700834916905e-01
            -3.34866329804053841634470245480770e-01 8.94388172389291691288804031501058e-01
            -4.31223969715811006331307453365298e-01 8.52121792755491158644076676864643e-01
            -5.22347134786688038765589681133861e-01 7.99511808872409468484931949205929e-01
            -6.07129713231435164111360336391954e-01 7.37196834677014800618621848116163e-01
            -6.84542559397257610598330757056829e-01 6.65933289541938089328709793335292e-01
            -7.53645986197922668203830198763171e-01 5.86586216368962465317338228487642e-01
            -8.13601171642053144772432915488025e-01 5.00118781140013846098213434743229e-01
            -8.63680340995803264014796241099248e-01 4.07580581386880913541403970157262e-01
            -9.03275600982259563309639815997798e-01 3.10094905498998041348812648720923e-01
            -9.31906318782347087292805554170627e-01 2.08845097524048450843281443667365e-01
            -9.49224956266170760699196762288921e-01 1.05060192974223351458640252076293e-01
            -9.55021288635125031873940315563232e-01 1.16956376424458628392888922573317e-16
            -9.49224956266170760699196762288921e-01 -1.05060192974223115536247519230528e-01
            -9.31906318782347087292805554170627e-01 -2.08845097524048256554252134264971e-01
            -9.03275600982259674331942278513452e-01 -3.10094905498997819304207723689615e-01
            -8.63680340995803486059401166130556e-01 -4.07580581386880302918740426321165e-01
            -8.13601171642053033750130452972371e-01 -5.00118781140014068142818359774537e-01
            -7.53645986197922890248435123794479e-01 -5.86586216368962354295035765971988e-01
            -6.84542559397257832642935682088137e-01 -6.65933289541937978306407330819638e-01
            -6.07129713231435386155965261423262e-01 -7.37196834677014689596319385600509e-01
            -5.22347134786688260810194606165169e-01 -7.99511808872409357462629486690275e-01
            -4.31223969715811228375912378396606e-01 -8.52121792755491047621774214348989e-01
            -3.34866329804054063679075170512078e-01 -8.94388172389291580266501568985404e-01
            -2.34443866270427403453169290514779e-01 -9.25797891180612175787700834916905e-01
            -1.31175571786355305015092653775355e-01 -9.45969677692058752427328727208078e-01
            -2.63149835559354609848536910021721e-02 -9.54658673760808373920383473887341e-01
            7.88650329276311956583356277405983e-02 -9.51759406745012692674379195523215e-01
            1.83087734744862840052803676371695e-01 -9.37307069818791860349449507339159e-01
            2.85087999479509190958737008259050e-01 -9.11477094774776119834314158651978e-01
            3.83627682090911970025359778446727e-01 -8.74583022519788477744384636025643e-01
            4.77510644317562626959272620297270e-01 -8.27072697112969046351338420208776e-01
            5.65597274175257402895056202396518e-01 -7.69522829545565500986015194939682e-01
            6.46818319302838062867522239685059e-01 -7.02631997250727780013335177500267e-01
            7.20187866237396945301441064657411e-01 -6.27212164319793763489485627360409e-01
            7.84815308068170902622284756944282e-01 -5.44178825358132334244487537944224e-01
            8.39916155197988678615672597516095e-01 -4.54539892620794194755262651597150e-01
            8.84821557984277862196620390022872e-01 -3.59383461323097064266107736330014e-01
            9.18986425667684958540348816313781e-01 -2.59864601638674974637410741706844e-01
            9.41996043035489560857342894450994e-01 -1.57191337712276751892304105240328e-01
            9.53571104502499378163804522046121e-01 -5.26099838830822313928692324225267e-02
            9.16040215144002578639970124640968e-01 5.43622722530010885066964476663998e-02
            9.03181018508296462599105325352866e-01 1.62323689620141542455655780941015e-01
            8.77643140169943047901313093461795e-01 2.68006438202931074332724392661476e-01
            8.39785075961092974949906420079060e-01 3.69926963870709335502340309176361e-01
            7.90138270117338503695236795465462e-01 4.66654525855648150134413754130946e-01
            7.29399654965585009236406222044025e-01 5.56831281216909834697048609086778e-01
            6.58421867521877035578370396251557e-01 6.39191345979107872210533969337121e-01
            5.78201280336695266903745960007655e-01 7.12578565368469529772710302495398e-01
            4.89864014608423770091860660613747e-01 7.75962743691536949164344605378574e-01
            3.94650131910213086694483308747294e-01 8.28454106024486658377270487108035e-01
            2.93896226443740860023723371341475e-01 8.69315788702649250296872196486220e-01
            1.89016662186472533813130780799838e-01 8.97974183271136539019607880618423e-01
            8.14837183217390625955545147007797e-02 9.14026988690182617958157607063185e-01
            -2.71930783337180313752323712606085e-02 9.17248858759887486513662224751897e-01
            -1.35488143777332759043474652571604e-01 9.07594565486898874340226939239074e-01
            -2.41881252675987451494776792060293e-01 8.85199633986297418353217381081777e-01
            -3.44878878997316395960126556019532e-01 8.50378440006056557365354819921777e-01
            -4.43035161841349001132783769207890e-01 8.03619796780660200496981815376785e-01
            -5.34972202158180754061334027937846e-01 7.45580093164782908843335462734103e-01
            -6.19399405430241301040439338976284e-01 6.77074079372592230186000961111858e-01
            -6.95131598790302729362622358166846e-01 5.99063429670696478979152743704617e-01
            -7.61105668250605216229587313137017e-01 5.12643242579456592800113412522478e-01
            -8.16395482492869417612268989614677e-01 4.19026668090248022302546360151609e-01
            -8.60224893721901806564744674687972e-01 3.19527877698836337838628196550417e-01
            -8.91978633079300808894629426504252e-01 2.15543616318279729338058814391843e-01
            -9.11210947669544024662968695338350e-01 1.08533595042047681378249990302720e-01
            -9.17651857953537763989970699185506e-01 1.12379941057442158795353540291617e-16
            -9.11210947669544024662968695338350e-01 -1.08533595042047861789491491890658e-01
            -8.91978633079301030939234351535561e-01 -2.15543616318279118715395270555746e-01
            -8.60224893721901917587047137203626e-01 -3.19527877698836115794023271519109e-01
            -8.16395482492869528634571452130331e-01 -4.19026668090247800257941435120301e-01
            -7.61105668250605327251889775652671e-01 -5.12643242579456481777810950006824e-01
            -6.95131598790303062429529745713808e-01 -5.99063429670695923867640431126347e-01
            -6.19399405430241745129649189038901e-01 -6.77074079372591897119093573564896e-01
            -5.34972202158180976105938952969154e-01 -7.45580093164782797821033000218449e-01
            -4.43035161841348834599330075434409e-01 -8.03619796780660311519284277892439e-01
            -3.44878878997316562493580249793013e-01 -8.50378440006056446343052357406123e-01
            -2.41881252675987507005928023318120e-01 -8.85199633986297418353217381081777e-01
            -1.35488143777333203132684502634220e-01 -9.07594565486898763317924476723420e-01
            -2.71930783337182534198372962919166e-02 -9.17248858759887486513662224751897e-01
            8.14837183217384242173153552357689e-02 -9.14026988690182728980460069578839e-01
            1.89016662186472894635613783975714e-01 -8.97974183271136427997305418102769e-01
            2.93896226443741082068328296372783e-01 -8.69315788702649250296872196486220e-01
            3.94650131910212698116424689942505e-01 -8.28454106024486769399572949623689e-01
            4.89864014608423770091860660613747e-01 -7.75962743691536949164344605378574e-01
            5.78201280336694822814536109945038e-01 -7.12578565368469973861920152558014e-01
            6.58421867521876924556067933735903e-01 -6.39191345979108094255138894368429e-01
            7.29399654965585009236406222044025e-01 -5.56831281216909834697048609086778e-01
            7.90138270117338170628329407918500e-01 -4.66654525855648483201321141677909e-01
            8.39785075961092974949906420079060e-01 -3.69926963870709446524642771692015e-01
            8.77643140169943158923615555977449e-01 -2.68006438202930907799270698887995e-01
            9.03181018508296351576802862837212e-01 -1.62323689620141820011411937230150e-01
            9.16040215144002578639970124640968e-01 -5.43622722530010676900147359447146e-02
            8.71730253722774683922125404933468e-01 5.59669391988803568982469016646064e-02
            8.57416467056930309276197021972621e-01 1.66981842002285024717522787796042e-01
            8.29023925706568909355098639935022e-01 2.75254907576474361352580899620079e-01
            7.87018834415709300778019041899825e-01 3.79008295178090703902995528551401e-01
            7.32090915622053528544199707539519e-01 4.76538377051132666650801184005104e-01
            6.65142084233629748979410578613169e-01 5.66243711947609362766797858057544e-01
            5.87271638210934976420674047403736e-01 6.46651340748558900450859709962970e-01
            4.99758208124817582262977566642803e-01 7.16440972412058396656675540725701e-01
            4.04038762077851942855488687200705e-01 7.74466663115631614999756493489258e-01
            3.01685010727822777720774638510193e-01 8.19775632622132599536257657746319e-01
            1.94377599842174730859767350921175e-01 8.51623908904899029614909977681236e-01
            8.38785141409771617393431597520248e-02 8.69488544147860697997032275452511e-01
            -2.79978544434687677544548733976626e-02 8.73076201534222717803856994578382e-01
            -1.39414499031995209321621587150730e-01 8.62327971828887207550451421411708e-01
            -2.48541961400738142806687847041758e-01 8.37420340666464979584304728632560e-01
            -3.53588371634594389458783325608238e-01 7.98762290662034302179961287038168e-01
            -4.52828870581688969210176765045617e-01 7.46988585927908510520012441702420e-01
            -5.44633931992961839441136362438556e-01 6.82949349264460603414761408203049e-01
            -6.27496119298127985608459766808664e-01 6.07696103167244094933607811981346e-01
            -7.00054837672485552602097413910087e-01 5.22464503856687079164089482219424e-01
            -7.61118674966321462349583271134179e-01 4.28654051837114080658608372687013e-01
            -8.09684964659472039549825694848550e-01 3.27805112137156628993039930719533e-01
            -8.44956249617863197620692972122924e-01 2.21573621558568134570776919645141e-01
            -8.66353376317605228251750304480083e-01 1.11703898239721766127985347338836e-01
            -8.73525004529844162348695135733578e-01 1.06975960077265082473854052717858e-16
            -8.66353376317605339274052766995737e-01 -1.11703898239721571838956037936441e-01
            -8.44956249617863197620692972122924e-01 -2.21573621558567940281747610242746e-01
            -8.09684964659472150572128157364205e-01 -3.27805112137156462459586236946052e-01
            -7.61118674966321795416490658681141e-01 -4.28654051837113581058247291366570e-01
            -7.00054837672485663624399876425741e-01 -5.22464503856686968141787019703770e-01
            -6.27496119298128096630762229324318e-01 -6.07696103167243983911305349465692e-01
            -5.44633931992961950463438824954210e-01 -6.82949349264460381370156483171741e-01
            -4.52828870581689413299386615108233e-01 -7.46988585927908177453105054155458e-01
            -3.53588371634594778036841944413027e-01 -7.98762290662034191157658824522514e-01
            -2.48541961400738142806687847041758e-01 -8.37420340666464979584304728632560e-01
            -1.39414499031994848499138583974855e-01 -8.62327971828887207550451421411708e-01
            -2.79978544434687851016896331657335e-02 -8.73076201534222717803856994578382e-01
            8.38785141409765511166796159159276e-02 -8.69488544147860697997032275452511e-01
            1.94377599842174536570738041518780e-01 -8.51623908904899029614909977681236e-01
            3.01685010727822777720774638510193e-01 -8.19775632622132599536257657746319e-01
            4.04038762077851776322034993427224e-01 -7.74466663115631726022058956004912e-01
            4.99758208124817582262977566642803e-01 -7.16440972412058396656675540725701e-01
            5.87271638210934754376069122372428e-01 -6.46651340748559233517767097509932e-01
            6.65142084233629082845595803519245e-01 -5.66243711947610139922915095667122e-01
            7.32090915622053750588804632570827e-01 -4.76538377051132333583893796458142e-01
            7.87018834415709189755716579384170e-01 -3.79008295178090870436449222324882e-01
            8.29023925706568798332796177419368e-01 -2.75254907576474971975244443456177e-01
            8.57416467056930309276197021972621e-01 -1.66981842002285330028854559714091e-01
            8.71730253722774683922125404933468e-01 -5.59669391988811340543641392741847e-02
            8.21573064090565852168879246164579e-01 5.74499851505146374996968461346114e-02
            8.05582078923552269422714289248688e-01 1.71231756838978649293281364407449e-01
            7.73911354926324901448708715179237e-01 2.81680697153808501376204276311910e-01
            7.27177326716575089804450726660434e-01 3.86647043105583565480998231578269e-01
            6.66289618994236554350152346160030e-01 4.84087744167801314887356056715362e-01
            5.92433341731383622530415777873714e-01 5.72106227931440391998307859466877e-01
            5.07046023354667418914232257520780e-01 6.48989314729582988938716425764142e-01
            4.11789630889655811074590019416064e-01 7.13240562730917959655130289320368e-01
            3.08518221663139413646348430120270e-01 7.63609394477811176393799996731104e-01
            1.99241856186226140579265120322816e-01 7.99115437954005969345416815485805e-01
            8.60874746128999085437172311685572e-02 8.19067608410764091964040289894911e-01
            -2.87425017307150650058833463162955e-02 8.23077559545402404062031109788222e-01
            -1.43013037972253176377535055507906e-01 8.11067242220336659386248356895521e-01
            -2.54499988104580743275562326743966e-01 7.83270423600766263483308193826815e-01
            -3.61033385457898592374448298869538e-01 7.40228137142708075835173531231703e-01
            -4.60539678632667315305582178552868e-01 6.82778151992193604868930378870573e-01
            -5.51082090818971526147151962504722e-01 6.12038666761787530923299982532626e-01
            -6.30898316954071503026568734640023e-01 5.29386545066528380054649005614920e-01
            -6.98434824985859736834470368194161e-01 4.36430516439818727558730415694299e-01
            -7.52377093607136337993779306998476e-01 3.34979864242962999121289158210857e-01
            -7.91675197917609430042773510649567e-01 2.27009210022565965925167574823718e-01
            -8.15564245017806777049429456383223e-01 1.14620079748228520521990958513925e-01
            -8.23579261779311400104575113800820e-01 1.00859370678217373596301940273011e-16
            -8.15564245017806777049429456383223e-01 -1.14620079748228340110749456925987e-01
            -7.91675197917609541065075973165222e-01 -2.27009210022565410813655262245447e-01
            -7.52377093607136560038384232029784e-01 -3.34979864242962499520928076890414e-01
            -6.98434824985859847856772830709815e-01 -4.36430516439818672047579184436472e-01
            -6.30898316954071725071173659671331e-01 -5.29386545066528158010044080583612e-01
            -5.51082090818971637169454425020376e-01 -6.12038666761787419900997520016972e-01
            -4.60539678632667759394792028615484e-01 -6.82778151992193271802022991323611e-01
            -3.61033385457898814419053223900846e-01 -7.40228137142708075835173531231703e-01
            -2.54499988104580909809016020517447e-01 -7.83270423600766152461005731311161e-01
            -1.43013037972253204133110671136819e-01 -8.11067242220336659386248356895521e-01
            -2.87425017307158213453188722041887e-02 -8.23077559545402293039728647272568e-01
            8.60874746128995199656586123637680e-02 -8.19067608410764202986342752410565e-01
            1.99241856186225752001206501518027e-01 -7.99115437954006080367719278001459e-01
            3.08518221663139413646348430120270e-01 -7.63609394477811176393799996731104e-01
            4.11789630889655811074590019416064e-01 -7.13240562730917959655130289320368e-01
            5.07046023354667529936534720036434e-01 -6.48989314729582766894111500732834e-01
            5.92433341731383289463508390326751e-01 -5.72106227931440614042912784498185e-01
            6.66289618994236443327849883644376e-01 -4.84087744167801536931960981746670e-01
            7.27177326716575089804450726660434e-01 -3.86647043105583565480998231578269e-01
            7.73911354926324901448708715179237e-01 -2.81680697153808445865053045054083e-01
            8.05582078923552269422714289248688e-01 -1.71231756838979121138066830098978e-01
            8.21573064090565963191181708680233e-01 -5.74499851505141864715930921647669e-02
            7.66191662005845874894305325142341e-01 5.88240005689373360309168958792725e-02
            7.48232778842367940441704377008136e-01 1.75093216990387018361374771302508e-01
            7.12735953515520548329220673622331e-01 2.87258396807711091636150513295433e-01
            6.60533201525250968089153502660338e-01 3.92690483272789436774985460942844e-01
            5.92848111133210120549108523846371e-01 4.88918237638973351977256243117154e-01
            5.11267163490965237393481856997823e-01 5.73686162902781959793685473414371e-01
            4.17702546866445478812579494842794e-01 6.45007370741993657503599024494179e-01
            3.14347336571638158453367850597715e-01 7.01210152493909610882383276475593e-01
            2.03624091136039186977768622455187e-01 7.40977162589533944192510261927964e-01
            8.81280695879882447485442753531970e-02 7.63376296017180044906069724675035e-01
            -2.94335992173172175667694716594269e-02 7.67882536073929089504019884770969e-01
            -1.46305369403730456401291348811355e-01 7.54390260312162719280593137227697e-01
            -2.59747865734001326387669905670919e-01 7.23215716240214079313375350466231e-01
            -3.67102092243549005257108319710824e-01 6.75089608748811631500075236544944e-01
            -4.65851756852213527704265061402111e-01 6.11139973007756021061709361674730e-01
            -5.53682251117901591541681227681693e-01 5.32865734277620406444953005120624e-01
            -6.28534902696700870095014579419512e-01 4.42101574372070538210266477108235e-01
            -6.88655228877769753914606098987861e-01 3.40974928271157884385189618114964e-01
            -7.32634060171049594778480695822509e-01 2.31856118848516867814169017947279e-01
            -7.59440570045754603789589509688085e-01 1.17302798512200642799818695038994e-01
            -7.68446436630566109826645515568089e-01 4.35366317748945553978623638323682e-16
            -7.59440570045754603789589509688085e-01 -1.17302798512200448510789385636599e-01
            -7.32634060171049594778480695822509e-01 -2.31856118848516978836471480462933e-01
            -6.88655228877769753914606098987861e-01 -3.40974928271157717851735924341483e-01
            -6.28534902696701203161921966966474e-01 -4.42101574372070149632207858303445e-01
            -5.53682251117901813586286152713001e-01 -5.32865734277620295422650542604970e-01
            -4.65851756852213472193113830144284e-01 -6.11139973007756132084011824190384e-01
            -3.67102092243548838723654625937343e-01 -6.75089608748811631500075236544944e-01
            -2.59747865734001326387669905670919e-01 -7.23215716240214079313375350466231e-01
            -1.46305369403730983757228045760712e-01 -7.54390260312162608258290674712043e-01
            -2.94335992173174049169048771545931e-02 -7.67882536073929089504019884770969e-01
            8.81280695879882308707564675387403e-02 -7.63376296017180044906069724675035e-01
            2.03624091136038853910861234908225e-01 -7.40977162589534055214812724443618e-01
            3.14347336571637991919914156824234e-01 -7.01210152493909610882383276475593e-01
            4.17702546866445645346033188616275e-01 -6.45007370741993546481296561978525e-01
            5.11267163490965015348876931966515e-01 -5.73686162902782181838290398445679e-01
            5.92848111133209565437596211268101e-01 -4.88918237638973851577617324437597e-01
            6.60533201525250635022246115113376e-01 -3.92690483272789880864195311005460e-01
            7.12735953515520437306918211106677e-01 -2.87258396807711258169604207068915e-01
            7.48232778842367940441704377008136e-01 -1.75093216990386935094647924415767e-01
            7.66191662005845874894305325142341e-01 -5.88240005689376552200364756117779e-02
            7.06036831452494739735925577406306e-01 6.00925904506959748796468545606331e-02
            6.85725437289629646819832942128414e-01 1.78549016935125426375208235185710e-01
            6.45686970793102887888892382761696e-01 2.91868913285708131422069300242583e-01
            5.87073265746167027856472486746497e-01 3.96792272405453838590716486578458e-01
            5.11570531725318300431126772309653e-01 4.90300640285966315978782859019702e-01
            4.21350844920854727959635965817142e-01 5.69703951433580324525962623738451e-01
            3.19009661459570381669692551440676e-01 6.32717917155823705854800209635869e-01
            2.07491150857522843597990913622198e-01 6.77529740388105983228683726338204e-01
            9.00034976234916350712467192352051e-02 7.02850266564715497885629247321049e-01
            -3.00733923682114830111533620993214e-02 7.07951070248517333460824829671765e-01
            -1.49285125615969127554905071519897e-01 6.92685410604538365220150808454491e-01
            -2.64202197602499189166280757490313e-01 6.57492452866619170315232167922659e-01
            -3.71518653395735698463653307044297e-01 6.03384634353223092695372997695813e-01
            -4.68147193953086404594188252303866e-01 5.31918538489123071677511234156555e-01
            -5.51307992093857612836416137724882e-01 4.45150114734336077582099733263021e-01
            -6.18608663066022468335347639367683e-01 3.45575532661416440216584078370943e-01
            -6.68113089099736101594828596716980e-01 2.36059371701615838823329340812052e-01
            -6.98397117990489424421696185163455e-01 1.19752212410176195334088333765976e-01
            -7.08589533365088231064987667195965e-01 8.67771903944871915200456071686808e-17
            -6.98397117990489424421696185163455e-01 -1.19752212410176014922846832178038e-01
            -6.68113089099736101594828596716980e-01 -2.36059371701615700045451262667484e-01
            -6.18608663066022690379952564398991e-01 -3.45575532661416051638525459566154e-01
            -5.51307992093857501814113675209228e-01 -4.45150114734336244115553427036502e-01
            -4.68147193953086571127641946077347e-01 -5.31918538489122960655208771640901e-01
            -3.71518653395736087041711925849086e-01 -6.03384634353222870650768072664505e-01
            -2.64202197602499355699734451263794e-01 -6.57492452866619059292929705407005e-01
            -1.49285125615968988777026993375330e-01 -6.92685410604538365220150808454491e-01
            -3.00733923682118126086137976926693e-02 -7.07951070248517222438522367156111e-01
            9.00034976234911354708856379147619e-02 -7.02850266564715497885629247321049e-01
            2.07491150857522510531083526075236e-01 -6.77529740388105983228683726338204e-01
            3.19009661459570381669692551440676e-01 -6.32717917155823705854800209635869e-01
            4.21350844920854894493089659590623e-01 -5.69703951433580213503660161222797e-01
            5.11570531725318189408824309793999e-01 -4.90300640285966482512236552793183e-01
            5.87073265746166694789565099199535e-01 -3.96792272405454227168775105383247e-01
            6.45686970793102776866589920246042e-01 -2.91868913285708297955522994016064e-01
            6.85725437289629646819832942128414e-01 -1.78549016935125370864057003927883e-01
            7.06036831452494628713623114890652e-01 -6.00925904506962801909786264786817e-02
            6.41449025708720199645540560595691e-01 6.12509554338709974463661467325437e-02
            6.18265386640472036638982444856083e-01 1.81539097184425096687121481409122e-01
            5.72736025624284494917048959905514e-01 2.95265942967229910731674635826494e-01
            5.06506492392875706798349710879847e-01 3.98321108263288314876859885771410e-01
            4.21970494836594489651560024867649e-01 4.86979910891186640320427159167593e-01
            3.22183384163518216070087873958983e-01 5.58037990725695376426074290066026e-01
            2.10751726546152595709315846761456e-01 6.08927123621574417633439679775620e-01
            9.17029524231416925950099994224729e-02 6.37808043725624052022737942024833e-01
            -3.06602053301538828022909655146577e-02 6.43636919336780466416314538946608e-01
            -1.51915223378431607503813438597717e-01 6.26203079703469445149721650523134e-01
            -2.67679629442559408047941360564437e-01 5.86136629213464654952758792205714e-01
            -3.73769396266160847108750431289081e-01 5.24885673779593719956437780638225e-01
            -4.66350163262040262601715312484885e-01 4.44663982519044265195873322227271e-01
            -5.42075820294130483745220772107132e-01 3.48370976369550722218093596893596e-01
            -5.98209444816017232859906016528839e-01 2.39486935462335709390302440624509e-01
            -6.32722221382747029849724640371278e-01 1.21947212730387971602041830010421e-01
            -6.44366768327036321117873285402311e-01 7.89121700308629139709712422601190e-17
            -6.32722221382747140872027102886932e-01 -1.21947212730387541390619787762262e-01
            -5.98209444816017232859906016528839e-01 -2.39486935462335570612424362479942e-01
            -5.42075820294130705789825697138440e-01 -3.48370976369550333640034978088806e-01
            -4.66350163262040318112866543742712e-01 -4.44663982519044154173570859711617e-01
            -3.73769396266160958131052893804736e-01 -5.24885673779593608934135318122571e-01
            -2.67679629442559297025638898048783e-01 -5.86136629213464765975061254721368e-01
            -1.51915223378431635259389054226631e-01 -6.26203079703469445149721650523134e-01
            -3.06602053301541881136227374327063e-02 -6.43636919336780466416314538946608e-01
            9.17029524231413872836782275044243e-02 -6.37808043725624052022737942024833e-01
            2.10751726546152595709315846761456e-01 -6.08927123621574528655742142291274e-01
            3.22183384163518216070087873958983e-01 -5.58037990725695376426074290066026e-01
            4.21970494836594156584652637320687e-01 -4.86979910891186917876183315456728e-01
            5.06506492392875484753744785848539e-01 -3.98321108263288592432616042060545e-01
            5.72736025624284383894746497389860e-01 -2.95265942967230077265128329599975e-01
            6.18265386640472036638982444856083e-01 -1.81539097184425179953848328295862e-01
            6.41449025708720199645540560595691e-01 -6.12509554338714970467272280529869e-02
            5.72689060867008992161686364852358e-01 6.22836887752551277008805641344225e-02
            5.45910756879043002065543532808078e-01 1.83938750261982641998059762045159e-01
            4.93606272635640941359724820358679e-01 2.96993040219697523873776390246348e-01
            4.18221307687765442295813045348041e-01 3.96160265700795655163801711751148e-01
            3.23280779212008373413311801414238e-01 4.76803477458235702712840975436848e-01
            2.13224000801077534505978405832138e-01 5.35151888538732189992686016921652e-01
            9.31971050941439727033355211460730e-02 5.68477192089762439763944712467492e-01
            -3.11875836658486622898767137712639e-02 5.75221133955694741146658088837285e-01
            -1.54113975676136244485903148415673e-01 5.55068374910231088215084582770942e-01
            -2.69834169469188978052187621869962e-01 5.08961235568154535258145187981427e-01
            -3.72937217397002085395030235304148e-01 4.39055634520695792222255704473355e-01
            -4.58602135529277865622077570151305e-01 3.48620279978338887261202216905076e-01
            -5.22823327503869950128034815861611e-01 2.41883828607806494748189152232953e-01
            -5.62597881760774187753781916399021e-01 1.23837158246140208173180496942223e-01
            -5.76065984349179882606506453157635e-01 7.05477363830892369698246110744778e-17
            -5.62597881760774187753781916399021e-01 -1.23837158246140069395302418797655e-01
            -5.22823327503869839105732353345957e-01 -2.41883828607806578014915999119694e-01
            -4.58602135529278143177833726440440e-01 -3.48620279978338609705446060615941e-01
            -3.72937217397001918861576541530667e-01 -4.39055634520695847733406935731182e-01
            -2.69834169469189366630246240674751e-01 -5.08961235568154424235842725465773e-01
            -1.54113975676136494286083689075895e-01 -5.55068374910230977192782120255288e-01
            -3.11875836658490578068292364832814e-02 -5.75221133955694630124355626321631e-01
            9.31971050941438478032452508159622e-02 -5.68477192089762439763944712467492e-01
            2.13224000801077284705797865171917e-01 -5.35151888538732301014988479437307e-01
            3.23280779212008317902160570156411e-01 -4.76803477458235758223992206694675e-01
            4.18221307687765442295813045348041e-01 -3.96160265700795655163801711751148e-01
            4.93606272635640941359724820358679e-01 -2.96993040219697523873776390246348e-01
            5.45910756879043002065543532808078e-01 -1.83938750261982586486908530787332e-01
            5.72689060867008881139383902336704e-01 -6.22836887752555440345147985681251e-02
            4.99951448791290165019063351792283e-01 6.31585557790349666484885915451741e-02
            4.68537660570923386593733539484674e-01 1.85507182996588249057623443150078e-01
            4.07683927975906912344328247854719e-01 2.96199711658770903355275549984071e-01
            3.21213914829558855323909938306315e-01 3.88280923091094465338102281748434e-01
            2.14560850072327058413179656781722e-01 4.55965016128259403860312204415095e-01
            9.44261380054428473007632760527486e-02 4.94999150280059085904582616421976e-01
            -3.16417155873667602095089534941508e-02 5.02930667340232506745678620063700e-01
            -1.55721403819732151507793105338351e-01 4.79261200921809793484840156452265e-01
            -2.70016543546842235912208707304671e-01 4.25477990650068471634170919060125e-01
            -3.67345550791521591182942074738094e-01 3.44960433427193347011296964410576e-01
            -4.41592886077538271383247092671809e-01 2.42767743496358573418447690528410e-01
            -4.88093316266273280490395336528309e-01 1.25321063404342347702424831368262e-01
            -5.03925048312349188606162897485774e-01 6.17130197425893810483697926343373e-17
            -4.88093316266273391512697799043963e-01 -1.25321063404342014635517443821300e-01
            -4.41592886077538271383247092671809e-01 -2.42767743496358656685174537415151e-01
            -3.67345550791521813227546999769402e-01 -3.44960433427193124966692039379268e-01
            -2.70016543546841958356452551015536e-01 -4.25477990650068638167624612833606e-01
            -1.55721403819732401307973645998572e-01 -4.79261200921809737973688925194438e-01
            -3.16417155873666630649942987929535e-02 -5.02930667340232506745678620063700e-01
            9.44261380054425975005827353925270e-02 -4.94999150280059141415733847679803e-01
            2.14560850072326642079545422348019e-01 -4.55965016128259570393765898188576e-01
            3.21213914829558633279305013275007e-01 -3.88280923091094631871555975521915e-01
            4.07683927975906856833177016596892e-01 -2.96199711658771014377578012499725e-01
            4.68537660570923386593733539484674e-01 -1.85507182996588221302047827521164e-01
            4.99951448791290109507912120534456e-01 -6.31585557790351609375179009475687e-02
            4.23362795748814246810098893547547e-01 6.38116741707628748470071400333836e-02
            3.85745153449504218912124997586943e-01 1.85765075229296638958942367025884e-01
            3.13852361451482098075871363107581e-01 2.91212434137102127440499543808983e-01
            2.14072409820093290111486794558004e-01 3.70784290307108133077917955233715e-01
            9.52711851348920918391982581852062e-02 4.17410335123270415103036157233873e-01
            -3.19953024402537811177182902611094e-02 4.26947639888645480432671774906339e-01
            -1.56418866984511184536899008890032e-01 3.98548773221057084370499978831504e-01
            -2.66943928764303062273199884657515e-01 3.34737099050294251156856262241490e-01
            -3.53749851009250437794406707325834e-01 2.41182564659348730451426945364801e-01
            -4.09123546586374065014979350962676e-01 1.26197900986168454195990307198372e-01
            -4.28144819640186469200671126600355e-01 5.24326182943875223052526023727039e-17
            -4.09123546586374176037281813478330e-01 -1.26197900986168176640234150909237e-01
            -3.53749851009250382283255476068007e-01 -2.41182564659348841473729407880455e-01
            -2.66943928764303117784351115915342e-01 -3.34737099050294195645705030983663e-01
            -1.56418866984511101270172162003291e-01 -3.98548773221057084370499978831504e-01
            -3.19953024402540725512622543647012e-02 -4.26947639888645480432671774906339e-01
            9.52711851348919946946836034840089e-02 -4.17410335123270415103036157233873e-01
            2.14072409820092957044579407011042e-01 -3.70784290307108299611371649007197e-01
            3.13852361451482209098173825623235e-01 -2.91212434137102016418197081293329e-01
            3.85745153449504163400973766329116e-01 -1.85765075229296722225669213912624e-01
            4.23362795748814191298947662289720e-01 -6.38116741707632217917023353948025e-02
            3.42957196621688276128026018341188e-01 6.41098108699240387675644115006435e-02
            2.96638926826499116362612085140427e-01 1.83671047407063331435850273010146e-01
            2.10257926230354053043214435092523e-01 2.78426491235470974228149998452864e-01
            9.54804276174105875929498665755091e-02 3.35578894608080546824169232422719e-01
            -3.21922318205779475763783636921289e-02 3.47409508757021479041782185959164e-01
            -1.55517151967882766294692942210531e-01 3.12320543685783269527433958501206e-01
            -2.57838618991637680277762001423980e-01 2.35050958561903999832765066457796e-01
            -3.25337551787462209151868819390074e-01 1.26036439021915969149745251343120e-01
            -3.48897845456782373929627283359878e-01 4.27276629668056443283607468474999e-17
            -3.25337551787462320174171281905728e-01 -1.26036439021915774860715941940725e-01
            -2.57838618991637569255459538908326e-01 -2.35050958561904055343916297715623e-01
            -1.55517151967883127117175945386407e-01 -3.12320543685783102993980264727725e-01
            -3.21922318205779545152722675993573e-02 -3.47409508757021479041782185959164e-01
            9.54804276174105043262230196887685e-02 -3.35578894608080546824169232422719e-01
            2.10257926230353969776487588205782e-01 -2.78426491235471029739301229710691e-01
            2.96638926826499005340309622624773e-01 -1.83671047407063497969303966783627e-01
            3.42957196621688276128026018341188e-01 -6.41098108699239416230497567994462e-02
            2.58595244305062255119054270835477e-01 6.37380032065438806299084717466030e-02
            1.99354190245300294526131779093703e-01 1.76612401211219710583932851477584e-01
            9.44434936787727635776334977890656e-02 2.49027026508569615526056395538035e-01
            -3.21030691220798580776119024449144e-02 2.64392561133809489426482741691871e-01
            -1.51295205670987059631826809891209e-01 2.19188946279062962796402302956267e-01
            -2.35827433905554439963481172526372e-01 1.23771785344938656248103825419093e-01
            -2.66334439061027605788467553793453e-01 -8.56596887685920857253176535227450e-17
            -2.35827433905554578741359250670939e-01 -1.23771785344938392570135476944415e-01
            -1.51295205670987115142978041149036e-01 -2.19188946279062935040826687327353e-01
            -3.21030691220800454277473079400806e-02 -2.64392561133809489426482741691871e-01
            9.44434936787727635776334977890656e-02 -2.49027026508569615526056395538035e-01
            1.99354190245300211259404932206962e-01 -1.76612401211219793850659698364325e-01
            2.58595244305062255119054270835477e-01 -6.37380032065439083854840873755165e-02
            1.69696341674339196137211160930747e-01 6.17644172333267418850688557085959e-02
            9.02935374401547946598967087084020e-02 1.56392994441470728483878360748349e-01
            -3.13586164631672395519679241715494e-02 1.77843551435925006920513169461628e-01
            -1.38337725211171908012985909408599e-01 1.16079134202598299729913833289174e-01
            -1.80587074880309561564217801787890e-01 2.21155383219554491592578459053036e-17
            -1.38337725211171991279712756295339e-01 -1.16079134202598202585399178587977e-01
            -3.13586164631672464908618280787778e-02 -1.77843551435925006920513169461628e-01
            9.02935374401546558820186305638344e-02 -1.56392994441470811750605207635090e-01
            1.69696341674339196137211160930747e-01 -6.17644172333267210683871439869108e-02
            7.42464472227394312042747515079100e-02 5.39432014606257073663364565163647e-02
            -2.83596192951612174892872531017929e-02 8.72819334252753764591403751182952e-02
            -9.17736558551563996743993811833207e-02 1.12390313889068041986152486471700e-17
            -2.83596192951612383059689648234780e-02 -8.72819334252753625813525673038384e-02
            7.42464472227394173264869436934532e-02 -5.39432014606257281830181682380498e-02
            -0.00000000000000000000000000000000e+00 0.00000000000000000000000000000000e+00
            ];
        
    case   33
        
        % DEGREE.             :          33
        % CARDIN.             :         595
        % LEBESGUE CONST.     : 1.61508e+02
        % ABS.DET.VAND.MATRIX : Inf
        % CONDITIONING VAND.  : 6.55369e+03
        % POINTS OUT DISK     : 0.00000e+00
        
        pts=[
            9.98900891485711484030218798579881e-01 4.68722624699400639003421531469940e-02
            9.90122514534650943751614704524400e-01 1.40204872281885717377747369027929e-01
            9.72642905324813011880280555487843e-01 2.32305356634983223296231358290242e-01
            9.46615675290434110955573032697430e-01 3.22364333161153704399026764804148e-01
            9.12269552664896732352417529909872e-01 4.09590360336506364991038253720035e-01
            8.69906372408790318218052561860532e-01 4.93216892697907249853983557841275e-01
            8.19898423673424581181734538404271e-01 5.72509017272071929482990526594222e-01
            7.62685178110381944982520963094430e-01 6.46769912017198689291319624317111e-01
            6.98769427778841656362374124000780e-01 7.15346969520127551334098825464025e-01
            6.28712866590884988937659727525897e-01 7.77637532133751974150470687163761e-01
            5.53131154125199420157343865867006e-01 8.33094188154091530584821612137603e-01
            4.72688505188565255554777877478045e-01 8.81229582494028496064686351019191e-01
            3.88091852672249715272556613854249e-01 9.21620699577337387786712952220114e-01
            3.00084635000340882449165746947983e-01 9.53912580814778920945684603793779e-01
            2.09440262766144358330677732737968e-01 9.77821443992945127376970049226657e-01
            1.16955321972082595949338212903967e-01 9.93137177162554118936554914398585e-01
            2.34425736032603457270617752783437e-02 9.99725185109815894790585844020825e-01
            -7.02761889452928750765536847211479e-02 9.97527572184010113964802712871460e-01
            -1.63377361818530103532154384993191e-01 9.86563651086546533619525689573493e-01
            -2.55042768561676402860882717504865e-01 9.66929773150250637669955722230952e-01
            -3.44466850284332659626329586899374e-01 9.38798481600386480749875772744417e-01
            -4.30863744940970350150166723324219e-01 9.02416995238588426353487648157170e-01
            -5.13474193514841803498427452723263e-01 8.58105035875144306345418954151683e-01
            -5.91572212413522424689915624185232e-01 8.06252018602229836297112797183217e-01
            -6.64471473438821624846184477064526e-01 7.47313629600077189429896407091292e-01
            -7.31531335263668758273070125142112e-01 6.81807821550437953561640824773349e-01
            -7.92162473411129330891355948551791e-01 6.10310261849792201616082820692100e-01
            -8.45832059259097435166552259033779e-01 5.33449273623570197067067510943161e-01
            -8.92068442557386265256980095728068e-01 4.51900313999934299946659166380414e-01
            -9.30465296307086520144480346061755e-01 3.66380038168246380259063244011486e-01
            -9.60685187576840182721582550584571e-01 2.77640001387500556795373540808214e-01
            -9.82462542875576105849688701709965e-01 1.86460054291681359694976549690182e-01
            -9.95605982021898094913581189757679e-01 9.36414895343511410885639634216204e-02
            -1.00000000000000000000000000000000e+00 1.22464679914735320717376402945840e-16
            -9.95605982021898094913581189757679e-01 -9.36414895343508912883834227613988e-02
            -9.82462542875575994827386239194311e-01 -1.86460054291681082139220393401047e-01
            -9.60685187576840293743885013100225e-01 -2.77640001387500334750768615776906e-01
            -9.30465296307086631166782808577409e-01 -3.66380038168246158214458318980178e-01
            -8.92068442557386598323887483275030e-01 -4.51900313999933633812844391286490e-01
            -8.45832059259097324144249796518125e-01 -5.33449273623570419111672435974469e-01
            -7.92162473411129441913658411067445e-01 -6.10310261849791979571477895660792e-01
            -7.31531335263668869295372587657766e-01 -6.81807821550437731517035899742041e-01
            -6.64471473438821735868486939580180e-01 -7.47313629600076967385291482059984e-01
            -5.91572212413522646734520549216541e-01 -8.06252018602229614252507872151909e-01
            -5.13474193514842025543032377754571e-01 -8.58105035875144195323116491636029e-01
            -4.30863744940970183616713029550738e-01 -9.02416995238588426353487648157170e-01
            -3.44466850284333325760144361993298e-01 -9.38798481600386258705270847713109e-01
            -2.55042768561676624905487642536173e-01 -9.66929773150250637669955722230952e-01
            -1.63377361818530131287730000622105e-01 -9.86563651086546533619525689573493e-01
            -7.02761889452926807875243753187533e-02 -9.97527572184010113964802712871460e-01
            2.34425736032600993963281865717363e-02 -9.99725185109815894790585844020825e-01
            1.16955321972082332271369864429289e-01 -9.93137177162554007914252451882930e-01
            2.09440262766144552619707042140362e-01 -9.77821443992945127376970049226657e-01
            3.00084635000340216315350971854059e-01 -9.53912580814779142990289528825087e-01
            3.88091852672249493227951688822941e-01 -9.21620699577337498809015414735768e-01
            4.72688505188565255554777877478045e-01 -8.81229582494028496064686351019191e-01
            5.53131154125198865045831553288735e-01 -8.33094188154091863651728999684565e-01
            6.28712866590885210982264652557205e-01 -7.77637532133751752105865762132453e-01
            6.98769427778841545340071661485126e-01 -7.15346969520127551334098825464025e-01
            7.62685178110381500893311113031814e-01 -6.46769912017199244402831936895382e-01
            8.19898423673424803226339463435579e-01 -5.72509017272071596416083139047259e-01
            8.69906372408789985151145174313569e-01 -4.93216892697907471898588482872583e-01
            9.12269552664896399285510142362909e-01 -4.09590360336507197658306722587440e-01
            9.46615675290434221977875495213084e-01 -3.22364333161153537865573071030667e-01
            9.72642905324812789835675630456535e-01 -2.32305356634983584118714361466118e-01
            9.90122514534650943751614704524400e-01 -1.40204872281885911666776678430324e-01
            9.98900891485711484030218798579881e-01 -4.68722624699399875725092101674818e-02
            9.83542320121304824986907533457270e-01 4.90865564880298074768028016023891e-02
            9.73767434668670661679357181128580e-01 1.46771825212633544310847355518490e-01
            9.54314810966585769236303349316586e-01 2.42998409598214032412144547379285e-01
            9.25377777928865996592833198519656e-01 3.36809966617507117181418152540573e-01
            8.87243924790357629817094675672706e-01 4.27274154870212086176906041146140e-01
            8.40292242915916975931622800999321e-01 5.13491900610700269247388405347010e-01
            7.84989359213956516825305698148441e-01 5.94606333146825538626956131338375e-01
            7.21884898588588619361416931496933e-01 6.69811300805827625204358355404111e-01
            6.51606021520398370761029127606889e-01 7.38359382831836108529444118175888e-01
            5.74851191063824429328121823346009e-01 7.99569317589134520574134512571618e-01
            4.92383231207524807437891922745621e-01 8.52832773246366859787315206631320e-01
            4.05021745586866210864229742583120e-01 8.97620393651581083283019779628376e-01
            3.13634971894770520073336683708476e-01 9.33487059311492783919561588845681e-01
            2.19131152945452711833240755368024e-01 9.60076311188984843347782316413941e-01
            1.22449510149285858973122742554551e-01 9.77123893353167183306595688918605e-01
            2.45509091084622939338277802789889e-02 9.84460379273538688238431859645061e-01
            -7.35916898970486316189365538775746e-02 9.82012855656965610862130233726930e-01
            -1.71002901625883024783192354334460e-01 9.69805647092746192505785529647255e-01
            -2.66714609692023041365160906934761e-01 9.47960074303914823623529173346469e-01
            -3.59775588140385182978064904091298e-01 9.16693248407389416065882414841326e-01
            -4.49260955157718355756912842480233e-01 8.76315913166151649882351648557233e-01
            -5.34281364963586025140784840914421e-01 8.27229356678121807711079327418702e-01
            -6.13991846528285312167838583263801e-01 7.69921423194755871755035059322836e-01
            -6.87600201274562561337688748608343e-01 7.04961664705700763455809010338271e-01
            -7.54374876302982722009460303524975e-01 6.32995680475239352880123533395818e-01
            -8.13652234893308845542492235836107e-01 5.54738700786753691218677886354271e-01
            -8.64843152024379224762640205881326e-01 4.70968478662838252457589760524570e-01
            -9.07438869363242361920640632888535e-01 3.82517560206341589168488326322404e-01
            -9.41016051534041109150052761833649e-01 2.90265010383157551210331348556792e-01
            -9.65240993415168890834365811315365e-01 1.95127676479656675390117470669793e-01
            -9.79872936650690418147746640897822e-01 9.80510760624467986312779999025224e-02
            -9.84766462415049836920388770522550e-01 1.20599109610425296720229791131172e-16
            -9.79872936650690418147746640897822e-01 -9.80510760624465627088852670567576e-02
            -9.65240993415169001856668273831019e-01 -1.95127676479656425589936930009571e-01
            -9.41016051534041331194657686864957e-01 -2.90265010383156885076516573462868e-01
            -9.07438869363242250898338170372881e-01 -3.82517560206341755701942020095885e-01
            -8.64843152024379335784942668396980e-01 -4.70968478662838030412984835493262e-01
            -8.13652234893309067587097160867415e-01 -5.54738700786753580196375423838617e-01
            -7.54374876302982944054065228556283e-01 -6.32995680475239130835518608364509e-01
            -6.87600201274562783382293673639651e-01 -7.04961664705700652433506547822617e-01
            -6.13991846528285534212443508295109e-01 -7.69921423194755649710430134291528e-01
            -5.34281364963585914118482378398767e-01 -8.27229356678121807711079327418702e-01
            -4.49260955157718966379576386316330e-01 -8.76315913166151316815444261010271e-01
            -3.59775588140386015645333372958703e-01 -9.16693248407389082998975027294364e-01
            -2.66714609692022652787102288129972e-01 -9.47960074303914934645831635862123e-01
            -1.71002901625883052538767969963374e-01 -9.69805647092746192505785529647255e-01
            -7.35916898970490757081464039401908e-02 -9.82012855656965610862130233726930e-01
            2.45509091084620510725411435259957e-02 -9.84460379273538688238431859645061e-01
            1.22449510149285192839307967460627e-01 -9.77123893353167294328898151434259e-01
            2.19131152945452489788635830336716e-01 -9.60076311188984843347782316413941e-01
            3.13634971894770686606790377481957e-01 -9.33487059311492672897259126330027e-01
            4.05021745586865822286171123778331e-01 -8.97620393651581305327624704659684e-01
            4.92383231207525029482496847776929e-01 -8.52832773246366748765012744115666e-01
            5.74851191063823985238911973283393e-01 -7.99569317589134742618739437602926e-01
            6.51606021520397704627214352512965e-01 -7.38359382831836663640956430754159e-01
            7.21884898588588841406021856528241e-01 -6.69811300805827403159753430372803e-01
            7.84989359213956405803003235632787e-01 -5.94606333146825649649258593854029e-01
            8.40292242915917086953925263514975e-01 -5.13491900610700158225085942831356e-01
            8.87243924790357518794792213157052e-01 -4.27274154870212308221510966177448e-01
            9.25377777928865663525925810972694e-01 -3.36809966617507783315232927634497e-01
            9.54314810966585658214000886800932e-01 -2.42998409598214365479051934926247e-01
            9.73767434668670661679357181128580e-01 -1.46771825212633488799696124260663e-01
            9.83542320121304824986907533457270e-01 -4.90865564880302376882248438505485e-02
            9.55777360948274812280089918203885e-01 5.09407483574611866239401081202232e-02
            9.44948021539475102592575694870902e-01 1.52245066038603271696416641134419e-01
            9.23412043464561849148708461143542e-01 2.51824386287486268187763016612735e-01
            8.91413437960464016818207255710149e-01 3.48550435615812836953608666590299e-01
            8.49314762013537061235979308548849e-01 4.41327269234924712826284576294711e-01
            7.97593010444037187056665061390959e-01 5.29103688548175687955676949059125e-01
            7.36834211364209901162780624872539e-01 6.10885151651069158162954408908263e-01
            6.67726786245614101211742763553048e-01 6.85745041888434658794437837059377e-01
            5.91053749828769237062431329832179e-01 7.52835166791388399332163317012601e-01
            5.07683838253269348328444721119013e-01 8.11395368436926167632350370695349e-01
            4.18561665930190951456779657746665e-01 8.60762136340934902456467625597725e-01
            3.24697022683367864104297950689215e-01 9.00376125297102425371065237413859e-01
            2.27153432427194768017386650171829e-01 9.29788492981608594156739400204970e-01
            1.27036103015715717834410725117777e-01 9.48665985516002008282043789222371e-01
            2.54794037960170104140100733047802e-02 9.56794713366804994159053876501275e-01
            -7.63659872497435415761302124337817e-02 9.54082574799392735265257670107530e-01
            -1.77346121145664475937664406046679e-01 9.40560299427450008380446888622828e-01
            -2.76316852625090203510183073376538e-01 9.16381100034167617174318820616463e-01
            -3.72156803753661780120864932541735e-01 8.81818936610189507696588862017961e-01
            -4.63780069589390719908550408945302e-01 8.37265412277449105893367686803686e-01
            -5.50148521919558874948563698126236e-01 7.83225336269321448234848048741696e-01
            -6.30283571668182829306203984742751e-01 7.20311004240297370060375214961823e-01
            -7.03277256701269504191031955997460e-01 6.49235260711557127244475395855261e-01
            -7.68302529400597844499998245737515e-01 5.70803422257707304687812666088575e-01
            -8.24622627443702849170392710220767e-01 4.85904152948203327255782824067865e-01
            -8.71599421615387726092194498050958e-01 3.95499395428347721992423657866311e-01
            -9.08700646066712525161790381389437e-01 3.00613471724748615443445487471763e-01
            -9.35505929099746391663927624904318e-01 2.02321477267459859383791354048299e-01
            -9.51711556146877524220428767876001e-01 1.01737099629170851811110765083868e-01
            -9.57133910978221980059288398479111e-01 1.17215098043486736074717777404563e-16
            -9.51711556146877635242731230391655e-01 -1.01737099629170199555083797804400e-01
            -9.35505929099746280641625162388664e-01 -2.02321477267460053672820663450693e-01
            -9.08700646066712636184092843905091e-01 -3.00613471724748337887689331182628e-01
            -8.71599421615388059159101885597920e-01 -3.95499395428347111369760114030214e-01
            -8.24622627443702960192695172736421e-01 -4.85904152948203105211177899036556e-01
            -7.68302529400597733477695783221861e-01 -5.70803422257707415710115128604230e-01
            -7.03277256701270059302544268575730e-01 -6.49235260711556683155265545792645e-01
            -6.30283571668183051350808909774059e-01 -7.20311004240297259038072752446169e-01
            -5.50148521919558652903958773094928e-01 -7.83225336269321559257150511257350e-01
            -4.63780069589390553375096715171821e-01 -8.37265412277449216915670149319340e-01
            -3.72156803753662446254679707635660e-01 -8.81818936610189285651983936986653e-01
            -2.76316852625090203510183073376538e-01 -9.16381100034167617174318820616463e-01
            -1.77346121145664281648635096644284e-01 -9.40560299427450008380446888622828e-01
            -7.63659872497444158767621047445573e-02 -9.54082574799392735265257670107530e-01
            2.54794037960169895973283615830951e-02 -9.56794713366804994159053876501275e-01
            1.27036103015715495789805800086469e-01 -9.48665985516002119304346251738025e-01
            2.27153432427193907594542565675511e-01 -9.29788492981608816201344325236278e-01
            3.24697022683367642059693025657907e-01 -9.00376125297102536393367699929513e-01
            4.18561665930190729412174732715357e-01 -8.60762136340934902456467625597725e-01
            5.07683838253269126283839796087705e-01 -8.11395368436926278654652833211003e-01
            5.91053749828769015017826404800871e-01 -7.52835166791388510354465779528255e-01
            6.67726786245613879167137838521739e-01 -6.85745041888434769816740299575031e-01
            7.36834211364210234229688012419501e-01 -6.10885151651068825096047021361301e-01
            7.97593010444036965012060136359651e-01 -5.29103688548176132044886799121741e-01
            8.49314762013536839191374383517541e-01 -4.41327269234925156915494426357327e-01
            8.91413437960464127840509718225803e-01 -3.48550435615812448375550047785509e-01
            9.23412043464561738126405998627888e-01 -2.51824386287486823299275329191005e-01
            9.44948021539475213614878157386556e-01 -1.52245066038602994140660484845284e-01
            9.55777360948274812280089918203885e-01 -5.09407483574609715182290869961435e-02
            9.19983500721934022159587129863212e-01 5.26065599015846652175554254426970e-02
            9.07990108856588484798066929215565e-01 1.57133872745072261656318346467742e-01
            8.84159677330390914029578652844066e-01 2.59612705252040609771313484088751e-01
            8.48802872262233498723560387588805e-01 3.58707089119585709191539990570163e-01
            8.02380623677444115848800265666796e-01 4.53125177508665544223731558304280e-01
            7.45498116580004976938766958483029e-01 5.41636086243271974716151362372329e-01
            6.78896901440514066727871522743953e-01 6.23085940268060411995065805967897e-01
            6.03445226951746294119516278442461e-01 6.96412916174319218676203036011430e-01
            5.20126721079127052327351066196570e-01 7.60661084691954036962613372452324e-01
            4.30027567965938828375982438956271e-01 8.14992872689426550714131280983565e-01
            3.34322347861907731569885982025880e-01 8.58699982220429314239140694553498e-01
            2.34258724673361062862397830031114e-01 8.91212624270815823024349811021239e-01
            1.31141180756149861030834813391266e-01 9.12106946829781994878771911317017e-01
            2.63140109931946711285810636127280e-02 9.21110560449023396678569497453282e-01
            -7.88562021451505446023588774551172e-02 9.18106089255760871026268432615325e-01
            -1.82998404093514921431307129751076e-01 9.03132701126745041086962828558171e-01
            -2.84754941984530329790459290961735e-01 8.76385597075083566664943646173924e-01
            -3.82799263730218941592653436600813e-01 8.38213466506513626974594899365911e-01
            -4.75853211657160157788126753075630e-01 7.89113941519746453501227279048180e-01
            -5.62703685246453866319882308744127e-01 7.29727109511030702648781698371749e-01
            -6.42218455754182793171480625460390e-01 6.60827168656053953732509853580268e-01
            -7.13360926544609363908477916993434e-01 5.83312335052740382757008319458691e-01
            -7.75203646712593341661090562411118e-01 4.98193133100769180998668161919340e-01
            -8.26940401824494131233223015442491e-01 4.06579221770626220155975261150161e-01
            -8.67896724156258292381949104310479e-01 3.09664928501920677650360858024214e-01
            -8.97538685411668923919137341727037e-01 2.08713679318719175226348738760862e-01
            -9.15479857294224319552711222058861e-01 1.05041528139163231614361393440049e-01
            -9.21486349190949183274312872526934e-01 1.12849530799467618779538881276731e-16
            -9.15479857294224319552711222058861e-01 -1.05041528139162995691968660594284e-01
            -8.97538685411669034941439804242691e-01 -2.08713679318718980937319429358467e-01
            -8.67896724156258403404251566826133e-01 -3.09664928501920455605755932992906e-01
            -8.26940401824494131233223015442491e-01 -4.06579221770626331178277723665815e-01
            -7.75203646712593674727997949958080e-01 -4.98193133100768681398307080598897e-01
            -7.13360926544609474930780379509088e-01 -5.83312335052740160712403394427383e-01
            -6.42218455754182904193783087976044e-01 -6.60827168656053731687904928548960e-01
            -5.62703685246454310409092158806743e-01 -7.29727109511030258559571848309133e-01
            -4.75853211657160657388487834396074e-01 -7.89113941519746120434319891501218e-01
            -3.82799263730218941592653436600813e-01 -8.38213466506513626974594899365911e-01
            -2.84754941984530496323912984735216e-01 -8.76385597075083455642641183658270e-01
            -1.82998404093515310009365748555865e-01 -9.03132701126744930064660366042517e-01
            -7.88562021451511691028102291056712e-02 -9.18106089255760760003965970099671e-01
            2.63140109931944456145291866278058e-02 -9.21110560449023396678569497453282e-01
            1.31141180756149638986229888359958e-01 -9.12106946829781994878771911317017e-01
            2.34258724673360452239734286195016e-01 -8.91212624270816045068954736052547e-01
            3.34322347861907898103339675799361e-01 -8.58699982220429203216838232037844e-01
            4.30027567965938606331377513924963e-01 -8.14992872689426661736433743499219e-01
            5.20126721079126719260443678649608e-01 -7.60661084691954147984915834967978e-01
            6.03445226951746405141818740958115e-01 -6.96412916174319107653900573495775e-01
            6.78896901440514066727871522743953e-01 -6.23085940268060300972763343452243e-01
            7.45498116580005310005674346029991e-01 -5.41636086243271530626941512309713e-01
            8.02380623677443893804195340635488e-01 -4.53125177508665932801790177109069e-01
            8.48802872262233165656653000041842e-01 -3.58707089119586319814203534406261e-01
            8.84159677330390914029578652844066e-01 -2.59612705252040720793615946604405e-01
            9.07990108856588484798066929215565e-01 -1.57133872745072566967650118385791e-01
            9.19983500721934022159587129863212e-01 -5.26065599015851925734921223920537e-02
            8.77709989938493029271171508298721e-01 5.41352991696741198124342986375268e-02
            8.64404801179324611126730815158226e-01 1.61585261556095538537647371413186e-01
            8.37996116760014397861766610731138e-01 2.66585756088272674002581652530353e-01
            7.98884265416828109884761488501681e-01 3.67545082300708259026578161865473e-01
            7.47662142947702945683374764485052e-01 4.62932799720292165179813537179143e-01
            6.85106224516313866423899980873102e-01 5.51302927783828944363619939394994e-01
            6.12164794080088725536370475310832e-01 6.31315865429423639376693699887255e-01
            5.29943569372040790277367250382667e-01 7.01758698083066567718901751504745e-01
            4.39688940347042145351252884211135e-01 7.61563584207198496223156780615682e-01
            3.42769075180609339437154403640307e-01 8.09823942689921527637864073767560e-01
            2.40653180233994457015711532221758e-01 8.45808195690538333622043865034357e-01
            1.34889228383376830189277484350896e-01 8.68970858613887453536506200180156e-01
            2.70804933289752955416496149609884e-02 8.78960809100769235868710893555544e-01
            -8.11387543999583932263774954662949e-02 8.75626609684997392335503718641121e-01
            -1.88128021320480953715303940043668e-01 8.59018803431019328797901835059747e-01
            -2.92265459204930411196698969433783e-01 8.29389147752579880545908963540569e-01
            -3.91972450646837999865823576328694e-01 7.87186798026956013885069296520669e-01
            -4.85737539291654862871894238196546e-01 7.33051498857281824683695958810858e-01
            -5.72139341974394199930031845724443e-01 6.67803886196484230985959129611729e-01
            -6.49868095439533277613008976913989e-01 5.92433047342746821328773876302876e-01
            -7.17745511016869564002718107076362e-01 5.08081527384289244331228019291302e-01
            -7.74742636276678164897191436466528e-01 4.16028009380477015177746125118574e-01
            -8.19995452899690557835299387079431e-01 3.17667930830058453661735029527335e-01
            -8.52817974314083238063233238790417e-01 2.14492330261114666489774549518188e-01
            -8.72712644552650074203370422765147e-01 1.08065244606855140330203823850752e-01
            -8.79377880694084512747110693453578e-01 1.07692730683299366979043705138154e-16
            -8.72712644552650074203370422765147e-01 -1.08065244606854918285598898819444e-01
            -8.52817974314083238063233238790417e-01 -2.14492330261114833023228243291669e-01
            -8.19995452899690668857601849595085e-01 -3.17667930830058287128281335753854e-01
            -7.74742636276678275919493898982182e-01 -4.16028009380476793133141200087266e-01
            -7.17745511016869675025020569592016e-01 -5.08081527384289022286623094259994e-01
            -6.49868095439533277613008976913989e-01 -5.92433047342746710306471413787222e-01
            -5.72139341974393977885426920693135e-01 -6.67803886196484342008261592127383e-01
            -4.85737539291655084916499163227854e-01 -7.33051498857281713661393496295204e-01
            -3.91972450646837833332369882555213e-01 -7.87186798026956124907371759036323e-01
            -2.92265459204930577730152663207264e-01 -8.29389147752579769523606501024915e-01
            -1.88128021320481342293362558848457e-01 -8.59018803431019217775599372544093e-01
            -8.11387543999584209819531110952084e-02 -8.75626609684997392335503718641121e-01
            2.70804933289750804359385938369087e-02 -8.78960809100769235868710893555544e-01
            1.34889228383376996722731178124377e-01 -8.68970858613887453536506200180156e-01
            2.40653180233994457015711532221758e-01 -8.45808195690538333622043865034357e-01
            3.42769075180609672504061791187269e-01 -8.09823942689921416615561611251906e-01
            4.39688940347042367395857809242443e-01 -7.61563584207198385200854318100028e-01
            5.29943569372040568232762325351359e-01 -7.01758698083066789763506676536053e-01
            6.12164794080088947580975400342140e-01 -6.31315865429423417332088774855947e-01
            6.85106224516313755401597518357448e-01 -5.51302927783829055385922401910648e-01
            7.47662142947702612616467376938090e-01 -4.62932799720292553757872155983932e-01
            7.98884265416828220907063951017335e-01 -3.67545082300708203515426930607646e-01
            8.37996116760014286839464148215484e-01 -2.66585756088272896047186577561661e-01
            8.64404801179324611126730815158226e-01 -1.61585261556095316493042446381878e-01
            8.77709989938493029271171508298721e-01 -5.41352991696741753235855298953538e-02
            8.29846832075457063737644602952059e-01 5.55517092287645258830153238704952e-02
            8.15038195697634137992793057492236e-01 1.65663806119061868260544656550337e-01
            7.85685183408973641938644050242146e-01 2.72819628464516072963164106113254e-01
            7.42311600409152338997387232666370e-01 3.75106978076804042920855408738134e-01
            6.85691449314341561205310426885262e-01 4.70700534778862256235498762180214e-01
            6.16835118062184384335466802440351e-01 5.57894429286688864344512239767937e-01
            5.36971349515112161832064430200262e-01 6.35132684487130116934849866083823e-01
            4.47525314514855387937330988279427e-01 7.01036981886325905044543560507009e-01
            3.50093179675009469331570244321483e-01 7.54431257735885818505039424053393e-01
            2.46413623750001781198548655993363e-01 7.94362689918340580952360596711515e-01
            1.38336810871527826627414015092654e-01 8.20118701080401080183435169601580e-01
            2.77913743257919183815563002326599e-02 8.31239674592709087974640169704799e-01
            -8.32499999531778056560682443887345e-02 8.27527156419476606075136260187719e-01
            -1.92805776010753771032568693044595e-01 8.09047396535456431188038095569937e-01
            -2.98920928427764576174041621925426e-01 7.76130166693572376424015146767488e-01
            -3.99701829795413299262207829087856e-01 7.29362875640176544500548061478185e-01
            -4.93350042541250921601658774306998e-01 6.69580086792054385291805829183431e-01
            -5.78194412090260345671310915349750e-01 5.97848625432481295405295895761810e-01
            -6.52720888657839282132044900208712e-01 5.15448541188768705190170749119716e-01
            -7.15599545504073786261756140447687e-01 4.23850265516340141136453212311608e-01
            -7.65708311507920513783176375000039e-01 3.24688371814573051299390726853744e-01
            -8.02152994552941756012387486407533e-01 2.19732406425764525970123486331431e-01
            -8.24283238406808393961000547278672e-01 1.10855311038730933170803893972334e-01
            -8.31704128343673132484070720238378e-01 -2.67496449323805004287723119465867e-16
            -8.24283238406808504983303009794326e-01 -1.10855311038730364181503773579607e-01
            -8.02152994552941756012387486407533e-01 -2.19732406425764331681094176929037e-01
            -7.65708311507920624805478837515693e-01 -3.24688371814572884765937033080263e-01
            -7.15599545504073897284058602963341e-01 -4.23850265516339974602999518538127e-01
            -6.52720888657839393154347362724366e-01 -5.15448541188768483145565824088408e-01
            -5.78194412090260456693613377865404e-01 -5.97848625432481073360690970730502e-01
            -4.93350042541250699557053849275690e-01 -6.69580086792054496314108291699085e-01
            -3.99701829795413188239905366572202e-01 -7.29362875640176544500548061478185e-01
            -2.98920928427764909240949009472388e-01 -7.76130166693572265401712684251834e-01
            -1.92805776010754326144081005622866e-01 -8.09047396535456320165735633054283e-01
            -8.32499999531781803563390553790668e-02 -8.27527156419476606075136260187719e-01
            2.77913743257915332729446333814849e-02 -8.31239674592709087974640169704799e-01
            1.38336810871527604582809090061346e-01 -8.20118701080401080183435169601580e-01
            2.46413623750001420376065652817488e-01 -7.94362689918340691974663059227169e-01
            3.50093179675009302798116550548002e-01 -7.54431257735885929527341886569047e-01
            4.47525314514855221403877294505946e-01 -7.01036981886326016066846023022663e-01
            5.36971349515112050809761967684608e-01 -6.35132684487130227957152328599477e-01
            6.16835118062184273313164339924697e-01 -5.57894429286688864344512239767937e-01
            6.85691449314341561205310426885262e-01 -4.70700534778862256235498762180214e-01
            7.42311600409152005930479845119407e-01 -3.75106978076804709054670183832059e-01
            7.85685183408973641938644050242146e-01 -2.72819628464516072963164106113254e-01
            8.15038195697634137992793057492236e-01 -1.65663806119061757238242194034683e-01
            8.29846832075457063737644602952059e-01 -5.55517092287651295667849637993640e-02
            7.76989849621096961840294170542620e-01 5.68683271267256471026563247050944e-02
            7.60429659947521985330354254983831e-01 1.69392931719429457038117448064440e-01
            7.27662232292287214363568637054414e-01 2.78307220064109350765590988885378e-01
            6.79385947486687347129930003575282e-01 3.81289873196264228472074364617583e-01
            6.16629730726471203539063026255462e-01 4.76145994657738103050803601945518e-01
            5.40731121817663251682972713751951e-01 5.60853890904055796262639432825381e-01
            4.53307767837768049723479180102004e-01 6.33608160192359992635147136752494e-01
            3.56222945796791978789741506261635e-01 6.92858171585110871326662618230330e-01
            2.51545850122703085194331151797087e-01 7.37341113956392457673416629404528e-01
            1.41507491374631894087698924522556e-01 7.66108910618631067102057841111673e-01
            2.84531461261727305900315343478724e-02 7.78548425931187559889679050684208e-01
            -8.52076285330297111819675137667218e-02 7.74394533222041991926687387604034e-01
            -1.97052350523294006467978078944725e-01 7.53735765502508203717013657296775e-01
            -3.04697243774635750934720590521465e-01 7.17012428539803958749132561933948e-01
            -4.05848044275108232881166259176098e-01 6.65007216504059472939047736872453e-01
            -4.98348898325028211164777758312994e-01 5.98828530200956499207620709057664e-01
            -5.80228310815700143443507386109559e-01 5.19886853432904749716669812187320e-01
            -6.49741164224844736096997621643823e-01 4.29864690985605923945200856906013e-01
            -7.05405912766802534186183493147837e-01 3.30680708959626701304301832351484e-01
            -7.46036158968766627275215341796866e-01 2.24448841733559084632432245598466e-01
            -7.70765939673153432920571503927931e-01 1.13433237122846683475607676427899e-01
            -7.79068182538863007735585597401951e-01 9.54083356063764461530331037580136e-17
            -7.70765939673153432920571503927931e-01 -1.13433237122846489186578367025504e-01
            -7.46036158968766738297517804312520e-01 -2.24448841733558918098978551824985e-01
            -7.05405912766802645208485955663491e-01 -3.30680708959626534770848138578003e-01
            -6.49741164224845069163905009190785e-01 -4.29864690985605535367142238101223e-01
            -5.80228310815700143443507386109559e-01 -5.19886853432904527672064887156012e-01
            -4.98348898325027989120172833281686e-01 -5.98828530200956610229923171573319e-01
            -4.05848044275108732481527340496541e-01 -6.65007216504059139872140349325491e-01
            -3.04697243774635750934720590521465e-01 -7.17012428539803958749132561933948e-01
            -1.97052350523294034223553694573638e-01 -7.53735765502508203717013657296775e-01
            -8.52076285330300720044505169425975e-02 -7.74394533222041991926687387604034e-01
            2.84531461261723628286546272647684e-02 -7.78548425931187559889679050684208e-01
            1.41507491374631338976186611944286e-01 -7.66108910618631178124360303627327e-01
            2.51545850122703085194331151797087e-01 -7.37341113956392457673416629404528e-01
            3.56222945796791812256287812488154e-01 -6.92858171585110982348965080745984e-01
            4.53307767837767827678874255070696e-01 -6.33608160192360103657449599268148e-01
            5.40731121817662918616065326204989e-01 -5.60853890904056240351849282887997e-01
            6.16629730726471314561365488771116e-01 -4.76145994657737992028501139429864e-01
            6.79385947486687347129930003575282e-01 -3.81289873196264283983225595875410e-01
            7.27662232292287214363568637054414e-01 -2.78307220064109517299044682658860e-01
            7.60429659947522096352656717499485e-01 -1.69392931719429096215634444888565e-01
            7.76989849621096961840294170542620e-01 -5.68683271267261050696539825821674e-02
            7.19571161862502917117012657399755e-01 5.80897896309049560636950104708376e-02
            7.00934646743600286988851166825043e-01 1.72764873854436645794763194317056e-01
            6.64144292458063834061476882197894e-01 2.82965438594350249257303175909328e-01
            6.10152949856805126849224052421050e-01 3.85837347109574457793002011385397e-01
            5.40358966352849634517951926682144e-01 4.78716271005691917928004386340035e-01
            4.56569969457857771644171407388058e-01 5.59196694940846450450067095516715e-01
            3.60956050179074783290644745648024e-01 6.25194218209538798980418050632579e-01
            2.55993558802141418784259485619259e-01 6.74999539626013111970337376988027e-01
            1.44400968719460315314861986735195e-01 7.07322727527114447632072824490024e-01
            2.90684693972834209962918805558729e-02 7.21326628324793217572619141719770e-01
            -8.70168880133190131287435065132740e-02 7.16648548344300140300333623599727e-01
            -2.00848553732243889635711298069509e-01 6.93409647399847672843975487921853e-01
            -3.09478347410393983540899398576585e-01 6.52211800819064158041271639376646e-01
            -4.10092814452108933576113258823170e-01 5.94122011188159326877666899235919e-01
            -5.00086093011356314086413021868793e-01 5.20644773545411054804787909233710e-01
            -5.77127404444744640521491874096682e-01 4.33683109749950057576484141463879e-01
            -6.39221419254088374373168335296214e-01 3.35489281215218815290768361592200e-01
            -6.84759935072309922077238297788426e-01 2.28606456521422529704068438149989e-01
            -7.12563528259998912872674736718182e-01 1.15802844685166619886906858027942e-01
            -7.21912100358149677603591953811701e-01 8.84087342969350860436854188905393e-17
            -7.12563528259999023894977199233836e-01 -1.15802844685166439475665356440004e-01
            -6.84759935072310033099540760304080e-01 -2.28606456521422363170614744376508e-01
            -6.39221419254088374373168335296214e-01 -3.35489281215218648757314667818719e-01
            -5.77127404444744862566096799127990e-01 -4.33683109749949946554181678948225e-01
            -5.00086093011356425108715484384447e-01 -5.20644773545410832760182984202402e-01
            -4.10092814452109100109566952596651e-01 -5.94122011188159215855364436720265e-01
            -3.09478347410393872518596936060931e-01 -6.52211800819064269063574101892300e-01
            -2.00848553732243889635711298069509e-01 -6.93409647399847672843975487921853e-01
            -8.70168880133193461956508940602362e-02 -7.16648548344300140300333623599727e-01
            2.90684693972830844599375410552966e-02 -7.21326628324793217572619141719770e-01
            1.44400968719460148781408292961714e-01 -7.07322727527114558654375287005678e-01
            2.55993558802141252250805791845778e-01 -6.74999539626013222992639839503681e-01
            3.60956050179074339201434895585408e-01 -6.25194218209539021025022975663887e-01
            4.56569969457857272043810326067614e-01 -5.59196694940846672494672020548023e-01
            5.40358966352849412473347001650836e-01 -4.78716271005692195483760542629170e-01
            6.10152949856804904804619127389742e-01 -3.85837347109574735348758167674532e-01
            6.64144292458063723039174419682240e-01 -2.82965438594350360279605638424982e-01
            7.00934646743600286988851166825043e-01 -1.72764873854436673550338809945970e-01
            7.19571161862502917117012657399755e-01 -5.80897896309048797358620674913254e-02
            6.57918660758466167237656918587163e-01 5.92137512189077966362482641216047e-02
            6.36772613664411846201574007864110e-01 1.75738074971310914706990047307045e-01
            5.95160170828931689435137286636746e-01 2.86614032396366402721810118237045e-01
            5.34418790403589860638078334886814e-01 3.88277978993391226225639911717735e-01
            4.56500750333431237759640453077736e-01 4.77462351869383239133526330988389e-01
            3.63910400537487688232829441403737e-01 5.51300691898961470194251432985766e-01
            2.59623671041794290559323599154595e-01 6.07419774079187013704483888432151e-01
            1.46992423139749556204591840469220e-01 6.44015884933852644778085050347727e-01
            2.96367178122246867355560340229204e-02 6.59912795348708836051798698463244e-01
            -8.86715360109577299674299410980893e-02 6.54599565543001138401280059042620e-01
            -2.04129813707565110902919514046516e-01 6.28246967094424735300606243981747e-01
            -3.13027191233041179874163617569138e-01 5.81701994200107153076828581106383e-01
            -4.11863617272656468148994690636755e-01 5.16460640586203001412002322467742e-01
            -4.97462407770615455682161609729519e-01 4.34619817038627842542553025850793e-01
            -5.67072347169394475052683901594719e-01 3.38809954965054505038324350607581e-01
            -6.18456114741467555262488531298004e-01 2.32110462165144776358616240941046e-01
            -6.49962193918363850819730487273773e-01 1.17950748130122920476203773887391e-01
            -6.60577953392049277425712716649286e-01 8.08974676208882676403779906816693e-17
            -6.49962193918363850819730487273773e-01 -1.17950748130122753942750080113910e-01
            -6.18456114741467555262488531298004e-01 -2.32110462165144637580738162796479e-01
            -5.67072347169394697097288826626027e-01 -3.38809954965054116460265731802792e-01
            -4.97462407770615622215615303503000e-01 -4.34619817038627676009099332077312e-01
            -4.11863617272656634682448384410236e-01 -5.16460640586202890389699859952088e-01
            -3.13027191233041346407617311342619e-01 -5.81701994200107042054526118590729e-01
            -2.04129813707565277436373207819997e-01 -6.28246967094424735300606243981747e-01
            -8.86715360109578965008836348715704e-02 -6.54599565543001138401280059042620e-01
            2.96367178122245271409962441566677e-02 -6.59912795348708947074101160978898e-01
            1.46992423139749417426713762324653e-01 -6.44015884933852644778085050347727e-01
            2.59623671041794124025869905381114e-01 -6.07419774079187124726786350947805e-01
            3.63910400537487466188224516372429e-01 -5.51300691898961692238856358017074e-01
            4.56500750333431126737337990562082e-01 -4.77462351869383350155828793504043e-01
            5.34418790403589749615775872371159e-01 -3.88277978993391392759093605491216e-01
            5.95160170828931578412834824121092e-01 -2.86614032396366513744112580752699e-01
            6.36772613664411846201574007864110e-01 -1.75738074971311081240443741080526e-01
            6.57918660758466167237656918587163e-01 -5.92137512189079631697019578950858e-02
            5.92286153177261742719394987943815e-01 6.02296149297701158276119315360120e-02
            5.68037888475516505870643868547631e-01 1.78223037277406293199533138249535e-01
            5.20534085877965679856060887686908e-01 2.88919987538587774711373867830844e-01
            4.51719556644412878476657624560175e-01 3.87788519563282307878182564309100e-01
            3.64411575687043465254788543461473e-01 4.70780944033839632290039389772573e-01
            2.62184542004504528289743348068441e-01 5.34499541341239448044575510721188e-01
            1.49223642366925257629617362908903e-01 5.76335664625099441948918865818996e-01
            3.01535092778108873567965986239869e-02 5.94576538082642547244915931514697e-01
            -9.01511120240243712942174170166254e-02 5.88475378211305355513616177631775e-01
            -2.06764936207289806713305324592511e-01 5.58281967213076435463392499514157e-01
            -3.14913779608380572927472940136795e-01 5.05232426881798035722681561310310e-01
            -4.10170015871505921900563862436684e-01 4.31498611631689565903968741622521e-01
            -4.88633843491921626700502656603931e-01 3.40099192522445303854539133681101e-01
            -5.47092944147739124183260628342396e-01 2.34776072511373889994956698501483e-01
            -5.83153995389456669684591361146886e-01 1.19841192506669635964300368868862e-01
            -5.95340653542244746532219323853496e-01 7.29082025762803361879173521046823e-17
            -5.83153995389456669684591361146886e-01 -1.19841192506669483308634482909838e-01
            -5.47092944147739235205563090858050e-01 -2.34776072511373751217078620356915e-01
            -4.88633843491921793233956350377412e-01 -3.40099192522445192832236671165447e-01
            -4.10170015871506199456320018725819e-01 -4.31498611631689288348212585333386e-01
            -3.14913779608380683949775402652449e-01 -5.05232426881798035722681561310310e-01
            -2.06764936207290056513485865252733e-01 -5.58281967213076213418787574482849e-01
            -9.01511120240245239498833029756497e-02 -5.88475378211305355513616177631775e-01
            3.01535092778110053179929650468694e-02 -5.94576538082642547244915931514697e-01
            1.49223642366925007829436822248681e-01 -5.76335664625099441948918865818996e-01
            2.62184542004504139711684729263652e-01 -5.34499541341239670089180435752496e-01
            3.64411575687043243210183618430165e-01 -4.70780944033839854334644314803882e-01
            4.51719556644412989498960087075830e-01 -3.87788519563282141344728870535619e-01
            5.20534085877965568833758425171254e-01 -2.88919987538588052267130024119979e-01
            5.68037888475516394848341406031977e-01 -1.78223037277406654022016141425411e-01
            5.92286153177261742719394987943815e-01 -6.02296149297699909275216612059012e-02
            5.22867898300985789461492458940484e-01 6.11144923503517886742564257929189e-02
            4.94679954564268609118471431429498e-01 1.80048778949551152583907764892501e-01
            4.39823686433857996558316472146544e-01 2.89276589271690864890729244507384e-01
            3.61256409523680155349012466103886e-01 3.82909423789739467025583508075215e-01
            2.63213706068344432953409750552964e-01 4.55899512158872977085621869264287e-01
            1.50981083588535791584206435800297e-01 5.04311939822331356531037727108924e-01
            3.06090318124722336745602291330215e-02 5.25536780273687553766137625643751e-01
            -9.14131607914539512371732143947156e-02 5.18429796870364056893265569669893e-01
            -2.08507246235698440184336277525290e-01 4.83374128927207824535372537866351e-01
            -3.14360652065287127232551256383886e-01 4.22259636576856167700100286310771e-01
            -4.03266793772814602370146985776955e-01 3.38381017920812765531479726632824e-01
            -4.70432718246330261457899268862093e-01 2.36260191001996827653286459280935e-01
            -5.12237493112215891422067670646356e-01 1.21402516032591972772181065920449e-01
            -5.26427412136688754884517038590275e-01 6.44687645256620455645082802988857e-17
            -5.12237493112215891422067670646356e-01 -1.21402516032591847872090795590339e-01
            -4.70432718246330316969050500119920e-01 -2.36260191001996716630983996765281e-01
            -4.03266793772814546858995754519128e-01 -3.38381017920812821042630957890651e-01
            -3.14360652065287238254853718899540e-01 -4.22259636576856056677797823795117e-01
            -2.08507246235698467939911893154203e-01 -4.83374128927207824535372537866351e-01
            -9.14131607914540900150512925392832e-02 -5.18429796870364056893265569669893e-01
            3.06090318124718693826302740035317e-02 -5.25536780273687664788440088159405e-01
            1.50981083588535791584206435800297e-01 -5.04311939822331356531037727108924e-01
            2.63213706068344432953409750552964e-01 -4.55899512158872977085621869264287e-01
            3.61256409523680210860163697361713e-01 -3.82909423789739411514432276817388e-01
            4.39823686433857774513711547115236e-01 -2.89276589271691197957636632054346e-01
            4.94679954564268442585017737656017e-01 -1.80048778949551541161966383697290e-01
            5.22867898300985789461492458940484e-01 -6.11144923503516915297417710917216e-02
            4.49801252510879434609591953631025e-01 6.18237591425921245713581697600603e-02
            4.16441551315957614320950597175397e-01 1.80886092037049139857884938464849e-01
            3.52196285353263083273134270712035e-01 2.86532930983927291990198682469781e-01
            2.61830232096713466649617885195767e-01 3.70928933240665836823524159626686e-01
            1.52045428319161041175178183948447e-01 4.27814833405902428253853031492326e-01
            3.09841106847281548553052488159665e-02 4.52971664500058657232273162662750e-01
            -9.23751566963164488788251560436038e-02 4.44533659445725426451190287480131e-01
            -2.08883381293417824675628935437999e-01 4.03126626476477956106947431180743e-01
            -3.09899681077871524959022053735680e-01 3.31821535803073941472973729105433e-01
            -3.87932139213486348872095277329208e-01 2.35906759801675552923327927601349e-01
            -4.37193445255086909906339087683591e-01 1.22495858627402254281690829884610e-01
            -4.54030113489047315589175468630856e-01 5.56026525200871319697331091616291e-17
            -4.37193445255086854395187856425764e-01 -1.22495858627402337548417676771351e-01
            -3.87932139213486515405548971102689e-01 -2.35906759801675247611996155683300e-01
            -3.09899681077871524959022053735680e-01 -3.31821535803073996984124960363260e-01
            -2.08883381293418102231385091727134e-01 -4.03126626476477900595796199922916e-01
            -9.23751566963163517343105013424065e-02 -4.44533659445725426451190287480131e-01
            3.09841106847280473024497382539266e-02 -4.52971664500058657232273162662750e-01
            1.52045428319160957908451337061706e-01 -4.27814833405902428253853031492326e-01
            2.61830232096713411138466653937940e-01 -3.70928933240665892334675390884513e-01
            3.52196285353262972250831808196381e-01 -2.86532930983927458523652376243263e-01
            4.16441551315957558809799365917570e-01 -1.80886092037049334146914247867244e-01
            4.49801252510879434609591953631025e-01 -6.18237591425920135490557072444062e-02
            3.73153907596797285162182333806413e-01 6.22683739930466606526948680766509e-02
            3.32716891629235345106962995487265e-01 1.80057377463620521540477170674421e-01
            2.56224837819147455153512282777228e-01 2.78334370207936498964329530281248e-01
            1.51966847093361667742072995679337e-01 3.46449515137487062954591010566219e-01
            3.12408904764234426898461549626518e-02 3.77021479383784163808002176665468e-01
            -9.28705013759967140662965334740875e-02 3.66737316247839784111306471459102e-01
            -2.06917933370024065276027158688521e-01 3.16711474380666102579340304146172e-01
            -2.98542596620866795831261697458103e-01 2.32365029979486076294747931569873e-01
            -3.57815537162163022077976393120480e-01 1.22838229065099266423821688931639e-01
            -3.78313612171829016794788458355470e-01 4.63300554220103565444022880411324e-17
            -3.57815537162163022077976393120480e-01 -1.22838229065099335812760728003923e-01
            -2.98542596620866962364715391231584e-01 -2.32365029979485909761294237796392e-01
            -2.06917933370024037520451543059608e-01 -3.16711474380666158090491535403999e-01
            -9.28705013759967973330233803608280e-02 -3.66737316247839728600155240201275e-01
            3.12408904764234322815052991018092e-02 -3.77021479383784163808002176665468e-01
            1.51966847093361362430741223761288e-01 -3.46449515137487173976893473081873e-01
            2.56224837819147510664663514035055e-01 -2.78334370207936498964329530281248e-01
            3.32716891629235234084660532971611e-01 -1.80057377463620743585082095705729e-01
            3.73153907596797285162182333806413e-01 -6.22683739930465982026497329115955e-02
            2.92878455064361775672665544334450e-01 6.22532373957088089322375878964522e-02
            2.42237109466498817811341837114014e-01 1.75995561888501378389193519069522e-01
            1.49710766986825200008937031270762e-01 2.59306654861286511870588356032385e-01
            3.12980728155091633690965124969807e-02 2.97781271481550591229137125992565e-01
            -9.25263424796736178024048058432527e-02 2.84766801004730896185179744861671e-01
            -2.00352112584688019092382660346630e-01 2.22513563609022135825199484315817e-01
            -2.73535182282008015874907869147137e-01 1.21785709593049157328792375665216e-01
            -2.99421533973650344506722831283696e-01 1.69638434752114208612126587869341e-16
            -2.73535182282007960363756637889310e-01 -1.21785709593049212839943606923043e-01
            -2.00352112584688185625836354120111e-01 -2.22513563609021997047321406171250e-01
            -9.25263424796736733135560371010797e-02 -2.84766801004730840674028513603844e-01
            3.12980728155090176523245304451848e-02 -2.97781271481550591229137125992565e-01
            1.49710766986825200008937031270762e-01 -2.59306654861286511870588356032385e-01
            2.42237109466498790055766221485101e-01 -1.75995561888501461655920365956263e-01
            2.92878455064361775672665544334450e-01 -6.22532373957087048488290292880265e-02
            2.08670983448241365021402771162684e-01 6.12713290479070804561700924750767e-02
            1.42419420602138607767628286637773e-01 1.64360773093534306976692960233777e-01
            3.09506980023966302151272600440279e-02 2.15266832999692653283219101467694e-01
            -9.03446525259242738670195649319794e-02 1.97827194431208414071576839887712e-01
            -1.82956214222075252973098713482614e-01 1.17578819410977447601496237439278e-01
            -2.17480470609554110694716655416414e-01 1.23214406571721714747237526501285e-16
            -1.82956214222075280728674329111527e-01 -1.17578819410977392090345006181451e-01
            -9.03446525259244542782610665199172e-02 -1.97827194431208303049274377372058e-01
            3.09506980023965747039760287862009e-02 -2.15266832999692681038794717096607e-01
            1.42419420602138496745325824122119e-01 -1.64360773093534390243419807120517e-01
            2.08670983448241365021402771162684e-01 -6.12713290479071012728518041967618e-02
            1.19471263550083056648176693670393e-01 5.75343282025850416561141287274950e-02
            2.95069653272245872865919835703608e-02 1.29278461984795228767453068030591e-01
            -8.26766796194355058080560638700263e-02 1.03673277092418553158026384153345e-01
            -1.32603098515744255436743515019771e-01 1.62391960154327334313257452641771e-17
            -8.26766796194355335636316794989398e-02 -1.03673277092418525402450768524432e-01
            2.95069653272244381003730495649506e-02 -1.29278461984795256523028683659504e-01
            1.19471263550083084403752309299307e-01 -5.75343282025849583893872818407544e-02
            2.24452762625274616914428094105460e-02 3.88763588766172368815787763196568e-02
            -4.48905525250549164439917149138637e-02 5.49750714617646410581653709290886e-18
            2.24452762625274616914428094105460e-02 -3.88763588766172368815787763196568e-02
            ];
        
    case   34
        
        % DEGREE.             :          34
        % CARDIN.             :         630
        % LEBESGUE CONST.     : 1.91470e+02
        % ABS.DET.VAND.MATRIX : Inf
        % CONDITIONING VAND.  : 5.39328e+03
        % POINTS OUT DISK     : 0.00000e+00
        
        pts=[
            9.98963673646727556842961348593235e-01 4.55145991329635943301035183594649e-02
            9.90685946036330755681831305992091e-01 1.36166649096246594741188573607360e-01
            9.74199082673479099803159897419391e-01 2.25690379321210610186199119198136e-01
            9.49639698900319295660210627829656e-01 3.13343967984882232347132458016858e-01
            9.17211301505453047155924650724046e-01 3.98401089846241451830621826957213e-01
            8.77182602402594269186408837413182e-01 4.80156934805915536212950200933847e-01
            8.29885291999025165310399643203709e-01 5.57934048184633324396486386831384e-01
            7.75711290704419687003223771171179e-01 6.31087944326052641130786469148006e-01
            7.15109501354899368408268856001087e-01 6.99012447007882120608712739340262e-01
            6.48582089462755972952834326861193e-01 7.61144712408964640992792283213930e-01
            5.76680322114867083271860792592634e-01 8.16969893010441983172142954572337e-01
            5.00000000000000111022302462515654e-01 8.66025403784438596588302061718423e-01
            4.19176520416664144530471958205453e-01 9.07904755319288936377120080578607e-01
            3.34879612170986218355750452246866e-01 9.42260922118820287707308125391137e-01
            2.47807785992899931581945338621153e-01 9.68809218164906393866431244532578e-01
            1.58682546456251433175665965791268e-01 9.87329655915469617255553202994633e-01
            6.82424133646710034950544354614976e-02 9.97668769190539150848451299680164e-01
            -2.27631978561055360599230112939040e-02 9.99740884841349153333567301160656e-01
            -1.13580186050474790659947643689520e-01 9.93528832665031225168661421776051e-01
            -2.03456013052633638560351414525940e-01 9.79084087682322912193910724454327e-01
            -2.91645939454824698611190569863538e-01 9.56526343599334860634542110346956e-01
            -3.77419195752614289318671580986120e-01 9.26042520987805262144831885962049e-01
            -4.60065037731152093325448504401720e-01 8.87885218402375220314581838465529e-01
            -5.38898635915575519028664075449342e-01 8.42370619269411591290008800569922e-01
            -6.13266750283716022273949874943355e-01 7.89875871891558833937097006128170e-01
            -6.82553143218653901591608246235410e-01 7.30835964278124250448342991148820e-01
            -7.46183685847685462810829903901322e-01 6.65740119697440735357929497695295e-01
            -8.03631115454978228740401391405612e-01 5.95127742818789662315737132303184e-01
            -8.54419404546488348017874159268104e-01 5.19583950035433894676373256515944e-01
            -8.98127705363696016149788192706183e-01 4.39734721005906048496569837880088e-01
            -9.34393837160671036912162890075706e-01 3.56241711589416920613615502588800e-01
            -9.62917287347799133456760500848759e-01 2.69796771157024217746567273934488e-01
            -9.83461701633742024775131085334579e-01 1.81116209709856090803725692239823e-01
            -9.95856842531531283313483982055914e-01 9.09348623088471752495820510375779e-02
            -1.00000000000000000000000000000000e+00 1.22464679914735320717376402945840e-16
            -9.95856842531531283313483982055914e-01 -9.09348623088469393271893181918131e-02
            -9.83461701633742135797433547850233e-01 -1.81116209709855396914335301516985e-01
            -9.62917287347799355501365425880067e-01 -2.69796771157024051213113580161007e-01
            -9.34393837160671147934465352591360e-01 -3.56241711589416698569010577557492e-01
            -8.98127705363696127172090655221837e-01 -4.39734721005905826451964912848780e-01
            -8.54419404546488792107084009330720e-01 -5.19583950035433228542558481422020e-01
            -8.03631115454978117718098928889958e-01 -5.95127742818789884360342057334492e-01
            -7.46183685847685573833132366416976e-01 -6.65740119697440513313324572663987e-01
            -6.82553143218654456703120558813680e-01 -7.30835964278123695336830678570550e-01
            -6.13266750283716244318554799974663e-01 -7.89875871891558611892492081096862e-01
            -5.38898635915575741073269000480650e-01 -8.42370619269411480267706338054268e-01
            -4.60065037731152703948112048237817e-01 -8.87885218402374998269976913434220e-01
            -3.77419195752614511363276506017428e-01 -9.26042520987805151122529423446395e-01
            -2.91645939454825364745005344957463e-01 -9.56526343599334638589937185315648e-01
            -2.03456013052633666315927030154853e-01 -9.79084087682322912193910724454327e-01
            -1.13580186050475040460128184349742e-01 -9.93528832665031114146358959260397e-01
            -2.27631978561062264798664500631276e-02 -9.99740884841349153333567301160656e-01
            6.82424133646709896172666276470409e-02 -9.97668769190539150848451299680164e-01
            1.58682546456250933575304884470825e-01 -9.87329655915469506233250740478979e-01
            2.47807785992899265448130563527229e-01 -9.68809218164906504888733707048232e-01
            3.34879612170986051822296758473385e-01 -9.42260922118820509751913050422445e-01
            4.19176520416663700441262108142837e-01 -9.07904755319289158421725005609915e-01
            5.00000000000000111022302462515654e-01 -8.66025403784438596588302061718423e-01
            5.76680322114866972249558330076979e-01 -8.16969893010442205216747879603645e-01
            6.48582089462755528863624476798577e-01 -7.61144712408965085082002133276546e-01
            7.15109501354899368408268856001087e-01 -6.99012447007882120608712739340262e-01
            7.75711290704419575980921308655525e-01 -6.31087944326053085219996319210622e-01
            8.29885291999024721221189793141093e-01 -5.57934048184633990530301161925308e-01
            8.77182602402594158164106374897528e-01 -4.80156934805915758257555125965155e-01
            9.17211301505452825111319725692738e-01 -3.98401089846241895919831677019829e-01
            9.49639698900319295660210627829656e-01 -3.13343967984882176835981226759031e-01
            9.74199082673478988780857434903737e-01 -2.25690379321210915497530891116185e-01
            9.90685946036330644659528843476437e-01 -1.36166649096247205363852117443457e-01
            9.98963673646727556842961348593235e-01 -4.55145991329636706579364613389771e-02
            9.84337395169534890015938799479045e-01 4.76122664812236515152754634527810e-02
            9.75146902126075576511254894285230e-01 1.42392256539960959660362505019293e-01
            9.56851725196460556333022395847365e-01 2.35842768464884583456964151082502e-01
            9.29622681518315285842390949255787e-01 3.27091280005018025800467285080231e-01
            8.93714001335996877095624313369626e-01 4.15285828393680889192296490364242e-01
            8.49460954321302086356126892496832e-01 4.99602964895292489533318303074338e-01
            7.97276719250873844302418547158595e-01 5.79255443124350288819357501779450e-01
            7.37648526267290161051448649232043e-01 6.53499569352818387990566861844854e-01
            6.71133107742498569159295129793463e-01 7.21642146178090082564438034751220e-01
            5.98351500217663923031352624093415e-01 7.83046944720362847469630196428625e-01
            5.19983245952311046167437780241016e-01 8.37140644920268073292390909045935e-01
            4.36760048221342012109147390219732e-01 8.83418188473791388126699075655779e-01
            3.49458939598703555162728662253357e-01 9.21447494425576940635380651656305e-01
            2.58895027013605560917142156540649e-01 9.50873493392390578549111523898318e-01
            1.65913881316739925120273824177275e-01 9.71421442750281638467413358739577e-01
            7.13836424130757929429336172688636e-02 9.82899491832438743088573573913891e-01
            -2.38130863265263274797245429681425e-02 9.85200473187172964806279651384102e-01
            -1.18787478695183440491334181388083e-01 9.78302903171540894078361816355027e-01
            -2.12652784380803483443855839141179e-01 9.62271182538329772349072754877852e-01
            -3.04532608314826147566378722331137e-01 9.37254995143580349470369128539460e-01
            -3.93569093336846864694678060914157e-01 9.03487910388753534540740020020166e-01
            -4.78930929775787606050840850002714e-01 8.61285202446160580436185227881651e-01
            -5.59821117164308823532792303012684e-01 8.11040906628962443569719198421808e-01
            -6.35484405617436243218776326102670e-01 7.53224140389617158319879308692180e-01
            -7.05214347397243201953642710577697e-01 6.88374723296624635437979122798424e-01
            -7.68359892825039358932315280981129e-01 6.17098136884659753675919091620017e-01
            -8.24331468956804536141191874776268e-01 5.40059871436622263018989542615600e-01
            -8.72606484266914117498004088702146e-01 4.57979212480173425436902334695333e-01
            -9.12734207944411068957890620367834e-01 3.71622525012562487933820420948905e-01
            -9.44339978245143929491689505084651e-01 2.81796098157134300432602458386100e-01
            -9.67128700607524427468320027401205e-01 1.89338617059028907485540571542515e-01
            -9.80887602870941455179831791610923e-01 9.51133323079494802376743223248923e-02
            -9.85488221872095282449777187139262e-01 1.20687499651307802549415780209390e-16
            -9.80887602870941455179831791610923e-01 -9.51133323079492304374937816646707e-02
            -9.67128700607524427468320027401205e-01 -1.89338617059028657685360030882293e-01
            -9.44339978245143818469387042568997e-01 -2.81796098157134522477207383417408e-01
            -9.12734207944411402024798007914796e-01 -3.71622525012561821800005645854981e-01
            -8.72606484266914228520306551217800e-01 -4.57979212480173203392297409664025e-01
            -8.24331468956804758185796799807576e-01 -5.40059871436622040974384617584292e-01
            -7.68359892825039469954617743496783e-01 -6.17098136884659531631314166588709e-01
            -7.05214347397243312975945173093351e-01 -6.88374723296624524415676660282770e-01
            -6.35484405617435799129566476040054e-01 -7.53224140389617602409089158754796e-01
            -5.59821117164309045577397228043992e-01 -8.11040906628962332547416735906154e-01
            -4.78930929775788161162353162580985e-01 -8.61285202446160136346975377819035e-01
            -3.93569093336846698161224367140676e-01 -9.03487910388753645563042482535820e-01
            -3.04532608314826369610983647362445e-01 -9.37254995143580238448066666023806e-01
            -2.12652784380804371622275539266411e-01 -9.62271182538329550304467829846544e-01
            -1.18787478695183246202304871985689e-01 -9.78302903171541005100664278870681e-01
            -2.38130863265265703410111797211357e-02 -9.85200473187172964806279651384102e-01
            7.13836424130757651873580016399501e-02 -9.82899491832438743088573573913891e-01
            1.65913881316740119409303133579670e-01 -9.71421442750281638467413358739577e-01
            2.58895027013605116827932306478033e-01 -9.50873493392390689571413986413972e-01
            3.49458939598703555162728662253357e-01 -9.21447494425576940635380651656305e-01
            4.36760048221341401486483846383635e-01 -8.83418188473791721193606463202741e-01
            5.19983245952310713100530392694054e-01 -8.37140644920268295336995834077243e-01
            5.98351500217663700986747699062107e-01 -7.83046944720363069514235121459933e-01
            6.71133107742498125070085279730847e-01 -7.21642146178090526653647884813836e-01
            7.37648526267290272073751111747697e-01 -6.53499569352818054923659474297892e-01
            7.97276719250873733280116084642941e-01 -5.79255443124350510863962426810758e-01
            8.49460954321301642266917042434216e-01 -4.99602964895293266689435540683917e-01
            8.93714001335997099140229238400934e-01 -4.15285828393680611636540334075107e-01
            9.29622681518315174820088486740133e-01 -3.27091280005018303356223441369366e-01
            9.56851725196460334288417470816057e-01 -2.35842768464885471635383851207735e-01
            9.75146902126075576511254894285230e-01 -1.42392256539960709860181964359072e-01
            9.84337395169534778993636336963391e-01 -4.76122664812240262155462744431134e-02
            9.57853389044037162314282340958016e-01 4.93745659569777770037113384660188e-02
            9.47699904834195527847384710184997e-01 1.47600315188838010493910246623273e-01
            9.27500565873027205121559291001176e-01 2.44261464361044844384451835139771e-01
            8.97469490178526618784360380232101e-01 3.38333381245899400546761626173975e-01
            8.57925014623910908717618895025225e-01 4.28818880122073975424967784420005e-01
            8.09286320487570876025529287289828e-01 5.14758792191329361820351095957449e-01
            7.52068990027239370199652057635831e-01 5.95242133006388951521614671946736e-01
            6.86879541179798436267844863323262e-01 6.69415759132706011946822854952188e-01
            6.14408998320263521897288683248917e-01 7.36493411681107823518743771273876e-01
            5.35425567231502474996318596822675e-01 7.95764050847618586992382461176021e-01
            4.50766491931828827688377714366652e-01 8.46599393112267728511710629391018e-01
            3.61329179680127565710279213817557e-01 8.88460571200699766869490758836037e-01
            2.68061688235659456580606274656020e-01 9.20903846211338028560078328155214e-01
            1.71952676209967125764421780331759e-01 9.43585311358129286141149805189343e-01
            7.40209230396403350393796927164658e-02 9.56264537468030972888755059102550e-01
            -2.46954703291523032515630831085218e-02 9.58807121590056543602997862763004e-01
            -1.23150085568943468139480046374956e-01 9.51186111699991898582595695188502e-01
            -2.20299279265555869589121584795066e-01 9.33482292398556512402763019053964e-01
            -3.15113245797920771273936679790495e-01 9.05883328574539237187934759276686e-01
            -4.06586933533846395238953164152917e-01 8.68681776110291847814437460328918e-01
            -4.93750698627347384128682961090817e-01 8.22271980716595907168198209546972e-01
            -5.75680583484631802626552143919980e-01 7.67145897770027396234127081697807e-01
            -6.51508110944447271783985797810601e-01 7.03887877463581168591133518930292e-01
            -7.20429490352043178091889785719104e-01 6.33168470549255069101945991860703e-01
            -7.81714137940070719068330618028995e-01 5.55737320333266393568294461147161e-01
            -8.34712421198265386301784474198939e-01 4.72415216270514803920121948976885e-01
            -8.78862545139663109416972019971581e-01 3.84085393392174123672333507784060e-01
            -9.13696507467222640563875302177621e-01 2.91684169794637737638254293415230e-01
            -9.38845059514598623273684552259510e-01 1.96191021434767659537001804892498e-01
            -9.54041620373862753190508101397427e-01 9.86181994410869067202440874098102e-02
            -9.59125102719445843391099515429232e-01 1.17458948702724558476243541106863e-16
            -9.54041620373862753190508101397427e-01 -9.86181994410866846756391623785021e-02
            -9.38845059514598734295987014775164e-01 -1.96191021434767021158762645427487e-01
            -9.13696507467222751586177764693275e-01 -2.91684169794637571104800599641749e-01
            -8.78862545139663109416972019971581e-01 -3.84085393392174290205787201557541e-01
            -8.34712421198265275279482011683285e-01 -4.72415216270514970453575642750366e-01
            -7.81714137940071163157540468091611e-01 -5.55737320333265838456782148568891e-01
            -7.20429490352043400136494710750412e-01 -6.33168470549254958079643529345049e-01
            -6.51508110944447382806288260326255e-01 -7.03887877463580946546528593898984e-01
            -5.75680583484631691604249681404326e-01 -7.67145897770027618278732006729115e-01
            -4.93750698627347939240195273669087e-01 -8.22271980716595574101290822000010e-01
            -4.06586933533846617283558089184226e-01 -8.68681776110291736792134997813264e-01
            -3.15113245797920771273936679790495e-01 -9.05883328574539237187934759276686e-01
            -2.20299279265556702256390053662471e-01 -9.33482292398556290358158094022656e-01
            -1.23150085568943287728238544787018e-01 -9.51186111699991898582595695188502e-01
            -2.46954703291527473407729331711380e-02 -9.58807121590056543602997862763004e-01
            7.40209230396401129947747676851577e-02 -9.56264537468030972888755059102550e-01
            1.71952676209966931475392470929364e-01 -9.43585311358129286141149805189343e-01
            2.68061688235659456580606274656020e-01 -9.20903846211338028560078328155214e-01
            3.61329179680127565710279213817557e-01 -8.88460571200699766869490758836037e-01
            4.50766491931828494621470326819690e-01 -8.46599393112267839534013091906672e-01
            5.35425567231502141929411209275713e-01 -7.95764050847618920059289848722983e-01
            6.14408998320263410874986220733263e-01 -7.36493411681108045563348696305184e-01
            6.86879541179798325245542400807608e-01 -6.69415759132706122969125317467842e-01
            7.52068990027238815088139745057561e-01 -5.95242133006389617655429447040660e-01
            8.09286320487570987047831749805482e-01 -5.14758792191329250798048633441795e-01
            8.57925014623910797695316432509571e-01 -4.28818880122074475025328865740448e-01
            8.97469490178526840828965305263409e-01 -3.38333381245898900946400544853532e-01
            9.27500565873027094099256828485522e-01 -2.44261464361045066429056760171079e-01
            9.47699904834195416825082247669343e-01 -1.47600315188838898672329946748505e-01
            9.57853389044037162314282340958016e-01 -4.93745659569776659814088759503647e-02
            9.23686024088397839015840418142034e-01 5.09611780504522771106934442286729e-02
            9.12473727014212365737932941556210e-01 1.52264934483665570486010665263166e-01
            8.90185234963741800484626764955465e-01 2.51720400875793559603010862701922e-01
            8.57091100037687292356736179499421e-01 3.48120322590780961746759203379042e-01
            8.13593040203548167887959152722033e-01 4.40294535165802469744988911770633e-01
            7.60219062983677251743586111842887e-01 5.27124168522694391825211823743302e-01
            6.97617056159218318356352028786205e-01 6.07555228535043068127663445920916e-01
            6.26546923290094648351100659056101e-01 6.80611391089099071471935076260706e-01
            5.47871359515183620203515602042899e-01 7.45405853335957324645733024226502e-01
            4.62545379601970174654468337394064e-01 8.01152098276845081592512087809155e-01
            3.71604725360964560643139975582017e-01 8.47173442014044986159149175364291e-01
            2.76153293143178379942526134982472e-01 8.82911247776751340055056971323211e-01
            1.77349734033798361876321791896771e-01 9.07931707014719924231371805944946e-01
            7.63933893975644318086182238403126e-02 9.21931105246413973297592292510672e-01
            -2.54902675007282197849889371354948e-02 9.24739508741387994383842396928230e-01
            -1.27064507081593475179559504795179e-01 9.16322827285577345968192730651936e-01
            -2.27096355672630950683910100451612e-01 8.96783227990316622602051666035550e-01
            -3.24371562138678404263458787681884e-01 8.66357895122007781729678299598163e-01
            -4.17709337245725176313015936102602e-01 8.25416151006423848279780486336676e-01
            -5.05976686842672385147068325750297e-01 7.74454972955971432391208963963436e-01
            -5.88102164875533572896415535069536e-01 7.14092960638342266754818865592824e-01
            -6.63088879291110600000536123843631e-01 6.45062827114523118510192034591455e-01
            -7.30026592956093622888147365301847e-01 5.68202504694796495243735989788547e-01
            -7.88102772702819920347394599957624e-01 4.84444973575585358105399791384116e-01
            -8.36612452381241600285477488796460e-01 3.94806936723719581472380468767369e-01
            -8.74966790193016596965946973796235e-01 3.00376478479677133659464516313164e-01
            -9.02700216433272917271324331522919e-01 2.02299856687652379605424357578158e-01
            -9.19476084876148291868958040140569e-01 1.01767588678087772535718613653444e-01
            -9.25090759203940127264331749756820e-01 1.13290943717990011971947515947109e-16
            -9.19476084876148291868958040140569e-01 -1.01767588678087536613325880807679e-01
            -9.02700216433272917271324331522919e-01 -2.02299856687652185316395048175764e-01
            -8.74966790193016707988249436311889e-01 -3.00376478479676967126010822539683e-01
            -8.36612452381241822330082413827768e-01 -3.94806936723719026360868156189099e-01
            -7.88102772702819809325092137441970e-01 -4.84444973575585580150004716415424e-01
            -7.30026592956093844932752290333156e-01 -5.68202504694796384221433527272893e-01
            -6.63088879291110822045141048874939e-01 -6.45062827114523007487889572075801e-01
            -5.88102164875533794941020460100845e-01 -7.14092960638342155732516403077170e-01
            -5.05976686842672607191673250781605e-01 -7.74454972955971321368906501447782e-01
            -4.17709337245725398357620861133910e-01 -8.25416151006423737257478023821022e-01
            -3.24371562138678570796912481455365e-01 -8.66357895122007670707375837082509e-01
            -2.27096355672630950683910100451612e-01 -8.96783227990316622602051666035550e-01
            -1.27064507081593502935135120424093e-01 -9.16322827285577345968192730651936e-01
            -2.54902675007282440711176008107941e-02 -9.24739508741387994383842396928230e-01
            7.63933893975635991413497549729072e-02 -9.21931105246414084319894755026326e-01
            1.77349734033798334120746176267858e-01 -9.07931707014719924231371805944946e-01
            2.76153293143178379942526134982472e-01 -8.82911247776751340055056971323211e-01
            3.71604725360963950020476431745919e-01 -8.47173442014045208203754100395599e-01
            4.62545379601970174654468337394064e-01 -8.01152098276845081592512087809155e-01
            5.47871359515183065092003289464628e-01 -7.45405853335957768734942874289118e-01
            6.26546923290094648351100659056101e-01 -6.80611391089099182494237538776360e-01
            6.97617056159218429378654491301859e-01 -6.07555228535042846083058520889608e-01
            7.60219062983676918676678724295925e-01 -5.27124168522695057959026598837227e-01
            8.13593040203548278910261615237687e-01 -4.40294535165802303211535217997152e-01
            8.57091100037687070312131254468113e-01 -3.48120322590781627880573978472967e-01
            8.90185234963741578440021839924157e-01 -2.51720400875794225736825637795846e-01
            9.12473727014212476760235404071864e-01 -1.52264934483665431708132587118598e-01
            9.23686024088397839015840418142034e-01 -5.09611780504529154889326036936836e-02
            8.83314815738499681252449136081850e-01 5.24201882236547539450910448977083e-02
            8.70915011975486708095672838680912e-01 1.56524700134773875337401705110096e-01
            8.46289470513588382161174195061903e-01 2.58431948362374930283635876548942e-01
            8.09783879975077169888209027703851e-01 3.56711378524785460708557138787000e-01
            7.61910698829872501391946570947766e-01 4.49983362853693114047359813412186e-01
            7.03341961601945619975140289170668e-01 5.36938567143830924877079269208480e-01
            6.34899844977721339311926840309752e-01 6.16356330935124319125861802604049e-01
            5.57545126247633859861707605887204e-01 6.87121802909828383043588928558165e-01
            4.72363696099018903762356558218016e-01 7.48241590961245983670835357770557e-01
            3.80551315091165631709912986480049e-01 7.98857707241363068639827815786703e-01
            2.83396827798202577408659408320091e-01 8.38259612429501976826884401816642e-01
            1.82264070256461102603751101014495e-01 8.65894190146862419155127099656966e-01
            7.85727246960877950821000581527187e-02 8.81373511498034334366025177587289e-01
            -2.62216096854817129480075266201311e-02 8.84480280742338087485165942780441e-01
            -1.30647850145544558442267657483171e-01 8.75170885649705798670083822798915e-01
            -2.33240081173183178009367111371830e-01 8.53576009720792172608128112187842e-01
            -3.32558132729713851194475182637689e-01 8.19998797677087498669834531028755e-01
            -4.27207797079136475382199478190159e-01 7.74910599973528735340266848652391e-01
            -5.15860400408608366085161378578050e-01 7.18944356071325785251246998086572e-01
            -5.97271454496286713364838760753628e-01 6.52885709355345733584385925496463e-01
            -6.70298126598012133925408306822646e-01 5.77661978423141708738342003925936e-01
            -7.33915282313916006451393059251131e-01 4.94329139564549602248177961882902e-01
            -7.87229876228271674420966519392096e-01 4.04057003169309147949661564780399e-01
            -8.29493488309553050896738568553701e-01 3.08112792153445391729604807551368e-01
            -8.60112830087119029087716626236215e-01 2.07843352927317898126702289118839e-01
            -8.78658073120837768144042456697207e-01 1.04656248624338532593469608400483e-01
            -8.84868882850189830691078896052204e-01 1.08365184504757921403894167251851e-16
            -8.78658073120837768144042456697207e-01 -1.04656248624338713004711109988421e-01
            -8.60112830087119251132321551267523e-01 -2.07843352927317315259614360911655e-01
            -8.29493488309553161919041031069355e-01 -3.08112792153445225196151113777887e-01
            -7.87229876228271785443268981907750e-01 -4.04057003169308981416207871006918e-01
            -7.33915282313916117473695521766786e-01 -4.94329139564549491225875499367248e-01
            -6.70298126598012578014618156885263e-01 -5.77661978423141264649132153863320e-01
            -5.97271454496287157454048610816244e-01 -6.52885709355345400517478537949501e-01
            -5.15860400408608477107463841093704e-01 -7.18944356071325674228944535570918e-01
            -4.27207797079136308848745784416678e-01 -7.74910599973528846362569311168045e-01
            -3.32558132729714073239080107668997e-01 -8.19998797677087387647532068513101e-01
            -2.33240081173183233520518342629657e-01 -8.53576009720792172608128112187842e-01
            -1.30647850145544974775901891916874e-01 -8.75170885649705687647781360283261e-01
            -2.62216096854819280537185477442108e-02 -8.84480280742338087485165942780441e-01
            7.85727246960871844594365143166215e-02 -8.81373511498034445388327640102943e-01
            1.82264070256461463426234104190371e-01 -8.65894190146862308132824637141312e-01
            2.83396827798202799453264333351399e-01 -8.38259612429501976826884401816642e-01
            3.80551315091165243131854367675260e-01 -7.98857707241363179662130278302357e-01
            4.72363696099018903762356558218016e-01 -7.48241590961245983670835357770557e-01
            5.57545126247633415772497755824588e-01 -6.87121802909828716110496316105127e-01
            6.34899844977721117267321915278444e-01 -6.16356330935124541170466727635358e-01
            7.03341961601945619975140289170668e-01 -5.36938567143830924877079269208480e-01
            7.61910698829872168325039183400804e-01 -4.49983362853693391603115969701321e-01
            8.09783879975077169888209027703851e-01 -3.56711378524785571730859601302654e-01
            8.46289470513588493183476657577557e-01 -2.58431948362374708239030951517634e-01
            8.70915011975486597073370376165258e-01 -1.56524700134774125137582245770318e-01
            8.83314815738499681252449136081850e-01 -5.24201882236547331284093331760232e-02
            8.37590518983204468383974017342553e-01 5.37750955060915733496607060715178e-02
            8.23837305817940013241695851320401e-01 1.60442300936757487050954296137206e-01
            7.96556706867356578705141600948991e-01 2.64475048221708641804639228212181e-01
            7.56196668812010086568875522061717e-01 3.64165122526666718005827760862303e-01
            7.03419902360955529019292953307740e-01 4.57875615587625184321751703464543e-01
            6.39093000560227220141484849591507e-01 5.44067803699289309626863087032689e-01
            5.64272209358979370819042742368765e-01 6.21326413515777664642314448428806e-01
            4.80186084080204467205987839406589e-01 6.88382860799832685394505915610353e-01
            3.88215316576293323347357500097132e-01 7.44136080540925948234587394836126e-01
            2.89870064306991470637342445115792e-01 7.87670606412289364683942949341144e-01
            1.86765153595658955909541987239209e-01 8.18271602702692502084858006128343e-01
            8.05935642256872808442125233341358e-02 8.35436601899056774378493628319120e-01
            -2.69013692407410257012578824742377e-02 8.38883755189130164708899428660516e-01
            -1.33954582967964669348859274577990e-01 8.28556460411191131321118064079201e-01
            -2.38808266146228687087926800813875e-01 8.04624291459980156560050090774894e-01
            -3.39740724196582521976495172566501e-01 7.67480213888035445179980342800263e-01
            -4.35094648948267936905409669634537e-01 7.17734132422184978317147852067137e-01
            -5.23304331593063443150981584039982e-01 6.56202876344793462060067668062402e-01
            -6.02921371580629861242073275207076e-01 5.83896787179527976263671007473022e-01
            -6.72638459315503478563869066420011e-01 5.02003128911472806805704749422148e-01
            -7.31310842144510475648644387547392e-01 4.11866593145316817192735925345914e-01
            -7.77975121163684057989939901744947e-01 3.14967219306381274179784668376669e-01
            -8.11865070201633343138780674053123e-01 2.12896092434173345164794000083930e-01
            -8.32424217232092811258326037204824e-01 1.07329217610026866891459462749481e-01
            -8.39314981629211143143720619264059e-01 1.02786440572863297513588490591854e-16
            -8.32424217232092922280628499720478e-01 -1.07329217610026672602430153347086e-01
            -8.11865070201633343138780674053123e-01 -2.12896092434173178631340306310449e-01
            -7.77975121163684169012242364260601e-01 -3.14967219306381107646330974603188e-01
            -7.31310842144510697693249312578700e-01 -4.11866593145316262081223612767644e-01
            -6.72638459315503700608473991451319e-01 -5.02003128911472695783402286906494e-01
            -6.02921371580629972264375737722730e-01 -5.83896787179527976263671007473022e-01
            -5.23304331593063554173284046555636e-01 -6.56202876344793240015462743031094e-01
            -4.35094648948268380994619519697153e-01 -7.17734132422184756272542927035829e-01
            -3.39740724196582910554553791371291e-01 -7.67480213888035334157677880284609e-01
            -2.38808266146228687087926800813875e-01 -8.04624291459980156560050090774894e-01
            -1.33954582967964336281951887031028e-01 -8.28556460411191131321118064079201e-01
            -2.69013692407410430484926422423086e-02 -8.38883755189130164708899428660516e-01
            8.05935642256867118549124029414088e-02 -8.35436601899056774378493628319120e-01
            1.86765153595658789376088293465727e-01 -8.18271602702692502084858006128343e-01
            2.89870064306991470637342445115792e-01 -7.87670606412289364683942949341144e-01
            3.88215316576293156813903806323651e-01 -7.44136080540926059256889857351780e-01
            4.80186084080204467205987839406589e-01 -6.88382860799832685394505915610353e-01
            5.64272209358979148774437817337457e-01 -6.21326413515777886686919373460114e-01
            6.39093000560226554007670074497582e-01 -5.44067803699290086782980324642267e-01
            7.03419902360955751063897878339048e-01 -4.57875615587624906765995547175407e-01
            7.56196668812009975546573059546063e-01 -3.64165122526666940050432685893611e-01
            7.96556706867356467682839138433337e-01 -2.64475048221709252427302772048279e-01
            8.23837305817940013241695851320401e-01 -1.60442300936757792362286068055255e-01
            8.37590518983204468383974017342553e-01 -5.37750955060923227502023280521826e-02
            7.87083374277397718188353792356793e-01 5.50382310969592114524573389644502e-02
            7.71763691691156772378690220648423e-01 1.64043436727635272287528778178967e-01
            7.41422506714335183275466079066973e-01 2.69855723459051510815243091201410e-01
            6.96650375999920523639730163267814e-01 3.70415575489673243314570072470815e-01
            6.38318738144725061900430773675907e-01 4.63765709684860527595162693614839e-01
            5.67562952128345621360949735390022e-01 5.48089171866708024793979348032735e-01
            4.85760198842077051128995890394435e-01 6.21744701760362672438020581466844e-01
            3.94502675829384197303539849599474e-01 6.83298678258367653270966002310161e-01
            2.95566606971814804794007613963913e-01 7.31553023224800313961679876229027e-01
            1.90877670311571767669533983280417e-01 7.65568520723392431648335332283750e-01
            8.24735169188455519151403905198094e-02 7.84683097787389094435184233589098e-01
            -2.75358896684706096202877034784251e-02 7.88524710916748805544784772791900e-01
            -1.37009341485000601945642983992002e-01 7.77018587481678513206873049057322e-01
            -2.43816062315340920108042155334260e-01 7.50388681086820663601599790126784e-01
            -3.45877180829373576109730947791832e-01 7.09153312569081317739971836999757e-01
            -4.41206193448024086567471613307134e-01 6.54115081472122272820968191808788e-01
            -5.27947629375815741248345602798508e-01 5.86345244359185335802919780689990e-01
            -6.04413165229334414796369401301490e-01 5.07162864022627113413932420371566e-01
            -6.69114486331449653810921063268324e-01 4.18109135427075506719063469063258e-01
            -7.20792255063570475037693086051149e-01 3.20917388102528788884626465005567e-01
            -7.58440622439917055963576331123477e-01 2.17479348856684823187990218684718e-01
            -7.81326805813891800411852273100521e-01 1.09808321464437919079415451051318e-01
            -7.89005351658768172562474774167640e-01 9.66252878419042254319885351206680e-17
            -7.81326805813891800411852273100521e-01 -1.09808321464437738668173949463380e-01
            -7.58440622439917166985878793639131e-01 -2.17479348856684295832053521735361e-01
            -7.20792255063570808104600473598111e-01 -3.20917388102528289284265383685124e-01
            -6.69114486331449764833223525783978e-01 -4.18109135427075451207912237805431e-01
            -6.04413165229334525818671863817144e-01 -5.07162864022626891369327495340258e-01
            -5.27947629375815852270648065314163e-01 -5.86345244359185224780617318174336e-01
            -4.41206193448024530656681463369750e-01 -6.54115081472121939754060804261826e-01
            -3.45877180829373742643184641565313e-01 -7.09153312569081317739971836999757e-01
            -2.43816062315341086641495849107741e-01 -7.50388681086820552579297327611130e-01
            -1.37009341485000629701218599620915e-01 -7.77018587481678513206873049057322e-01
            -2.75358896684713347347006617837906e-02 -7.88524710916748694522482310276246e-01
            8.24735169188451772148695795294771e-02 -7.84683097787389205457486696104752e-01
            1.90877670311571406847050980104541e-01 -7.65568520723392542670637794799404e-01
            2.95566606971814804794007613963913e-01 -7.31553023224800313961679876229027e-01
            3.94502675829384197303539849599474e-01 -6.83298678258367653270966002310161e-01
            4.85760198842077217662449584167916e-01 -6.21744701760362450393415656435536e-01
            5.67562952128345288294042347843060e-01 -5.48089171866708246838584273064043e-01
            6.38318738144724950878128311160253e-01 -4.63765709684860694128616387388320e-01
            6.96650375999920523639730163267814e-01 -3.70415575489673243314570072470815e-01
            7.41422506714335183275466079066973e-01 -2.69855723459051455304091859943583e-01
            7.71763691691156661356387758132769e-01 -1.64043436727635716376738628241583e-01
            7.87083374277397718188353792356793e-01 -5.50382310969587881799292006235191e-02
            7.32207768813968762344757124083117e-01 5.62149033265838538042658001359086e-02
            7.15045439303496288552253190573538e-01 1.67327080291319069127453644796333e-01
            6.81123050740160773663944837608142e-01 2.74517252313882575975867439410649e-01
            6.31235715160603616524781500629615e-01 3.75272972612242405876514794726972e-01
            5.66552749428264612596706228941912e-01 4.67232612499193566968358481972245e-01
            4.88590267437170322484263351725531e-01 5.48240715957162283444858985603787e-01
            3.99175643687256331837431844178354e-01 6.16398521700378565491007520904532e-01
            3.00404681174899990114823822295875e-01 6.70108468530098644322379186633043e-01
            1.94592487547004838743802679346118e-01 7.08111640815073939414503456646344e-01
            8.42192109399524102553158400041866e-02 7.29517276406939751964841889275704e-01
            -2.81280925906395272428905940387267e-02 7.33823645349998221476539583818521e-01
            -1.39816097471172462451960427642916e-01 7.20929810006133098276848159002839e-01
            -2.48226931529610339577374134023557e-01 6.91137990947496394511517792125233e-01
            -3.50819536700384959626575209767907e-01 6.45146483162448047821158070291858e-01
            -4.45189229271754027816854204502306e-01 5.84033288612874512679695726546925e-01
            -5.29124063633886310142884212837089e-01 5.09230848781876521691458492568927e-01
            -6.00656678409200672774659324204549e-01 4.22492469459484709659591317176819e-01
            -6.58110409735596313396399636985734e-01 3.25851224740974387827918690163642e-01
            -7.00138590846307362625111636589281e-01 2.21572303493226513415592648925667e-01
            -7.25756116797532935258630004682345e-01 1.12099915247573719834228711533797e-01
            -7.34362534493384622180656151613221e-01 4.16055950414762691271314576135750e-16
            -7.25756116797532935258630004682345e-01 -1.12099915247573539422987209945859e-01
            -7.00138590846307362625111636589281e-01 -2.21572303493226624437895111441321e-01
            -6.58110409735596424418702099501388e-01 -3.25851224740974221294464996390161e-01
            -6.00656678409201005841566711751511e-01 -4.22492469459484321081532698372030e-01
            -5.29124063633886532187489137868397e-01 -5.09230848781876521691458492568927e-01
            -4.45189229271753916794551741986652e-01 -5.84033288612874623701998189062579e-01
            -3.50819536700384793093121515994426e-01 -6.45146483162448047821158070291858e-01
            -2.48226931529610339577374134023557e-01 -6.91137990947496394511517792125233e-01
            -1.39816097471172989807897124592273e-01 -7.20929810006132987254545696487185e-01
            -2.81280925906397076541320956266645e-02 -7.33823645349998221476539583818521e-01
            8.42192109399523963775280321897299e-02 -7.29517276406939751964841889275704e-01
            1.94592487547004505676895291799156e-01 -7.08111640815074050436805919161998e-01
            3.00404681174899879092521359780221e-01 -6.70108468530098755344681649148697e-01
            3.99175643687256498370885537951835e-01 -6.16398521700378565491007520904532e-01
            4.88590267437170100439658426694223e-01 -5.48240715957162505489463910635095e-01
            5.66552749428264168507496378879296e-01 -4.67232612499194011057568332034862e-01
            6.31235715160603394480176575598307e-01 -3.75272972612242849965724644789589e-01
            6.81123050740160773663944837608142e-01 -2.74517252313882742509321133184130e-01
            7.15045439303496288552253190573538e-01 -1.67327080291318985860726797909592e-01
            7.32207768813968762344757124083117e-01 -5.62149033265841591155975720539573e-02
            6.73279313374652188528557417157572e-01 5.73045147720045444650338595238281e-02
            6.53910293365423611611220167105785e-01 1.70264997760090464051785374977044e-01
            6.15729464787545976989235896326136e-01 2.78327266763319647324692596157547e-01
            5.59835220563545288285922651994042e-01 3.78382567050947193898480236384785e-01
            4.87835536333351749149755960388575e-01 4.67552489803924553601888192133629e-01
            4.01801711922772863960773293001694e-01 5.43271778695918361457017908833222e-01
            3.04208783818711137048040882291389e-01 6.03362127647268375874034518346889e-01
            1.97864322875723724903807010377932e-01 6.46094846724866944676080038334476e-01
            8.58276656142673843863377669549664e-02 6.70240593404117457332347385090543e-01
            -2.86780973208736814084041100159084e-02 6.75104738515108104834894220402930e-01
            -1.42358843610173868565738075631089e-01 6.60547349459122412618228281644406e-01
            -2.51944185160903333375870261079399e-01 6.26987215814729603735599994251970e-01
            -3.54281551218176893325306764381821e-01 5.75389801524097466156604241405148e-01
            -4.46426882085700083013790617769700e-01 5.07239470253191493398503553180490e-01
            -5.25729324362996131014824641169980e-01 4.24496782951679862971872125854134e-01
            -5.89907491171339670721351922111353e-01 3.29542096083996094435519808030222e-01
            -6.37115093500549845018099404114764e-01 2.25107083107759203821629512276559e-01
            -6.65994054582279781939746499119792e-01 1.14196149201946900442194987590483e-01
            -6.75713579286000398660405608097790e-01 8.27510472013001698962015443453308e-17
            -6.65994054582279781939746499119792e-01 -1.14196149201946733908741293817002e-01
            -6.37115093500549845018099404114764e-01 -2.25107083107759065043751434131991e-01
            -5.89907491171339892765956847142661e-01 -3.29542096083995650346309957967605e-01
            -5.25729324362996019992522178654326e-01 -4.24496782951679973994174588369788e-01
            -4.46426882085700194036093080285355e-01 -5.07239470253191382376201090664836e-01
            -3.54281551218177226392214151928783e-01 -5.75389801524097244111999316373840e-01
            -2.51944185160903499909323954852880e-01 -6.26987215814729603735599994251970e-01
            -1.42358843610173757543435613115435e-01 -6.60547349459122412618228281644406e-01
            -2.86780973208739971280767377947996e-02 -6.75104738515107993812591757887276e-01
            8.58276656142669264193401090778934e-02 -6.70240593404117457332347385090543e-01
            1.97864322875723419592475238459883e-01 -6.46094846724867055698382500850130e-01
            3.04208783818711137048040882291389e-01 -6.03362127647268375874034518346889e-01
            4.01801711922773030494226986775175e-01 -5.43271778695918361457017908833222e-01
            4.87835536333351638127453497872921e-01 -4.67552489803924664624190654649283e-01
            5.59835220563545066241317726962734e-01 -3.78382567050947582476538855189574e-01
            6.15729464787545865966933433810482e-01 -2.78327266763319869369297521188855e-01
            6.53910293365423611611220167105785e-01 -1.70264997760090436296209759348130e-01
            6.73279313374652077506254954641918e-01 -5.73045147720048358985778236274200e-02
            6.10544212178937506507736543426290e-01 5.82999035492518802303862912594923e-02
            5.88477553593361846218101618433138e-01 1.72792600234568577421967461305030e-01
            5.45141782957611509274897798604798e-01 2.81040122140679304862942444742657e-01
            4.82103167932711407228651978584821e-01 3.79130121789729823689185650437139e-01
            4.01640088311170984081144297306309e-01 4.63517371023402180441053133108653e-01
            3.06660689435021838189499021609663e-01 5.31151894785558131850677909824299e-01
            2.00597774246057819480526518418628e-01 5.79589205167400534080002216796856e-01
            8.72847328434386143802825586135441e-02 6.07078651569548322086689040588681e-01
            -2.91830062222959603357441693560759e-02 6.12626693775973896194386725255754e-01
            -1.44595995407575422797563646781782e-01 5.96032811086054215010676671226975e-01
            -2.54782908577634137348155718427734e-01 5.57896749655142243362604403955629e-01
            -3.55761303601303369159580824998557e-01 4.99596846105890390887793728325050e-01
            -4.43881558185786284642659893506789e-01 4.23240210851485498810831131777377e-01
            -5.15958776735315427508510310872225e-01 3.31586571635294757864897974286578e-01
            -5.69387900776149868953268651239341e-01 2.27948529779818526153079005780455e-01
            -6.02237862557228775806095200096024e-01 1.16071834143998520172402777461684e-01
            -6.13321378870043565356695580703672e-01 7.51102063481839963897465822337687e-17
            -6.02237862557228886828397662611678e-01 -1.16071834143998103838768543027982e-01
            -5.69387900776149979975571113754995e-01 -2.27948529779818387375200927635888e-01
            -5.15958776735315649553115235903533e-01 -3.31586571635294424797990586739616e-01
            -4.43881558185786395664962356022443e-01 -4.23240210851485443299679900519550e-01
            -3.55761303601303480181883287514211e-01 -4.99596846105890335376642497067223e-01
            -2.54782908577634026325853255912079e-01 -5.57896749655142354384906866471283e-01
            -1.44595995407575422797563646781782e-01 -5.96032811086054215010676671226975e-01
            -2.91830062222962482998411815060535e-02 -6.12626693775973896194386725255754e-01
            8.72847328434383229467385945099522e-02 -6.07078651569548433108991503104335e-01
            2.00597774246057819480526518418628e-01 -5.79589205167400645102304679312510e-01
            3.06660689435021838189499021609663e-01 -5.31151894785558131850677909824299e-01
            4.01640088311170651014236909759347e-01 -4.63517371023402457996809289397788e-01
            4.82103167932711240695198284811340e-01 -3.79130121789730101244941806726274e-01
            5.45141782957611398252595336089144e-01 -2.81040122140679471396396138516138e-01
            5.88477553593361846218101618433138e-01 -1.72792600234568632933118692562857e-01
            6.10544212178937395485434080910636e-01 -5.82999035492523590140656608582503e-02
            5.44194348487826440319281573465560e-01 5.91847020495814002405410292340093e-02
            5.18748425581112893034685384918703e-01 1.74786695259977614691493386089860e-01
            4.69046402841691467688889360942994e-01 2.82215856861476377392961012446904e-01
            3.97412291613026935621633128903341e-01 3.76448918656529074588945604773471e-01
            3.07195623320575372794394297670806e-01 4.53079647408124897012271503626835e-01
            2.02614829105066729386663837431115e-01 5.08524875408776999563542631221935e-01
            8.85599906708133544075423060348839e-02 5.40192045420120114940232269873377e-01
            -2.96358144998466951913762557069276e-02 5.46600435767955028509845760709140e-01
            -1.46445881922336346159241315945110e-01 5.27450397242031354672064935584785e-01
            -2.56408302669044796395780849707080e-01 4.83637364360082422365394450025633e-01
            -3.54381356160309080038928186695557e-01 4.17209985844979258651221698528389e-01
            -4.35783931304105365267531624340336e-01 3.31274332087359901777290360769257e-01
            -4.96809734159174454237728468797286e-01 2.29848658746310746670005187297647e-01
            -5.34605266009321233866558031877503e-01 1.17675517580720701005247974535450e-01
            -5.47403249791949653157985267171171e-01 6.70375637700570183282071669953234e-17
            -5.34605266009321233866558031877503e-01 -1.17675517580720562227369896390883e-01
            -4.96809734159174398726577237539459e-01 -2.29848658746310829936732034184388e-01
            -4.35783931304105642823287780629471e-01 -3.31274332087359568710382973222295e-01
            -3.54381356160308969016625724179903e-01 -4.17209985844979369673524161044043e-01
            -2.56408302669045129462688237254042e-01 -4.83637364360082255831940756252152e-01
            -1.46445881922336595959421856605331e-01 -5.27450397242031354672064935584785e-01
            -2.96358144998470698916470666972600e-02 -5.46600435767954917487543298193486e-01
            8.85599906708132295074520357047732e-02 -5.40192045420120114940232269873377e-01
            2.02614829105066479586483296770894e-01 -5.08524875408777110585845093737589e-01
            3.07195623320575317283243066412979e-01 -4.53079647408125008034573966142489e-01
            3.97412291613026935621633128903341e-01 -3.76448918656529074588945604773471e-01
            4.69046402841691467688889360942994e-01 -2.82215856861476377392961012446904e-01
            5.18748425581112893034685384918703e-01 -1.74786695259977531424766539203119e-01
            5.44194348487826440319281573465560e-01 -5.91847020495817957574935519460269e-02
            4.74372450689452551664260226971237e-01 5.99271768475556423916295045728475e-02
            4.44565884992798698860383410647046e-01 1.76016085624595530756408834349713e-01
            3.86825609743092380110596195663675e-01 2.81045256399961473903204023372382e-01
            3.04779658788150498160973711492261e-01 3.68415320103567145437750696146395e-01
            2.03583280970372426654790842803777e-01 4.32636494308297703259569289002684e-01
            8.95950168822927800471589421249519e-02 4.69673526449912781544071549433284e-01
            -3.00228316239241101170964753919179e-02 4.77199243586278909479148069294752e-01
            -1.47754235202958661421490660359268e-01 4.54740777232066628599227442464326e-01
            -2.56201696782126231433096563705476e-01 4.03709275424772418006114094168879e-01
            -3.48551063508542591229399931762600e-01 3.27311235103684095015807997697266e-01
            -4.18999685033574986725568578549428e-01 2.30347026114513186989540827198653e-01
            -4.63121015374898914451762266253354e-01 1.18909266317465317497337196073204e-01
            -4.78142749080267104311303683061851e-01 5.85555987196665110243543384055374e-17
            -4.63121015374899025474064728769008e-01 -1.18909266317464998308217616340698e-01
            -4.18999685033574986725568578549428e-01 -2.30347026114513270256267674085393e-01
            -3.48551063508542813274004856793908e-01 -3.27311235103683872971203072665958e-01
            -2.56201696782125953877340407416341e-01 -4.03709275424772584539567787942360e-01
            -1.47754235202958855710519969761663e-01 -4.54740777232066573088076211206499e-01
            -3.00228316239240164420287726443348e-02 -4.77199243586278909479148069294752e-01
            8.95950168822925580025540170936438e-02 -4.69673526449912837055222780691111e-01
            2.03583280970372038076732223998988e-01 -4.32636494308297814281871751518338e-01
            3.04779658788150276116368786460953e-01 -3.68415320103567311971204389919876e-01
            3.86825609743092324599444964405848e-01 -2.81045256399961584925506485888036e-01
            4.44565884992798698860383410647046e-01 -1.76016085624595503000833218720800e-01
            4.74372450689452496153108995713410e-01 -5.99271768475558297417649100680137e-02
            4.01166292459533391223658327362500e-01 6.04660896039361309139970046544477e-02
            3.65520906885226315452541712147649e-01 1.76025591399435021866537454116042e-01
            2.97397384672087372603499488832313e-01 2.75944446923509612012992420204682e-01
            2.02848799723907180503346125988173e-01 3.51344427376170775900732223817613e-01
            9.02762087329623819087487390788738e-02 3.95525913606835310964981999859447e-01
            -3.03178195745227342661198832729497e-02 4.04563186676649810813444219093071e-01
            -1.48217976565251902121289617753064e-01 3.77653245213941723967820962570840e-01
            -2.52948315894281516857944325238350e-01 3.17187155610005599992717861823621e-01
            -3.35203087310703529144717549570487e-01 2.28537595277214733435755533719203e-01
            -3.87673593405049643489945765395532e-01 1.19581466683325796096504234355962e-01
            -4.05697599447814249984389789460693e-01 4.96836266585530730025551078553584e-17
            -3.87673593405049754512248227911186e-01 -1.19581466683325532418535885881283e-01
            -3.35203087310703473633566318312660e-01 -2.28537595277214816702482380605943e-01
            -2.52948315894281627880246787754004e-01 -3.17187155610005544481566630565794e-01
            -1.48217976565251818854562770866323e-01 -3.77653245213941723967820962570840e-01
            -3.03178195745230118218760395620848e-02 -4.04563186676649810813444219093071e-01
            9.02762087329622986420218921921332e-02 -3.95525913606835310964981999859447e-01
            2.02848799723906847436438738441211e-01 -3.51344427376170942434185917591094e-01
            2.97397384672087428114650720090140e-01 -2.75944446923509556501841188946855e-01
            3.65520906885226259941390480889822e-01 -1.76025591399435132888839916631696e-01
            4.01166292459533391223658327362500e-01 -6.04660896039364709197982961086382e-02
            3.24582859375005639002154111949494e-01 6.06750519631312559831748387750849e-02
            2.80746145640698385737010767115862e-01 1.73830653909703480852755319574499e-01
            1.98993109269518353432459889518213e-01 2.63509462816865214218609025920159e-01
            9.03649508326063860552679329884995e-02 3.17599858614269481282832430224516e-01
            -3.04674949437274585062329634865819e-02 3.28796633624246992244621878853650e-01
            -1.47185136701693225491638372659509e-01 2.95587601338228034286714773770655e-01
            -2.44024610167098338076030472620914e-01 2.22457825584039731170449272212863e-01
            -3.07907207842392505181550177439931e-01 1.19283887803361993151796127676789e-01
            -3.30205230925833981281414253317052e-01 4.04384779115035168810079841666811e-17
            -3.07907207842392560692701408697758e-01 -1.19283887803361784984979010459938e-01
            -2.44024610167098254809303625734174e-01 -2.22457825584039786681600503470690e-01
            -1.47185136701693558558545760206471e-01 -2.95587601338227867753261079997174e-01
            -3.04674949437274689145738193474244e-02 -3.28796633624246992244621878853650e-01
            9.03649508326063027885410861017590e-02 -3.17599858614269481282832430224516e-01
            1.98993109269518270165733042631473e-01 -2.63509462816865269729760257177986e-01
            2.80746145640698274714708304600208e-01 -1.73830653909703647386209013347980e-01
            3.24582859375005639002154111949494e-01 -6.06750519631311657775540879811160e-02
            2.44470322110710486240847671979282e-01 6.02565225685871147520700219502032e-02
            1.88465117501909029673612394617521e-01 1.66965524555115318872111629389110e-01
            8.92848257243006315775346592999995e-02 2.35424737018764568263762271271844e-01
            -3.03495436279515168331855079486559e-02 2.49950979407059459269646595203085e-01
            -1.43031198286690003351750988258573e-01 2.07216464649039810996811183940736e-01
            -2.22946129130745879232122774737945e-01 1.17011155069035935327725894694595e-01
            -2.51786788583065246349690369243035e-01 -8.09808075219540004884190623574690e-17
            -2.22946129130746018010000852882513e-01 -1.17011155069035685527545354034373e-01
            -1.43031198286690058862902219516400e-01 -2.07216464649039783241235568311822e-01
            -3.03495436279516903055331056293653e-02 -2.49950979407059459269646595203085e-01
            8.92848257243006315775346592999995e-02 -2.35424737018764568263762271271844e-01
            1.88465117501908946406885547730781e-01 -1.66965524555115402138838476275851e-01
            2.44470322110710486240847671979282e-01 -6.02565225685871355687517336718884e-02
            1.60264682330249846886616182928265e-01 5.83315739723395398907968001367408e-02
            8.52750563243824949433147253330390e-02 1.47700730172128175121670778935368e-01
            -2.96157162623477167306962343218402e-02 1.67959073213609172414706449671939e-01
            -1.30648966067902105869791284931125e-01 1.09627499241269674157273072978569e-01
            -1.70550112648764962131053835037164e-01 2.08863649549530534493411261796884e-17
            -1.30648966067902189136518131817866e-01 -1.09627499241269577012758418277372e-01
            -2.96157162623477202001431862754544e-02 -1.67959073213609172414706449671939e-01
            8.52750563243823700432244550029282e-02 -1.47700730172128230632822010193195e-01
            1.60264682330249846886616182928265e-01 -5.83315739723395190741150884150557e-02
            7.00544051568275233377036670390225e-02 5.08975046205532577481278622144600e-02
            -2.67584017082521975761100208046628e-02 8.23538924186099918767212102466146e-02
            -8.65920068971506307065055807470344e-02 1.06044624078341047191676745179725e-17
            -2.67584017082522183927917325263479e-02 -8.23538924186099918767212102466146e-02
            7.00544051568275094599158592245658e-02 -5.08975046205532785648095739361452e-02
            -0.00000000000000000000000000000000e+00 0.00000000000000000000000000000000e+00
            ];
        
    case   35
        
        % DEGREE.             :          35
        % CARDIN.             :         666
        % LEBESGUE CONST.     : 2.27483e+02
        % ABS.DET.VAND.MATRIX : Inf
        % CONDITIONING VAND.  : 9.60598e+03
        % POINTS OUT DISK     : 0.00000e+00
        
        pts=[
            9.99021226519973604141000578238163e-01 4.42333467253788539808034840916662e-02
            9.91202530899414568921201862394810e-01 1.32353854264222442482790143003513e-01
            9.75626331552506775857125376205659e-01 2.19438513441460564257212695338239e-01
            9.52414533358131309981331469316501e-01 3.04805768725286585496547786533483e-01
            9.21748800108878385550781331403414e-01 3.87787505597902093512630017357878e-01
            8.83869132745561114639087918476434e-01 4.67734279457481749719960362199345e-01
            8.39071991024448626816933938243892e-01 5.44020398402732308085205659153871e-01
            7.87707973317718357364469738968182e-01 6.16048820120364104546695216413355e-01
            7.30179072705834153467208125221077e-01 6.83255824550693557917213638575049e-01
            6.66935530836650802832821227639215e-01 7.45115425761428529227714534499682e-01
            5.98472314174057329339007083035540e-01 8.01143488500748124359063240262913e-01
            5.25325240214298827545746917166980e-01 8.50901517212062086237267521937611e-01
            4.48066783987578542980401152817649e-01 8.94000087856275715836318340734579e-01
            3.67301597664756895866844388365280e-01 9.30101895682896140371553883596789e-01
            2.83661778334296565962091563051217e-01 9.58924395097040194180237904220121e-01
            1.97801920985517354356630903566838e-01 9.80242010961802634483319707214832e-01
            1.10393995415269716153794377078157e-01 9.93887904029550739437581796664745e-01
            2.21220871531871178528039223465385e-02 9.99755276685242999512581718590809e-01
            -6.63229564351039135861043405384407e-02 9.97798208782571083297341374418465e-01
            -1.54248932965302260056361660645052e-01 9.88032017031364118153646813880187e-01
            -2.40967702456614030204207210772438e-01 9.70533135123567203272898495924892e-01
            -3.25800572960117384990752498197253e-01 9.45438515535970358527606549614575e-01
            -4.08083612243464954882909978550742e-01 9.12944557691388713926983200508403e-01
            -4.87172843960796742024399463844020e-01 8.73305570866892644232848397223279e-01
            -5.62449287640780282160335445951205e-01 8.26831783878908987972522481868509e-01
            -6.33323803048046807262494439783040e-01 7.73886917122106998689901047328021e-01
            -6.99241701004314042400267226184951e-01 7.14885335964162482724759684060700e-01
            -7.59687084583285043848377426911611e-01 6.50288807774936805650156657065963e-01
            -8.14186886703574086432411149871768e-01 5.80602887970720793475720711285248e-01
            -8.62314572520027855517810166929848e-01 5.06372963357643812720709775021533e-01
            -9.03693477637203756991368663875619e-01 4.28179983740455405438751768087968e-01
            -9.37999756018967456583368402789347e-01 3.46635915202619382391446833935333e-01
            -9.64964914522809857899687813187484e-01 2.62378950641979358238131680991501e-01
            -9.84377914222725580728479144454468e-01 1.76068515046036239146687307766115e-01
            -9.96086822074944810978536224865820e-01 8.83801045973423432533522259291203e-02
            -1.00000000000000000000000000000000e+00 1.22464679914735320717376402945840e-16
            -9.96086822074944810978536224865820e-01 -8.83801045973421073309594930833555e-02
            -9.84377914222725469706176681938814e-01 -1.76068515046035989346506767105893e-01
            -9.64964914522809968921990275703138e-01 -2.62378950641979136193526755960193e-01
            -9.37999756018967345561065940273693e-01 -3.46635915202619548924900527708814e-01
            -9.03693477637204090058276051422581e-01 -4.28179983740454794816088224251871e-01
            -8.62314572520027744495507704414194e-01 -5.06372963357644034765314700052841e-01
            -8.14186886703574197454713612387422e-01 -5.80602887970720571431115786253940e-01
            -7.59687084583285043848377426911611e-01 -6.50288807774936583605551732034655e-01
            -6.99241701004313931377964763669297e-01 -7.14885335964162704769364609092008e-01
            -6.33323803048046918284796902298694e-01 -7.73886917122106776645296122296713e-01
            -5.62449287640780837271847758529475e-01 -8.26831783878908543883312631805893e-01
            -4.87172843960796186912887151265750e-01 -8.73305570866892866277453322254587e-01
            -4.08083612243465621016724753644667e-01 -9.12944557691388380860075812961441e-01
            -3.25800572960117607035357423228561e-01 -9.45438515535970247505304087098921e-01
            -2.40967702456614751849173217124189e-01 -9.70533135123567203272898495924892e-01
            -1.54248932965302926190176435738977e-01 -9.88032017031364007131344351364532e-01
            -6.63229564351039413416799561673542e-02 -9.97798208782571083297341374418465e-01
            2.21220871531866494774654086086230e-02 -9.99755276685242999512581718590809e-01
            1.10393995415269258186796719201084e-01 -9.93887904029550739437581796664745e-01
            1.97801920985517382112206519195752e-01 -9.80242010961802856527924632246140e-01
            2.83661778334296565962091563051217e-01 -9.58924395097040194180237904220121e-01
            3.67301597664757284444903007170069e-01 -9.30101895682896029349251421081135e-01
            4.48066783987578709513854846591130e-01 -8.94000087856275604814015878218925e-01
            5.25325240214298050389629679557402e-01 -8.50901517212062530326477372000227e-01
            5.98472314174057218316704620519886e-01 -8.01143488500748235381365702778567e-01
            6.66935530836650358743611377576599e-01 -7.45115425761428862294621922046645e-01
            7.30179072705833709377998275158461e-01 -6.83255824550694002006423488637665e-01
            7.87707973317718246342167276452528e-01 -6.16048820120364215568997678929009e-01
            8.39071991024448404772329013212584e-01 -5.44020398402732530129810584185179e-01
            8.83869132745561225661390380992088e-01 -4.67734279457481583186506668425864e-01
            9.21748800108878385550781331403414e-01 -3.87787505597902093512630017357878e-01
            9.52414533358131309981331469316501e-01 -3.04805768725286863052303942822618e-01
            9.75626331552506886879427838721313e-01 -2.19438513441460175679154076533450e-01
            9.91202530899414457898899399879156e-01 -1.32353854264222275949336449230032e-01
            9.99021226519973604141000578238163e-01 -4.42333467253798601204195506397809e-02
            9.85077856548110419865338371891994e-01 4.62236326336379760304495789569046e-02
            9.76420956925105332224745779967634e-01 1.38264682955303142009029215842020e-01
            9.59183234824251607086864623852307e-01 2.29090658271684011193514152182615e-01
            9.33516175967174510752499827503925e-01 3.17903376645942870037941929695080e-01
            8.99645343390000018501950762583874e-01 4.03922348715638646066139472168288e-01
            8.57868395187282861691357993549900e-01 4.86391636661307025235601031454280e-01
            8.08552468681968949937299839803018e-01 5.64586497415199062288593268021941e-01
            7.52130954009400554127751092892140e-01 6.37819751729419182062486015638569e-01
            6.89099685469223732781074431841262e-01 7.05447823131864271140045730135171e-01
            6.20012584115734677325804113934282e-01 7.66876393699400638048757627984742e-01
            5.45476789879737578026208666415187e-01 8.21565626945142901682572755817091e-01
            4.66147326001002781925564022458275e-01 8.69034911920910091431835553521523e-01
            3.82721342660482855002612723183120e-01 9.08867086843519800254398433025926e-01
            2.95931990399456279483558773790719e-01 9.40712105127538555926491881109541e-01
            2.06541977166207868510383605098468e-01 9.64290111607260302939437224267749e-01
            1.15336865611157815547649363452365e-01 9.79393901913965692074270918965340e-01
            2.31181695340406424821200204178240e-02 9.85890743395364421708393365406664e-01
            -6.93036898481828728124654048770026e-02 9.83723541574916260366023834649241e-01
            -1.61116505912123147981063198130869e-01 9.72911341900143500360798043402610e-01
            -2.51513424328969836807345927809365e-01 9.53549162370553649026305720326491e-01
            -3.39700033729345318711523304955335e-01 9.25807158516043671170336892828345e-01
            -4.24901347018984021364218506278121e-01 8.89929128063983498897471235977719e-01
            -5.06368611993180173236339669529116e-01 8.46230368436024060763145371311111e-01
            -5.83385891398087608195055508986115e-01 7.95094905903017235004881513305008e-01
            -6.55276354613046230213058152003214e-01 7.36972120748340286944255694834283e-01
            -7.21408225662415247825265396386385e-01 6.72372798097807256034741385519737e-01
            -7.81200335285562208476051182515221e-01 6.01864639121617028827415651903721e-01
            -8.34127228273220944210208926961059e-01 5.26067272056058299334324601659318e-01
            -8.79723781186765640960345535859233e-01 4.45646806888289725989693579322193e-01
            -9.17589289879713998487886783550493e-01 3.61309981557818626907163661599043e-01
            -9.47390990900171758859471538016805e-01 2.73797951118082083521443337303936e-01
            -9.68866985828015114812217234430136e-01 1.83879774439185322831846747249074e-01
            -9.81828542847623220168884472514037e-01 9.23456556908983511311461711557058e-02
            -9.86161755329859168739403685322031e-01 1.20769983710624738708724249825979e-16
            -9.81828542847623220168884472514037e-01 -9.23456556908981152087534383099410e-02
            -9.68866985828015225834519696945790e-01 -1.83879774439185073031666206588852e-01
            -9.47390990900171869881774000532459e-01 -2.73797951118081861476838412272627e-01
            -9.17589289879714109510189246066147e-01 -3.61309981557818404862558736567735e-01
            -8.79723781186765974027252923406195e-01 -4.45646806888289059855878804228269e-01
            -8.34127228273220833187906464445405e-01 -5.26067272056058521378929526690627e-01
            -7.81200335285562319498353645030875e-01 -6.01864639121616806782810726872412e-01
            -7.21408225662415358847567858902039e-01 -6.72372798097807033990136460488429e-01
            -6.55276354613046452257663077034522e-01 -7.36972120748340175921953232318629e-01
            -5.83385891398087830239660434017424e-01 -7.95094905903017012960276588273700e-01
            -5.06368611993180395280944594560424e-01 -8.46230368436023949740842908795457e-01
            -4.24901347018983910341916043762467e-01 -8.89929128063983498897471235977719e-01
            -3.39700033729345929334186848791433e-01 -9.25807158516043449125731967797037e-01
            -2.51513424328970058851950852840673e-01 -9.53549162370553649026305720326491e-01
            -1.61116505912123175736638813759782e-01 -9.72911341900143500360798043402610e-01
            -6.93036898481826785234360954746080e-02 -9.83723541574916260366023834649241e-01
            2.31181695340403996208333836648308e-02 -9.85890743395364421708393365406664e-01
            1.15336865611157579625256630606600e-01 -9.79393901913965803096573381480994e-01
            2.06541977166208062799412914500863e-01 -9.64290111607260302939437224267749e-01
            2.95931990399455613349743998696795e-01 -9.40712105127538777971096806140849e-01
            3.82721342660482632958007798151812e-01 -9.08867086843519911276700895541580e-01
            4.66147326001002781925564022458275e-01 -8.69034911920910091431835553521523e-01
            5.45476789879737022914696353836916e-01 -8.21565626945143234749480143364053e-01
            6.20012584115734899370409038965590e-01 -7.66876393699400416004152702953434e-01
            6.89099685469223621758771969325608e-01 -7.05447823131864271140045730135171e-01
            7.52130954009400110038541242829524e-01 -6.37819751729419737173998328216840e-01
            8.08552468681969171981904764834326e-01 -5.64586497415198840243988342990633e-01
            8.57868395187282750669055531034246e-01 -4.86391636661307358302508419001242e-01
            8.99645343389999685435043375036912e-01 -4.03922348715639478733407941035694e-01
            9.33516175967174621774802290019579e-01 -3.17903376645942703504488235921599e-01
            9.59183234824251607086864623852307e-01 -2.29090658271684399771572770987405e-01
            9.76420956925105332224745779967634e-01 -1.38264682955303336298058525244414e-01
            9.85077856548110419865338371891994e-01 -4.62236326336378997026166359773924e-02
            9.59787818032195372275339195766719e-01 4.79010185759465925703359800991166e-02
            9.50249015493488946582090193260228e-01 1.43226993884779857379996315103199e-01
            9.31266211321196024641722033265978e-01 2.37129514980909616994608768436592e-01
            9.03028065151569858670654866728000e-01 3.28675336422172281736209242808400e-01
            8.65815220367773474841044389904710e-01 4.16954634706366900065432901101303e-01
            8.19997514939853178184137050266145e-01 5.01090050505975548311710099369520e-01
            7.66030305808835465519734952977160e-01 5.80245408259331241218603736342629e-01
            7.04449943344868989569818040763494e-01 6.53634026459016914678556986473268e-01
            6.35868440856280692230484419269487e-01 7.20526536046118604161847542854957e-01
            5.60967392126358821435871959693031e-01 7.80258129207615502842543264705455e-01
            4.80491197428115079937072096072370e-01 8.32235166535103876306322945310967e-01
            3.95239665339936596666348123108037e-01 8.75941076879940938582080889318604e-01
            3.06060063888602351678258628453477e-01 9.10941491269401271146932685951469e-01
            2.13838700018984140260869253324927e-01 9.36888559860673542090125920367427e-01
            1.19492111077436180543998034409015e-01 9.53524409028879360583630386827281e-01
            2.39579558518758610474730375017316e-02 9.60683704231010349161579142673872e-01
            -7.18143043025122190803344324194768e-02 9.58295293174897144794499581621494e-01
            -1.66872841636786867214325980057765e-01 9.46382912962654643251880770549178e-01
            -2.60272921700047510373821069151745e-01 9.25064954180698006958039059099974e-01
            -3.51086292534846577950702339876443e-01 8.94553284280904192904415594966849e-01
            -4.38410410062177291479201812762767e-01 8.55151141946690840356382068421226e-01
            -5.21377407970017636706927532941336e-01 8.07250123370744199213788760971511e-01
            -5.99162722958642257609085390868131e-01 7.51326290396124307768843664234737e-01
            -6.70993289621148236712144807825098e-01 6.87935439199788389963430290663382e-01
            -7.36155223514782686144997114752186e-01 6.17707576540482583560276452772086e-01
            -7.94000916065261019838317224639468e-01 5.41340658468530411262520374293672e-01
            -8.43955470791728945556542385020293e-01 4.59593653725034634316415349530871e-01
            -8.85522416886271535041430524870520e-01 3.73279000769548008342724187968997e-01
            -9.18288643363852852274931137799285e-01 2.83254533401656960478476321441121e-01
            -9.41928504744882988397591816465138e-01 1.90414955223282666985085143096512e-01
            -9.56207057466295307079917620285414e-01 9.56829476723257271730815887167410e-02
            -9.60982394856230381918749117176048e-01 1.17686401389764042076352405265389e-16
            -9.56207057466295307079917620285414e-01 -9.56829476723254912506888558709761e-02
            -9.41928504744883099419894278980792e-01 -1.90414955223282444940480218065204e-01
            -9.18288643363853074319536062830593e-01 -2.83254533401656349855812777605024e-01
            -8.85522416886271424019128062354866e-01 -3.73279000769548174876177881742478e-01
            -8.43955470791729056578844847535947e-01 -4.59593653725034412271810424499563e-01
            -7.94000916065261241882922149670776e-01 -5.41340658468530300240217911778018e-01
            -7.36155223514782908189602039783495e-01 -6.17707576540482361515671527740778e-01
            -6.70993289621148458756749732856406e-01 -6.87935439199788278941127828147728e-01
            -5.99162722958642479653690315899439e-01 -7.51326290396124085724238739203429e-01
            -5.21377407970017525684625070425682e-01 -8.07250123370744199213788760971511e-01
            -4.38410410062177902101865356598864e-01 -8.55151141946690507289474680874264e-01
            -3.51086292534847355106819577486021e-01 -8.94553284280903859837508207419887e-01
            -2.60272921700047121795762450346956e-01 -9.25064954180698117980341521615628e-01
            -1.66872841636786894969901595686679e-01 -9.46382912962654643251880770549178e-01
            -7.18143043025126492917564746676362e-02 -9.58295293174897144794499581621494e-01
            2.39579558518756251250803046559668e-02 -9.60683704231010349161579142673872e-01
            1.19492111077435528287971067129547e-01 -9.53524409028879360583630386827281e-01
            2.13838700018983918216264328293619e-01 -9.36888559860673542090125920367427e-01
            3.06060063888602518211712322226958e-01 -9.10941491269401160124630223435815e-01
            3.95239665339936263599440735561075e-01 -8.75941076879941160626685814349912e-01
            4.80491197428115301981677021103678e-01 -8.32235166535103765284020482795313e-01
            5.60967392126358377346662109630415e-01 -7.80258129207615613864845727221109e-01
            6.35868440856280026096669644175563e-01 -7.20526536046119048251057392917573e-01
            7.04449943344869211614422965794802e-01 -6.53634026459016692633952061441960e-01
            7.66030305808835354497432490461506e-01 -5.80245408259331352240906198858283e-01
            8.19997514939853289206439512781799e-01 -5.01090050505975437289407636853866e-01
            8.65815220367773363818741927389055e-01 -4.16954634706367122110037826132611e-01
            9.03028065151569525603747479181038e-01 -3.28675336422172947870024017902324e-01
            9.31266211321195913619419570750324e-01 -2.37129514980909922305940540354641e-01
            9.50249015493488946582090193260228e-01 -1.43226993884779801868845083845372e-01
            9.59787818032195372275339195766719e-01 -4.79010185759470158428641184400476e-02
            9.27135887393431668002108381188009e-01 4.94142232936151670763536003505578e-02
            9.16631067324560455666926372941816e-01 1.47682786986007064111703357411898e-01
            8.95740450995711534609711179655278e-01 2.44278045690799999745124182481959e-01
            8.64700737437357425108075403841212e-01 3.38105536529361649922265087298001e-01
            8.23863619006954595036518185224850e-01 4.28102156538928080298234135625535e-01
            7.73691796574003998188118202961050e-01 5.13248208053966092911934993026080e-01
            7.14753736934314098938614279177273e-01 5.92578952288174476414894797926536e-01
            6.47717231854056163520283462275984e-01 6.65195540210422708859994145313976e-01
            5.73341831722217976086142243730137e-01 7.30275196863435338556769238493871e-01
            4.92470239541195176080634610116249e-01 7.87080543732822213165434277470922e-01
            4.06018762765047391827266665131901e-01 8.34967953540288632119370504369726e-01
            3.14966931169905817178289453295292e-01 8.73394842797877490880864570499398e-01
            2.20346398390209002871031884751574e-01 9.01925819495694724992063129320741e-01
            1.23229252870798083874248618485581e-01 9.20237616267354119337085194274550e-01
            2.47158706764495500474154709991126e-02 9.28122753138410194750917980854865e-01
            -7.40775522086237758756510629609693e-02 9.25491888357372838314063301368151e-01
            -1.72031646827285583656319545298174e-01 9.12374830673451597817802394274622e-01
            -2.68036554147035643858032472053310e-01 8.88920201591515524164321959688095e-01
            -3.61004500206327294531405414090841e-01 8.55393751431057114409384212194709e-01
            -4.49882121028201964474391161274980e-01 8.12175348268884267355360861984082e-01
            -5.33662397655052633815842000331031e-01 7.59754673882022113495793291804148e-01
            -6.11396066075796884575765943736769e-01 6.98725675457512407362514750275295e-01
            -6.82202372766430031880702244961867e-01 6.29779835933455434116012838785537e-01
            -7.45279053979382877237469529063674e-01 5.53698339221017965527948945236858e-01
            -7.99911425712348744809787604026496e-01 4.71343219078576347591535977699095e-01
            -8.45480481363605873568189963407349e-01 3.83647591924780040351095067308052e-01
            -8.81469905324154701098393616121029e-01 2.91605084256675972653738426743075e-01
            -9.07471923039877559347132773837075e-01 1.96258574464464569109267699786869e-01
            -9.23191921260176573404976352321682e-01 9.86883766026238340440812635279144e-02
            -9.28451786123823064045268438349012e-01 1.13702550803918275967662731338757e-16
            -9.23191921260176684427278814837337e-01 -9.86883766026232095436299118773604e-02
            -9.07471923039877559347132773837075e-01 -1.96258574464464763398297009189264e-01
            -8.81469905324154701098393616121029e-01 -2.91605084256675750609133501711767e-01
            -8.45480481363606206635097350954311e-01 -3.83647591924779429728431523471954e-01
            -7.99911425712348855832090066542150e-01 -4.71343219078576125546931052667787e-01
            -7.45279053979382766215167066548020e-01 -5.53698339221018076550251407752512e-01
            -6.82202372766430586992214557540137e-01 -6.29779835933454990026802988722920e-01
            -6.11396066075797106620370868768077e-01 -6.98725675457512296340212287759641e-01
            -5.33662397655052411771237075299723e-01 -7.59754673882022224518095754319802e-01
            -4.49882121028201797940937467501499e-01 -8.12175348268884378377663324499736e-01
            -3.61004500206327905154068957926938e-01 -8.55393751431056892364779287163401e-01
            -2.68036554147035643858032472053310e-01 -8.88920201591515524164321959688095e-01
            -1.72031646827285417122865851524693e-01 -9.12374830673451597817802394274622e-01
            -7.40775522086246224207073396428314e-02 -9.25491888357372838314063301368151e-01
            2.47158706764495292307337592774275e-02 -9.28122753138410194750917980854865e-01
            1.23229252870797847951855885639816e-01 -9.20237616267354230359387656790204e-01
            2.20346398390208170203763415884168e-01 -9.01925819495694947036668054352049e-01
            3.14966931169905595133684528263984e-01 -8.73394842797877601903167033015052e-01
            4.06018762765047225293812971358420e-01 -8.34967953540288632119370504369726e-01
            4.92470239541194954036029685084941e-01 -7.87080543732822324187736739986576e-01
            5.73341831722217754041537318698829e-01 -7.30275196863435338556769238493871e-01
            6.47717231854055941475678537244676e-01 -6.65195540210422930904599070345284e-01
            7.14753736934314432005521666724235e-01 -5.92578952288174254370289872895228e-01
            7.73691796574003776143513277929742e-01 -5.13248208053966425978842380573042e-01
            8.23863619006954372991913260193542e-01 -4.28102156538928468876292754430324e-01
            8.64700737437357536130377866356866e-01 -3.38105536529361261344206468493212e-01
            8.95740450995711423587408717139624e-01 -2.44278045690800499345485263802402e-01
            9.16631067324560566689228835457470e-01 -1.47682786986006814311522816751676e-01
            9.27135887393431668002108381188009e-01 -4.94142232936149658484303870409349e-02
            8.88536483214324102064551880175713e-01 5.08083543805703460871647791918804e-02
            8.76953051314205200839069220819511e-01 1.51762698540996637808220270926540e-01
            8.53937195263361537023172331828391e-01 2.50738583834806072481171668187017e-01
            8.19788961943631155904199658834841e-01 3.46445708233085514216043065971462e-01
            7.74953525799328857281977889215341e-01 4.37636383004120610440423888576333e-01
            7.20015385307558486438495037873508e-01 5.23121798244107427677818122901954e-01
            6.55690743146687293751995184720727e-01 6.01787520832299582806967919168528e-01
            5.82818169399144658804345908720279e-01 6.72608022771041924592339000810171e-01
            5.02347669507967609092702332418412e-01 7.34660050511564466368952253105817e-01
            4.15328299503006703741192495726864e-01 7.87134660975923106107643434370402e-01
            3.22894489951251140169574682659004e-01 8.29347767367141330829838352656225e-01
            2.26251256919501680942019561371126e-01 8.60749057286783303410970802360680e-01
            1.26658492747102863207331324701954e-01 8.80929166898663074114494975219714e-01
            2.54145414225457680346131894566497e-02 8.89625017612489465967939850088442e-01
            -7.61607273159865122424960759417445e-02 8.86723245715618224593868035299238e-01
            -1.76743124501133580528389188657457e-01 8.72261680242412906771676261996618e-01
            -2.75021404764635601924993579814327e-01 8.46428849814931050232758025231306e-01
            -3.69714360425998811443548675015336e-01 8.09561524884017225112131654896075e-01
            -4.59587523993965796353933228601818e-01 7.62140327411452767059074631106341e-01
            -5.43469261338138220907012509997003e-01 7.04783465227667660357724344066810e-01
            -6.20266045731651005645801433274755e-01 6.38238672747242774541120979847619e-01
            -6.88976713644389504587195460771909e-01 5.63373463107304517372142527165124e-01
            -7.48705516440687279811072585289367e-01 4.81163818807092302787253856877214e-01
            -7.98673797832663567852762298571179e-01 3.92681468283505974437019858669373e-01
            -8.38230144855736214459795974107692e-01 2.99079914291936477255262616381515e-01
            -8.66858880032823297945299145794706e-01 2.01579396233791063863804993161466e-01
            -8.84186784018883842328762057150016e-01 1.01450982469783027029031075016974e-01
            -8.89987961085845546982397991087055e-01 1.08992090782345989386090167602522e-16
            -8.84186784018883842328762057150016e-01 -1.01450982469782804984426149985666e-01
            -8.66858880032823408967601608310360e-01 -2.01579396233790841819200068130158e-01
            -8.38230144855736325482098436623346e-01 -2.99079914291936255210657691350207e-01
            -7.98673797832663567852762298571179e-01 -3.92681468283506140970473552442854e-01
            -7.48705516440687612877979972836329e-01 -4.81163818807091803186892775556771e-01
            -6.88976713644389615609497923287563e-01 -5.63373463107304295327537602133816e-01
            -6.20266045731651227690406358306063e-01 -6.38238672747242552496516054816311e-01
            -5.43469261338138664996222360059619e-01 -7.04783465227667216268514494004194e-01
            -4.59587523993966295954294309922261e-01 -7.62140327411452545014469706075033e-01
            -3.69714360425998866954699906273163e-01 -8.09561524884017225112131654896075e-01
            -2.75021404764635768458447273587808e-01 -8.46428849814930939210455562715651e-01
            -1.76743124501133969106447807462246e-01 -8.72261680242412795749373799480963e-01
            -7.61607273159871228651596197778417e-02 -8.86723245715618113571565572783584e-01
            2.54145414225455494594552163789558e-02 -8.89625017612489465967939850088442e-01
            1.26658492747102641162726399670646e-01 -8.80929166898663185136797437735368e-01
            2.26251256919501098074931633163942e-01 -8.60749057286783414433273264876334e-01
            3.22894489951251306703028376432485e-01 -8.29347767367141219807535890140571e-01
            4.15328299503006537207738801953383e-01 -7.87134660975923106107643434370402e-01
            5.02347669507967276025794944871450e-01 -7.34660050511564466368952253105817e-01
            5.82818169399144880848950833751587e-01 -6.72608022771041813570036538294517e-01
            6.55690743146687404774297647236381e-01 -6.01787520832299471784665456652874e-01
            7.20015385307558708483099962904816e-01 -5.23121798244106983588608272839338e-01
            7.74953525799328635237372964184033e-01 -4.37636383004120999018482507381123e-01
            8.19788961943630822837292271287879e-01 -3.46445708233086124838706609807559e-01
            8.53937195263361537023172331828391e-01 -2.50738583834806183503474130702671e-01
            8.76953051314205200839069220819511e-01 -1.51762698540996915363976427215675e-01
            8.88536483214324102064551880175713e-01 -5.08083543805708526264197644195519e-02
            8.44803672787821091638704729120946e-01 5.21057069992025972959837076814438e-02
            8.31997310253804189805748592334567e-01 1.55527251593132992413259785280388e-01
            8.06578716587698973938813651329838e-01 2.56591161588662242110103761660866e-01
            7.68933211759195822665446939936373e-01 3.53765411129135398660139344428899e-01
            7.19631463247780378544860013789730e-01 4.45576937645494663975398452748777e-01
            6.59420835305450370178448338265298e-01 5.30633971983269003835914645605953e-01
            5.89214059676476886728835324902320e-01 6.07647136204264248782180857233470e-01
            5.10075399514548943891156795871211e-01 6.75448989241787201009969976439606e-01
            4.23204516238212591350276170487632e-01 7.33011724117192398075815162883373e-01
            3.29918283886635299584355607294128e-01 7.79462748445989617174234354024520e-01
            2.31630826651517185421624844821054e-01 8.14097912048921346084284778044093e-01
            1.29832082195825898596197589540679e-01 8.36392181150908964326617933693342e-01
            2.60652157175829922441945285527254e-02 8.46007597357892771050558167189592e-01
            -7.80967728615203776731945595201978e-02 8.42798400761590627006114573305240e-01
            -1.81074893971510109125233611848671e-01 8.26813239511127395786616034456529e-01
            -2.81308104266474956478560898176511e-01 7.98294432356684180440709042159142e-01
            -3.77276970450452386884876432304736e-01 7.57674295344250792183515841315966e-01
            -4.67526702337368593731525834300555e-01 7.05568588345048097743017478933325e-01
            -5.50689205987329177816036462900229e-01 6.42767180763551104760722409992013e-01
            -6.25503822616188753791277576965513e-01 5.70222077922465375721117197826970e-01
            -6.90836438897675320092162110086065e-01 4.89032989632455228345975228876341e-01
            -7.45696678965363402014077109924983e-01 4.00430659712398107075159714440815e-01
            -7.89252917501276241019070312177064e-01 3.05758209167639960490703288087389e-01
            -8.20844886327994238683913863496855e-01 2.06450775844657014035377073923883e-01
            -8.39993683401184076942058709391858e-01 1.04013759204202596575505879172852e-01
            -8.46409032476425404745157266006572e-01 1.03655211239166244371178260501219e-16
            -8.39993683401184076942058709391858e-01 -1.04013759204202388408688761956000e-01
            -8.20844886327994238683913863496855e-01 -2.06450775844657180568830767697364e-01
            -7.89252917501276241019070312177064e-01 -3.05758209167639738446098363056080e-01
            -7.45696678965363402014077109924983e-01 -4.00430659712397885030554789409507e-01
            -6.90836438897675431114464572601719e-01 -4.89032989632455061812521535102860e-01
            -6.25503822616188864813580039481167e-01 -5.70222077922465153676512272795662e-01
            -5.50689205987328955771431537868921e-01 -6.42767180763551215783024872507667e-01
            -4.67526702337368760264979528074036e-01 -7.05568588345047986720715016417671e-01
            -3.77276970450452220351422738531255e-01 -7.57674295344250903205818303831620e-01
            -2.81308104266475178523165823207819e-01 -7.98294432356684069418406579643488e-01
            -1.81074893971510469947716615024547e-01 -8.26813239511127284764313571940875e-01
            -7.80967728615204054287701751491113e-02 -8.42798400761590627006114573305240e-01
            2.60652157175827840773774113358741e-02 -8.46007597357892771050558167189592e-01
            1.29832082195826065129651283314161e-01 -8.36392181150908964326617933693342e-01
            2.31630826651517185421624844821054e-01 -8.14097912048921346084284778044093e-01
            3.29918283886635632651262994841090e-01 -7.79462748445989506151931891508866e-01
            4.23204516238212813394881095518940e-01 -7.33011724117192287053512700367719e-01
            5.10075399514548610824249408324249e-01 -6.75448989241787423054574901470914e-01
            5.89214059676476997751137787417974e-01 -6.07647136204264137759878394717816e-01
            6.59420835305450259156145875749644e-01 -5.30633971983269114858217108121607e-01
            7.19631463247780156500255088758422e-01 -4.45576937645495052553457071553566e-01
            7.68933211759195933687749402452027e-01 -3.53765411129135398660139344428899e-01
            8.06578716587698862916511188814184e-01 -2.56591161588662464154708686692175e-01
            8.31997310253804189805748592334567e-01 -1.55527251593132770368654860249080e-01
            8.44803672787821091638704729120946e-01 -5.21057069992026528071349389392708e-02
            7.96483699051493410081548063317314e-01 5.33183102531095895471047185765201e-02
            7.82270428572870435424135848734295e-01 1.59003464249727805013279180457175e-01
            7.54097523764034050053339797159424e-01 2.61851197659947632079280310790637e-01
            7.12467730778726382467880284821149e-01 3.60026190244555621688959945458919e-01
            6.58123934258998621871228351665195e-01 4.51776506935070876203042189445114e-01
            5.92035900541173498723424017953221e-01 5.35464861156545457454569714172976e-01
            5.15382972152600316029236182657769e-01 6.09597832245283521857004416233394e-01
            4.29533022416314635982814706949284e-01 6.72852515575963705529716207820456e-01
            3.36018045719183644504113317452720e-01 7.24100129826018901191275745077292e-01
            2.36506819035778692583704696517088e-01 7.62426160105078132289690984180197e-01
            1.32775122563729336411242343274353e-01 7.87146677494851343404036470019491e-01
            2.66740508840295313663926179970076e-02 7.97820543776877832975458204600727e-01
            -7.99030198656159457160086390103970e-02 7.94257283554486326337951140885707e-01
            -1.85054219332821651144982411096862e-01 7.76520483290760732408841704454971e-01
            -2.86903121872017663473997117762337e-01 7.44926656606599735255258565302938e-01
            -3.83632231404546053532556015852606e-01 7.00039596087653981371090594620910e-01
            -4.73515414679244128759449949939153e-01 6.42660312392277943693841280037304e-01
            -5.54948704161202788220919046580093e-01 5.73812740197356285776209006144200e-01
            -6.26478920870425781686208210885525e-01 4.94725466059736662671753038011957e-01
            -6.86829606395154668163627320609521e-01 4.06809804260017449095698793826159e-01
            -7.34923801322466929697441173630068e-01 3.11634611865774679984042450087145e-01
            -7.69903263604511556295051377674099e-01 2.10898292440026197125391149711504e-01
            -7.91143783908186737363621432450600e-01 1.06398487989412177112669155576441e-01
            -7.98266324645476199606264344765805e-01 -2.56742031427302686819458723702586e-16
            -7.91143783908186848385923894966254e-01 -1.06398487989411622001156842998171e-01
            -7.69903263604511556295051377674099e-01 -2.10898292440026030591937455938023e-01
            -7.34923801322466929697441173630068e-01 -3.11634611865774513450588756313664e-01
            -6.86829606395154779185929783125175e-01 -4.06809804260017227051093868794851e-01
            -6.26478920870425892708510673401179e-01 -4.94725466059736440627148112980649e-01
            -5.54948704161202788220919046580093e-01 -5.73812740197356174753906543628545e-01
            -4.73515414679243962225996256165672e-01 -6.42660312392278054716143742552958e-01
            -3.83632231404545886999102322079125e-01 -7.00039596087653981371090594620910e-01
            -2.86903121872017996540904505309300e-01 -7.44926656606599624232956102787284e-01
            -1.85054219332822178500919108046219e-01 -7.76520483290760732408841704454971e-01
            -7.99030198656163204162794500007294e-02 -7.94257283554486326337951140885707e-01
            2.66740508840291601355687589602894e-02 -7.97820543776877832975458204600727e-01
            1.32775122563729142122213033871958e-01 -7.87146677494851343404036470019491e-01
            2.36506819035778331761221693341213e-01 -7.62426160105078243311993446695851e-01
            3.36018045719183477970659623679239e-01 -7.24100129826018901191275745077292e-01
            4.29533022416314469449361013175803e-01 -6.72852515575963816552018670336111e-01
            5.15382972152600205006933720142115e-01 -6.09597832245283632879306878749048e-01
            5.92035900541173387701121555437567e-01 -5.35464861156545457454569714172976e-01
            6.58123934258998621871228351665195e-01 -4.51776506935070876203042189445114e-01
            7.12467730778726049400972897274187e-01 -3.60026190244556287822774720552843e-01
            7.54097523764034050053339797159424e-01 -2.61851197659947576568129079532810e-01
            7.82270428572870435424135848734295e-01 -1.59003464249727721746552333570435e-01
            7.96483699051493410081548063317314e-01 -5.33183102531101654752987428764754e-02
            7.43974173687808937316390256455634e-01 5.44518911073879688378163166362356e-02
            7.28117655826578946687277493765578e-01 1.62195125799872663652223536701058e-01
            6.96742574253033986053651460679248e-01 2.66481452981036481819643313428969e-01
            6.50517634359059515603007639583666e-01 3.65088190643742815932881740081939e-01
            5.90428040485055927177882040268742e-01 4.55913707370820431297175900908769e-01
            5.17754497999886043047013117757160e-01 5.37022214959972599146453831053805e-01
            4.34045917289434257657632088012178e-01 6.06685026388489756499211580376141e-01
            3.41086401420873319700888259831117e-01 6.63417399775878435796983012551209e-01
            2.40857221083257411198275121932966e-01 7.06010183079309294740255609212909e-01
            1.35494587242569269891490080226504e-01 7.33555585070139515302400923246751e-01
            2.72441215137632988807503409134370e-02 7.45466523327890429051478804467479e-01
            -8.15870053652208160333003661435214e-02 7.41489136882776178616438755852869e-01
            -1.88679246872142908353353618622350e-01 7.21708196821533864984132833342301e-01
            -2.91750117807500986000235343453824e-01 6.86545299538885656076558916538488e-01
            -3.88602841503823681623686070452095e-01 6.36749881142339213546677001431817e-01
            -4.77173170306401162044096508907387e-01 5.73383244522690294076028294512071e-01
            -5.55573381428202783816061582911061e-01 4.97795939525486341725724059870117e-01
            -6.22132510483710654547451213147724e-01 4.11598978325827036250927903893171e-01
            -6.75431965193753480747318462817930e-01 3.16629499500809430401204735971987e-01
            -7.14335760217046589204414885898586e-01 2.14911612610307695137024097675749e-01
            -7.38014728705500999694777419790626e-01 1.08613257815860841937194436468417e-01
            -7.45964194556031578997590258950368e-01 9.13542663141577531103202580309675e-17
            -7.38014728705500999694777419790626e-01 -1.08613257815860661525952934880479e-01
            -7.14335760217046700226717348414240e-01 -2.14911612610307528603570403902268e-01
            -6.75431965193753591769620925333584e-01 -3.16629499500809263867751042198506e-01
            -6.22132510483710876592056138179032e-01 -4.11598978325826647672869285088382e-01
            -5.55573381428202894838364045426715e-01 -4.97795939525486175192270366096636e-01
            -4.77173170306400995510642815133906e-01 -5.73383244522690294076028294512071e-01
            -3.88602841503824125712895920514711e-01 -6.36749881142338880479769613884855e-01
            -2.91750117807500986000235343453824e-01 -6.86545299538885656076558916538488e-01
            -1.88679246872142936108929234251264e-01 -7.21708196821533864984132833342301e-01
            -8.15870053652211491002077536904835e-02 -7.41489136882776178616438755852869e-01
            2.72441215137629449971612416447897e-02 -7.45466523327890429051478804467479e-01
            1.35494587242568770291128998906061e-01 -7.33555585070139626324703385762405e-01
            2.40857221083257355687123890675139e-01 -7.06010183079309294740255609212909e-01
            3.41086401420873153167434566057636e-01 -6.63417399775878546819285475066863e-01
            4.34045917289434091124178394238697e-01 -6.06685026388489867521514042891795e-01
            5.17754497999885709980105730210198e-01 -5.37022214959972932213361218600767e-01
            5.90428040485056038200184502784396e-01 -4.55913707370820375786024669650942e-01
            6.50517634359059515603007639583666e-01 -3.65088190643742871444032971339766e-01
            6.96742574253033875031348998163594e-01 -2.66481452981036648353097007202450e-01
            7.28117655826578946687277493765578e-01 -1.62195125799872330585316149154096e-01
            7.43974173687808937316390256455634e-01 -5.44518911073884059881322627916234e-02
            6.87578835978234992332147612614790e-01 5.55071020818233354376936006246979e-02
            6.69770905294939433716194798762444e-01 1.65083701458089648905769308839808e-01
            6.34616259978970420618793468747754e-01 2.70384719681069085606139879018883e-01
            5.83025386878125995160360162117286e-01 3.68682915690865642410756208846578e-01
            5.16334462506279567861611212720163e-01 4.57432417844491845393406492803479e-01
            4.36270746773531836737447520135902e-01 5.34334660654136595070440307608806e-01
            3.44907847861826100110960169331520e-01 5.97397916425919550675871505518444e-01
            2.44612016862253978111141350382240e-01 6.44988879960954664127825708419550e-01
            1.37980863114728347085247150971554e-01 6.75874970302067779037713535217335e-01
            2.77760774905431925829724093546247e-02 6.89256253933140383693967123690527e-01
            -8.31480939505451349669229443861695e-02 6.84786162636992656871370854787529e-01
            -1.91918773433997741362233568906959e-01 6.62580469430163798705279987188987e-01
            -2.95718857495802456281097647661227e-01 6.23214290102596879528107365331380e-01
            -3.91859978482432536051049964953563e-01 5.67707188020773578784883284242824e-01
            -4.77852131860941553576083151710918e-01 4.97496767972074149799510678349179e-01
            -5.51468166028425188507355869660387e-01 4.14401442955923793309835900799953e-01
            -6.10801464368669000393197165976744e-01 3.20573338242274852305513377359603e-01
            -6.54315325621007914946858363691717e-01 2.18442552457575961399882658042770e-01
            -6.80882763635785592803983945486834e-01 1.10654219306817958035082938295091e-01
            -6.89815695723652311244222801178694e-01 8.44780583769575372717241065371354e-17
            -6.80882763635785703826286408002488e-01 -1.10654219306817777623841436707153e-01
            -6.54315325621008025969160826207371e-01 -2.18442552457575794866428964269289e-01
            -6.10801464368669111415499628492398e-01 -3.20573338242274685772059683586122e-01
            -5.51468166028425299529658332176041e-01 -4.14401442955923626776382207026472e-01
            -4.77852131860941720109536845484399e-01 -4.97496767972073983266056984575698e-01
            -3.91859978482432647073352427469217e-01 -5.67707188020773578784883284242824e-01
            -2.95718857495802289747643953887746e-01 -6.23214290102596879528107365331380e-01
            -1.91918773433997741362233568906959e-01 -6.62580469430163798705279987188987e-01
            -8.31480939505454541560425241186749e-02 -6.84786162636992656871370854787529e-01
            2.77760774905428699244058776685051e-02 -6.89256253933140494716269586206181e-01
            1.37980863114728152796217841569160e-01 -6.75874970302067890060015997732989e-01
            2.44612016862253811577687656608759e-01 -6.44988879960954775150128170935204e-01
            3.44907847861825711532901550526731e-01 -5.97397916425919772720476430549752e-01
            4.36270746773531392648237670073286e-01 -5.34334660654136928137347695155768e-01
            5.16334462506279345817006287688855e-01 -4.57432417844492067438011417834787e-01
            5.83025386878125884138057699601632e-01 -3.68682915690865864455361133877886e-01
            6.34616259978970309596491006232100e-01 -2.70384719681069196628442341534537e-01
            6.69770905294939433716194798762444e-01 -1.65083701458089704416920540097635e-01
            6.87578835978234992332147612614790e-01 -5.55071020818232591098606576451857e-02
            6.27536038280470886974171662586741e-01 5.64792657025432187634095271278056e-02
            6.07366513671764307602529697760474e-01 1.67622507036655321588369815799524e-01
            5.67675729570815357227786535077030e-01 2.73378223074351112131807894911617e-01
            5.09739380436314171163303399225697e-01 3.70347338086086053099421633305610e-01
            4.35419588199630613889468122579274e-01 4.55413184928929459793778278253740e-01
            3.47105052133780400680507227662019e-01 5.25841677292940179455627003335394e-01
            2.47634274093362194424372546563973e-01 5.79369185484782778239321032742737e-01
            1.40204326729423983666222852662031e-01 6.14275291348590712914301548153162e-01
            2.82680969438978205166002055648278e-02 6.29438083921061708458921657438623e-01
            -8.45766927364728776650437680473260e-02 6.24370218572929180922415071108844e-01
            -1.94703117922358726055165334400954e-01 5.99234580666335725496196573658381e-01
            -2.98571624695960935458316498625209e-01 5.54839050285270807272297588497167e-01
            -3.92843793786283923541446938543231e-01 4.92610536304946278196581488373340e-01
            -4.74489640111365462704640094671049e-01 4.14549114366481286086951740799122e-01
            -5.40884998991891463582248888997128e-01 3.23163742800130160404137313889805e-01
            -5.89895868963158487296993826021207e-01 2.21391622640169566382795096615155e-01
            -6.19947000338011977582652889395831e-01 1.12503793566920071156367555431643e-01
            -6.30072525027910668171671204618178e-01 7.71616301006121411480634271694730e-17
            -6.19947000338011977582652889395831e-01 -1.12503793566919918500701669472619e-01
            -5.89895868963158487296993826021207e-01 -2.21391622640169427604917018470587e-01
            -5.40884998991891685626853814028436e-01 -3.23163742800129827337229926342843e-01
            -4.74489640111365629238093788444530e-01 -4.14549114366481175064649278283468e-01
            -3.92843793786284034563749401058885e-01 -4.92610536304946111663127794599859e-01
            -2.98571624695961101991770192398690e-01 -5.54839050285270807272297588497167e-01
            -1.94703117922358864833043412545521e-01 -5.99234580666335614473894111142727e-01
            -8.45766927364730303207096540063503e-02 -6.24370218572929180922415071108844e-01
            2.82680969438976678609343196058035e-02 -6.29438083921061708458921657438623e-01
            1.40204326729423844888344774517464e-01 -6.14275291348590712914301548153162e-01
            2.47634274093362055646494468419405e-01 -5.79369185484782889261623495258391e-01
            3.47105052133780178635902302630711e-01 -5.25841677292940401500231928366702e-01
            4.35419588199630447356014428805793e-01 -4.55413184928929515304929509511567e-01
            5.09739380436314060141000936710043e-01 -3.70347338086086219632875327079091e-01
            5.67675729570815246205484072561376e-01 -2.73378223074351223154110357427271e-01
            6.07366513671764307602529697760474e-01 -1.67622507036655460366247893944092e-01
            6.27536038280470886974171662586741e-01 -5.64792657025433714190754130868299e-02
            5.64033982963366042895358987152576e-01 5.73566500228833014984886062848091e-02
            5.40942365429666671694519664015388e-01 1.69721762077592847051121793811035e-01
            4.95704503897247739097053909063106e-01 2.75138445251385477252625832988997e-01
            4.30172441732469323927290361098130e-01 3.69290928149191677309914894067333e-01
            3.47029069260047839939886671345448e-01 4.48324597058728291365525819855975e-01
            2.49678285917935699478320543676091e-01 5.09003804288777117470488065009704e-01
            1.42105644214390147705984190906747e-01 5.48844335965835816715241435304051e-01
            2.87151807400035270767535422464789e-02 5.66215116041981936234606109792367e-01
            -8.58508856077697113384772364952369e-02 5.60404982739918011702684452757239e-01
            -1.96902206611709734707105212692113e-01 5.31651803599692218682548627839424e-01
            -2.99892328141939668029181120800786e-01 4.81132737153660450246661639539525e-01
            -3.90604822522185923805437823830289e-01 4.10916039917861797281517510782578e-01
            -4.65325909574256291190152978742844e-01 3.23876391727240919848895828181412e-01
            -5.20996499214883557193900287529686e-01 2.23577206005446754710774825980479e-01
            -5.55337430963164124797515341924736e-01 1.14124743200583342317422363976220e-01
            -5.66942783038435149656208977830829e-01 6.94304664547711983454988626761340e-17
            -5.55337430963164124797515341924736e-01 -1.14124743200583203539544285831653e-01
            -5.20996499214883668216202750045341e-01 -2.23577206005446643688472363464825e-01
            -4.65325909574256402212455441258498e-01 -3.23876391727240808826593365665758e-01
            -3.90604822522186201361193980119424e-01 -4.10916039917861519725761354493443e-01
            -2.99892328141939779051483583316440e-01 -4.81132737153660394735510408281698e-01
            -1.96902206611709984507285753352335e-01 -5.31651803599692107660246165323770e-01
            -8.58508856077698501163553146398044e-02 -5.60404982739918011702684452757239e-01
            2.87151807400036380990560047621329e-02 -5.66215116041981936234606109792367e-01
            1.42105644214389897905803650246526e-01 -5.48844335965835927737543897819705e-01
            2.49678285917935366411413156129129e-01 -5.09003804288777339515092990041012e-01
            3.47029069260047562384130515056313e-01 -4.48324597058728457898979513629456e-01
            4.30172441732469434949592823613784e-01 -3.69290928149191510776461200293852e-01
            4.95704503897247628074751446547452e-01 -2.75138445251385754808381989278132e-01
            5.40942365429666671694519664015388e-01 -1.69721762077593180118029181357997e-01
            5.64033982963366042895358987152576e-01 -5.73566500228831835372922398619266e-02
            4.97217378183809732838938089116709e-01 5.81163765345261498773687947050348e-02
            4.70412260625999223417892380894045e-01 1.71216060701738753691003580570396e-01
            4.18247096336165802288320492152707e-01 2.75085442718895178959570557708503e-01
            3.43534122823623888631772160806577e-01 3.64124897315863060853757815493736e-01
            2.50301135829167076263246372036519e-01 4.33534284448315987425814910238842e-01
            1.43574349814125618030047348838707e-01 4.79571726089993322084126248228131e-01
            2.91074334377692985065255726340183e-02 4.99755331845644523713900753136841e-01
            -8.69286722093951802481370805253391e-02 4.92996998304650935196491445822176e-01
            -1.98278430637103347811134312905779e-01 4.59661068977536835244990243154461e-01
            -2.98938947546706246249925698066363e-01 4.01544692443010775573242199243396e-01
            -3.83483588416603959903028453481966e-01 3.21780937602912042727609787107212e-01
            -4.47354529773935083447611305018654e-01 2.24669889126749455776632657943992e-01
            -4.87108472637749423395092662758543e-01 1.15446828774130358374883087435592e-01
            -5.00602271658334041504190281557385e-01 6.13060969632272557453795150837552e-17
            -4.87108472637749423395092662758543e-01 -1.15446828774130233474792817105481e-01
            -4.47354529773935138958762536276481e-01 -2.24669889126749344754330195428338e-01
            -3.83483588416603904391877222224139e-01 -3.21780937602912098238761018365039e-01
            -2.98938947546706357272228160582017e-01 -4.01544692443010664550939736727742e-01
            -1.98278430637103375566709928534692e-01 -4.59661068977536835244990243154461e-01
            -8.69286722093953051482273508554499e-02 -4.92996998304650879685340214564349e-01
            2.91074334377689515618303772725994e-02 -4.99755331845644579225051984394668e-01
            1.43574349814125618030047348838707e-01 -4.79571726089993322084126248228131e-01
            2.50301135829167076263246372036519e-01 -4.33534284448315987425814910238842e-01
            3.43534122823623944142923392064404e-01 -3.64124897315863005342606584235909e-01
            4.18247096336165580243715567121399e-01 -2.75085442718895512026477945255465e-01
            4.70412260625999056884438687120564e-01 -1.71216060701739114513486583746271e-01
            4.97217378183809732838938089116709e-01 -5.81163765345260527328541400038375e-02
            4.27185833086666910674011887749657e-01 5.87153412900709228972040421012935e-02
            3.95503414091779248451530293095857e-01 1.71791375611541563550588307407452e-01
            3.34488316181431988294292523278273e-01 2.72126429497154043168904991034651e-01
            2.48665750042135674791055066634726e-01 3.52279111002541944763777337357169e-01
            1.44400782792326515258096719662717e-01 4.06304862414569867290481397503754e-01
            2.94262700724359435588972644382011e-02 4.30196840902374866288937482750043e-01
            -8.77306544824991985098705526979757e-02 4.22183087720045369106713906148798e-01
            -1.98380997735506103829550283990102e-01 3.82857946280633298918871787464013e-01
            -2.94318329919147858575456666585524e-01 3.15137982424148310744982381947921e-01
            -3.68427417989454608626687104333541e-01 2.24045676071605665002905993787863e-01
            -4.15211929910771271323710607248358e-01 1.16336926865599890601465915551671e-01
            -4.31202072458794161136097500275355e-01 5.28070237822367344892653682870621e-17
            -4.15211929910771271323710607248358e-01 -1.16336926865599959990404954623955e-01
            -3.68427417989454830671292029364849e-01 -2.24045676071605359691574221869814e-01
            -2.94318329919147803064305435327697e-01 -3.15137982424148310744982381947921e-01
            -1.98380997735506381385306440279237e-01 -3.82857946280633187896569324948359e-01
            -8.77306544824991152431437058112351e-02 -4.22183087720045369106713906148798e-01
            2.94262700724358429449356577833896e-02 -4.30196840902374866288937482750043e-01
            1.44400782792326404235794257147063e-01 -4.06304862414569867290481397503754e-01
            2.48665750042135619279903835376899e-01 -3.52279111002542000274928568614996e-01
            3.34488316181431877271990060762619e-01 -2.72126429497154209702358684808132e-01
            3.95503414091779192940379061838030e-01 -1.71791375611541757839617616809846e-01
            4.27185833086666910674011887749657e-01 -5.87153412900708118749015795856394e-02
            3.53979275067754950434562033478869e-01 5.90686937399652334246269447248778e-02
            3.15620128059793558783496791875223e-01 1.70805071707952171866651269738213e-01
            2.43058642825675047527411720693635e-01 2.64032069842623617894616927515017e-01
            1.44157982197965939263895052135922e-01 3.28647096330167032274260918711661e-01
            2.96355673575436386057990745257484e-02 3.57648110445219102881964090556721e-01
            -8.80983210492752993880927192549279e-02 3.47892402311315185325923948767013e-01
            -1.96285389384108888144453430868452e-01 3.00437154280172036280305292166304e-01
            -2.83201890097550312841434561050846e-01 2.20424878820005665236436698251055e-01
            -3.39429071688833905451332384473062e-01 1.16526147495296578115997476743360e-01
            -3.58873846577929311862931172072422e-01 4.39493707509359431671133798030400e-17
            -3.39429071688833905451332384473062e-01 -1.16526147495296633627148708001187e-01
            -2.83201890097550479374888254824327e-01 -2.20424878820005498702983004477574e-01
            -1.96285389384108860388877815239539e-01 -3.00437154280172036280305292166304e-01
            -8.80983210492753826548195661416685e-02 -3.47892402311315129814772717509186e-01
            2.96355673575436281974582186649059e-02 -3.57648110445219102881964090556721e-01
            1.44157982197965661708138895846787e-01 -3.28647096330167143296563381227315e-01
            2.43058642825675103038562951951462e-01 -2.64032069842623617894616927515017e-01
            3.15620128059793392250043098101742e-01 -1.70805071707952366155680579140608e-01
            3.53979275067755005945713264736696e-01 -5.90686937399651709745818095598224e-02
            2.77533406743540211891740909777582e-01 5.89915466859746370764661094199255e-02
            2.29545359405734866742321287347295e-01 1.66774465714541769711942720277875e-01
            1.41866834072554542922617315525713e-01 2.45720564522607959334621341440652e-01
            2.96582443085026056794895055190864e-02 2.82179345423466509945598090780550e-01
            -8.76785253331803376974917796360387e-02 2.69846753981732578875352146496880e-01
            -1.89854881410359777049734475440346e-01 2.10855207295758018126718980056467e-01
            -2.59203603714237507116280312402523e-01 1.15404879708924712478079754873761e-01
            -2.83733668145109030334083399793599e-01 1.60750413344845869297074584462866e-16
            -2.59203603714237451605129081144696e-01 -1.15404879708924754111443178317131e-01
            -1.89854881410359915827612553584913e-01 -2.10855207295757879348840901911899e-01
            -8.76785253331803932086430108938657e-02 -2.69846753981732578875352146496880e-01
            2.96582443085024703710583793281330e-02 -2.82179345423466509945598090780550e-01
            1.41866834072554542922617315525713e-01 -2.45720564522607959334621341440652e-01
            2.29545359405734838986745671718381e-01 -1.66774465714541825223093951535702e-01
            2.77533406743540211891740909777582e-01 -5.89915466859745399319514547187282e-02
            1.97545091087414498298713283475081e-01 5.80044722931877185234661453705485e-02
            1.34825920454075376397895524860360e-01 1.55597406766492807328461367433192e-01
            2.93004727109989031308412421594767e-02 2.03789263990177077490173473961477e-01
            -8.55276680905724395742595334013458e-02 1.87279469803112580406079246131412e-01
            -1.73201378583012433054477696714457e-01 1.11309767207060872351576108485460e-01
            -2.05884875157807734069592697778717e-01 1.16644876864395803990139162320582e-16
            -1.73201378583012460810053312343371e-01 -1.11309767207060816840424877227633e-01
            -8.55276680905726199855010349892837e-02 -1.87279469803112469383776783615758e-01
            2.93004727109988510891369628552638e-02 -2.03789263990177105245749089590390e-01
            1.34825920454075265375593062344706e-01 -1.55597406766492890595188214319933e-01
            1.97545091087414498298713283475081e-01 -5.80044722931877393401478570922336e-02
            1.12999731409395218206803690463857e-01 5.44178025788326219513990622544952e-02
            2.79086288836726502393670301671591e-02 1.22275692473760674849891927351564e-01
            -7.81982404237352296538787754798250e-02 9.80574919663763505672804399182496e-02
            -1.25420239738665229012326562951785e-01 1.53595495144250045030655946409024e-17
            -7.81982404237352574094543911087385e-02 -9.80574919663763228117048242893361e-02
            2.79086288836725114614889520225915e-02 -1.22275692473760702605467542980477e-01
            1.12999731409395245962379306092771e-01 -5.44178025788325456235661192749831e-02
            2.12118267373994674740433907800252e-02 3.67399616305238430058466292393859e-02
            -4.24236534747989280091928776528221e-02 5.19539914360489921679212668163442e-18
            2.12118267373994674740433907800252e-02 -3.67399616305238430058466292393859e-02
            ];
        
    case   36
        
        % DEGREE.             :          36
        % CARDIN.             :         703
        % LEBESGUE CONST.     : 2.72661e+02
        % ABS.DET.VAND.MATRIX : Inf
        % CONDITIONING VAND.  : 1.05343e+04
        % POINTS OUT DISK     : 0.00000e+00
        
        pts=[
            9.99074115102229987073201300518122e-01 4.30222330045304732215605270084779e-02
            9.91677319899289977378487037640298e-01 1.28748177452580797597292416867276e-01
            9.76938492777181699544541970681166e-01 2.13520915439796038493014407322335e-01
            9.54966754855255173239925170491915e-01 2.96712819273490246985147678060457e-01
            9.25924777193849801726344139751745e-01 3.77707965203964823874827061445103e-01
            8.90027576434676670480428128939820e-01 4.55906693508458693564477925974643e-01
            8.47540922892831116719492001720937e-01 5.30730048161933365413744922989281e-01
            7.98779372886365024442056892439723e-01 6.01624063224922456249998958810465e-01
            7.44103939871360697821955909603275e-01 6.68063864213533475933104455180001e-01
            6.83919421624610612830963418673491e-01 7.29557554086487480837774910469307e-01
            6.18671403262503361020208103582263e-01 7.85649855078714431932951356429840e-01
            5.48842958284719295569686892122263e-01 8.35925479418636818707000202266499e-01
            4.74951072067050228397988576034550e-01 8.80012203973535633849678561091423e-01
            3.97542814282555889704440232890192e-01 9.17583626059393697715904636424966e-01
            3.17191288589106001882811369796400e-01 9.48361580012171523357267233222956e-01
            2.34491389570409769493863905154285e-01 9.72118196629061293023710277338978e-01
            1.50055398344652701769774694184889e-01 9.88677590232340364195806614588946e-01
            6.45084494493163573825000867145718e-02 9.97917160865392172119925362494541e-01
            -2.15160974362221327216282418248738e-02 9.99768501979890866770972479571356e-01
            -1.07381346664162963255861882316822e-01 9.94217906893951952618238010472851e-01
            -1.92451581970829621592855573908309e-01 9.81306470271609443400961936276872e-01
            -2.76096973097468723068459439673461e-01 9.61129783872300746949690619658213e-01
            -3.57698238833125348179464708664455e-01 9.33837228822925191629167329665506e-01
            -4.36651231956063923256294856400928e-01 8.99630869652243370104827135946834e-01
            -5.12371412128423187049008902249625e-01 8.58763958275803207520482374093262e-01
            -5.84298173628368444632030787033727e-01 8.11539059007361007758163395919837e-01
            -6.51898995878712472773486297228374e-01 7.58305808478562326513383595738560e-01
            -7.14673386042960934183554400078719e-01 6.99458327051647121841426724131452e-01
            -7.72156584499163911594621367839864e-01 6.35432300890177770291700198868057e-01
            -8.23923005757554172134859982179478e-01 5.66701756291117630937037574767601e-01
            -8.69589389346610786013513916259399e-01 4.93775550159977205666450572607573e-01
            -9.08817637339502937265933724120259e-01 4.17193602612316860600571999384556e-01
            -9.41317317512847084870486469299067e-01 3.37522899594113356958047234002152e-01
            -9.66847813605277495163647927256534e-01 2.55353295116187095636917092633666e-01
            -9.85220106756060642894112788781058e-01 1.71293144181477674514724185428349e-01
            -9.96298174934607594366298144450411e-01 8.59647987374465710752602376487630e-02
            -1.00000000000000000000000000000000e+00 1.22464679914735320717376402945840e-16
            -9.96298174934607816410903069481719e-01 -8.59647987374463351528675048029982e-02
            -9.85220106756060642894112788781058e-01 -1.71293144181477452470119260397041e-01
            -9.66847813605277606185950389772188e-01 -2.55353295116186873592312167602358e-01
            -9.41317317512847084870486469299067e-01 -3.37522899594113134913442308970843e-01
            -9.08817637339502826243631261604605e-01 -4.17193602612317027134025693158037e-01
            -8.69589389346611119080421303806361e-01 -4.93775550159977094644148110091919e-01
            -8.23923005757554394179464907210786e-01 -5.66701756291117408892432649736293e-01
            -7.72156584499164133639226292871172e-01 -6.35432300890177659269397736352403e-01
            -7.14673386042961156228159325110028e-01 -6.99458327051646899796821799100144e-01
            -6.51898995878712694818091222259682e-01 -7.58305808478562326513383595738560e-01
            -5.84298173628368666676635712065035e-01 -8.11539059007360896735860933404183e-01
            -5.12371412128423853182823677343549e-01 -8.58763958275802874453574986546300e-01
            -4.36651231956063368144782543822657e-01 -8.99630869652243592149432060978143e-01
            -3.57698238833125792268674558727071e-01 -9.33837228822925080606864867149852e-01
            -2.76096973097469167157669289736077e-01 -9.61129783872300635927388157142559e-01
            -1.92451581970830315482245964631147e-01 -9.81306470271609221356357011245564e-01
            -1.07381346664163421222859540193895e-01 -9.94217906893951841595935547957197e-01
            -2.15160974362226010969667555627893e-02 -9.99768501979890866770972479571356e-01
            6.45084494493158855377146210230421e-02 -9.97917160865392172119925362494541e-01
            1.50055398344652229924989228493359e-01 -9.88677590232340475218109077104600e-01
            2.34491389570410158071922523959074e-01 -9.72118196629061182001407814823324e-01
            3.17191288589105557793601519733784e-01 -9.48361580012171745401872158254264e-01
            3.97542814282555445615230382827576e-01 -9.17583626059393919760509561456274e-01
            4.74951072067050616976047194839339e-01 -8.80012203973535411805073636060115e-01
            5.48842958284718851480477042059647e-01 -8.35925479418637151773907589813462e-01
            6.18671403262503027953300716035301e-01 -7.85649855078714653977556281461148e-01
            6.83919421624610834875568343704799e-01 -7.29557554086487258793169985437999e-01
            7.44103939871360253732746059540659e-01 -6.68063864213533920022314305242617e-01
            7.98779372886365135464359354955377e-01 -6.01624063224922234205394033779157e-01
            8.47540922892830783652584614173975e-01 -5.30730048161933809502954773051897e-01
            8.90027576434676337413520741392858e-01 -4.55906693508459304187141469810740e-01
            9.25924777193849912748646602267399e-01 -3.77707965203964601830222136413795e-01
            9.54966754855255062217622707976261e-01 -2.96712819273490857607811221896554e-01
            9.76938492777181588522239508165512e-01 -2.13520915439796676871253566787345e-01
            9.91677319899290088400789500155952e-01 -1.28748177452580575552687491835968e-01
            9.99074115102229987073201300518122e-01 -4.30222330045311532331631099168590e-02
            9.85740033665666870454913350840798e-01 4.49121060807192787334152228595485e-02
            9.77571881300765777034200709749712e-01 1.34364162386691854411679969416582e-01
            9.61303260453912122862618616636610e-01 2.22702834926890497202478513827373e-01
            9.37068978041032507597662970511010e-01 3.09196121639536136704862201440847e-01
            9.05069846958470702880106273369165e-01 3.93127311910996923849381801119307e-01
            8.65571022084085206493853092979407e-01 4.73800925465651501244934706846834e-01
            8.18899803120424096825047399761388e-01 5.50548475334485365451087091059890e-01
            7.65442922486311183583040929079289e-01 6.22734007148646795393176489596954e-01
            7.05643340730226720225459757784847e-01 6.89759368857633559102282561070751e-01
            6.39996576019698948378788827540120e-01 7.51069167205562604472390830778750e-01
            5.69046598121710212048185439925874e-01 8.06155369894603235358943038590951e-01
            4.93381320897892383658955850478378e-01 8.54561515300593654842487012501806e-01
            4.13627730665112103292102574414457e-01 8.95886494857816906289826874854043e-01
            3.30446690789390151721249822003301e-01 9.29787876770899357481425795413088e-01
            2.44527465563918355861972031561891e-01 9.55984743512511614405013915529707e-01
            1.56582008748052975422027088825416e-01 9.74260019594471726733786454133224e-01
            6.73390640942427148862847730015346e-02 9.84462270323605226352015051816124e-01
            -2.24618732522108392746229554859383e-02 9.86506956637304921464703966194065e-01
            -1.12076684442823218401663609711250e-01 9.80377135620828177309249440440908e-01
            -2.00762792929054384449827352909779e-01 9.66123600901624524084354561637156e-01
            -2.87785317685456232261742570699425e-01 9.43864461757341954850630827422719e-01
            -3.72423162665290019557318146325997e-01 9.13784164425154976640897075412795e-01
            -4.53974992029468948917525494834990e-01 8.76131963722154960549914903822355e-01
            -5.31765041636197977048539087263634e-01 8.31219857641435577733091122354381e-01
            -6.05148718635475368898823944618925e-01 7.79420002038463288762670799769694e-01
            -6.73517942768455446511666195874568e-01 7.21161626830451485403727929224260e-01
            -7.36306185111977873347655076941010e-01 6.56927479262088387379492360196309e-01
            -7.92993162515647442845079240214545e-01 5.87249823709831142437565176805947e-01
            -8.43109148831874044560663605807349e-01 5.12706031171653697775525415636366e-01
            -8.86238867214666714566817518061725e-01 4.33913794989120138456684117045370e-01
            -9.22024931234363909204887477244483e-01 3.51526012445824986851761195794097e-01
            -9.50170806294145076087431789346738e-01 2.66225374654877999791580123201129e-01
            -9.70443266809088878055433724512113e-01 1.78718709565336919542488658407819e-01
            -9.82674328786822370851439245598158e-01 8.97311249632139484866399925522273e-02
            -9.86762641795784545273306775925448e-01 1.20843571079339390008444013230836e-16
            -9.82674328786822370851439245598158e-01 -8.97311249632137264420350675209193e-02
            -9.70443266809088989077736187027767e-01 -1.78718709565336225653098267684982e-01
            -9.50170806294145076087431789346738e-01 -2.66225374654877777746975198169821e-01
            -9.22024931234364020227189939760137e-01 -3.51526012445824764807156270762789e-01
            -8.86238867214666825589119980577379e-01 -4.33913794989119916412079192014062e-01
            -8.43109148831874488649873455869965e-01 -5.12706031171653031641710640542442e-01
            -7.92993162515647331822776777698891e-01 -5.87249823709831364482170101837255e-01
            -7.36306185111977984369957539456664e-01 -6.56927479262088165334887435165001e-01
            -6.73517942768456001623178508452838e-01 -7.21161626830450930292215616645990e-01
            -6.05148718635475590943428869650234e-01 -7.79420002038463066718065874738386e-01
            -5.31765041636198199093144012294943e-01 -8.31219857641435466710788659838727e-01
            -4.53974992029469559540189038671087e-01 -8.76131963722154738505309978791047e-01
            -3.72423162665290241601923071357305e-01 -9.13784164425154865618594612897141e-01
            -2.87785317685456898395557345793350e-01 -9.43864461757341732806025902391411e-01
            -2.00762792929054412205402968538692e-01 -9.66123600901624524084354561637156e-01
            -1.12076684442823468201844150371471e-01 -9.80377135620828066286946977925254e-01
            -2.24618732522115192862255383943193e-02 -9.86506956637304921464703966194065e-01
            6.73390640942427010084969651870779e-02 -9.84462270323605226352015051816124e-01
            1.56582008748052503577241623133887e-01 -9.74260019594471837756088916648878e-01
            2.44527465563917689728157256467966e-01 -9.55984743512511725427316378045361e-01
            3.30446690789389985187796128229820e-01 -9.29787876770899357481425795413088e-01
            4.13627730665111714714043955609668e-01 -8.95886494857817128334431799885351e-01
            4.93381320897892383658955850478378e-01 -8.54561515300593654842487012501806e-01
            5.69046598121710101025882977410220e-01 -8.06155369894603457403547963622259e-01
            6.39996576019698504289578977477504e-01 -7.51069167205563048561600680841366e-01
            7.05643340730226720225459757784847e-01 -6.89759368857633559102282561070751e-01
            7.65442922486310850516133541532326e-01 -6.22734007148647128460083877143916e-01
            8.18899803120423652735837549698772e-01 -5.50548475334486031584901866153814e-01
            8.65571022084085095471550630463753e-01 -4.73800925465651723289539631878142e-01
            9.05069846958470480835501348337857e-01 -3.93127311910997367938591651181923e-01
            9.37068978041032507597662970511010e-01 -3.09196121639536081193710970183020e-01
            9.61303260453912011840316154120956e-01 -2.22702834926890774758234670116508e-01
            9.77571881300765666011898247234058e-01 -1.34364162386692465034343513252679e-01
            9.85740033665666870454913350840798e-01 -4.49121060807193550612481658390607e-02
            9.61532184459006566967786966415588e-01 4.65091815279966916407694554891350e-02
            9.52554617523422741953709191875532e-01 1.39093300887278337185648524609860e-01
            9.34683304775859147284222672169562e-01 2.30378743572820288143532252433943e-01
            9.08085105848277618356689799838932e-01 3.19513202001788121364711514615919e-01
            8.73008360957571061256032862729626e-01 4.05664451751799826073607846410596e-01
            8.29780572219871004335800535045564e-01 4.88028121816127036236565572835389e-01
            7.78805345851529051692807570361765e-01 5.65835204799059243718772904685466e-01
            7.20558623806621278973238986509386e-01 6.38359236930759244010857855755603e-01
            6.55584240035157916892671892128419e-01 7.04923080863747442137423604435753e-01
            5.84488842852021184270938647387084e-01 7.64905247921870534710819811152760e-01
            5.07936230825099976904368759278441e-01 8.17745700772620209839658400596818e-01
            4.26641155066914246063447535561863e-01 8.62951082344811881696955424558837e-01
            3.41362645796055075297914527254761e-01 9.00099322170631377382221671723528e-01
            2.52896925476544354172148132420261e-01 9.28843577143872112245048811018933e-01
            1.62069974703217267730792627844494e-01 9.48915469900565744509890464541968e-01
            6.97298202434580016717546868676436e-02 9.60127594586119625930109577893745e-01
            -2.32613827602395836779969329199957e-02 9.62375266613286650674297106888844e-01
            -1.16035400500542174029305897420272e-01 9.55637500073951540180416941439034e-01
            -2.07726026970404042959472690199618e-01 9.39977203678899808636515444959514e-01
            -2.97477171495167058701269979792414e-01 9.15540593396135582437977973313536e-01
            -3.84450851820529682090210599199054e-01 8.82555827271783499554658192209899e-01
            -4.67835018127073953841943421139149e-01 8.41330875179886361614478573756060e-01
            -5.46851134920632420133301820897032e-01 7.92250643390669195831321758305421e-01
            -6.20761450008435522462946209998336e-01 7.35773380804400689569888527330477e-01
            -6.88875882692555285835567246977007e-01 6.72426400404881330352679924544645e-01
            -7.50558466867452866999599336850224e-01 6.02801155880188899160998516890686e-01
            -8.05233288864152907393645364209078e-01 5.27547719378951285307266516610980e-01
            -8.52389864600998747867777183273574e-01 4.47368711961849241376398822467308e-01
            -8.91587905835981575641824292688398e-01 3.63012743418081429425114947662223e-01
            -9.22461431019426569832830864470452e-01 2.75267422697464958503132947953418e-01
            -9.44722182365112739255152973782970e-01 1.84952004217882604031331084115664e-01
            -9.58162317235558003147843919578008e-01 9.29097387075156488922544895103783e-02
            -9.62656348712723652916167793591740e-01 1.17891401612991533091420831195150e-16
            -9.58162317235558003147843919578008e-01 -9.29097387075153990920739488501567e-02
            -9.44722182365112739255152973782970e-01 -1.84952004217882354231150543455442e-01
            -9.22461431019426458810528401954798e-01 -2.75267422697465180547737872984726e-01
            -8.91587905835981908708731680235360e-01 -3.63012743418080763291300172568299e-01
            -8.52389864600998858890079645789228e-01 -4.47368711961849019331793897436000e-01
            -8.05233288864153129438250289240386e-01 -5.27547719378951063262661591579672e-01
            -7.50558466867452978021901799365878e-01 -6.02801155880188677116393591859378e-01
            -6.88875882692555396857869709492661e-01 -6.72426400404881219330377462028991e-01
            -6.20761450008435078373736359935720e-01 -7.35773380804401133659098377393093e-01
            -5.46851134920632642177906745928340e-01 -7.92250643390669084809019295789767e-01
            -4.67835018127074453442304502459592e-01 -8.41330875179885917525268723693443e-01
            -3.84450851820529515556756905425573e-01 -8.82555827271783610576960654725553e-01
            -2.97477171495167280745874904823722e-01 -9.15540593396135471415675510797882e-01
            -2.07726026970404903382316774695937e-01 -9.39977203678899697614212982443860e-01
            -1.16035400500541993618064395832334e-01 -9.55637500073951651202719403954688e-01
            -2.32613827602398230698366177193748e-02 -9.62375266613286650674297106888844e-01
            6.97298202434579739161790712387301e-02 -9.60127594586119625930109577893745e-01
            1.62069974703217434264246321617975e-01 -9.48915469900565744509890464541968e-01
            2.52896925476543965594089513615472e-01 -9.28843577143872223267351273534587e-01
            3.41362645796055075297914527254761e-01 -9.00099322170631377382221671723528e-01
            4.26641155066913635440783991725766e-01 -8.62951082344812214763862812105799e-01
            5.07936230825099643837461371731479e-01 -8.17745700772620431884263325628126e-01
            5.84488842852020962226333722355776e-01 -7.64905247921870756755424736184068e-01
            6.55584240035157472803462042065803e-01 -7.04923080863747886226633454498369e-01
            7.20558623806621389995541449025040e-01 -6.38359236930758910943950468208641e-01
            7.78805345851528940670505107846111e-01 -5.65835204799059465763377829716774e-01
            8.29780572219870560246590684982948e-01 -4.88028121816127757881531579187140e-01
            8.73008360957571283300637787760934e-01 -4.05664451751799548517851690121461e-01
            9.08085105848277507334387337323278e-01 -3.19513202001788398920467670905055e-01
            9.34683304775858925239617747138254e-01 -2.30378743572821176321951952559175e-01
            9.52554617523422741953709191875532e-01 -1.39093300887278087385467983949638e-01
            9.61532184459006455945484503899934e-01 -4.65091815279970594021463625722390e-02
            9.30264542969737928679307970014634e-01 4.79524409055313433070111273082148e-02
            9.20403507391583719510208538849838e-01 1.43349014913827260686574049941555e-01
            9.00785965665541810132310729386518e-01 2.37226053702984357451910568670428e-01
            8.71619868614180060006901840097271e-01 3.28588437307969494227677387243602e-01
            8.33214384121916840086896627326496e-01 4.16467701734274442504357693906059e-01
            7.85976619878534177310314134956570e-01 4.99932304917183656378654177387943e-01
            7.30407307936389416092026749538491e-01 5.78097501299400406971074062312255e-01
            6.67095496826092482223202750901692e-01 6.50134720354052952906442897074157e-01
            5.96712307495543936575188581628026e-01 7.15280349638403700751609903818462e-01
            5.20003819260931643420065029204125e-01 7.72843829275706939441192844242323e-01
            4.37783161180375690602062377365655e-01 8.22214972061693250005021127435612e-01
            3.50921892683631331255611485175905e-01 8.62870431600730958265899062098470e-01
            2.60340764825312376284927040615003e-01 8.94379249907814699582786488463171e-01
            1.66999960094659338771805323631270e-01 9.16407425670414332863344952784246e-01
            7.18889142422853427705220497045957e-02 9.28721454745479180203915348101873e-01
            -2.39841719849209558668157171723578e-02 9.31190805361442275334127316455124e-01
            -1.19603020022524902943317215431307e-01 9.23789301787472094673603351111524e-01
            -2.13954046294148519935518493184645e-01 9.06595401802731015727943031379255e-01
            -3.06037106449530416085735851083882e-01 8.79791365024397475913531252444955e-01
            -3.94876097143444571013759514244157e-01 8.43661320910384482374411163618788e-01
            -4.79529302973986770730618900415720e-01 7.98588256916401340035349676327314e-01
            -5.59099378900106191991881132707931e-01 7.45049958733646988662258081603795e-01
            -6.32742862322272725528193859645398e-01 6.83613945641625586624456900608493e-01
            -6.99679113995861023944655698869610e-01 6.14931454662599574767511967365863e-01
            -7.59198593001344623765191954589682e-01 5.39730537287147038583157154789660e-01
            -8.10670378054556439728628447483061e-01 4.58808341947241071778762488975190e-01
            -8.53548855429253405802114684775006e-01 3.73022664044566021335214145437931e-01
            -8.87379502598350078379496608249610e-01 2.83282853105864151910253667665529e-01
            -9.11803706285776116580166217318038e-01 1.90540173451732020026838654302992e-01
            -9.26562563856415444263348035747185e-01 9.57777205581755164409685221471591e-02
            -9.31499627748446190622644280665554e-01 1.14075803752908567695403061543297e-16
            -9.26562563856415444263348035747185e-01 -9.57777205581752943963635971158510e-02
            -9.11803706285776116580166217318038e-01 -1.90540173451731381648599494837981e-01
            -8.87379502598350189401799070765264e-01 -2.83282853105863929865648742634221e-01
            -8.53548855429253405802114684775006e-01 -3.73022664044566187868667839211412e-01
            -8.10670378054556328706325984967407e-01 -4.58808341947241238312216182748671e-01
            -7.59198593001345067854401804652298e-01 -5.39730537287146483471644842211390e-01
            -6.99679113995861245989260623900918e-01 -6.14931454662599463745209504850209e-01
            -6.32742862322272836550496322161052e-01 -6.83613945641625364579851975577185e-01
            -5.59099378900106191991881132707931e-01 -7.45049958733647210706863006635103e-01
            -4.79529302973987325842131212993991e-01 -7.98588256916401006968442288780352e-01
            -3.94876097143444793058364439275465e-01 -8.43661320910384371352108701103134e-01
            -3.06037106449530416085735851083882e-01 -8.79791365024397475913531252444955e-01
            -2.13954046294149352602786962052051e-01 -9.06595401802730793683338106347946e-01
            -1.19603020022524722532075713843369e-01 -9.23789301787472094673603351111524e-01
            -2.39841719849213895476847113741314e-02 -9.31190805361442275334127316455124e-01
            7.18889142422851207259171246732876e-02 -9.28721454745479180203915348101873e-01
            1.66999960094659116727200398599962e-01 -9.16407425670414332863344952784246e-01
            2.60340764825312376284927040615003e-01 -8.94379249907814699582786488463171e-01
            3.50921892683631331255611485175905e-01 -8.62870431600730958265899062098470e-01
            4.37783161180375302024003758560866e-01 -8.22214972061693472049626052466920e-01
            5.20003819260931310353157641657162e-01 -7.72843829275707272508100231789285e-01
            5.96712307495543936575188581628026e-01 -7.15280349638403922796214828849770e-01
            6.67095496826092371200900288386038e-01 -6.50134720354053063928745359589811e-01
            7.30407307936388860980514436960220e-01 -5.78097501299401073104888837406179e-01
            7.85976619878534288332616597472224e-01 -4.99932304917183545356351714872289e-01
            8.33214384121916618042291702295188e-01 -4.16467701734274886593567543968675e-01
            8.71619868614180171029204302612925e-01 -3.28588437307968994627316305923159e-01
            9.00785965665541699110008266870864e-01 -2.37226053702984551740939878072822e-01
            9.20403507391583608487906076334184e-01 -1.43349014913828121109418134437874e-01
            9.30264542969737928679307970014634e-01 -4.79524409055312322847086647925607e-02
            8.93292046501261816082717359677190e-01 4.92842955783934916214050758753729e-02
            8.82448691142210916993349201220553e-01 1.47254642149134834516743808308092e-01
            8.60893604069369655640286964626284e-01 2.43437516840610213009199469524901e-01
            8.28888434840507448697621839528438e-01 3.36665389846840024112850642268313e-01
            7.86821682854711546006853950530058e-01 4.25806601079352309291436995408731e-01
            7.35203981495957115122052982769674e-01 5.09779096987668989271469399682246e-01
            6.74661899735548131751272649125895e-01 5.87563565223620853927855023357552e-01
            6.05930336433578853316817003360484e-01 6.58215807712456024702873946807813e-01
            5.29843599662291664387225864629727e-01 7.20878201938424667538640733255306e-01
            4.47325279336265368979042023056536e-01 7.74790111320351804202744006033754e-01
            3.59377036081978407100478989377734e-01 8.19297118309348926246116207039449e-01
            2.67066442434690964891075282139354e-01 8.53858968131358864184221602045000e-01
            1.71514023954036504138187524404202e-01 8.78056126748264942349919692787807e-01
            7.38796575616340739367515766389261e-02 8.91594873432797752066392149572494e-01
            -2.46515077935302549805296479235039e-02 8.94310866140279214775432592432480e-01
            -1.22883437237898560101534428667946e-01 8.86171136398421821489534977445146e-01
            -2.19623728216514241262657947117987e-01 8.67274489499921585888841946143657e-01
            -3.13698084644767727358072306742542e-01 8.37850305140050100050075343460776e-01
            -4.03964571272120875899958036825410e-01 7.98255753057879657852424770680955e-01
            -4.89327475229140607115851935304818e-01 7.48971457479486124597656271362212e-01
            -5.68750606497442801057218275673222e-01 6.90595662990915348800058382039424e-01
            -6.41269875852855220088599708105903e-01 6.23836972659311483901944939134410e-01
            -7.06004997602608708184845909272553e-01 5.49505746551581908398986797692487e-01
            -7.62170175061181343068028581910767e-01 4.68504265060926738950541903250269e-01
            -8.09083639057591064158714289078489e-01 3.81815776445128873817225212405901e-01
            -8.46175923689584608133884557901183e-01 2.90492561524644310466669594461564e-01
            -8.72996778868269651674438591726357e-01 1.95643160418902839481347655237187e-01
            -8.89220635744270126998856085265288e-01 9.84189163709243697297779362997971e-02
            -8.94650558672530515913479121081764e-01 1.09563094303370576293668682017012e-16
            -8.89220635744270126998856085265288e-01 -9.84189163709241476851730112684891e-02
            -8.72996778868269651674438591726357e-01 -1.95643160418902645192318345834792e-01
            -8.46175923689584719156187020416837e-01 -2.90492561524644143933215900688083e-01
            -8.09083639057591286203319214109797e-01 -3.81815776445128318705712899827631e-01
            -7.62170175061181232045726119395113e-01 -4.68504265060926960995146828281577e-01
            -7.06004997602608930229450834303861e-01 -5.49505746551581797376684335176833e-01
            -6.41269875852855442133204633137211e-01 -6.23836972659311372879642476618756e-01
            -5.68750606497443023101823200704530e-01 -6.90595662990915237777755919523770e-01
            -4.89327475229140829160456860336126e-01 -7.48971457479486013575353808846558e-01
            -4.03964571272121097944562961856718e-01 -7.98255753057879546830122308165301e-01
            -3.13698084644767949402677231773851e-01 -8.37850305140049989027772880945122e-01
            -2.19623728216514241262657947117987e-01 -8.67274489499921585888841946143657e-01
            -1.22883437237898587857110044296860e-01 -8.86171136398421821489534977445146e-01
            -2.46515077935302757972113596451891e-02 -8.94310866140279214775432592432480e-01
            7.38796575616332690250587234004342e-02 -8.91594873432797863088694612088148e-01
            1.71514023954036476382611908775289e-01 -8.78056126748264942349919692787807e-01
            2.67066442434690964891075282139354e-01 -8.53858968131358864184221602045000e-01
            3.59377036081977851988966676799464e-01 -8.19297118309349148290721132070757e-01
            4.47325279336265368979042023056536e-01 -7.74790111320351804202744006033754e-01
            5.29843599662290998253411089535803e-01 -7.20878201938425111627850583317922e-01
            6.05930336433578853316817003360484e-01 -6.58215807712456135725176409323467e-01
            6.74661899735548242773575111641549e-01 -5.87563565223620631883250098326243e-01
            7.35203981495956782055145595222712e-01 -5.09779096987669544382981712260516e-01
            7.86821682854711657029156413045712e-01 -4.25806601079352198269134532893077e-01
            8.28888434840507226653016914497130e-01 -3.36665389846840690246665417362237e-01
            8.60893604069369433595682039594976e-01 -2.43437516840610851387438628989912e-01
            8.82448691142211028015651663736207e-01 -1.47254642149134695738865730163525e-01
            8.93292046501261816082717359677190e-01 -4.92842955783941161218564275259268e-02
            8.51394993642096586938805558020249e-01 5.05259110615988854542379726808576e-02
            8.39443274212204104678392013738630e-01 1.50868460147654787073534521368856e-01
            8.15707611294722800820977681723889e-01 2.49093146760980793663620147526672e-01
            7.80521201567799360887534021458123e-01 3.43821111612694352288599475286901e-01
            7.34377985094438523461235490685795e-01 4.33722581722537137149942054747953e-01
            6.77925711486748072687191779550631e-01 5.17535537516619736919665228924714e-01
            6.11956846921270281036697724630358e-01 5.94083428815858405336314262967790e-01
            5.37397449650969916135068160656374e-01 6.62291691021458794885745646752184e-01
            4.55294170177307444546954684483353e-01 7.21202829646408916097755081864307e-01
            3.66799558571485162516978562052827e-01 7.69989861439222988970243477524491e-01
            2.73155885197867431823937067747465e-01 8.07967923416022526517110691202106e-01
            1.75677701961156840226863096177112e-01 8.34603886835591612936013916623779e-01
            7.57333888791832249287594436282234e-02 8.49523841158271730833462243026588e-01
            -2.52740549730181528198524887329768e-02 8.52518342930315475847180550772464e-01
            -1.25926706494810303205156287731370e-01 8.43545355910872207694239932607161e-01
            -2.24811623092160017822749296101392e-01 8.22730841168664794871290268929442e-01
            -3.20540677294451403778197118299431e-01 7.90366988864694808292199468269246e-01
            -4.11770043021358611579074704422965e-01 7.46908116542870703646883612236707e-01
            -4.97219059955312014942307996534510e-01 6.92964291507568219685708754695952e-01
            -5.75688211205114042101627092051785e-01 6.29292766815959914161737742688274e-01
            -6.46075961893718297979205544834258e-01 5.56787351105012762175761054095346e-01
            -7.07394222293309504756564365379745e-01 4.76465861477476604335379306576215e-01
            -7.58782218439161271206216952123214e-01 3.89455835580846176924296742072329e-01
            -7.99518575509262974243540611496428e-01 2.96978703450380354667004212387837e-01
            -8.29031444345546097984822608850664e-01 2.00332641308818365510902026471740e-01
            -8.46906528962556026662866770493565e-01 1.00874348017845380520718379102618e-01
            -8.52892902354938198250522418675246e-01 1.04449256288447107882496922219880e-16
            -8.46906528962556026662866770493565e-01 -1.00874348017845547054172072876099e-01
            -8.29031444345546320029427533881972e-01 -2.00332641308817810399389713893470e-01
            -7.99518575509263085265843074012082e-01 -2.96978703450380132622399287356529e-01
            -7.58782218439161382228519414638868e-01 -3.89455835580845954879691817041021e-01
            -7.07394222293309615778866827895399e-01 -4.76465861477476493313076844060561e-01
            -6.46075961893718742068415394896874e-01 -5.56787351105012318086551204032730e-01
            -5.75688211205114486190836942114402e-01 -6.29292766815959581094830355141312e-01
            -4.97219059955312181475761690307991e-01 -6.92964291507568108663406292180298e-01
            -4.11770043021358445045621010649484e-01 -7.46908116542870814669186074752361e-01
            -3.20540677294451570311650812072912e-01 -7.90366988864694697269897005753592e-01
            -2.24811623092160073333900527359219e-01 -8.22730841168664794871290268929442e-01
            -1.25926706494810691783214906536159e-01 -8.43545355910872096671937470091507e-01
            -2.52740549730183575172226539962139e-02 -8.52518342930315475847180550772464e-01
            7.57333888791826420616715154210397e-02 -8.49523841158271841855764705542242e-01
            1.75677701961157201049346099352988e-01 -8.34603886835591501913711454108125e-01
            2.73155885197867598357390761520946e-01 -8.07967923416022526517110691202106e-01
            3.66799558571484773938919943248038e-01 -7.69989861439223099992545940040145e-01
            4.55294170177307444546954684483353e-01 -7.21202829646408916097755081864307e-01
            5.37397449650969472045858310593758e-01 -6.62291691021459127952653034299146e-01
            6.11956846921270058992092799599050e-01 -5.94083428815858627380919187999098e-01
            6.77925711486748072687191779550631e-01 -5.17535537516619736919665228924714e-01
            7.34377985094438190394328103138832e-01 -4.33722581722537414705698211037088e-01
            7.80521201567799360887534021458123e-01 -3.43821111612694407799750706544728e-01
            8.15707611294722911843280144239543e-01 -2.49093146760980627130166453753191e-01
            8.39443274212203993656089551222976e-01 -1.50868460147655036873715062029078e-01
            8.51394993642096586938805558020249e-01 -5.05259110615988646375562609591725e-02
            8.05097380427555853188437140488531e-01 5.16889667957954809796028428081627e-02
            7.91877703699053858699130614695605e-01 1.54218168981618108936970656941412e-01
            7.65655416968454183290759829105809e-01 2.54215113096353972910179663813324e-01
            7.26861089458919029659966781764524e-01 3.50037852082203893022693819148117e-01
            6.76131722955627734172878717799904e-01 4.40112979214182797882415343337925e-01
            6.14300292254075674946989238378592e-01 5.22961463395044678925671632896410e-01
            5.42382067736959738724067392467987e-01 5.97222934805010097214506004092982e-01
            4.61557944662564667570592291667708e-01 6.61678022136596544200415337400045e-01
            3.73155052897268302292133057562751e-01 7.15268374637776371827158072846942e-01
            2.78624965479827346737096149809076e-01 7.57114040202065297080480377189815e-01
            1.79519863832210219145579799260304e-01 7.86527914157783891724307068216149e-01
            7.74670509835629073069895866865409e-02 8.03027021507769389607744869863382e-01
            -2.58577687005424709798528937199080e-02 8.06340447365477719365856046351837e-01
            -1.28758004537461362426498112654372e-01 7.96413785369929794200061223818921e-01
            -2.29544037499582298522682322072797e-01 7.73410031036655176706062775338069e-01
            -3.26560963712047569451613071578322e-01 7.37706905375832944216085707012098e-01
            -4.18215767928626358518329197977437e-01 6.89890652723747832553158332302701e-01
            -5.03003480798015822905711047496879e-01 6.30746414626995433039269300934393e-01
            -5.79531890418983786084083931200439e-01 5.61245337839993529982507425302174e-01
            -6.46544402421295849592297599883750e-01 4.82528628122123826038603056076681e-01
            -7.02940673210535105219776141893817e-01 3.95888811670712881252143233723473e-01
            -7.47794677579501243513959707343020e-01 3.02748511876605785886340527213179e-01
            -7.80369914016511789789376507542329e-01 2.04637089887418799349916298524477e-01
            -8.00131498039861721593979382305406e-01 1.03165532539778476150971187053074e-01
            -8.06754944986226574243914910766762e-01 9.87989861073681385724380795147329e-17
            -8.00131498039861832616281844821060e-01 -1.03165532539778295739729685465136e-01
            -7.80369914016511789789376507542329e-01 -2.04637089887418605060886989122082e-01
            -7.47794677579501354536262169858674e-01 -3.02748511876605619352886833439698e-01
            -7.02940673210535327264381066925125e-01 -3.95888811670712381651782152403030e-01
            -6.46544402421295960614600062399404e-01 -4.82528628122123770527451824818854e-01
            -5.79531890418983897106386393716093e-01 -5.61245337839993418960204962786520e-01
            -5.03003480798016044950315972528188e-01 -6.30746414626995210994664375903085e-01
            -4.18215767928626802607539048040053e-01 -6.89890652723747610508553407271393e-01
            -3.26560963712047958029671690383111e-01 -7.37706905375832833193783244496444e-01
            -2.29544037499582298522682322072797e-01 -7.73410031036655176706062775338069e-01
            -1.28758004537461029359590725107410e-01 -7.96413785369929794200061223818921e-01
            -2.58577687005424883270876534879790e-02 -8.06340447365477719365856046351837e-01
            7.74670509835623521954772741082706e-02 -8.03027021507769389607744869863382e-01
            1.79519863832210052612126105486823e-01 -7.86527914157783891724307068216149e-01
            2.78624965479827346737096149809076e-01 -7.57114040202065297080480377189815e-01
            3.73155052897268135758679363789270e-01 -7.15268374637776482849460535362596e-01
            4.61557944662564667570592291667708e-01 -6.61678022136596544200415337400045e-01
            5.42382067736959516679462467436679e-01 -5.97222934805010430281413391639944e-01
            6.14300292254075119835476925800322e-01 -5.22961463395045456081788870505989e-01
            6.76131722955627956217483642831212e-01 -4.40112979214182520326659187048790e-01
            7.26861089458918918637664319248870e-01 -3.50037852082204059556147512921598e-01
            7.65655416968453961246154904074501e-01 -2.54215113096354528021691976391594e-01
            7.91877703699053858699130614695605e-01 -1.54218168981618414248302428859461e-01
            8.05097380427555853188437140488531e-01 -5.16889667957961956856749452526856e-02
            7.54781111720619346527882953523658e-01 5.27794368578014747028781528115360e-02
            7.40090155931766968677720797131769e-01 1.57311018870686908366351985932852e-01
            7.10994187097777730066638923744904e-01 2.58780720839886235751237109070644e-01
            6.68059525155831002152240216673817e-01 3.55213550436644265317909230361693e-01
            6.12121844463172859462929409346543e-01 4.44732552323577945418975332358968e-01
            5.44269908346317166092376282904297e-01 5.25595340955313461428488608362386e-01
            4.65824377561345148723859210804221e-01 5.96228014131193084779170021647587e-01
            3.78312105134517573379326904614572e-01 6.55255787211322937579893732618075e-01
            2.83436417904887827390325583110098e-01 7.01529751735795237266302137868479e-01
            1.83043963204886639406510084882029e-01 7.34149237620995487318964478618000e-01
            7.90887659705241247154461348145560e-02 7.52479343678283507657056361495052e-01
            -2.64058041313164071350882977640140e-02 7.56163295243441058168798463157145e-01
            -1.31386415291898206447740449220873e-01 7.45129388389684677029833892447641e-01
            -2.33809739328655341594753735989798e-01 7.19592385563040171092552554910071e-01
            -3.31682222744016985682691256442922e-01 6.80049335475617633406386630667839e-01
            -4.23098888976602360845191697080736e-01 6.27269898617816235031341420835815e-01
            -5.06280416603111627082967061141971e-01 5.62281366692353179459473722090479e-01
            -5.79607771805879301574293549492722e-01 4.86348667549798607812050477150478e-01
            -6.41653721024514345216971378249582e-01 4.00949744806796681828586770279799e-01
            -6.91210610433696914789436505088815e-01 3.07746791354705839793837185425218e-01
            -7.27313871551203527943130211497191e-01 2.08553896665682358957383257802576e-01
            -7.49260795466233031625336025172146e-01 1.05301737604602402287312656881113e-01
            -7.56624210269034924714048884197837e-01 9.26597417263367544676420031503809e-17
            -7.49260795466233031625336025172146e-01 -1.05301737604602235753858963107632e-01
            -7.27313871551203749987735136528499e-01 -2.08553896665681859357022176482133e-01
            -6.91210610433697136834041430120124e-01 -3.07746791354705395704627335362602e-01
            -6.41653721024514456239273840765236e-01 -4.00949744806796626317435539021972e-01
            -5.79607771805879523618898474524030e-01 -4.86348667549798441278596783376997e-01
            -5.06280416603111738105269523657626e-01 -5.62281366692353068437171259574825e-01
            -4.23098888976602804934401547143352e-01 -6.27269898617815901964434033288853e-01
            -3.31682222744017152216144950216403e-01 -6.80049335475617522384084168152185e-01
            -2.33809739328655508128207429763279e-01 -7.19592385563040060070250092394417e-01
            -1.31386415291898234203316064849787e-01 -7.45129388389684677029833892447641e-01
            -2.64058041313170975550317365332376e-02 -7.56163295243440947146496000641491e-01
            7.90887659705237638929631316386804e-02 -7.52479343678283618679358824010706e-01
            1.83043963204886306339602697335067e-01 -7.34149237620995598341266941133654e-01
            2.83436417904887827390325583110098e-01 -7.01529751735795237266302137868479e-01
            3.78312105134517573379326904614572e-01 -6.55255787211322937579893732618075e-01
            4.65824377561345315257312904577702e-01 -5.96228014131192973756867559131933e-01
            5.44269908346316944047771357872989e-01 -5.25595340955313794495395995909348e-01
            6.12121844463172748440626946830889e-01 -4.44732552323578111952429026132450e-01
            6.68059525155831002152240216673817e-01 -3.55213550436644265317909230361693e-01
            7.10994187097777730066638923744904e-01 -2.58780720839886124728934646554990e-01
            7.40090155931766968677720797131769e-01 -1.57311018870687324699986220366554e-01
            7.54781111720619457550185416039312e-01 -5.27794368578010653081378222850617e-02
            7.00738602665552989812169926153729e-01 5.37988730573791401612382401253853e-02
            6.84313883737570960441587430977961e-01 1.60135619185482774851081444467127e-01
            6.51849427372332645980179677280830e-01 2.62718922124535736450923195661744e-01
            6.04106172911441752226835433248198e-01 3.59144316199222324303974573922460e-01
            5.42203181774155718031238393450622e-01 4.47151671898806168936602034591488e-01
            4.67591407606190223589237575652078e-01 5.24678171397264692110695705196122e-01
            3.82019687156034903896539844936342e-01 5.89906659254768039879479601950152e-01
            2.87493749023814582077562818085426e-01 6.41308235001038839939724311989266e-01
            1.86229201082878187412106285592017e-01 6.77678089266540051305298675288213e-01
            8.05995985091108035902607298339717e-02 6.98163743492947297397677175467834e-01
            -2.69191903406584137625756625311624e-02 7.02285031308028884211580589180812e-01
            -1.33807016184490173982268856889277e-01 6.89945353218440970977098913863301e-01
            -2.37558518978525534670609431486810e-01 6.61433940819977306269095151947113e-01
            -3.35741851432967919333094641842763e-01 6.17419077454105402757988940720679e-01
            -4.26055679451419588854577114034328e-01 5.58932434212852768951051984913647e-01
            -5.06383123451578320839416846865788e-01 4.87344888442814483386911206252989e-01
            -5.74841376228465206210671567532700e-01 4.04334391542050086698623090342153e-01
            -6.29825834359514447058359110087622e-01 3.11846639201478703640191270096693e-01
            -6.70047708748799930589257201063447e-01 2.12049465946979320829512971613440e-01
            -6.94564232751116450437223193148384e-01 1.07282032935476168145072506376891e-01
            -7.02800759823092202616123813641025e-01 3.98174504207428437862524638364421e-16
            -6.94564232751116450437223193148384e-01 -1.07282032935476001611618812603410e-01
            -6.70047708748799930589257201063447e-01 -2.12049465946979431851815434129094e-01
            -6.29825834359514447058359110087622e-01 -3.11846639201478537106737576323212e-01
            -5.74841376228465539277578955079662e-01 -4.04334391542049698120564471537364e-01
            -5.06383123451578431861719309381442e-01 -4.87344888442814372364608743737335e-01
            -4.26055679451419477832274651518674e-01 -5.58932434212852768951051984913647e-01
            -3.35741851432967752799640948069282e-01 -6.17419077454105513780291403236333e-01
            -2.37558518978525534670609431486810e-01 -6.61433940819977306269095151947113e-01
            -1.33807016184490645827054322580807e-01 -6.89945353218440859954796451347647e-01
            -2.69191903406585837654763082582576e-02 -7.02285031308028884211580589180812e-01
            8.05995985091107897124729220195150e-02 -6.98163743492947297397677175467834e-01
            1.86229201082877882100774513673969e-01 -6.77678089266540162327601137803867e-01
            2.87493749023814415544109124311944e-01 -6.41308235001038950962026774504920e-01
            3.82019687156035014918842307451996e-01 -5.89906659254767928857177139434498e-01
            4.67591407606190001544632650620770e-01 -5.24678171397264914155300630227430e-01
            5.42203181774155273942028543388005e-01 -4.47151671898806613025811884654104e-01
            6.04106172911441530182230508216890e-01 -3.59144316199222712882033192727249e-01
            6.51849427372332534957877214765176e-01 -2.62718922124535847473225658177398e-01
            6.84313883737570960441587430977961e-01 -1.60135619185482691584354597580386e-01
            7.00738602665552989812169926153729e-01 -5.37988730573794315947822042289772e-02
            6.43200358241771130707320480723865e-01 5.47444183981842802388939617230790e-02
            6.24696655007099810319459720631130e-01 1.62658357950148740878049125058169e-01
            5.88221566390210948149785963323666e-01 2.65892912695214256313391842923011e-01
            5.34824414280585802572431930457242e-01 3.61478212452046088198898132759496e-01
            4.66041337524468135544708502493449e-01 4.46664442178357101731478451256407e-01
            3.83851100007098822164408602475305e-01 5.19000949143099687965730026917299e-01
            2.90618165218463786469982323978911e-01 5.76406743743644867095099471043795e-01
            1.89024674943655157655086895829299e-01 6.17230365787801882326846225623740e-01
            8.19932889270767878420187457777502e-02 6.40297393996742014721235136676114e-01
            -2.73968947271279426869394768573329e-02 6.44944231966926628807357246842002e-01
            -1.35998919601434148374252686153341e-01 6.31037198630430062884499875508482e-01
            -2.40688503171416573467311650347256e-01 5.98976374015871448897030404623365e-01
            -3.38453916725611980709231829678174e-01 5.49684089674415288229170073464047e-01
            -4.26482627317106566255944244403508e-01 4.84578394880328999771990083900164e-01
            -5.02242209215653212517338488396490e-01 4.05532261935198201641128434857819e-01
            -5.63553197185153509352062428661156e-01 3.14819704164922942180027121139574e-01
            -6.08651785730360717074916010460583e-01 2.15050356696614847207271736806433e-01
            -6.36240570569622021501743347471347e-01 1.09094402007344229432739268759178e-01
            -6.45525872593886163031129399314523e-01 7.90541193638904797794678914553491e-17
            -6.36240570569622021501743347471347e-01 -1.09094402007344062899285574985697e-01
            -6.08651785730360717074916010460583e-01 -2.15050356696614708429393658661866e-01
            -5.63553197185153731396667353692465e-01 -3.14819704164922553601968502334785e-01
            -5.02242209215653101495036025880836e-01 -4.05532261935198368174582128631300e-01
            -4.26482627317106732789397938176990e-01 -4.84578394880328944260838852642337e-01
            -3.38453916725612369287290448482963e-01 -5.49684089674415066184565148432739e-01
            -2.40688503171416712245189728491823e-01 -5.98976374015871337874727942107711e-01
            -1.35998919601434009596374608008773e-01 -6.31037198630430062884499875508482e-01
            -2.73968947271282410593773448681532e-02 -6.44944231966926517785054784326348e-01
            8.19932889270763298750210879006772e-02 -6.40297393996742014721235136676114e-01
            1.89024674943654880099330739540164e-01 -6.17230365787801882326846225623740e-01
            2.90618165218463786469982323978911e-01 -5.76406743743644867095099471043795e-01
            3.83851100007098988697862296248786e-01 -5.19000949143099576943427564401645e-01
            4.66041337524467969011254808719968e-01 -4.46664442178357268264932145029888e-01
            5.34824414280585469505524542910280e-01 -3.61478212452046421265805520306458e-01
            5.88221566390210837127483500808012e-01 -2.65892912695214478357996767954319e-01
            6.24696655007099810319459720631130e-01 -1.62658357950148713122473509429256e-01
            6.43200358241771019685018018208211e-01 -5.47444183981845577946501180122141e-02
            5.82350134564275312420988939265953e-01 5.56076955603680422868251298496034e-02
            5.61302483402646323895623936550692e-01 1.64813279679114826903330026652839e-01
            5.19967898031489794696824446873507e-01 2.68062082453446703933508388217888e-01
            4.59840318062331054882463376998203e-01 3.61622423138967474809390978407464e-01
            3.83092910896137006648842771028285e-01 4.42112787254212602494618522541714e-01
            2.92499527791312996516381872424972e-01 5.06624043324458872561422140279319e-01
            1.91334449652024535248884262728097e-01 5.52824586472889345500902891217265e-01
            8.32540459852660619244346662526368e-02 5.79044608695778673101983713422669e-01
            -2.78353758197012364494771219369795e-02 5.84336450074390056919071412266931e-01
            -1.37918754618179956183965373384126e-01 5.68508849673542426828021234541666e-01
            -2.43017390280947875869088647959870e-01 5.32133858210132704158468186506070e-01
            -3.39332744283327492063051522563910e-01 4.76526162649764772893945519172121e-01
            -4.23383728784466228933780485021998e-01 4.03695569994427516657964361002087e-01
            -4.92132522211788492327855237817857e-01 3.16274367620943519519016717822524e-01
            -5.43094364047596922517868733848445e-01 2.17422185556811198292592735015205e-01
            -5.74427360548161569653302649385296e-01 1.10711799218676895661950254634576e-01
            -5.84999055582625882010461282334290e-01 7.16417220923487336689385141534295e-17
            -5.74427360548161680675605111900950e-01 -1.10711799218676507083891635829787e-01
            -5.43094364047597033540171196364099e-01 -2.17422185556811059514714656870638e-01
            -4.92132522211788714372460162849165e-01 -3.16274367620943186452109330275562e-01
            -4.23383728784466284444931716279825e-01 -4.03695569994427461146813129744260e-01
            -3.39332744283327603085353985079564e-01 -4.76526162649764661871643056656467e-01
            -2.43017390280947792602361801073130e-01 -5.32133858210132815180770649021724e-01
            -1.37918754618179983939540989013040e-01 -5.68508849673542426828021234541666e-01
            -2.78353758197015105357863262725004e-02 -5.84336450074390056919071412266931e-01
            8.32540459852657843686785099635017e-02 -5.79044608695778673101983713422669e-01
            1.91334449652024535248884262728097e-01 -5.52824586472889345500902891217265e-01
            2.92499527791312996516381872424972e-01 -5.06624043324458872561422140279319e-01
            3.83092910896136673581935383481323e-01 -4.42112787254212824539223447573022e-01
            4.59840318062330832837858451966895e-01 -3.61622423138967752365147134696599e-01
            5.19967898031489683674521984357852e-01 -2.68062082453446814955810850733542e-01
            5.61302483402646323895623936550692e-01 -1.64813279679114882414481257910666e-01
            5.82350134564275312420988939265953e-01 -5.56076955603685002538227877266763e-02
            5.18332461910003594596219045342878e-01 5.63720523853544000503212885178073e-02
            4.94095812076246476696184117827215e-01 1.66480262639560283588480160688050e-01
            4.46755791217857245456457349064294e-01 2.68804040842262670363282950347639e-01
            3.78525966095519861287499452373595e-01 3.58558840849414528495486820247606e-01
            2.92596687499950935951176234084414e-01 4.31547827967976804774963284216938e-01
            1.92985912994745489879022670720587e-01 4.84358118281718208475439269022900e-01
            8.43513316863423595615145700321591e-02 5.14520361309990459375285354326479e-01
            -2.82274241419420875154333572254473e-02 5.20624204091716613618245901307091e-01
            -1.39486296989878300056631132974871e-01 5.02384237722357185340626983816037e-01
            -2.44222945618451953153638100957323e-01 4.60653342757077033375878727383679e-01
            -3.37540000744215529238090311991982e-01 3.97382809463893982293569706598646e-01
            -4.15074060583945469993238930328516e-01 3.15531097659450365799926885301829e-01
            -4.73199718672454805457050497352611e-01 2.18925502416077777390057690354297e-01
            -5.09199083839553257035959177301265e-01 1.12083193997949637221722696267534e-01
            -5.21388865780448407249991760181729e-01 6.38517205589095075033336028231487e-17
            -5.09199083839553257035959177301265e-01 -1.12083193997949512321632425937423e-01
            -4.73199718672454749945899266094784e-01 -2.18925502416077860656784537241037e-01
            -4.15074060583945692037843855359824e-01 -3.15531097659450088244170729012694e-01
            -3.37540000744215418215787849476328e-01 -3.97382809463894037804720937856473e-01
            -2.44222945618452286220545488504285e-01 -4.60653342757076866842425033610198e-01
            -1.39486296989878522101236058006180e-01 -5.02384237722357074318324521300383e-01
            -2.82274241419424448684694084477087e-02 -5.20624204091716502595943438791437e-01
            8.43513316863422485392121075165051e-02 -5.14520361309990459375285354326479e-01
            1.92985912994745240078842130060366e-01 -4.84358118281718319497741731538554e-01
            2.92596687499950880440025002826587e-01 -4.31547827967976860286114515474765e-01
            3.78525966095519861287499452373595e-01 -3.58558840849414528495486820247606e-01
            4.46755791217857245456457349064294e-01 -2.68804040842262670363282950347639e-01
            4.94095812076246476696184117827215e-01 -1.66480262639560228077328929430223e-01
            5.18332461910003483573916582827223e-01 -5.63720523853547816894860034153680e-02
            4.51253619467907818307850220662658e-01 5.70065892689374173474270435235667e-02
            4.22899694962017291821609887847444e-01 1.67437834147475178570019238577515e-01
            3.67973427305381239893478095837054e-01 2.67348344113248592712750451028114e-01
            2.89926035899548129037839316879399e-01 3.50460374379955530432795285378234e-01
            1.93661525384773436364582721580518e-01 4.11551690421273097530985296543804e-01
            8.52285489928048811680838525717263e-02 4.46783700172181386101044608949451e-01
            -2.85596505810588180418463366549986e-02 4.53942646885762968178568144139717e-01
            -1.40553342273866843648022495472105e-01 4.32578707611239066110897510952782e-01
            -2.43715550552574433673669318523025e-01 3.84034257224300512589820755238179e-01
            -3.31564214466967155381382781342836e-01 3.11359522076758765685156049585203e-01
            -3.98579479378518786170104704069672e-01 2.19120923056912941806473327233107e-01
            -4.40550529727932183021721357363276e-01 1.13114150571018118318633582930488e-01
            -4.54840170063028459424003813182935e-01 5.57018558391325545695155544992529e-17
            -4.40550529727932294044023819878930e-01 -1.13114150571017813007301811012439e-01
            -3.98579479378518786170104704069672e-01 -2.19120923056913025073200174119847e-01
            -3.31564214466967377425987706374144e-01 -3.11359522076758599151702355811722e-01
            -2.43715550552574183873488777862804e-01 -3.84034257224300679123274449011660e-01
            -1.40553342273867065692627420503413e-01 -4.32578707611239010599746279694955e-01
            -2.85596505810587278362255858610297e-02 -4.53942646885762968178568144139717e-01
            8.52285489928046591234789275404182e-02 -4.46783700172181441612195840207278e-01
            1.93661525384773047786524102775729e-01 -4.11551690421273264064438990317285e-01
            2.89926035899547962504385623105918e-01 -3.50460374379955696966248979151715e-01
            3.67973427305381184382326864579227e-01 -2.67348344113248648223901682285941e-01
            4.22899694962017291821609887847444e-01 -1.67437834147475150814443622948602e-01
            4.51253619467907762796698989404831e-01 -5.70065892689375908197746412042761e-02
            3.81173738374918524840495592798106e-01 5.74526969300892739744845982841071e-02
            3.47304778966907978787759248007205e-01 1.67253166541021680568945839695516e-01
            2.82576265825768835338038797999616e-01 2.62192458326352240138845672845491e-01
            1.92739611400492616422042146950844e-01 3.33834799576734730930382966107572e-01
            8.57771966784294376262565151591843e-02 3.75814453874836418290072970194160e-01
            -2.88068983955396228091583310515489e-02 3.84401344711592540814848462105147e-01
            -1.40831374130073738726309784397017e-01 3.58832489153207423449032376083778e-01
            -2.40342364244844786114185808401089e-01 3.01379792223118170291229489521356e-01
            -3.18497880571368296998002733744215e-01 2.17148178170570749223600159893977e-01
            -3.68353462504198148064205042828689e-01 1.13621995548484316929105375493236e-01
            -3.85479222800985121821781831386033e-01 4.72075896341035862991005315168631e-17
            -3.68353462504198259086507505344343e-01 -1.13621995548484067128924834833015e-01
            -3.18497880571368241486851502486388e-01 -2.17148178170570832490327006780717e-01
            -2.40342364244844869380912655287830e-01 -3.01379792223118114780078258263529e-01
            -1.40831374130073655459582937510277e-01 -3.58832489153207423449032376083778e-01
            -2.88068983955398864871266795262272e-02 -3.84401344711592540814848462105147e-01
            8.57771966784293404817418604579871e-02 -3.75814453874836418290072970194160e-01
            1.92739611400492311110710375032795e-01 -3.33834799576734897463836659881053e-01
            2.82576265825768890849190029257443e-01 -2.62192458326352184627694441587664e-01
            3.47304778966907923276608016749378e-01 -1.67253166541021763835672686582257e-01
            3.81173738374918469329344361540279e-01 -5.74526969300896001024980819238408e-02
            3.08080812987386098988906724116532e-01 5.75902848747065071455253359999915e-02
            2.66472792058722596220121658916469e-01 1.64992967533005518987465620739385e-01
            1.88876143985814592962668712061713e-01 2.50112435668377874886658673858619e-01
            8.57707260687787659270142626155575e-02 3.01452833445886081431552838694188e-01
            -2.89185036758457733596650029994635e-02 3.12080355658712893518469400078175e-01
            -1.39702129256086576836182189254032e-01 2.80559696542882486269832043035422e-01
            -2.31618208164071581744991590312566e-01 2.11147895773989291434702408878366e-01
            -2.92252964618701094323682809772436e-01 1.13219401669938463106390713619476e-01
            -3.13417338771993625456957488495391e-01 3.83825540724403653941646753131895e-17
            -2.92252964618701149834834041030263e-01 -1.13219401669938268817361404217081e-01
            -2.31618208164071498478264743425825e-01 -2.11147895773989319190278024507279e-01
            -1.39702129256086909903089576800994e-01 -2.80559696542882319736378349261940e-01
            -2.89185036758457802985589069066918e-02 -3.12080355658712893518469400078175e-01
            8.57707260687786965380752235432738e-02 -3.01452833445886081431552838694188e-01
            1.88876143985814537451517480803886e-01 -2.50112435668377930397809905116446e-01
            2.66472792058722485197819196400815e-01 -1.64992967533005657765343698883953e-01
            3.08080812987386098988906724116532e-01 -5.75902848747064169399045852060226e-02
            2.31815878428090510476877739165502e-01 5.71374823318364366553367972301203e-02
            1.78709654364398895509680187387858e-01 1.58322938374593241706023150072724e-01
            8.46632021706283793838210272042488e-02 2.23238517233974365083781776775140e-01
            -2.87785693382411819629673743747844e-02 2.37012842110827848252085914282361e-01
            -1.35627517431077176945919404715823e-01 1.96490381174476369530168540222803e-01
            -2.11405835769224836884205842579831e-01 1.10954341876844553294034767532139e-01
            -2.38753624849148970987755546957487e-01 -7.67890223624630279705607402359199e-17
            -2.11405835769224947906508305095485e-01 -1.10954341876844317371642034686374e-01
            -1.35627517431077232457070635973650e-01 -1.96490381174476341774592924593890e-01
            -2.87785693382413484964210681482655e-02 -2.37012842110827848252085914282361e-01
            8.46632021706283793838210272042488e-02 -2.23238517233974365083781776775140e-01
            1.78709654364398812242953340501117e-01 -1.58322938374593324972749996959465e-01
            2.31815878428090510476877739165502e-01 -5.71374823318364505331246050445770e-02
            1.51832770643846259872589143924415e-01 5.52626091005272920830826421934034e-02
            8.07885298263072010316321325262834e-02 1.39929838327957689614322589477524e-01
            -2.80575619614573772142573915289177e-02 1.59122341054810656491014242419624e-01
            -1.23775208682388851433309184812970e-01 1.03859731954283399102401119762362e-01
            -1.61577059652614374307688649423653e-01 1.97874828919215149101025935177363e-17
            -1.23775208682388920822248223885254e-01 -1.03859731954283301957886465061165e-01
            -2.80575619614573806837043434825318e-02 -1.59122341054810656491014242419624e-01
            8.07885298263070761315418621961726e-02 -1.39929838327957745125473820735351e-01
            1.51832770643846259872589143924415e-01 -5.52626091005272712664009304717183e-02
            6.63135928705178151476573589206964e-02 4.81796454052642875165446412211168e-02
            -2.53295385604150914693466489779894e-02 7.79563038316353207335396291455254e-02
            -8.19681086202054265399397081637289e-02 1.00381981853897149171413741278689e-17
            -2.53295385604151122860283606996745e-02 -7.79563038316353207335396291455254e-02
            6.63135928705178012698695511062397e-02 -4.81796454052643083332263529428019e-02
            -0.00000000000000000000000000000000e+00 0.00000000000000000000000000000000e+00
            ];
        
    case   37
        
        % DEGREE.             :          37
        % CARDIN.             :         741
        % LEBESGUE CONST.     : 3.28261e+02
        % ABS.DET.VAND.MATRIX : Inf
        % CONDITIONING VAND.  : 9.91628e+03
        % POINTS OUT DISK     : 0.00000e+00
        
        pts=[
            9.99122830098858383252036219346337e-01 4.18756537291996230876200968396006e-02
            9.92114701314477875904174197785323e-01 1.25333233564304258322863461216912e-01
            9.78147600733805466788339799677487e-01 2.07911690817759259308772357144335e-01
            9.57319497532067242850928323605331e-01 2.89031796944471619514871463252348e-01
            9.29776485888251458256092973897466e-01 3.68124552684677919245359589694999e-01
            8.95711760239412901896116636635270e-01 4.44635179184927398221560679303366e-01
            8.55364260160506706398564347182401e-01 5.18027009373130176150823444913840e-01
            8.09016994374947451262869435595348e-01 5.87785252292473137103456792829093e-01
            7.56995055651756398873430953244679e-01 6.53420603990105375302732682030182e-01
            6.99663340513365539230505874002120e-01 7.14472679632803253646500252216356e-01
            6.37423989748689745482579382951371e-01 7.70513242775789253258267308410723e-01
            5.70713567684431821724899691616884e-01 8.21149209133703927854242010653252e-01
            4.99999999999999888977697537484346e-01 8.66025403784438707610604524234077e-01
            4.25779291565072548486625692021335e-01 9.04827052466019354781678885046858e-01
            3.48572047321815292608704339727410e-01 9.37281989491891454058247745706467e-01
            2.68919820615265647845149032946210e-01 9.63162566797657992978543006756809e-01
            1.87381314585724739751881884330942e-01 9.82287250728688610124095248465892e-01
            1.04528463267653679014124179502687e-01 9.94521895368273289861349439888727e-01
            2.09424198833570510136503628473292e-02 9.99780683474845499603134157950990e-01
            -6.27905195293131795919450155452068e-02 9.98026728428271558968276622181293e-01
            -1.46083028562411315620650498203759e-01 9.89272332962988332205611641256837e-01
            -2.28350870110655551625811199301097e-01 9.73578902873160290099008307151962e-01
            -3.09016994374947340240566973079694e-01 9.51056516295153642204240895807743e-01
            -3.87515586452102989145629408085370e-01 9.21863151588500517874535944429226e-01
            -4.63296035119861504547600361547666e-01 8.86203579231214844114106199413072e-01
            -5.35826794978996434615226007736055e-01 8.44327925502015186332016583037330e-01
            -6.04599114862374831247393558442127e-01 7.96529918024196370573974945727969e-01
            -6.69130606358858237570075289113447e-01 7.43144825477394244117590460518841e-01
            -7.28968627421411330402634121128358e-01 6.84547105928688837117590537673095e-01
            -7.83693457325839726301808241260005e-01 6.21147780278310523982554514077492e-01
            -8.32921240710099430870627656986471e-01 5.53391549243344105235564711620100e-01
            -8.76306680043863583939867112349020e-01 4.81753674101715212430008250521496e-01
            -9.13545457642600755576722804107703e-01 4.06736643075800430313648803348769e-01
            -9.44376370237480999847434759431053e-01 3.28866646738583401354816260209191e-01
            -9.68583161128631076053352444432676e-01 2.48689887164854822598769601427193e-01
            -9.85996037070504982580132491420954e-01 1.66768746716102173044404821666831e-01
            -9.96492859249504370211525383638218e-01 8.36778433323157322387686463116552e-02
            -1.00000000000000000000000000000000e+00 1.22464679914735320717376402945840e-16
            -9.96492859249504370211525383638218e-01 -8.36778433323154824385881056514336e-02
            -9.85996037070504871557830028905300e-01 -1.66768746716102367333434131069225e-01
            -9.68583161128631187075654906948330e-01 -2.48689887164854572798589060766972e-01
            -9.44376370237480888825132296915399e-01 -3.28866646738583567888269953982672e-01
            -9.13545457642600866599025266623357e-01 -4.06736643075800208269043878317461e-01
            -8.76306680043863694962169574864674e-01 -4.81753674101714990385403325490188e-01
            -8.32921240710099319848325194470817e-01 -5.53391549243344327280169636651408e-01
            -7.83693457325839837324110703775659e-01 -6.21147780278310301937949589046184e-01
            -7.28968627421411774491843971190974e-01 -6.84547105928688393028380687610479e-01
            -6.69130606358858126547772826597793e-01 -7.43144825477394355139892923034495e-01
            -6.04599114862375386358905871020397e-01 -7.96529918024195926484765095665352e-01
            -5.35826794978996323592923545220401e-01 -8.44327925502015297354319045552984e-01
            -4.63296035119862115170263905383763e-01 -8.86203579231214511047198811866110e-01
            -3.87515586452103211190234333116678e-01 -9.21863151588500406852233481913572e-01
            -3.09016994374947562285171898111003e-01 -9.51056516295153531181938433292089e-01
            -2.28350870110655801425991739961319e-01 -9.73578902873160290099008307151962e-01
            -1.46083028562412425843675123360299e-01 -9.89272332962988221183309178741183e-01
            -6.27905195293132073475206311741204e-02 -9.98026728428271558968276622181293e-01
            2.09424198833563605937069240781057e-02 -9.99780683474845499603134157950990e-01
            1.04528463267653873303153488905082e-01 -9.94521895368273289861349439888727e-01
            1.87381314585724267907096418639412e-01 -9.82287250728688721146397710981546e-01
            2.68919820615265481311695339172729e-01 -9.63162566797658215023147931788117e-01
            3.48572047321815070564099414696102e-01 -9.37281989491891565080550208222121e-01
            4.25779291565072603997776923279162e-01 -9.04827052466019576826283810078166e-01
            4.99999999999999333866185224906076e-01 -8.66025403784439040677511911781039e-01
            5.70713567684431821724899691616884e-01 -8.21149209133703927854242010653252e-01
            6.37423989748689301393369532888755e-01 -7.70513242775789586325174695957685e-01
            6.99663340513365761275110799033428e-01 -7.14472679632803031601895327185048e-01
            7.56995055651756176828826028213371e-01 -6.53420603990105708369640069577144e-01
            8.09016994374947118195962048048386e-01 -5.87785252292473248125759255344747e-01
            8.55364260160506595376261884666746e-01 -5.18027009373130287173125907429494e-01
            8.95711760239412901896116636635270e-01 -4.44635179184927453732711910561193e-01
            9.29776485888251125189185586350504e-01 -3.68124552684678696401476827304577e-01
            9.57319497532067353873230786120985e-01 -2.89031796944471341959115306963213e-01
            9.78147600733805355766037337161833e-01 -2.07911690817759814420284669722605e-01
            9.92114701314477875904174197785323e-01 -1.25333233564303786478077995525382e-01
            9.99122830098858383252036219346337e-01 -4.18756537291999283989518687576492e-02
            9.86364821814821546297480381326750e-01 4.36729630991271253193097834355285e-02
            9.78645179721267965966546853451291e-01 1.30677089147138880687037953975960e-01
            9.63266312200220742312239963212050e-01 2.16658489794028519259683207565104e-01
            9.40348579741471013448972371406853e-01 3.00944244001842609037566944607534e-01
            9.10071344674518778461447254812811e-01 3.82874701465055811144821973357466e-01
            8.72671567415155169378238042554585e-01 4.61808645268598716437935536305304e-01
            8.28441951928927111659106685692677e-01 5.37128310279612275479621530394070e-01
            7.77728654925743390080583594681229e-01 6.08244217997209069004327375296270e-01
            7.20928576714282787207821456831880e-01 6.74599790020987688521358904836234e-01
            6.58486254918942970348894050403032e-01 7.35675704031652277770092496211873e-01
            5.90890385370200887926728228194406e-01 7.90993958192284685182471548614558e-01
            5.18669997397142812367576425458537e-01 8.40121612160816932934892520279391e-01
            4.42390313455679029530642765166704e-01 8.82674175435210317530732027080376e-01
            3.62648325496469137174671004686388e-01 9.18318616512944996266298858245136e-01
            2.80068122693476972973058991556172e-01 9.46775969314068488458246974914800e-01
            1.95296007100013824242523696739227e-01 9.67823516469006772666716642561369e-01
            1.08995435458879810775023599944689e-01 9.81296532383953534761644732498098e-01
            2.18418267538073203326565163706618e-02 9.87089572441984142159299153718166e-01
            -6.54827238598573585504070138085808e-02 9.85157298250150526008894757978851e-01
            -1.52294783374560094291183531822753e-01 9.75514832473877935292705387837486e-01
            -2.37914929720457801742838910286082e-01 9.58237640481604091569067804812221e-01
            -3.21673069164309655132427678836393e-01 9.33460939725951011070037566241808e-01
            -4.02913680701484477886253898759605e-01 9.01378641483824294411419941752683e-01
            -4.81000946396611728239633976045297e-01 8.62241833237755939123303505766671e-01
            -5.55323727520998455808864946448011e-01 8.16356813575918049963320299866609e-01
            -6.25300347541796974759620297845686e-01 7.64082694990372290888558381993789e-01
            -6.90383144529535641709117044229060e-01 7.05828593334920539881238710222533e-01
            -7.50062757355267950565291812381474e-01 6.42050425938846869300391517754178e-01
            -8.03872112132022698105515701172408e-01 5.73247343435661194099850490601966e-01
            -8.51390077701252856456903828075156e-01 4.99957823232617282194212293688906e-01
            -8.92244761555139542785752837517066e-01 4.22755455194908702498679531345260e-01
            -9.26116420399699102894430779997492e-01 3.42244452527269094055384357488947e-01
            -9.52739962579580046408977977989707e-01 2.59054922986425184561198875599075e-01
            -9.71907022779692542080454131792067e-01 1.73837937433566208644819539586024e-01
            -9.83467592766309794960477574932156e-01 8.72604343221029254973331035216688e-02
            -9.87331195404886563515844954963541e-01 1.20913198815092431030584903507744e-16
            -9.83467592766309794960477574932156e-01 -8.72604343221026895749403706759040e-02
            -9.71907022779692653102756594307721e-01 -1.73837937433565986600214614554716e-01
            -9.52739962579580157431280440505361e-01 -2.59054922986424962516593950567767e-01
            -9.26116420399698991872128317481838e-01 -3.42244452527269260588838051262428e-01
            -8.92244761555139875852660225064028e-01 -4.22755455194908147387167218766990e-01
            -8.51390077701252745434601365559502e-01 -4.99957823232617504238817218720214e-01
            -8.03872112132022809127818163688062e-01 -5.73247343435660972055245565570658e-01
            -7.50062757355268172609896737412782e-01 -6.42050425938846758278089055238524e-01
            -6.90383144529535530686814581713406e-01 -7.05828593334920761925843635253841e-01
            -6.25300347541797085781922760361340e-01 -7.64082694990372068843953456962481e-01
            -5.55323727520999010920377259026282e-01 -8.16356813575917605874110449803993e-01
            -4.81000946396611173128121663467027e-01 -8.62241833237756161167908430797979e-01
            -4.02913680701485088508917442595703e-01 -9.01378641483823961344512554205721e-01
            -3.21673069164309877177032603867701e-01 -9.33460939725950900047735103726154e-01
            -2.37914929720458467876653685380006e-01 -9.58237640481603869524462879780913e-01
            -1.52294783374560760424998306916677e-01 -9.75514832473877824270402925321832e-01
            -6.54827238598573863059826294374943e-02 -9.85157298250150526008894757978851e-01
            2.18418267538068588962119065399747e-02 -9.87089572441984142159299153718166e-01
            1.08995435458879366685813749882072e-01 -9.81296532383953534761644732498098e-01
            1.95296007100013796486948081110313e-01 -9.67823516469006772666716642561369e-01
            2.80068122693476972973058991556172e-01 -9.46775969314068488458246974914800e-01
            3.62648325496469525752729623491177e-01 -9.18318616512944885243996395729482e-01
            4.42390313455679196064096458940185e-01 -8.82674175435210206508429564564722e-01
            5.18669997397142035211459187848959e-01 -8.40121612160817377024102370342007e-01
            5.90890385370200776904425765678752e-01 -7.90993958192284796204774011130212e-01
            6.58486254918942637281986662856070e-01 -7.35675704031652610836999883758835e-01
            7.20928576714282343118611606769264e-01 -6.74599790020988132610568754898850e-01
            7.77728654925743279058281132165575e-01 -6.08244217997209180026629837811925e-01
            8.28441951928926889614501760661369e-01 -5.37128310279612497524226455425378e-01
            8.72671567415155280400540505070239e-01 -4.61808645268598549904481842531823e-01
            9.10071344674518778461447254812811e-01 -3.82874701465055811144821973357466e-01
            9.40348579741471013448972371406853e-01 -3.00944244001842886593323100896669e-01
            9.63266312200220853334542425727705e-01 -2.16658489794028130681624588760315e-01
            9.78645179721268076988849315966945e-01 -1.30677089147138741909159875831392e-01
            9.86364821814821546297480381326750e-01 -4.36729630991281245200319460764149e-02
            9.63175814102933403049178195942659e-01 4.51959047670713529032404665031208e-02
            9.54711390416450811358117789495736e-01 1.35190531065047858660932433849666e-01
            9.37856928703191261575966564123519e-01 2.23997098115086445968557882224559e-01
            9.12760546578713194421084153873380e-01 3.10835170612804301271125950734131e-01
            8.79642791951497193814191177807515e-01 3.94941612454724144676276864629472e-01
            8.38794704839995852729828129668022e-01 4.75577293205790729846427211668924e-01
            7.90575259702487320723207631090190e-01 5.52033583604210842388226865296019e-01
            7.35408210756628100135401382431155e-01 6.23638583020885040042458058451302e-01
            6.73778368012152295563055304228328e-01 6.89763024146295644634108157333685e-01
            6.06227336743073386138291880342877e-01 7.49825803014248726263701882999158e-01
            5.33348757841062393048048306809505e-01 8.03299085764423326239125344727654e-01
            4.55783090877947660857216760632582e-01 8.49712947265314433309413288952783e-01
            3.74211985723967799355449415088515e-01 8.88659500833186011270470316958381e-01
            2.89352292184203496727690207990236e-01 9.19796482754913435897492490767036e-01
            2.01949760296714020402220057803788e-01 9.42850260113801019734580677322811e-01
            1.12772486654390671767522746904433e-01 9.57618235485492297343057543912437e-01
            2.26041643444776126081752209984188e-02 9.63970627371420696327675159409409e-01
            -6.77628041744542386481953144539148e-02 9.61851610723284622395112819503993e-01
            -1.57534270733807990616526240046369e-01 9.51279807535579835509054191788891e-01
            -2.45921320457618719501624582335353e-01 9.32348123194841726935067072190577e-01
            -3.32147204774850546282749519377830e-01 9.05222930023768301843745121004758e-01
            -4.15454167513768790609418601889047e-01 8.70142605195265650408487090317067e-01
            -4.95110104090420943823147581497324e-01 8.27415435865282211658211508620298e-01
            -5.70414995270047020525794323475566e-01 7.77416909934196653786386832507560e-01
            -6.40707058961281772369034115399700e-01 7.20586416245648564427028759382665e-01
            -7.05368565980971196083260110754054e-01 6.57423383221581780766484826017404e-01
            -7.63831268680444264163043044391088e-01 5.88482889867314340470727529464057e-01
            -8.15581394726280661799933113798033e-01 5.14370787717282063056245533516631e-01
            -8.60164162150051314625898157828487e-01 4.35738376589970222152459200515295e-01
            -8.97187775988609881316904193226947e-01 3.53276680941687126757955184075399e-01
            -9.26326871392313844211230389191769e-01 2.67710377118800080253890882886481e-01
            -9.47325372943024324179361883579986e-01 1.79791424875944572114860875444720e-01
            -9.59998745054087332384540331986500e-01 9.02924591266621306973050309352402e-02
            -9.64235613675704539282662608457031e-01 1.18084805791183543950063011953402e-16
            -9.59998745054087332384540331986500e-01 -9.02924591266618947749122980894754e-02
            -9.47325372943024435201664346095640e-01 -1.79791424875944322314680334784498e-01
            -9.26326871392313955233532851707423e-01 -2.67710377118799858209285957855172e-01
            -8.97187775988609992339206655742601e-01 -3.53276680941686904713350259044091e-01
            -8.60164162150051647692805545375450e-01 -4.35738376589969556018644425421371e-01
            -8.15581394726280550777630651282379e-01 -5.14370787717282285100850458547939e-01
            -7.63831268680444375185345506906742e-01 -5.88482889867314118426122604432749e-01
            -7.05368565980971307105562573269708e-01 -6.57423383221581558721879900986096e-01
            -6.40707058961281994413639040431008e-01 -7.20586416245648453404726296867011e-01
            -5.70414995270047242570399248506874e-01 -7.77416909934196431741781907476252e-01
            -4.95110104090421165867752506528632e-01 -8.27415435865282100635909046104643e-01
            -4.15454167513768624075964908115566e-01 -8.70142605195265650408487090317067e-01
            -3.32147204774851156905413063213928e-01 -9.05222930023768079799140195973450e-01
            -2.45921320457618941546229507366661e-01 -9.32348123194841726935067072190577e-01
            -1.57534270733808018372101855675282e-01 -9.51279807535579835509054191788891e-01
            -6.77628041744540582369538128659769e-02 -9.61851610723284622395112819503993e-01
            2.26041643444773732163355361990398e-02 -9.63970627371420696327675159409409e-01
            1.12772486654390449722917821873125e-01 -9.57618235485492408365360006428091e-01
            2.01949760296714214691249367206183e-01 -9.42850260113801019734580677322811e-01
            2.89352292184202830593875432896311e-01 -9.19796482754913657942097415798344e-01
            3.74211985723967577310844490057207e-01 -8.88659500833186122292772779474035e-01
            4.55783090877947660857216760632582e-01 -8.49712947265314433309413288952783e-01
            5.33348757841061837936535994231235e-01 -8.03299085764423659306032732274616e-01
            6.06227336743073608182896805374185e-01 -7.49825803014248504219096957967849e-01
            6.73778368012152184540752841712674e-01 -6.89763024146295644634108157333685e-01
            7.35408210756627767068493994884193e-01 -6.23638583020885595153970371029573e-01
            7.90575259702487542767812556121498e-01 -5.52033583604210509321319477749057e-01
            8.38794704839995741707525667152368e-01 -4.75577293205791062913334599215887e-01
            8.79642791951496860747283790260553e-01 -3.94941612454724977343545333496877e-01
            9.12760546578713305443386616389034e-01 -3.10835170612804134737672256960650e-01
            9.37856928703191261575966564123519e-01 -2.23997098115086862302192116658262e-01
            9.54711390416450811358117789495736e-01 -1.35190531065048052949961743252061e-01
            9.63175814102933403049178195942659e-01 -4.51959047670712765754075235236087e-02
            9.33208530361422927690284723212244e-01 4.65745014765074419327284260816668e-02
            9.23933884724843834668206454807660e-01 1.39260626109359880731020098210138e-01
            9.05476769046834717435956463305047e-01 2.30562716074427825896364652180637e-01
            8.78020618435216948505228629073827e-01 3.19573370182421767626834707698436e-01
            8.41838304449971652765327689849073e-01 4.05407960563071323445427651677164e-01
            7.97289423183083378887658909661695e-01 4.87213424494336078129919087587041e-01
            7.44816721431022510380159928899957e-01 5.64176742522992102912837708572624e-01
            6.84941696478169714801254031044664e-01 6.35533018617222444923697821650421e-01
            6.18259413222510767482731353084091e-01 7.00573082047025841312404281779891e-01
            5.45432590153336338545386752230115e-01 7.58650535441539597414362106064800e-01
            4.67185012957155865187530707771657e-01 8.09188178976518512897087020974141e-01
            3.84294341210371925843247709053685e-01 8.51683746845504963118855812354013e-01
            2.97584379649028785141950947945588e-01 8.85714899003067879235118198266719e-01
            2.07916890827238437511326196727168e-01 9.10943418569916563143351595499553e-01
            1.16183030533752368329558635196008e-01 9.27118573184199101788749430852477e-01
            2.32944910853650245796675477549798e-02 9.34079606892360025938160106306896e-01
            -6.98255594809261970201674785130308e-02 9.31757337814029584777131276496220e-01
            -1.62251652266622720111044486657192e-01 9.20174845702632082655725298536709e-01
            -2.53065215237423979388609041052405e-01 8.99447242568427896003413479775190e-01
            -3.41363702404789637334658891631989e-01 8.69780528643637973473801139334682e-01
            -4.26269563733459810883630325406557e-01 8.31469545059587700208680871583056e-01
            -5.06938966627962672717444547743071e-01 7.84895043583080154192543886892963e-01
            -5.82570182320053975288942638144363e-01 7.30519902534278009476054194237804e-01
            -6.52411553809410516002742497221334e-01 6.68884526494000097862624443223467e-01
            -7.15768966168594089616306064272067e-01 6.00601475520210481562344284611754e-01
            -7.72012744969045261456130901933648e-01 5.26349377250958316842854856076883e-01
            -8.20583914268448344486728274205234e-01 4.46866182398023781274787324946374e-01
            -8.60999751964774850954142948467052e-01 3.62941830661206887853609259764198e-01
            -8.92858587305407902512399687111611e-01 2.75410399952694451286561161396094e-01
            -9.15843792871539497113531069771852e-01 1.85141816956042121189440763373568e-01
            -9.29726931363707986832878304994665e-01 9.30332114039655183601595922482375e-02
            -9.34370025914311952419666340574622e-01 1.14427326145519150615272146553603e-16
            -9.29726931363707986832878304994665e-01 -9.30332114039652824377668594024726e-02
            -9.15843792871539608135833532287506e-01 -1.85141816956041871389260222713347e-01
            -8.92858587305408124557004612142919e-01 -2.75410399952693840663897617559996e-01
            -8.60999751964774739931840485951398e-01 -3.62941830661207054387062953537679e-01
            -8.20583914268448455509030736720888e-01 -4.46866182398023559230182399915066e-01
            -7.72012744969045483500735826964956e-01 -5.26349377250958316842854856076883e-01
            -7.15768966168594311660910989303375e-01 -6.00601475520210370540041822096100e-01
            -6.52411553809410738047347422252642e-01 -6.68884526493999986840321980707813e-01
            -5.82570182320054197333547563175671e-01 -7.30519902534277787431449269206496e-01
            -5.06938966627962561695142085227417e-01 -7.84895043583080154192543886892963e-01
            -4.26269563733460365995142637984827e-01 -8.31469545059587367141773484036094e-01
            -3.41363702404790414490776129241567e-01 -8.69780528643637640406893751787720e-01
            -2.53065215237423590810550422247616e-01 -8.99447242568428007025715942290844e-01
            -1.62251652266622747866620102286106e-01 -9.20174845702632082655725298536709e-01
            -6.98255594809266272315895207611902e-02 -9.31757337814029584777131276496220e-01
            2.32944910853647955961687188164433e-02 -9.34079606892360025938160106306896e-01
            1.16183030533751729951319475730998e-01 -9.27118573184199212811051893368131e-01
            2.07916890827238215466721271695860e-01 -9.10943418569916563143351595499553e-01
            2.97584379649028951675404641719069e-01 -8.85714899003067768212815735751064e-01
            3.84294341210371537265189090248896e-01 -8.51683746845505185163460737385321e-01
            4.67185012957156087232135632802965e-01 -8.09188178976518401874784558458487e-01
            5.45432590153335894456176902167499e-01 -7.58650535441539819458967031096108e-01
            6.18259413222510101348916577990167e-01 -7.00573082047026285401614131842507e-01
            6.84941696478169936845858956075972e-01 -6.35533018617222222879092896619113e-01
            7.44816721431022510380159928899957e-01 -5.64176742522992213935140171088278e-01
            7.97289423183083489909961372177349e-01 -4.87213424494335967107616625071387e-01
            8.41838304449971541743025227333419e-01 -4.05407960563071545490032576708472e-01
            8.78020618435216615438321241526864e-01 -3.19573370182422433760649482792360e-01
            9.05476769046834606413654000789393e-01 -2.30562716074428131207696424098685e-01
            9.23933884724843834668206454807660e-01 -1.39260626109359852975444482581224e-01
            9.33208530361422927690284723212244e-01 -4.65745014765078443885748527009127e-02
            8.97761938841069806471750780474395e-01 4.78486589868959907856371671641682e-02
            8.87589937346531243633762642275542e-01 1.43003832535012392890294563585485e-01
            8.67361187198912642060122379916720e-01 2.36538715519074960180745392790413e-01
            8.37304888220385179486981996888062e-01 3.27393520340231336529512873312342e-01
            7.97761590288262989467682473332388e-01 4.14538825756119777565800177399069e-01
            7.49179334768817484224712188733974e-01 4.96987240634881033418679407986929e-01
            6.92108578029568155542960994353052e-01 5.73804591491223869859084061317844e-01
            6.27195954548687928387096235383069e-01 6.44120507045289780734265150385909e-01
            5.55176950287983639320543716166867e-01 7.07138279877037145837448406382464e-01
            4.76867569343062958076018276187824e-01 7.62143893439657604815806735132355e-01
            3.93155088290872811729315117190708e-01 8.08514112152358910279303927381989e-01
            3.04988002991544715492011619062396e-01 8.45723542908526693118176353891613e-01
            2.13365281751299706858304716661223e-01 8.73350587989559667967398581822636e-01
            1.19325046612372046017647164717346e-01 8.91082221935482365893221867736429e-01
            2.39328110154564295541934626498914e-02 8.98717538248486436103235064365435e-01
            -7.17305928933301695238355932815466e-02 8.96170025743827425301901712373365e-01
            -1.66581260522544905011699256647262e-01 8.83468548756118021714200949645601e-01
            -2.59544495907544470192362950911047e-01 8.60757020094881308835965683101676e-01
            -3.49566988445193349566153528940049e-01 8.28292770454915339151114039850654e-01
            -4.35628747323876686081689513230231e-01 7.86443632756697375008059225365287e-01
            -5.16754658426965218787074718420627e-01 7.35683774452414951383616426028311e-01
            -5.92025532765391382383768359431997e-01 6.76588325019265690585257289058063e-01
            -6.60588521256185723373732798791025e-01 6.09826859512671015650653316697571e-01
            -7.21666777843367635014715233410243e-01 5.36155812013348165301351855305256e-01
            -7.74568261474170460800792170630302e-01 4.56409904926922238566078249277780e-01
            -8.18693577200697686357955262792530e-01 3.71492691245529471633091134208371e-01
            -8.53542767564186233286704919009935e-01 2.82366316931376759580274438121705e-01
            -8.78720977312787310253838768403511e-01 1.90040619418536421703080918632622e-01
            -8.93942927269347431540325032983674e-01 9.55616857513058998163657520308334e-02
            -8.99036146658476198467724316287786e-01 1.10100173932307330544194570725843e-16
            -8.93942927269347542562627495499328e-01 -9.55616857513052891937022081947362e-02
            -8.78720977312787310253838768403511e-01 -1.90040619418536615992110228035017e-01
            -8.53542767564186344309007381525589e-01 -2.82366316931376537535669513090397e-01
            -8.18693577200698019424862650339492e-01 -3.71492691245528861010427590372274e-01
            -7.74568261474170571823094633145956e-01 -4.56409904926922072032624555504299e-01
            -7.21666777843367523992412770894589e-01 -5.36155812013348276323654317820910e-01
            -6.60588521256186167462942648853641e-01 -6.09826859512670571561443466634955e-01
            -5.92025532765391604428373284463305e-01 -6.76588325019265690585257289058063e-01
            -5.16754658426964996742469793389319e-01 -7.35683774452415062405918888543965e-01
            -4.35628747323876519548235819456750e-01 -7.86443632756697486030361687880941e-01
            -3.49566988445193960188817072776146e-01 -8.28292770454915117106509114819346e-01
            -2.59544495907544470192362950911047e-01 -8.60757020094881308835965683101676e-01
            -1.66581260522544738478245562873781e-01 -8.83468548756118021714200949645601e-01
            -7.17305928933309883133162543344952e-02 -8.96170025743827425301901712373365e-01
            2.39328110154564087375117509282063e-02 -8.98717538248486436103235064365435e-01
            1.19325046612371823973042239686038e-01 -8.91082221935482476915524330252083e-01
            2.13365281751298901946611863422731e-01 -8.73350587989559890012003506853944e-01
            3.04988002991544548958557925288915e-01 -8.45723542908526804140478816407267e-01
            3.93155088290872645195861423417227e-01 -8.08514112152358910279303927381989e-01
            4.76867569343062736031413351156516e-01 -7.62143893439657715838109197648009e-01
            5.55176950287983417275938791135559e-01 -7.07138279877037145837448406382464e-01
            6.27195954548687817364793772867415e-01 -6.44120507045290002778870075417217e-01
            6.92108578029568488609868381900014e-01 -5.73804591491223536792176673770882e-01
            7.49179334768817262180107263702666e-01 -4.96987240634881421996738026791718e-01
            7.97761590288262878445380010816734e-01 -4.14538825756120166143858796203858e-01
            8.37304888220385290509284459403716e-01 -3.27393520340230947951454254507553e-01
            8.67361187198912531037819917401066e-01 -2.36538715519075459781106474110857e-01
            8.87589937346531354656065104791196e-01 -1.43003832535012143090114022925263e-01
            8.97761938841069806471750780474395e-01 -4.78486589868957895577139538545453e-02
            8.57584580105539839856021444575163e-01 4.90384605252103741857006014015496e-02
            8.46404653597279121868268703110516e-01 1.46476090248025131446141244850878e-01
            8.24190548020286906094611367734615e-01 2.42004180128147339257083103802870e-01
            7.91231858212855354572923261002870e-01 3.34377375422604761201483825061587e-01
            7.47958251100444226899810473696562e-01 4.22391450264138823555981616664212e-01
            6.94933864330216755078595269878861e-01 5.04899006587010035218554548919201e-01
            6.32849951874070892898771489853971e-01 5.80824432215505059851068381249206e-01
            5.62515872475980449607391165045556e-01 6.49177923113582355796324918628670e-01
            4.84848538423010511078103945692419e-01 7.09068386994194166383920219232095e-01
            4.00860462191421185185191689015483e-01 7.59715060069996228619970679574180e-01
            3.11646556798099161333936990558868e-01 8.00457685503341842547797568840906e-01
            2.18369861934931408509186212540953e-01 8.30765120863891759483976784395054e-01
            1.22246381967778400268187510846474e-01 8.50242262382472802073607454076409e-01
            2.45292334599293594676883145666579e-02 8.58635195732941003399218971026130e-01
            -7.35076911186980930246193111088360e-02 8.55834506193735911061537535715615e-01
            -1.70586330528067958711702090113249e-01 8.41876705036103567536542868765537e-01
            -2.65441116240834495965117412197287e-01 8.16943753543839523700853533227928e-01
            -3.56835471063533082869412282889243e-01 7.81360690869680296621879733720561e-01
            -4.43577929811397986270549154141918e-01 7.35591396652864770722146658954443e-01
            -5.24537671879156897070117793191457e-01 6.80232543638623399218090526119340e-01
            -5.98659263216988701827858676551841e-01 6.16005819136451027162593163666315e-01
            -6.64976415527439912445117897732416e-01 5.43748516722349584107121245324379e-01
            -7.22624583311130330720573056169087e-01 4.64402620836589341557498755719280e-01
            -7.70852234539489811204759917018237e-01 3.79002526575949238996088297426468e-01
            -8.09030648024069432011629032786004e-01 2.88661554771729111923406208006782e-01
            -8.36662109758739558351692267024191e-01 1.94557438150106426499874601176998e-01
            -8.53386401382914105973043206176953e-01 9.79169677849428266025455513954512e-02
            -8.58985496178764185160048327816185e-01 1.05195383840932458936845863734721e-16
            -8.53386401382914105973043206176953e-01 -9.79169677849426045579406263641431e-02
            -8.36662109758739669373994729539845e-01 -1.94557438150106232210845291774604e-01
            -8.09030648024069543033931495301658e-01 -2.88661554771728889878801282975473e-01
            -7.70852234539489811204759917018237e-01 -3.79002526575949350018390759942122e-01
            -7.22624583311130663787480443716049e-01 -4.64402620836588841957137674398837e-01
            -6.64976415527440023467420360248070e-01 -5.43748516722349362062516320293071e-01
            -5.98659263216988812850161139067495e-01 -6.16005819136450805117988238635007e-01
            -5.24537671879157341159327643254073e-01 -6.80232543638623066151183138572378e-01
            -4.43577929811398430359759004204534e-01 -7.35591396652864437655239271407481e-01
            -3.56835471063533138380563514147070e-01 -7.81360690869680296621879733720561e-01
            -2.65441116240834718009722337228595e-01 -8.16943753543839412678551070712274e-01
            -1.70586330528068319534185093289125e-01 -8.41876705036103456514240406249883e-01
            -7.35076911186986758917072393160197e-02 -8.55834506193735800039235073199961e-01
            2.45292334599291478314242453961924e-02 -8.58635195732941003399218971026130e-01
            1.22246381967778178223582585815166e-01 -8.50242262382472802073607454076409e-01
            2.18369861934930853397673899962683e-01 -8.30765120863891870506279246910708e-01
            3.11646556798099327867390684332349e-01 -8.00457685503341731525495106325252e-01
            4.00860462191420963140586763984174e-01 -7.59715060069996339642273142089834e-01
            4.84848538423010233522347789403284e-01 -7.09068386994194277406222681747749e-01
            5.62515872475980560629693627561210e-01 -6.49177923113582244774022456113016e-01
            6.32849951874071003921073952369625e-01 -5.80824432215504948828765918733552e-01
            6.94933864330216977123200194910169e-01 -5.04899006587009702151647161372239e-01
            7.47958251100444004855205548665253e-01 -4.22391450264139156622889004211174e-01
            7.91231858212855132528318335971562e-01 -3.34377375422605371824147368897684e-01
            8.24190548020286906094611367734615e-01 -2.42004180128147450279385566318524e-01
            8.46404653597279121868268703110516e-01 -1.46476090248025436757473016768927e-01
            8.57584580105539839856021444575163e-01 -4.90384605252108668471677788147645e-02
            8.13179500019916012831799889681861e-01 5.01551947874138565053314664510253e-02
            8.00852527709153827473187448049430e-01 1.49705282734654804288609852847003e-01
            7.76385447422436980602356015879195e-01 2.46985991196800896974039574160997e-01
            7.40149155156543780975653135101311e-01 3.40522643796059898413375321979402e-01
            6.92692956164982831523957429453731e-01 4.28897320225040734609223136430955e-01
            6.34736238050280343614417688513640e-01 5.10770350473264911350668171508005e-01
            5.67157565581229761164649971760809e-01 5.84900622858940844039921103103552e-01
            4.90981362546556665549246645241510e-01 6.50164398016940592306411872414174e-01
            4.07362382534520339749661843598005e-01 7.05572343642098087634906278253766e-01
            3.17568204045609148167272905993741e-01 7.50284531758485750962961446930422e-01
            2.22960015294568908439387655562314e-01 7.83623171171354160335909000423271e-01
            1.24971979984588407730505821291445e-01 8.05082882090741969172142944444204e-01
            2.50894968474632273913726976388716e-02 8.14338357173936100430466922261985e-01
            -7.51733174870444498250066089894972e-02 8.11249292853187031759887304360745e-01
            -1.74296580955909191645858413721726e-01 7.95862516194778435441037345299264e-01
            -2.70777685925633782026977769419318e-01 7.68411275048435760126608329301234e-01
            -3.63154077192300639431721265282249e-01 7.29311702247682602795464390510460e-01
            -4.50025422827615206866624930626131e-01 6.79156507460268676901193884987151e-01
            -5.30074841783520045446209678630112e-01 6.18705992313780872571271629567491e-01
            -6.02088866466527705689770755270729e-01 5.48876524997977788267178311798489e-01
            -6.64975837669499192372768447967246e-01 4.70726649057127133346511982381344e-01
            -7.17782453012446031159754511463689e-01 3.85441036948895310310092554573203e-01
            -7.59708218034868654200408855103888e-01 2.94312531617477057821474772936199e-01
            -7.90117580875798752870764474209864e-01 1.98722548312413260784836666061892e-01
            -8.08549566592165702694217088719597e-01 1.00120133741545394578942307362013e-01
            -8.14724765069040901543928612227319e-01 9.97750075727880259255456975804072e-17
            -8.08549566592165702694217088719597e-01 -1.00120133741545200289912997959618e-01
            -7.90117580875798752870764474209864e-01 -1.98722548312413399562714744206460e-01
            -7.59708218034868654200408855103888e-01 -2.94312531617476891288021079162718e-01
            -7.17782453012446031159754511463689e-01 -3.85441036948895088265487629541894e-01
            -6.64975837669499303395070910482900e-01 -4.70726649057126966813058288607863e-01
            -6.02088866466527816712073217786383e-01 -5.48876524997977566222573386767181e-01
            -5.30074841783519823401604753598804e-01 -6.18705992313780872571271629567491e-01
            -4.50025422827615373400078624399612e-01 -6.79156507460268565878891422471497e-01
            -3.63154077192300528409418802766595e-01 -7.29311702247682713817766853026114e-01
            -2.70777685925633948560431463192799e-01 -7.68411275048435649104305866785580e-01
            -1.74296580955909552468341416897601e-01 -7.95862516194778435441037345299264e-01
            -7.51733174870444775805822246184107e-02 -8.11249292853187031759887304360745e-01
            2.50894968474630296328964362828629e-02 -8.14338357173936100430466922261985e-01
            1.24971979984588560386171707250469e-01 -8.05082882090741969172142944444204e-01
            2.22960015294568908439387655562314e-01 -7.83623171171354160335909000423271e-01
            3.17568204045609481234180293540703e-01 -7.50284531758485639940658984414767e-01
            4.07362382534520561794266768629313e-01 -7.05572343642097976612603815738112e-01
            4.90981362546556387993490488952375e-01 -6.50164398016940703328714334929828e-01
            5.67157565581229872186952434276463e-01 -5.84900622858940621995316178072244e-01
            6.34736238050280232592115225997986e-01 -5.10770350473265022372970634023659e-01
            6.92692956164982498457050041906768e-01 -4.28897320225041067676130523977918e-01
            7.40149155156543891997955597616965e-01 -3.40522643796059898413375321979402e-01
            7.76385447422436980602356015879195e-01 -2.46985991196801091263068883563392e-01
            8.00852527709153827473187448049430e-01 -1.49705282734654582244004927815695e-01
            8.13179500019916012831799889681861e-01 -5.01551947874139120164826977088524e-02
            7.64913744838197073860897035046946e-01 5.12049504750933734409379383123451e-02
            7.51263840940416427471859606157523e-01 1.52701097870984264792681983635703e-01
            7.24207616003283205508012088102987e-01 2.51472290557811284372746740700677e-01
            6.84227889001774558508373047516216e-01 3.45755954262145004385331503726775e-01
            6.32038099111369544580441015568795e-01 4.33869594771560174173430368682602e-01
            5.68569574369061636609501420025481e-01 5.14240822083715243273616124497494e-01
            4.94954912102474553492470477067400e-01 5.85435409743195189768982800160302e-01
            4.12507767703719274710039144338225e-01 6.46182888646585573688696513272589e-01
            3.22699412417800646224463889666367e-01 6.95399218593720669367996833898360e-01
            2.27132478472395482604895278200274e-01 7.32206133010737669764012025552802e-01
            1.27512360067781826966637481746147e-01 7.55946811637892679414107988122851e-01
            2.56167805769350123701322274882841e-02 7.66197601502657033023524490999989e-01
            -7.67359309701801522995978643848503e-02 7.62775577017048234118590244179359e-01
            -1.77719288011224330059434350914671e-01 7.45741804289081433587682568031596e-01
            -2.75531240147460443346005831699586e-01 7.15400251396624553557046510832151e-01
            -3.68426330775808552608907575631747e-01 6.72292364069848491503478271624772e-01
            -4.54746844803280703128933737389161e-01 6.17187403579344096016257026349194e-01
            -5.32952390612085546983678341348423e-01 5.51068719250525251851513530709781e-01
            -6.01647388384541126349347450741334e-01 4.75116200571620406201134301227285e-01
            -6.59605974257983285191642153222347e-01 3.90685222037803592254334716926678e-01
            -7.05793875894436206763771224359516e-01 2.99282456461217150067710690564127e-01
            -7.39386869094985632600014469062444e-01 2.02538988358947236179119499865919e-01
            -7.59785486100134854758891833625967e-01 1.02181207211174254756436141633458e-01
            -7.66625713106174888622490470879711e-01 -2.46565634614108600021462686184788e-16
            -7.59785486100134965781194296141621e-01 -1.02181207211173713522711636869644e-01
            -7.39386869094985632600014469062444e-01 -2.02538988358947069645665806092438e-01
            -7.05793875894436317786073686875170e-01 -2.99282456461216983534256996790646e-01
            -6.59605974257983285191642153222347e-01 -3.90685222037803425720881023153197e-01
            -6.01647388384541237371649913256988e-01 -4.75116200571620239667680607453804e-01
            -5.32952390612085658005980803864077e-01 -5.51068719250525029806908605678473e-01
            -4.54746844803280536595480043615680e-01 -6.17187403579344096016257026349194e-01
            -3.68426330775808441586605113116093e-01 -6.72292364069848491503478271624772e-01
            -2.75531240147460776412913219246548e-01 -7.15400251396624442534744048316497e-01
            -1.77719288011224857415371047864028e-01 -7.45741804289081322565380105515942e-01
            -7.67359309701805131220808675607259e-02 -7.62775577017048234118590244179359e-01
            2.56167805769346550170961762660227e-02 -7.66197601502657033023524490999989e-01
            1.27512360067781632677608172343753e-01 -7.55946811637892679414107988122851e-01
            2.27132478472395149537987890653312e-01 -7.32206133010737780786314488068456e-01
            3.22699412417800479691010195892886e-01 -6.95399218593720780390299296414014e-01
            4.12507767703719052665434219306917e-01 -6.46182888646585573688696513272589e-01
            4.94954912102474442470168014551746e-01 -5.85435409743195300791285262675956e-01
            5.68569574369061525587198957509827e-01 -5.14240822083715243273616124497494e-01
            6.32038099111369544580441015568795e-01 -4.33869594771560174173430368682602e-01
            6.84227889001774114419163197453599e-01 -3.45755954262145615007995047562872e-01
            7.24207616003283205508012088102987e-01 -2.51472290557811228861595509442850e-01
            7.51263840940416427471859606157523e-01 -1.52701097870984181525955136748962e-01
            7.64913744838197073860897035046946e-01 -5.12049504750939216135563469833869e-02
            7.13068891298475615592167287104530e-01 5.21899159867123124678656154173950e-02
            6.97871065875161344926880246930523e-01 1.55457410510414312243554491033137e-01
            6.67799330291722892383177168085240e-01 2.55411600226504331700994043785613e-01
            6.23494611383070829191410666680895e-01 3.49922135116672416987881888417178e-01
            5.65901187313095577202659569593379e-01 4.36974687214220669506659078251687e-01
            4.96246561925012819038727229781216e-01 5.14713882507497277885022413101979e-01
            4.16015302628076122370970324482187e-01 5.81482845015747207284562136919703e-01
            3.26917399420681542565603194816504e-01 6.35858510224055928361508449597750e-01
            2.30851819422350057475767926007393e-01 6.76681955232831588986641691008117e-01
            1.29866033686468346219911040861916e-01 7.03083099187345239577950906095793e-01
            2.61123789095025655992987623221779e-02 7.14499247540558268809718356351368e-01
            -7.81978158889067020975716104658204e-02 7.10687084910470168175322669412708e-01
            -1.80841360004799528438113043193880e-01 6.91727860925054671703549047379056e-01
            -2.79630584499956758026684155993280e-01 6.58025658527499834882235063560074e-01
            -3.72459968567198485001057406407199e-01 6.10298781649823429695800314220833e-01
            -4.57351015050886822166376077802852e-01 5.49564445811645319039939749927726e-01
            -5.32494418678831293867403928743443e-01 4.77117097937425516107623479911126e-01
            -5.96288628262938491531031104386784e-01 3.94500827467624437527859981855727e-01
            -6.47373980982254848548507197847357e-01 3.03476456773049296788968831606326e-01
            -6.84661681235413932533617753506405e-01 2.05984012283074169324947888526367e-01
            -7.07357006428569135003669998695841e-01 1.04101376190473660088287033431698e-01
            -7.14976245107721952720680747006554e-01 8.75593370037565166183682728600294e-17
            -7.07357006428569135003669998695841e-01 -1.04101376190473479677045531843760e-01
            -6.84661681235414043555920216022059e-01 -2.05984012283074002791494194752886e-01
            -6.47373980982254959570809660363011e-01 -3.03476456773049130255515137832845e-01
            -5.96288628262938824597938491933746e-01 -3.94500827467624048949801363050938e-01
            -5.32494418678831404889706391259097e-01 -4.77117097937425349574169786137645e-01
            -4.57351015050886655632922384029371e-01 -5.49564445811645430062242212443380e-01
            -3.72459968567198929090267256469815e-01 -6.10298781649823207651195389189525e-01
            -2.79630584499956758026684155993280e-01 -6.58025658527499834882235063560074e-01
            -1.80841360004799556193688658822794e-01 -6.91727860925054671703549047379056e-01
            -7.81978158889070351644789980127825e-02 -7.10687084910470168175322669412708e-01
            2.61123789095022290629444228216016e-02 -7.14499247540558268809718356351368e-01
            1.29866033686467846619549959541473e-01 -7.03083099187345350600253368611448e-01
            2.30851819422350029720192310378479e-01 -6.76681955232831588986641691008117e-01
            3.26917399420681376032149501043023e-01 -6.35858510224056039383810912113404e-01
            4.16015302628075955837516630708706e-01 -5.81482845015747318306864599435357e-01
            4.96246561925012541482971073492081e-01 -5.14713882507497610951929800648941e-01
            5.65901187313095688224962032109033e-01 -4.36974687214220558484356615736033e-01
            6.23494611383070829191410666680895e-01 -3.49922135116672472499033119675005e-01
            6.67799330291722892383177168085240e-01 -2.55411600226504442723296506301267e-01
            6.97871065875161455949182709446177e-01 -1.55457410510413951421071487857262e-01
            7.13068891298475615592167287104530e-01 -5.21899159867127288014998498510977e-02
            6.57867696200895135660857704351656e-01 5.31085709137692763004423568418133e-02
            6.40829268431289178487020308239153e-01 1.57950228651289631409682101548242e-01
            6.07193699221436178348199064203072e-01 2.58701058434178399192404640416498e-01
            5.57832132145919645793696872715373e-01 3.52751666693033982813432203329285e-01
            4.94023005863557462813417942015803e-01 4.37666192076463067550662344729062e-01
            4.17418943227671757068009128488484e-01 5.11245392980582025188596162479371e-01
            3.30003949222269110652661083804560e-01 5.71583606751350115082743741368176e-01
            2.34042026275106951338500493875472e-01 6.17118105346308953862433099857299e-01
            1.32018537784037881532839264764334e-01 6.46669569170020941406562542397296e-01
            2.65758385105087958921732393946513e-02 6.59472630832121264887746292515658e-01
            -7.95551610207970855137560306502564e-02 6.55195697760700412892731492320308e-01
            -1.83625723670066937076583712951106e-01 6.33949540275738576688979719619965e-01
            -2.82940476530436080260244580131257e-01 5.96284422696003124642061266058590e-01
            -3.74927219670458999889461892962572e-01 5.43175851782233931608345756103517e-01
            -4.57203544761222158143709748401307e-01 4.75999311624448862012570771184983e-01
            -5.27638538200638995689928378851619e-01 3.96494639326522180233780545677291e-01
            -5.84407970656428243927393850754015e-01 3.06720964139087393096616551702027e-01
            -6.26041543647595344346257206780137e-01 2.09003377093557929367051428926061e-01
            -6.51460969502778430850753466074821e-01 1.05872712365726831529322282676731e-01
            -6.60007898444538332327624630124774e-01 8.08276560242075250792400675874093e-17
            -6.51460969502778541873055928590475e-01 -1.05872712365726664995868588903249e-01
            -6.26041543647595344346257206780137e-01 -2.09003377093557790589173350781493e-01
            -5.84407970656428243927393850754015e-01 -3.06720964139087226563162857928546e-01
            -5.27638538200639106712230841367273e-01 -3.96494639326522013700326851903810e-01
            -4.57203544761222269166012210916961e-01 -4.75999311624448695479117077411502e-01
            -3.74927219670459166422915586736053e-01 -5.43175851782233931608345756103517e-01
            -2.82940476530435969237942117615603e-01 -5.96284422696003235664363728574244e-01
            -1.83625723670066937076583712951106e-01 -6.33949540275738576688979719619965e-01
            -7.95551610207973908250878025683051e-02 -6.55195697760700412892731492320308e-01
            2.65758385105084905808414674766027e-02 -6.59472630832121375910048755031312e-01
            1.32018537784037714999385570990853e-01 -6.46669569170021052428865004912950e-01
            2.34042026275106812560622415730904e-01 -6.17118105346309064884735562372953e-01
            3.30003949222268722074602464999771e-01 -5.71583606751350337127348666399485e-01
            4.17418943227671312978799278425868e-01 -5.11245392980582358255503550026333e-01
            4.94023005863557296279964248242322e-01 -4.37666192076463289595267269760370e-01
            5.57832132145919423749091947684065e-01 -3.52751666693034204858037128360593e-01
            6.07193699221436067325896601687418e-01 -2.58701058434178510214707102932152e-01
            6.40829268431289178487020308239153e-01 -1.57950228651289686920833332806069e-01
            6.57867696200895135660857704351656e-01 -5.31085709137691999726094138623012e-02
            5.99489027963163167989080193365226e-01 5.39549890853567928883371962456295e-02
            5.80220957343211884982281389966374e-01 1.60130809512554150852992052023183e-01
            5.42304107746855890148651724302908e-01 2.61159893965949019278838250102126e-01
            4.86957157918209759817074200327625e-01 3.53795084544201832166265830892371e-01
            4.15959004364388262864338230428984e-01 4.35059010001638768461162953826715e-01
            3.31591586158086537583500330583774e-01 5.02339780909877187120571306877537e-01
            2.36566541538197977478930056349782e-01 5.53474937933123745104069257649826e-01
            1.33938053625673042512644883572648e-01 5.86820955050503911820669600274414e-01
            2.70046864650213720715488108226054e-02 6.01306063834670667667126053856919e-01
            -8.07966335381461175924044937346480e-02 5.96464700970913863642408614396118e-01
            -1.86001083259706073702588469132024e-01 5.72452471845161237062882264581276e-01
            -2.85227305123098018313498869247269e-01 5.30041149258842270164393539744196e-01
            -3.75286086714025246546810876679956e-01 4.70593868016033922696550462205778e-01
            -4.53282864691542941582014236701070e-01 3.96021312649265821992372593740583e-01
            -5.16710758435491079865187202813104e-01 3.08720306446528924837480190035421e-01
            -5.63531143252294475232133663666900e-01 2.11496775578686346808154894461040e-01
            -5.92239173449999878329208513605408e-01 1.07475564323618197337673052516038e-01
            -6.01912149317007205695517768617719e-01 7.37129787028976574760414564316049e-17
            -5.92239173449999878329208513605408e-01 -1.07475564323618044682007166557014e-01
            -5.63531143252294475232133663666900e-01 -2.11496775578686208030276816316473e-01
            -5.16710758435491301909792127844412e-01 -3.08720306446528591770572802488459e-01
            -4.53282864691543052604316699216724e-01 -3.96021312649265710970070131224929e-01
            -3.75286086714025357569113339195610e-01 -4.70593868016033811674247999690124e-01
            -2.85227305123098129335801331762923e-01 -5.30041149258842159142091077228542e-01
            -1.86001083259706212480466547276592e-01 -5.72452471845161126040579802065622e-01
            -8.07966335381462702480703796936723e-02 -5.96464700970913863642408614396118e-01
            2.70046864650212263547768287708095e-02 -6.01306063834670778689428516372573e-01
            1.33938053625672903734766805428080e-01 -5.86820955050503911820669600274414e-01
            2.36566541538197838701051978205214e-01 -5.53474937933123856126371720165480e-01
            3.31591586158086371050046636810293e-01 -5.02339780909877298142873769393191e-01
            4.15959004364388151842035767913330e-01 -4.35059010001638879483465416342369e-01
            4.86957157918209704305922969069798e-01 -3.53795084544201998699719524665852e-01
            5.42304107746855779126349261787254e-01 -2.61159893965949185812291943875607e-01
            5.80220957343211884982281389966374e-01 -1.60130809512554261875294514538837e-01
            5.99489027963163056966777730849572e-01 -5.39549890853569455440030822046538e-02
            5.38075857408108815249647705059033e-01 5.47169666568197918254945477656292e-02
            5.16046968584592091744411845866125e-01 1.61910780926558584003061014300329e-01
            4.72891056234277851189062857883982e-01 2.62475948801455083447820015862817e-01
            4.10374928479392497848721177433617e-01 3.52295320492805541512382205837639e-01
            3.31058002935553985501826446125051e-01 4.27691680370237914399211831550929e-01
            2.38187523853870292134260466809792e-01 4.85578292601674066375494476233143e-01
            1.35565619559763234081017913013056e-01 5.23585272480970864705795975169167e-01
            2.73936428725957657748235618555555e-02 5.40156609786239361170601114281453e-01
            -8.18998327723925029220097826510028e-02 5.34613872021152403135602071415633e-01
            -1.87840319640856928673500192417123e-01 5.07183979521056760297881282895105e-01
            -2.86090601752924444944881088304101e-01 4.58989915307781659592478717968334e-01
            -3.72628301015008600582945064161322e-01 3.92004750032781068558307424609666e-01
            -4.43910553851572242667344880828750e-01 3.08970864232835651375097540949355e-01
            -4.97019056456176999692075924031087e-01 2.13287674948663047436170359105745e-01
            -5.29779540492206324486801349848974e-01 1.08872463191854451647344603770762e-01
            -5.40850787894031848068721046729479e-01 6.62351186210750164667211195957211e-17
            -5.29779540492206324486801349848974e-01 -1.08872463191854312869466525626194e-01
            -4.97019056456177055203227155288914e-01 -2.13287674948662908658292280961177e-01
            -4.43910553851572409200798574602231e-01 -3.08970864232835540352795078433701e-01
            -3.72628301015008878138701220450457e-01 -3.92004750032780791002551268320531e-01
            -2.86090601752924611478334782077582e-01 -4.58989915307781604081327486710506e-01
            -1.87840319640857178473680733077344e-01 -5.07183979521056649275578820379451e-01
            -8.18998327723926416998878607955703e-02 -5.34613872021152403135602071415633e-01
            2.73936428725958698582321204639811e-02 -5.40156609786239361170601114281453e-01
            1.35565619559762984280837372352835e-01 -5.23585272480970975728098437684821e-01
            2.38187523853869959067353079262830e-01 -4.85578292601674232908948170006624e-01
            3.31058002935553763457221521093743e-01 -4.27691680370238080932665525324410e-01
            4.10374928479392553359872408691444e-01 -3.52295320492805374978928512064158e-01
            4.72891056234277740166760395368328e-01 -2.62475948801455361003576172151952e-01
            5.16046968584591980722109383350471e-01 -1.61910780926558917069968401847291e-01
            5.38075857408108815249647705059033e-01 -5.47169666568196808031920852499752e-02
            4.73737826919700066863327947430662e-01 5.53720105851480404179909555750783e-02
            4.48198498047993054704818405298283e-01 1.63130912332288047217332405125489e-01
            3.98496672134661555908508034917759e-01 2.62095384370731598888681901371456e-01
            3.27311787479531379752017983264523e-01 3.46930226396887420037273841444403e-01
            2.38481439639881387382303046251764e-01 4.13061970118444921062916819209931e-01
            1.36794495660625459176884533007978e-01 4.56925436113811256344519051708630e-01
            2.77329250123696628704816902200037e-02 4.76155933577541101708874293763074e-01
            -8.28237348017027558144675936091517e-02 4.69716741413736149635127503643162e-01
            -1.88915345634490972059893465484492e-01 4.37954998138669782115073303430108e-01
            -2.84822481285208983781132019430515e-01 3.82582987553521824963809194741771e-01
            -3.65374763246290257256987388245761e-01 3.06585829081447991395492636002018e-01
            -4.26229597147031180615073253648006e-01 2.14060549206809558331343623649445e-01
            -4.64106283140156783417751285014674e-01 1.09995209716923919573972057150968e-01
            -4.76962879279762663742303629987873e-01 5.84111063422066794539109473701211e-17
            -4.64106283140156783417751285014674e-01 -1.09995209716923794673881786820857e-01
            -4.26229597147031236126224484905833e-01 -2.14060549206809447309041161133791e-01
            -3.65374763246290201745836156987934e-01 -3.06585829081448046906643867259845e-01
            -2.84822481285209094803434481946169e-01 -3.82582987553521713941506732226117e-01
            -1.88915345634490999815469081113406e-01 -4.37954998138669782115073303430108e-01
            -8.28237348017028668367700561248057e-02 -4.69716741413736094123976272385335e-01
            2.77329250123693332730212546266557e-02 -4.76155933577541157220025525020901e-01
            1.36794495660625459176884533007978e-01 -4.56925436113811256344519051708630e-01
            2.38481439639881387382303046251764e-01 -4.13061970118444921062916819209931e-01
            3.27311787479531435263169214522350e-01 -3.46930226396887364526122610186576e-01
            3.98496672134661333863903109886451e-01 -2.62095384370731931955589288918418e-01
            4.48198498047992888171364711524802e-01 -1.63130912332288408039815408301365e-01
            4.73737826919700066863327947430662e-01 -5.53720105851479502123702047811094e-02
            4.06547427651715587160197173943743e-01 5.58786577557876668054248625594482e-02
            3.76395664773515770118450518566533e-01 1.63491708849465927633204387348087e-01
            3.18328357334655198673800668984768e-01 2.58979327822580152052012181229657e-01
            2.36652091887618459820075145216833e-01 3.35259634802684725052301928371890e-01
            1.37424423396560302368385464433231e-01 3.86675268380249959054850705797435e-01
            2.80046140970841191120133117919977e-02 4.09412966223700325318901604987332e-01
            -8.34921693173881346305975625909923e-02 4.01786377302033481662135727674467e-01
            -1.88796720484849023247164723215974e-01 3.64361130826246548686242476833286e-01
            -2.80099082581475034015028313660878e-01 2.99912886118338384289216946854140e-01
            -3.50627777091073011828115113530657e-01 2.13221474657193404977917339238047e-01
            -3.95152013389175049695722918841057e-01 1.10716401844065712167797244092071e-01
            -4.10369632554378194200239704514388e-01 5.02557856974994755424034964007478e-17
            -3.95152013389174994184571687583230e-01 -1.10716401844065781556736283164355e-01
            -3.50627777091073233872720038561965e-01 -2.13221474657193127422161182948912e-01
            -2.80099082581474978503877082403051e-01 -2.99912886118338439800368178111967e-01
            -1.88796720484849273047345263876196e-01 -3.64361130826246437663940014317632e-01
            -8.34921693173880513638707157042518e-02 -4.01786377302033481662135727674467e-01
            2.80046140970840219674986570908004e-02 -4.09412966223700325318901604987332e-01
            1.37424423396560219101658617546491e-01 -3.86675268380249959054850705797435e-01
            2.36652091887618404308923913959006e-01 -3.35259634802684836074604390887544e-01
            3.18328357334655087651498206469114e-01 -2.58979327822580263074314643745311e-01
            3.76395664773515659096148056050879e-01 -1.63491708849466094166658081121568e-01
            4.06547427651715587160197173943743e-01 -5.58786577557875627220163039510226e-02
            3.36524700965150747045129264733987e-01 5.61560404728186982059590093285806e-02
            3.00057027896828809598872567221406e-01 1.62382743082479880092350299491955e-01
            2.31073519991387338334831724750984e-01 2.51012755851289126596270762092900e-01
            1.37049610719792075430589761708688e-01 3.12441641659402413733204184609349e-01
            2.81742495828915667788194809872948e-02 3.40012627562139124748341600934509e-01
            -8.37542286648404743498730340434122e-02 3.30737969429012790278932243381860e-01
            -1.86606636655979069017163851640362e-01 2.85622720379896222198112809564918e-01
            -2.69237320065140617320054161609733e-01 2.09555817684477563300760039055604e-01
            -3.22691962197785564558927262623911e-01 1.10780290549410867506630040679738e-01
            -3.41177923144609374084268438309664e-01 4.17822451518787558719241583035432e-17
            -3.22691962197785564558927262623911e-01 -1.10780290549410936895569079752022e-01
            -2.69237320065140783853507855383214e-01 -2.09555817684477424522881960911036e-01
            -1.86606636655979013506012620382535e-01 -2.85622720379896277709264040822745e-01
            -8.37542286648405576165998809301527e-02 -3.30737969429012734767781012124033e-01
            2.81742495828915563704786251264522e-02 -3.40012627562139124748341600934509e-01
            1.37049610719791770119257989790640e-01 -3.12441641659402524755506647125003e-01
            2.31073519991387393845982956008811e-01 -2.51012755851289126596270762092900e-01
            3.00057027896828698576570104705752e-01 -1.62382743082480074381379608894349e-01
            3.36524700965150747045129264733987e-01 -5.61560404728186426948077780707536e-02
            2.63594064565845109804342882853234e-01 5.60286480407418407967412576908828e-02
            2.18016256125511398433758358805790e-01 1.58398081871693297006942202642676e-01
            1.34741456385568530995655578408332e-01 2.33379048345630557559360340746935e-01
            2.81686347488580568487748223560629e-02 2.68006657178514240413846891897265e-01
            -8.32747997399428674381027803974575e-02 2.56293480221188307854873755786684e-01
            -1.80319264825902131343937639940123e-01 2.00264832180446522569283729353629e-01
            -2.46184890874369483038108796790766e-01 1.09608575306820915651329073625675e-01
            -2.69482912771137006480159925558837e-01 1.52676592455635419319246373027225e-16
            -2.46184890874369455282533181161853e-01 -1.09608575306820957284692497069045e-01
            -1.80319264825902270121815718084690e-01 -2.00264832180446411546981266837975e-01
            -8.32747997399429229492540116552846e-02 -2.56293480221188307854873755786684e-01
            2.81686347488579284792376000723380e-02 -2.68006657178514240413846891897265e-01
            1.34741456385568530995655578408332e-01 -2.33379048345630557559360340746935e-01
            2.18016256125511370678182743176876e-01 -1.58398081871693352518093433900503e-01
            2.63594064565845109804342882853234e-01 -5.60286480407417505911205068969139e-02
            1.87456184652248003530417008732911e-01 5.50421020790464662897356618032063e-02
            1.27940170527267749189803680565092e-01 1.47650827735951145625037383979361e-01
            2.78040562419275029404364119045567e-02 1.93381458837587644206124082302267e-01
            -8.11596494461509915252506175420422e-02 1.77714843126385357852115021159989e-01
            -1.64355739881757001441542342945468e-01 1.05625020395634053316236133923667e-01
            -1.95370044187070490693258761893958e-01 1.10687658477705240270908913226538e-16
            -1.64355739881757029197117958574381e-01 -1.05625020395634011682872710480297e-01
            -8.11596494461511580587043113155232e-02 -1.77714843126385274585388174273248e-01
            2.78040562419274543681790845539581e-02 -1.93381458837587671961699697931181e-01
            1.27940170527267665923076833678351e-01 -1.47650827735951228891764230866102e-01
            1.87456184652248003530417008732911e-01 -5.50421020790464871064173735248914e-02
            1.07140145842429229672276846940804e-01 5.15959748930508790842885957772523e-02
            2.64614307623948011305436978091166e-02 1.15935103218603841046530078529031e-01
            -7.41432813965409581724586018935952e-02 9.29727341754273961527132996707223e-02
            -1.18916590416566103627360462269280e-01 1.45630821819164510667796834088755e-17
            -7.41432813965409859280342175225087e-02 -9.29727341754273683971376840418088e-02
            2.64614307623946692915595235717774e-02 -1.15935103218603868802105694157945e-01
            1.07140145842429257427852462569717e-01 -5.15959748930508096953495567049686e-02
            2.00964394095705135845353339618669e-02 3.48080541086056086119704389147955e-02
            -4.01928788191410202301767640165053e-02 4.92220803943784971223879724644269e-18
            2.00964394095705135845353339618669e-02 -3.48080541086056086119704389147955e-02
            ];
        
    case   38
        
        % DEGREE.             :          38
        % CARDIN.             :         780
        % LEBESGUE CONST.     : 3.92581e+02
        % ABS.DET.VAND.MATRIX : Inf
        % CONDITIONING VAND.  : 8.83661e+03
        % POINTS OUT DISK     : 0.00000e+00
        
        pts=[
            9.99167799344582885368026836658828e-01 4.07885860615855716515554263423837e-02
            9.92518502491027687639757459692191e-01 1.22094316874159850017100836794270e-01
            9.79264158757421121492825477616861e-01 2.02587530152080974588102435518522e-01
            9.59492973614497368650688713387353e-01 2.81732556841429671035115234190016e-01
            9.33336521037366750874753051903099e-01 3.59002699847598638616119615107891e-01
            9.00968867902419145998749172576936e-01 4.33883739117558064890545210801065e-01
            8.62605415600980696133603942143964e-01 5.05877353689468289843489401391707e-01
            8.18501466578593572798183686245466e-01 5.74504437936463219216420839074999e-01
            7.68950525339362034316081917495467e-01 6.39308289935551443683436900755623e-01
            7.14282345221903591792056431586388e-01 6.99857650743561765516176365053980e-01
            6.54860733945284989587776180997025e-01 7.55749574354258268904516171460273e-01
            5.91081132528676667092781826795544e-01 8.06612109237530017225026313099079e-01
            5.23367983696611971389245354657760e-01 8.52106773615456614123786494019441e-01
            4.52171907282685803242117117406451e-01 8.91930808002693753522294173308183e-01
            3.77966701428906537429952550155576e-01 9.25819190020898075133004567760509e-01
            3.01246189537234365651841017097468e-01 9.53546398078927603947363422776107e-01
            2.22520933956314448387558968533995e-01 9.74927912181823619341969333618181e-01
            1.42314838273285337866269628648297e-01 9.89821441880932684220795181317953e-01
            6.11616608218428295384860859940090e-02 9.98127873193366821347183304169448e-01
            -2.03985373914053122468281742385443e-02 9.99791928189206480226403073174879e-01
            -1.01822986703835202670909154676337e-01 9.94802532857004040423021251626778e-01
            -1.82569820839361574016379563545343e-01 9.83192890799503005361259511118988e-01
            -2.62101682939102131886244251290918e-01 9.65040262269139970108255965897115e-01
            -3.39889301582616765173838757618796e-01 9.40465450013811543605868337181164e-01
            -4.15415013001886157528730336707667e-01 9.09631995354518552154843291646102e-01
            -4.88176206048281102756192240121891e-01 8.72745089844856214433832519716816e-01
            -5.57688666986829284510918114392553e-01 8.30050209755080703466489921993343e-01
            -6.23489801858733483364005678595277e-01 7.81831482468029914656426626606844e-01
            -6.85141714967844150940834424545756e-01 7.28409795658269132445639115758240e-01
            -7.42234123004269941148436373623554e-01 6.70140661837559492575167041650275e-01
            -7.94387085412112670113060630683322e-01 6.07411852477747427059284746064804e-01
            -8.41253532831181316531399261293700e-01 5.40640817455597444407544571731705e-01
            -8.82521576786321149121761209244141e-01 4.70271906992736909991492666449631e-01
            -9.17916585253759298446141201566206e-01 3.96773414578242555883491604618030e-01
            -9.47203010291910119100577958306530e-01 3.20634460552735478522379253263352e-01
            -9.70185955574064506912179695063969e-01 2.42361737093212237237338513295981e-01
            -9.86712473391288868995729899324942e-01 1.62476136260206072137179944547825e-01
            -9.96672582494193215474354019534076e-01 8.15092835470633686467678558074113e-02
            -1.00000000000000000000000000000000e+00 1.22464679914735320717376402945840e-16
            -9.96672582494193215474354019534076e-01 -8.15092835470631188465873151471897e-02
            -9.86712473391288980018032361840596e-01 -1.62476136260205406003365169453900e-01
            -9.70185955574064506912179695063969e-01 -2.42361737093212431526367822698376e-01
            -9.47203010291910119100577958306530e-01 -3.20634460552735256477774328232044e-01
            -9.17916585253759409468443664081860e-01 -3.96773414578242333838886679586722e-01
            -8.82521576786321260144063671759795e-01 -4.70271906992736687946887741418323e-01
            -8.41253532831181205509096798778046e-01 -5.40640817455597555429847034247359e-01
            -7.94387085412112892157665555714630e-01 -6.07411852477747205014679821033496e-01
            -7.42234123004269830126133911107900e-01 -6.70140661837559603597469504165929e-01
            -6.85141714967844372985439349577064e-01 -7.28409795658268910401034190726932e-01
            -6.23489801858733705408610603626585e-01 -7.81831482468029692611821701575536e-01
            -5.57688666986829506555523039423861e-01 -8.30050209755080481421884996962035e-01
            -4.88176206048281269289645933895372e-01 -8.72745089844856103411530057201162e-01
            -4.15415013001886379573335261738976e-01 -9.09631995354518441132540829130448e-01
            -3.39889301582616598640385063845315e-01 -9.40465450013811543605868337181164e-01
            -2.62101682939102798020059026384843e-01 -9.65040262269139748063651040865807e-01
            -1.82569820839361379727350254142948e-01 -9.83192890799503005361259511118988e-01
            -1.01822986703835882682511737584719e-01 -9.94802532857003929400718789111124e-01
            -2.03985373914048924437469878512275e-02 -9.99791928189206480226403073174879e-01
            6.11616608218423576937006203024794e-02 -9.98127873193366932369485766685102e-01
            1.42314838273284866021484162956767e-01 -9.89821441880932795243097643833607e-01
            2.22520933956314226342954043502687e-01 -9.74927912181823619341969333618181e-01
            3.01246189537234143607236092066159e-01 -9.53546398078927714969665885291761e-01
            3.77966701428905704762684081288171e-01 -9.25819190020898408199911955307471e-01
            4.52171907282685747730965886148624e-01 -8.91930808002693753522294173308183e-01
            5.23367983696611305255430579563836e-01 -8.52106773615456947190693881566403e-01
            5.91081132528676667092781826795544e-01 -8.06612109237529906202723850583425e-01
            6.54860733945285211632381106028333e-01 -7.55749574354257935837608783913311e-01
            7.14282345221903147702846581523772e-01 -6.99857650743562209605386215116596e-01
            7.68950525339362256360686842526775e-01 -6.39308289935551110616529513208661e-01
            8.18501466578593239731276298698504e-01 -5.74504437936463663305630689137615e-01
            8.62605415600980585111301479628310e-01 -5.05877353689468511888094326423015e-01
            9.00968867902419034976446710061282e-01 -4.33883739117558342446301367090200e-01
            9.33336521037366750874753051903099e-01 -3.59002699847598805149573308881372e-01
            9.59492973614497368650688713387353e-01 -2.81732556841429782057417696705670e-01
            9.79264158757421121492825477616861e-01 -2.02587530152080974588102435518522e-01
            9.92518502491027687639757459692191e-01 -1.22094316874160668806581497847219e-01
            9.99167799344582885368026836658828e-01 -4.07885860615854120569956364761310e-02
            9.86941008148129572674633891438134e-01 4.24997558964184465879476704230910e-02
            9.79634042224077128402370817639166e-01 1.27184614365954518078183355100919e-01
            9.65074208595191551651737427164335e-01 2.10927842448706298617011611895578e-01
            9.43369303175623397095250766142271e-01 2.93109434583126660101015659165569e-01
            9.14680021491221073581812106567668e-01 3.73120947013861503638310068708961e-01
            8.79218768946079420878447763243457e-01 4.50370002496438659456146069715032e-01
            8.37248088247241839532364338083426e-01 5.24284676051131826035600624891231e-01
            7.89078715630353699772570053028176e-01 5.94317729295410601686455720482627e-01
            7.35067280277289514245353529986460e-01 6.59950662005464039339130977168679e-01
            6.75613663958465116010643214394804e-01 7.20697550910449402650215233734343e-01
            6.11158040448114725506911781849340e-01 7.76108647298380582846277775388444e-01
            5.42177616631670855618096993566724e-01 8.25773706798238027460001831059344e-01
            4.69183099432943395701300914879539e-01 8.69325026685760615663411954301409e-01
            3.92714914718737484466970499852323e-01 9.06440168225766673693044594983803e-01
            3.13339206174813089678110600289074e-01 9.36844343895740006011862988088978e-01
            2.31643643776112739818273666969617e-01 9.60312451816504819568365292070666e-01
            1.48233072883873939762366944705718e-01 9.76670742327784502379017794737592e-01
            6.37250361821918853699742157914443e-02 9.85798104369895789034217159496620e-01
            -2.12547983919547170406083580473933e-02 9.87626962147661768831596873496892e-01
            -1.06077269875206922633559258883906e-01 9.82143775437957056162474600569112e-01
            -1.90114382365474066105548445193563e-01 9.69389139836781876802263013814809e-01
            -2.72743954483877504291200466468581e-01 9.49457486203673095559452121960931e-01
            -3.53354225787995468444080415792996e-01 9.22496381528658204729254066478461e-01
            -4.31348386032145147961358588872827e-01 8.88705436397890569111268632696010e-01
            -5.06148993741633690390813171688933e-01 8.48334827146706937917031154938741e-01
            -5.77202251387411324756726571649779e-01 8.01683443641569293269810714264167e-01
            -6.43982105509215085881180584692629e-01 7.49096676404067185472968048998155e-01
            -7.05994141431342647763358399970457e-01 6.90963859460336005113845203595702e-01
            -7.62779243735928758063380428211531e-01 6.27715387848144068527744821039960e-01
            -8.13916995392870323833278689562576e-01 5.59819531122614399976100685307756e-01
            -8.59028790380423568073808837652905e-01 4.87778966452273365916880720760673e-01
            -8.97780636751729033129265644674888e-01 4.12127056973163985453822988347383e-01
            -9.29885629394331836294895765604451e-01 3.33423902954795514652630572527414e-01
            -9.55106074175254726732475774042541e-01 2.52252195013709101800714051933028e-01
            -9.73255247745197005215800345467869e-01 1.69212900076018746275963167136069e-01
            -9.84198779972883963651497651881073e-01 8.49208120285501882884560131969920e-02
            -9.87855648774506711617959808791056e-01 1.20977425829133157439759138630800e-16
            -9.84198779972883963651497651881073e-01 -8.49208120285499384882754725367704e-02
            -9.73255247745197005215800345467869e-01 -1.69212900076018524231358242104761e-01
            -9.55106074175254837754778236558195e-01 -2.52252195013708879756109126901720e-01
            -9.29885629394331836294895765604451e-01 -3.33423902954795292608025647496106e-01
            -8.97780636751728922106963182159234e-01 -4.12127056973164151987276682120864e-01
            -8.59028790380423679096111300168559e-01 -4.87778966452273143872275795729365e-01
            -8.13916995392870545877883614593884e-01 -5.59819531122614177931495760276448e-01
            -7.62779243735928980107985353242839e-01 -6.27715387848143957505442358524306e-01
            -7.05994141431342869807963325001765e-01 -6.90963859460335783069240278564394e-01
            -6.43982105509215196903483047208283e-01 -7.49096676404067074450665586482501e-01
            -5.77202251387411546801331496681087e-01 -8.01683443641569182247508251748513e-01
            -5.06148993741634356524627946782857e-01 -8.48334827146706715872426229907433e-01
            -4.31348386032144592849846276294556e-01 -8.88705436397890791155873557727318e-01
            -3.53354225787995912533290265855612e-01 -9.22496381528658093706951603962807e-01
            -2.72743954483877948380410316531197e-01 -9.49457486203672984537149659445276e-01
            -1.90114382365474732239363220287487e-01 -9.69389139836781765779960551299155e-01
            -1.06077269875207366722769108946522e-01 -9.82143775437956945140172138053458e-01
            -2.12547983919551784770529678780804e-02 -9.87626962147661768831596873496892e-01
            6.37250361821914135251887500999146e-02 -9.85798104369895789034217159496620e-01
            1.48233072883873467917581479014189e-01 -9.76670742327784613401320257253246e-01
            2.31643643776113128396332285774406e-01 -9.60312451816504708546062829555012e-01
            3.13339206174812645588900750226458e-01 -9.36844343895740228056467913120287e-01
            3.92714914718737040377760649789707e-01 -9.06440168225766895737649520015111e-01
            4.69183099432943784279359533684328e-01 -8.69325026685760393618807029270101e-01
            5.42177616631670411528887143504107e-01 -8.25773706798238360526909218606306e-01
            6.11158040448114392440004394302377e-01 -7.76108647298380804890882700419752e-01
            6.75613663958465338055248139426112e-01 -7.20697550910449180605610308703035e-01
            7.35067280277289070156143679923844e-01 -6.59950662005464483428340827231295e-01
            7.89078715630353810794872515543830e-01 -5.94317729295410379641850795451319e-01
            8.37248088247241506465456950536463e-01 -5.24284676051132270124810474953847e-01
            8.79218768946079087811540375696495e-01 -4.50370002496439270078809613551130e-01
            9.14680021491221184604114569083322e-01 -3.73120947013861281593705143677653e-01
            9.43369303175623286072948303626617e-01 -2.93109434583127270723679203001666e-01
            9.65074208595191440629434964648681e-01 -2.10927842448706936995250771360588e-01
            9.79634042224077239424673280154821e-01 -1.27184614365954296033578430069610e-01
            9.86941008148129572674633891438134e-01 -4.24997558964191196606563494242437e-02
            9.64696414043536232263420515664620e-01 4.39533205546035893318546072805475e-02
            9.56702635738237328055788566416595e-01 1.31495750607171169033193791619851e-01
            9.40781318092213214576702284830390e-01 2.17948565457338705453338434381294e-01
            9.17064390157689701688070726959268e-01 3.02595389854073026913994226561044e-01
            8.85748377868869174456278869911330e-01 3.84734813552011167825384063689853e-01
            8.47092775566145594901001913967775e-01 4.63686203417653319824864865950076e-01
            8.01417895744276576053266580856871e-01 5.38795343369864010441006030305289e-01
            7.49102214842172653419538619345985e-01 6.09439855420356613180388194450643e-01
            6.90579237067929008198063911549980e-01 6.75034356893714604375134058500407e-01
            6.26333902246430707094759782194160e-01 7.35035311092598009352627741463948e-01
            5.56898567455237247791899335425114e-01 7.88945531213998463293535223783692e-01
            4.82848595746180608845321557964780e-01 8.36318300195670216723442536022048e-01
            4.04797588505912908640738123722258e-01 8.76761072354396486794314569124253e-01
            3.23392300961572509709895939522539e-01 9.09938726143147302849456536932848e-01
            2.39307282963283490806460918065568e-01 9.35576341073760198163711265806342e-01
            1.53239289451658100560393904743250e-01 9.53461475794688206875093783310149e-01
            6.59015069269235503890413951921801e-02 9.63445928446944210854496759566246e-01
            -2.19823562390260504595396184868150e-02 9.65446964711378807777464317041449e-01
            -1.09684066678123345872641891673993e-01 9.59448003371304536379682303959271e-01
            -1.96476900397161452493932642937580e-01 9.45498753709679728984838220640086e-01
            -2.81641664641675393276898375916062e-01 9.23714803602334821874819681397639e-01
            -3.64472657353605233865323498321231e-01 8.94276661720429300039825193380238e-01
            -4.44283514840800697331957280766801e-01 8.57428261778755307354060732905054e-01
            -5.20412899202735701464916928671300e-01 8.13474941224151648633267086552223e-01
            -5.92229978384631650101255218032748e-01 7.62780911113258297540085095533868e-01
            -6.59139653450537266188291596336057e-01 7.05766238144996060910330015758518e-01
            -7.20587489760527999393957543361466e-01 6.42903363855606757581995225336868e-01
            -7.76064311190745814705849170422880e-01 5.74713189819293313043147009011591e-01
            -8.25110419327119259946812235284597e-01 5.01760761293725709997204376122681e-01
            -8.67319402671199890519915243203286e-01 4.24650585077080366946944423034438e-01
            -9.02341504293830531935327599057928e-01 3.44021620374331593694705588859506e-01
            -9.29886520031212637782402907760115e-01 2.60541984180045593788577207305934e-01
            -9.49726203208002939248899565427564e-01 1.74903415050549515541433720500208e-01
            -9.61696155961150100921486227889545e-01 8.78155411403982733009598860007827e-02
            -9.65697191492360995646038190898253e-01 1.18263797450670855627809473918303e-16
            -9.61696155961150100921486227889545e-01 -8.78155411403980373785671531550179e-02
            -9.49726203208003050271202027943218e-01 -1.74903415050548849407618945406284e-01
            -9.29886520031212637782402907760115e-01 -2.60541984180045371743972282274626e-01
            -9.02341504293830642957630061573582e-01 -3.44021620374331371650100663828198e-01
            -8.67319402671200001542217705718940e-01 -4.24650585077080200413490729260957e-01
            -8.25110419327119593013719622831559e-01 -5.01760761293725043863389601028757e-01
            -7.76064311190745703683546707907226e-01 -5.74713189819293535087751934042899e-01
            -7.20587489760528110416260005877120e-01 -6.42903363855606535537390300305560e-01
            -6.59139653450537821299803908914328e-01 -7.05766238144995505798817703180248e-01
            -5.92229978384631872145860143064056e-01 -7.62780911113258075495480170502560e-01
            -5.20412899202735923509521853702608e-01 -8.13474941224151537610964624036569e-01
            -4.44283514840801252443469593345071e-01 -8.57428261778755085309455807873746e-01
            -3.64472657353605455909928423352540e-01 -8.94276661720429189017522730864584e-01
            -2.81641664641676003899561919752159e-01 -9.23714803602334599830214756366331e-01
            -1.96476900397161480249508258566493e-01 -9.45498753709679728984838220640086e-01
            -1.09684066678123581795034624519758e-01 -9.59448003371304425357379841443617e-01
            -2.19823562390267165933543935807393e-02 -9.65446964711378807777464317041449e-01
            6.59015069269235365112535873777233e-02 -9.63445928446944210854496759566246e-01
            1.53239289451657656471184054680634e-01 -9.53461475794688317897396245825803e-01
            2.39307282963282852428221758600557e-01 -9.35576341073760309186013728321996e-01
            3.23392300961572287665291014491231e-01 -9.09938726143147302849456536932848e-01
            4.04797588505912464551528273659642e-01 -8.76761072354396708838919494155562e-01
            4.82848595746180608845321557964780e-01 -8.36318300195670216723442536022048e-01
            5.56898567455237136769596872909460e-01 -7.88945531213998685338140148815000e-01
            6.26333902246430263005549932131544e-01 -7.35035311092598342419535129010910e-01
            6.90579237067929008198063911549980e-01 -6.75034356893714604375134058500407e-01
            7.49102214842172431374933694314677e-01 -6.09439855420356946247295581997605e-01
            8.01417895744276131964056730794255e-01 -5.38795343369864676574820805399213e-01
            8.47092775566145483878699451452121e-01 -4.63686203417653541869469790981384e-01
            8.85748377868868952411673944880022e-01 -3.84734813552011556403442682494642e-01
            9.17064390157689701688070726959268e-01 -3.02595389854072971402842995303217e-01
            9.40781318092213103554399822314736e-01 -2.17948565457339010764670206299343e-01
            9.56702635738237217033486103900941e-01 -1.31495750607171751900281719827035e-01
            9.64696414043536232263420515664620e-01 -4.39533205546036656596875502600597e-02
            9.35937505067357733423705212771893e-01 4.52711703524822442479269568593736e-02
            9.27198908757143724912452853459399e-01 1.35390826337516867461374658887507e-01
            9.09803306055977811794832632585894e-01 2.24246374656105584843857059240690e-01
            8.83913115019291484308894268906442e-01 3.11008194994418951662140671032830e-01
            8.49770065385062833840379425964784e-01 3.94866215612654780642287732916884e-01
            8.07692941608384229468242665461730e-01 4.75037476766611455047950585139915e-01
            7.58074606456895838668685883021681e-01 5.50773440991862206495000009454088e-01
            7.01378332956976380252456237940351e-01 6.21366981996377520935936900059460e-01
            6.38133478938317066919694298121613e-01 6.86158986908190327014267495542299e-01
            5.68930544562494588944900897331536e-01 7.44544510234691703232101644971408e-01
            4.94415658982062300452753333956935e-01 7.95978422075703462290618972474476e-01
            4.15284547606744602887829387327656e-01 8.39980497854477148322871471464168e-01
            3.32276036302738164707193391222972e-01 8.76139902045178553535720311629120e-01
            2.46165153174665890523087341534847e-01 9.04119024033499196768559613701655e-01
            1.57755892336982839196934946812689e-01 9.23656630295996872170860569895012e-01
            6.78737072375550781755393359162554e-02 9.34570303467119778417782072210684e-01
            -2.26421963787772385912067107938128e-02 9.36758145520997675959051775862463e-01
            -1.12946695908127614504934399519698e-01 9.30199729165855360157877385063330e-01
            -2.02196642569610618433983972863643e-01 9.14956288568132047878123103146208e-01
            -2.89558733658333622429381648544222e-01 8.91170147625567676819002826960059e-01
            -3.74217292868232076497037041917793e-01 8.59063391127316999806851072207792e-01
            -4.55381886041967776090899633345543e-01 8.18935791208110552830135020485613e-01
            -5.32294701241683099190993289084872e-01 7.71162008456602543482460987434024e-01
            -6.04237624234886139262812321248930e-01 7.16188093810399939442845607118215e-01
            -6.70538943333551795689118080190383e-01 6.54527323898641877342186035093619e-01
            -7.30579620985171485081366427039029e-01 5.86755408716406301472545692377025e-01
            -7.83799073559590109283590209088288e-01 5.13505116375603254397219643578865e-01
            -8.29700405367319149263494182378054e-01 4.35460365119605230521671046517440e-01
            -8.67855048040708898504647095251130e-01 3.53349837762878371538732835688279e-01
            -8.97906761961325572407588424539426e-01 2.67940178175877730115672648025793e-01
            -9.19574962373284510164239691221155e-01 1.80028833337790850066539860563353e-01
            -9.32657339127517470700468038558029e-01 9.04366077889508512832605902076466e-02
            -9.37031745597124210434003543923609e-01 1.14753292794497518413777334951728e-16
            -9.32657339127517470700468038558029e-01 -9.04366077889506153608678573618818e-02
            -9.19574962373284510164239691221155e-01 -1.80028833337790628021934935532045e-01
            -8.97906761961325461385285962023772e-01 -2.67940178175877896649126341799274e-01
            -8.67855048040709231571554482798092e-01 -3.53349837762877760916069291852182e-01
            -8.29700405367319260285796644893708e-01 -4.35460365119605008477066121486132e-01
            -7.83799073559590331328195134119596e-01 -5.13505116375603143374917181063211e-01
            -7.30579620985171596103668889554683e-01 -5.86755408716406079427940767345717e-01
            -6.70538943333551906711420542706037e-01 -6.54527323898641766319883572577965e-01
            -6.04237624234885695173602471186314e-01 -7.16188093810400272509752994665178e-01
            -5.32294701241683321235598214116180e-01 -7.71162008456602432460158524918370e-01
            -4.55381886041968331202411945923814e-01 -8.18935791208110108740925170422997e-01
            -3.74217292868231909963583348144311e-01 -8.59063391127317110829153534723446e-01
            -2.89558733658333844473986573575530e-01 -8.91170147625567565796700364444405e-01
            -2.02196642569611451101252441731049e-01 -9.14956288568131825833518178114900e-01
            -1.12946695908127434093692897931760e-01 -9.30199729165855471180179847578984e-01
            -2.26421963787774675747055397323493e-02 -9.36758145520997675959051775862463e-01
            6.78737072375550504199637202873419e-02 -9.34570303467119778417782072210684e-01
            1.57755892336983005730388640586170e-01 -9.23656630295996872170860569895012e-01
            2.46165153174665474189453107101144e-01 -9.04119024033499307790862076217309e-01
            3.32276036302738164707193391222972e-01 -8.76139902045178553535720311629120e-01
            4.15284547606743992265165843491559e-01 -8.39980497854477481389778859011130e-01
            4.94415658982061967385845946409972e-01 -7.95978422075703684335223897505784e-01
            5.68930544562494366900295972300228e-01 -7.44544510234691925276706570002716e-01
            6.38133478938316622830484448058996e-01 -6.86158986908190771103477345604915e-01
            7.01378332956976491274758700456005e-01 -6.21366981996377187869029512512498e-01
            7.58074606456895727646383420506027e-01 -5.50773440991862317517302471969742e-01
            8.07692941608383785379032815399114e-01 -4.75037476766612176692916591491667e-01
            8.49770065385063055884984350996092e-01 -3.94866215612654558597682807885576e-01
            8.83913115019291373286591806390788e-01 -3.11008194994419173706745596064138e-01
            9.09803306055977589750227707554586e-01 -2.24246374656106445266701143737009e-01
            9.27198908757143724912452853459399e-01 -1.35390826337516617661194118227286e-01
            9.35937505067357622401402750256239e-01 -4.52711703524826050704099600352492e-02
            9.01911202000919010046686707937624e-01 4.64909083580891877018892444084486e-02
            8.92350718890518201931172370677814e-01 1.38979909880090346518954902421683e-01
            8.73331096169056242395356548513519e-01 2.29995689783216106238938891692669e-01
            8.45053946568907643488444136892213e-01 3.18573458158423028496741835624562e-01
            8.07819014910363786263758356653852e-01 4.03774268625369636698252406858956e-01
            7.62021000731969766484041883813916e-01 4.84694971397630625098429391073296e-01
            7.08145374377226244355654216633411e-01 5.60477786895110408060816098441137e-01
            6.46763230888177220734291950066108e-01 6.30319398420982279773738810035866e-01
            5.78525236255893138270778308651643e-01 6.93479467518516856650023783004144e-01
            5.04154730199098066734109124809038e-01 7.49288481742898082593740127776982e-01
            4.24440058583205770403878887009341e-01 7.97154851659693242105220178927993e-01
            3.40226216758029609277258487054496e-01 8.36571181840027766618561599898385e-01
            2.52405892396862396864776201255154e-01 8.67119649378357837399278196244268e-01
            1.61910002785067369535099146560242e-01 8.88476432919209302419005780393491e-01
            6.96978268652659604942556370588136e-02 9.00415145244104708766030853439588e-01
            -2.32531633580927675486460515230647e-02 9.02809233032396685203480046766344e-01
            -1.15957664265147142312883943304769e-01 8.95633318357950569676972918387037e-01
            -2.07432985084107540663111990397738e-01 8.78963467701473377680088105989853e-01
            -2.96709464657902377560105833254056e-01 8.52976385626896260738760702224681e-01
            -3.82840750093665860287472924028407e-01 8.17947541669037603284664328384679e-01
            -4.64913828338828272190852430867380e-01 7.74248250288005035457672420307063e-01
            -5.42058704346604192103598052199231e-01 7.22341734843545690836208450491540e-01
            -6.13457623239916816082484274375020e-01 6.62778217312197881483371020294726e-01
            -6.78353738716529153229828352777986e-01 5.96189085797458773186008329503238e-01
            -7.36059135808128761624402613961138e-01 5.23280201658817945009616323659429e-01
            -7.85962122950126462761488710384583e-01 4.44824417205747613124344752577599e-01
            -8.27533716064409285984027064841939e-01 3.61653383270960471218558041073265e-01
            -8.60333245922166645058837275428232e-01 2.74648733504692044160577779621235e-01
            -8.84013029347340384411779723450309e-01 1.84732738838682797322121587058064e-01
            -8.98322054744784548319103123503737e-01 9.28585311848678096602327514119679e-02
            -9.03108642885617984852331119327573e-01 1.10598910879218215680920917595158e-16
            -8.98322054744784548319103123503737e-01 -9.28585311848676014934156341951166e-02
            -8.84013029347340495434082185965963e-01 -1.84732738838682186699458043221966e-01
            -8.60333245922166756081139737943886e-01 -2.74648733504691877627124085847754e-01
            -8.27533716064409285984027064841939e-01 -3.61653383270960637752011734846747e-01
            -7.85962122950126351739186247868929e-01 -4.44824417205747779657798446351080e-01
            -7.36059135808129205713612464023754e-01 -5.23280201658817500920406473596813e-01
            -6.78353738716529375274433277809294e-01 -5.96189085797458662163705866987584e-01
            -6.13457623239916927104786736890674e-01 -6.62778217312197659438766095263418e-01
            -5.42058704346604081081295589683577e-01 -7.22341734843545912880813375522848e-01
            -4.64913828338828771791213512187824e-01 -7.74248250288004702390765032760100e-01
            -3.82840750093666082332077849059715e-01 -8.17947541669037492262361865869025e-01
            -2.96709464657902377560105833254056e-01 -8.52976385626896260738760702224681e-01
            -2.07432985084108345574804843636230e-01 -8.78963467701473266657785643474199e-01
            -1.15957664265146961901642441716831e-01 -8.95633318357950569676972918387037e-01
            -2.32531633580931873517272379103815e-02 -9.02809233032396685203480046766344e-01
            6.96978268652657384496507120275055e-02 -9.00415145244104708766030853439588e-01
            1.61910002785067175246069837157847e-01 -8.88476432919209302419005780393491e-01
            2.52405892396862396864776201255154e-01 -8.67119649378357837399278196244268e-01
            3.40226216758029609277258487054496e-01 -8.36571181840027766618561599898385e-01
            4.24440058583205381825820268204552e-01 -7.97154851659693464149825103959301e-01
            5.04154730199097733667201737262076e-01 -7.49288481742898304638345052808290e-01
            5.78525236255893027248475846135989e-01 -6.93479467518517078694628708035452e-01
            6.46763230888177220734291950066108e-01 -6.30319398420982279773738810035866e-01
            7.08145374377225689244141904055141e-01 -5.60477786895110963172328411019407e-01
            7.62021000731969877506344346329570e-01 -4.84694971397630514076126928557642e-01
            8.07819014910363564219153431622544e-01 -4.03774268625370080787462256921572e-01
            8.45053946568907754510746599407867e-01 -3.18573458158422584407531985561945e-01
            8.73331096169056131373054085997865e-01 -2.29995689783216328283543816723977e-01
            8.92350718890518090908869908162160e-01 -1.38979909880091151430647755660175e-01
            9.01911202000919010046686707937624e-01 -4.64909083580890836184806858000229e-02
            8.63336427435993813972459065553267e-01 4.76315980199311928000582838649279e-02
            8.52856692713438335751163776876638e-01 1.42316610983304225879209070626530e-01
            8.32024433051634315638978023343952e-01 2.35274093076530188550776756528649e-01
            8.01092523862749317231646273285151e-01 3.25375666390539663996861463601817e-01
            7.60436436622861755552094109589234e-01 4.11527619880126371842976595871733e-01
            7.10549681156868562226236463175155e-01 4.92684185534455476584980715415440e-01
            6.52037815097736950242790499032708e-01 5.67860232584081137119369486754294e-01
            5.85611093237150881485320041974774e-01 6.36143225653992394619251626863843e-01
            5.12075845994475309375104643550003e-01 6.96704301706914774783285793091636e-01
            4.32324691657750947992866485947161e-01 7.48808331317773134827575631788932e-01
            3.47325701206848524993375804115203e-01 7.91822842149080940998828737065196e-01
            2.58110647243158797259354741981952e-01 8.25225696308346301499625496944645e-01
            1.65762479667885626044565583470103e-01 8.48611428394781319717310452688253e-01
            7.14021801372499709259500377811491e-02 8.61696167300008974976321951544378e-01
            -2.38248451362954201393495878846807e-02 8.64321082018776665201187370257685e-01
            -1.18762669063876696862180892821925e-01 8.56454309642202371577468511532061e-01
            -2.12258875069197466833870180380472e-01 8.38191342130325311998717552341986e-01
            -3.03178545864670023757270200803760e-01 8.09753867169068497489092806063127e-01
            -3.90418039809887762459084115107544e-01 7.71487077182037017664129052718636e-01
            -4.72918387626105718446467562898761e-01 7.23855479162105686086192690709140e-01
            -5.49678146848767923415834957268089e-01 6.67437256185764327121034966694424e-01
            -6.19765557982436710027229764818912e-01 6.02917249053795289981394489586819e-01
            -6.82329854798872426080436071060831e-01 5.31078643251662763091758279188070e-01
            -7.36611591486566297248828050214797e-01 4.52793462138650126824757080612471e-01
            -7.81951861294118422129884038440650e-01 3.69011981765553553902492467386764e-01
            -8.17800294765622548531780466873897e-01 2.80751195810700404642545890965266e-01
            -8.43721740480309567722372321441071e-01 1.89082470654353934635949485709716e-01
            -8.59401547201323889879631678923033e-01 9.51185404421662078489063674169302e-02
            -8.64649383315501673941128046863014e-01 1.05889009966206196431677876286734e-16
            -8.59401547201323889879631678923033e-01 -9.51185404421659858043014423856221e-02
            -8.43721740480309567722372321441071e-01 -1.89082470654353740346920176307322e-01
            -8.17800294765622659554082929389551e-01 -2.80751195810700238109092197191785e-01
            -7.81951861294118533152186500956304e-01 -3.69011981765552998790980154808494e-01
            -7.36611591486566297248828050214797e-01 -4.52793462138650348869362005643779e-01
            -6.82329854798872648125040996092139e-01 -5.31078643251662652069455816672416e-01
            -6.19765557982436932071834689850220e-01 -6.02917249053795178959092027071165e-01
            -5.49678146848768145460439882299397e-01 -6.67437256185764216098732504178770e-01
            -4.72918387626105940491072487930069e-01 -7.23855479162105686086192690709140e-01
            -3.90418039809887928992537808881025e-01 -7.71487077182036906641826590202982e-01
            -3.03178545864670245801875125835068e-01 -8.09753867169068386466790343547473e-01
            -2.12258875069197466833870180380472e-01 -8.38191342130325311998717552341986e-01
            -1.18762669063876724617756508450839e-01 -8.56454309642202371577468511532061e-01
            -2.38248451362954409560312996063658e-02 -8.64321082018776665201187370257685e-01
            7.14021801372491937698328001715709e-02 -8.61696167300009085998624414060032e-01
            1.65762479667885598288989967841189e-01 -8.48611428394781319717310452688253e-01
            2.58110647243158797259354741981952e-01 -8.25225696308346301499625496944645e-01
            3.47325701206847969881863491536933e-01 -7.91822842149081163043433662096504e-01
            4.32324691657750947992866485947161e-01 -7.48808331317773134827575631788932e-01
            5.12075845994474754263592330971733e-01 -6.96704301706915218872495643154252e-01
            5.85611093237150881485320041974774e-01 -6.36143225653992505641554089379497e-01
            6.52037815097737061265092961548362e-01 -5.67860232584080915074764561722986e-01
            7.10549681156868118137026613112539e-01 -4.92684185534456031696493027993711e-01
            7.60436436622861866574396572104888e-01 -4.11527619880126205309522902098252e-01
            8.01092523862749095187041348253842e-01 -3.25375666390540274619525007437915e-01
            8.32024433051634204616675560828298e-01 -2.35274093076530799173440300364746e-01
            8.52856692713438446773466239392292e-01 -1.42316610983304087101330992481962e-01
            8.63336427435993813972459065553267e-01 -4.76315980199317964838279237937968e-02
            8.20696622450672763626755568111548e-01 4.87041207244033463874544054306170e-02
            8.09175840860648309948999212792842e-01 1.45428663078988718027062532200944e-01
            7.86296004200258802363521226652665e-01 2.40111705787506068965342365117976e-01
            7.52378295222995485680428373598261e-01 3.31424106478117042051678708958207e-01
            7.07898844214364220128743454552023e-01 4.18084039204376423093378889461746e-01
            6.53482045166367098154580617119791e-01 4.98874988471722624616688790410990e-01
            5.89891790654543335392645531101152e-01 5.72662826448387285438457183772698e-01
            5.18020748460682023406320695357863e-01 6.38411733634113298663237401342485e-01
            4.38877830473917374121128887054510e-01 6.95198739495395345855399682477582e-01
            3.53574029779368081971568926746841e-01 7.42226678948593066031946818839060e-01
            2.63306824750548063018840139193344e-01 7.78835382810297960354262158944039e-01
            1.69343369077908784126051955354342e-01 8.04510945125560317237045637739357e-01
            7.30027037086583285852015023920103e-02 8.18892937281000765636918004020117e-01
            -2.43627595967614331284867290605689e-02 8.21779467632472337967897146882024e-01
            -1.21386223161270498382968696660100e-01 8.13130015621193025232571471860865e-01
            -2.16705690234477832412096631742315e-01 7.93066000593568354304352396866307e-01
            -3.08983084441524724628180820218404e-01 7.61869077339722977626479405444115e-01
            -3.96923033442286521399466892034980e-01 7.19977182277641847285565290803788e-01
            -4.79291053119538346116712546063354e-01 6.67978385785830020004993912152713e-01
            -5.54930877029937374977919262164505e-01 6.06602636984264753650109014415648e-01
            -6.22780687850320591181230156507809e-01 5.36711516848819680802762377425097e-01
            -6.81888022965389417606729693943635e-01 4.59286143502971089258579695524531e-01
            -7.31423144955004378431340228416957e-01 3.75413399469984143674849974559038e-01
            -7.70690689288758168373760781832971e-01 2.86270674224758658876766048706486e-01
            -7.99139425719723406338346194388578e-01 1.93109336226475220010811995052791e-01
            -8.16369996348808912856043207284529e-01 9.72371664484568687392140873271273e-02
            -8.22140521734258777897252912225667e-01 1.00683175839119503562298970369148e-16
            -8.16369996348808912856043207284529e-01 -9.72371664484570213948799732861517e-02
            -7.99139425719723628382951119419886e-01 -1.93109336226474664899299682474521e-01
            -7.70690689288758279396063244348625e-01 -2.86270674224758492343312354933005e-01
            -7.31423144955004489453642690932611e-01 -3.75413399469983921630245049527730e-01
            -6.81888022965389528629032156459289e-01 -4.59286143502971033747428464266704e-01
            -6.22780687850320924248137544054771e-01 -5.36711516848819236713552527362481e-01
            -5.54930877029937819067129112227121e-01 -6.06602636984264420583201626868686e-01
            -4.79291053119538512650166239836835e-01 -6.67978385785829908982691449637059e-01
            -3.96923033442286410377164429519325e-01 -7.19977182277641958307867753319442e-01
            -3.08983084441524891161634513991885e-01 -7.61869077339722977626479405444115e-01
            -2.16705690234477887923247863000142e-01 -7.93066000593568354304352396866307e-01
            -1.21386223161270886961027315464889e-01 -8.13130015621192914210269009345211e-01
            -2.43627595967616308869629904165777e-02 -8.21779467632472337967897146882024e-01
            7.30027037086577595959013819992833e-02 -8.18892937281000876659220466535771e-01
            1.69343369077909117192959342901304e-01 -8.04510945125560206214743175223703e-01
            2.63306824750548229552293832966825e-01 -7.78835382810297960354262158944039e-01
            3.53574029779367748904661539199878e-01 -7.42226678948593177054249281354714e-01
            4.38877830473917374121128887054510e-01 -6.95198739495395345855399682477582e-01
            5.18020748460681579317110845295247e-01 -6.38411733634113742752447251405101e-01
            5.89891790654543113348040606069844e-01 -5.72662826448387396460759646288352e-01
            6.53482045166367098154580617119791e-01 -4.98874988471722624616688790410990e-01
            7.07898844214363998084138529520715e-01 -4.18084039204376700649135045750882e-01
            7.52378295222995485680428373598261e-01 -3.31424106478117153073981171473861e-01
            7.86296004200258913385823689168319e-01 -2.40111705787505874676313055715582e-01
            8.09175840860648198926696750277188e-01 -1.45428663078988967827243072861165e-01
            8.20696622450672763626755568111548e-01 -4.87041207244033255707726937089319e-02
            7.74344853840810865008847940771375e-01 4.97145890816549571034066445918143e-02
            7.61630132748663646324871479009744e-01 1.48327455066678104422805972717470e-01
            7.36409465933185014563377990270965e-01 2.44504788340240225563704257183417e-01
            6.99096976046222118306161519285524e-01 3.36667359748955397069636319429264e-01
            6.50305333140159147475856116216164e-01 4.23301862418264229770414885933860e-01
            5.90835694642596331860318059625570e-01 5.02985760209476717719212501833681e-01
            5.21664550373536317628975211846409e-01 5.74410645723841595255976244516205e-01
            4.43927688609537907105107024108293e-01 6.36403724315860452875881492218468e-01
            3.58901546471614152356011118172319e-01 6.87947071348943506308160067419522e-01
            2.67982250862995596829563282881281e-01 7.28194346489800081734244940889766e-01
            1.72662694103975528081562629267864e-01 7.56484690593313691131527320976602e-01
            7.45080206812861883802767692941416e-02 7.72353576991433143916765402536839e-01
            -2.48700723811046409128522327591782e-02 7.75540439008220339189847436500713e-01
            -1.23839799542567810530790950451774e-01 7.65992948457465350209361076849746e-01
            -2.20776080619278086691892326598463e-01 7.43867874870056899894166235753801e-01
            -3.14087224555903987699423396406928e-01 7.09528511342619405688481037941528e-01
            -4.02241064948732185424518092986546e-01 6.63538709274910654123402764525963e-01
            -4.83790118175656425059116827469552e-01 6.06653619945425659487625580368331e-01
            -5.57395351037236141955588664131938e-01 5.39807294948281279900470508437138e-01
            -6.21848167644810767562546516273869e-01 4.64097349091864397330198244162602e-01
            -6.76090254531578005448011481348658e-01 3.80766937594022858437625700389617e-01
            -7.19230958130460895638691454223590e-01 2.91184343507757681379644054686651e-01
            -7.50561909281054706610802895738743e-01 1.96820510551320410064235488789564e-01
            -7.69568654631657356190999053069390e-01 9.92248902530275256328451405352098e-02
            -7.75939103949082165101458485878538e-01 9.50251339984508807398422971696687e-17
            -7.69568654631657467213301515585044e-01 -9.92248902530273590993914467617287e-02
            -7.50561909281054706610802895738743e-01 -1.96820510551320243530781795016082e-01
            -7.19230958130460895638691454223590e-01 -2.91184343507757514846190360913170e-01
            -6.76090254531578338514918868895620e-01 -3.80766937594022414348415850327001e-01
            -6.21848167644810878584848978789523e-01 -4.64097349091864341819047012904775e-01
            -5.57395351037236252977891126647592e-01 -5.39807294948281279900470508437138e-01
            -4.83790118175656591592570521243033e-01 -6.06653619945425548465323117852677e-01
            -4.02241064948732629513727943049162e-01 -6.63538709274910432078797839494655e-01
            -3.14087224555904376277482015211717e-01 -7.09528511342619294666178575425874e-01
            -2.20776080619278086691892326598463e-01 -7.43867874870056899894166235753801e-01
            -1.23839799542567491341671370719268e-01 -7.65992948457465350209361076849746e-01
            -2.48700723811046547906400405736349e-02 -7.75540439008220339189847436500713e-01
            7.45080206812856471465522645303281e-02 -7.72353576991433143916765402536839e-01
            1.72662694103975361548108935494383e-01 -7.56484690593313691131527320976602e-01
            2.67982250862995596829563282881281e-01 -7.28194346489800081734244940889766e-01
            3.58901546471613985822557424398838e-01 -6.87947071348943506308160067419522e-01
            4.43927688609537907105107024108293e-01 -6.36403724315860452875881492218468e-01
            5.21664550373536095584370286815101e-01 -5.74410645723841817300581169547513e-01
            5.90835694642595776748805747047300e-01 -5.02985760209477383853027276927605e-01
            6.50305333140159369520461041247472e-01 -4.23301862418263952214658729644725e-01
            6.99096976046222007283859056769870e-01 -3.36667359748955563603090013202745e-01
            7.36409465933184903541075527755311e-01 -2.44504788340240808430792185390601e-01
            7.61630132748663646324871479009744e-01 -1.48327455066678381978562129006605e-01
            7.74344853840810865008847940771375e-01 -4.97145890816556440539031314074236e-02
            7.24552394571228774999838151416043e-01 5.06656390384024740702884059828648e-02
            7.10449806377033254989328270312399e-01 1.51010768082635110642897302568599e-01
            6.82519120826385661260360393498559e-01 2.48416644298342037533444681685069e-01
            6.41303976942845577191576467157574e-01 3.40987373102526469814677057001973e-01
            5.87606580620574803219824389088899e-01 4.26921170556658291506124669467681e-01
            5.22472090599103267116731785790762e-01 5.04545433041538649021617857215460e-01
            4.47168275637314760473373098648153e-01 5.72349292584189206500866475835210e-01
            3.63160838836620536440591422433499e-01 6.29013024184359337276362111879280e-01
            2.72084889397302853719651238861843e-01 6.73433732760491343682929255010094e-01
            1.75713117077841429747309121012222e-01 7.04746819747957498059065528650535e-01
            7.59212888051677969869501794164535e-02 7.22342811526655692588860802061390e-01
            -2.53482609949120737957706239740219e-02 7.25879222131757373404070676770061e-01
            -1.26124435727945821694717665195640e-01 7.15287219353441638958202020148747e-01
            -2.24445741783954211268081735397573e-01 6.90772964477563977681029427913018e-01
            -3.18398466779385380664990634613787e-01 6.52813599590731485911021536594490e-01
            -4.06153927791843394334847516802256e-01 6.02147960552329108985247785312822e-01
            -4.86004064593078932698944072399172e-01 5.39762196394928839282556509715505e-01
            -5.56394685098439589765462187642697e-01 4.66870575055099767958211032237159e-01
            -6.15955715947933302167882629873930e-01 3.84891849029230848078242388510262e-01
            -6.63527869425742489184472105989698e-01 2.95421640969997567616189826367190e-01
            -6.98185207676944474819435981771676e-01 2.00201386706419265371081905868778e-01
            -7.19253165034617558681873106252169e-01 1.01084440176302289837728665133909e-01
            -7.26321677673240961858880382351344e-01 8.89487517713870137949191384308616e-17
            -7.19253165034617558681873106252169e-01 -1.01084440176302137182062779174885e-01
            -6.98185207676944585841738444287330e-01 -2.00201386706418765770720824548334e-01
            -6.63527869425742711229077031021006e-01 -2.95421640969997123526979976304574e-01
            -6.15955715947933302167882629873930e-01 -3.84891849029230792567091157252435e-01
            -5.56394685098439811810067112674005e-01 -4.66870575055099601424757338463678e-01
            -4.86004064593079099232397766172653e-01 -5.39762196394928728260254047199851e-01
            -4.06153927791843838424057366864872e-01 -6.02147960552328886940642860281514e-01
            -3.18398466779385547198444328387268e-01 -6.52813599590731485911021536594490e-01
            -2.24445741783954377801535429171054e-01 -6.90772964477563977681029427913018e-01
            -1.26124435727945849450293280824553e-01 -7.15287219353441638958202020148747e-01
            -2.53482609949127399295853990679461e-02 -7.25879222131757262381768214254407e-01
            7.59212888051674639200427918694913e-02 -7.22342811526655692588860802061390e-01
            1.75713117077841124435977349094173e-01 -7.04746819747957609081367991166189e-01
            2.72084889397302853719651238861843e-01 -6.73433732760491343682929255010094e-01
            3.63160838836620536440591422433499e-01 -6.29013024184359337276362111879280e-01
            4.47168275637314927006826792421634e-01 -5.72349292584189095478564013319556e-01
            5.22472090599103045072126860759454e-01 -5.04545433041538871066222782246768e-01
            5.87606580620574692197521926573245e-01 -4.26921170556658458039578363241162e-01
            6.41303976942845577191576467157574e-01 -3.40987373102526469814677057001973e-01
            6.82519120826385661260360393498559e-01 -2.48416644298341954266717834798328e-01
            7.10449806377033143967025807796745e-01 -1.51010768082635526976531537002302e-01
            7.24552394571228886022140613931697e-01 -5.06656390384020785533358832708473e-02
            6.71534458445377402391329724196112e-01 5.15567387698229878667532943836704e-02
            6.55794259905631449214524764101952e-01 1.53461770050169754586733006362920e-01
            6.24682799739137539773992102709599e-01 2.51769787508705322753854716211208e-01
            5.78929304203347427915105072315782e-01 3.44176534538213452218968768647755e-01
            5.19606196454755475677700360392919e-01 4.28516075308649380115610938446480e-01
            4.48103959859054157277569174766541e-01 5.02811562467234018924955307738855e-01
            3.66098546239561062343170760868816e-01 5.65321572764905244667943406966515e-01
            2.75512092986951895312586202635430e-01 6.14580924541313189379820869362447e-01
            1.78467869787949928728210124972975e-01 6.49435020341109559005587925639702e-01
            7.72405109834707198634973224216083e-02 6.69066909699708833869635782320984e-01
            -2.57972999324398745424335999132381e-02 6.73016437769763387066745963238645e-01
            -1.28230444002711441164876760012703e-01 6.61191030960775694147457670624135e-01
            -2.27657975148644109442130911702407e-01 6.33867866785598588208472392580006e-01
            -3.21749396311044377760879342531553e-01 5.91687377054458174541196058271453e-01
            -4.08299284326056777238989070610842e-01 5.35638236696126757152569552999921e-01
            -4.85278983174892153407142814103281e-01 4.67034190055555520348917752926354e-01
            -5.50884153961501366048025829513790e-01 3.87483257839905836927840709904558e-01
            -6.03577067087010532553392749832710e-01 2.98850046476068775813672573349322e-01
            -6.42122645328199959102732918836409e-01 2.03212043316386120617167421187332e-01
            -6.65617413000813118451048921997426e-01 1.02810922095908766071836737410194e-01
            -6.73510672663845788576963968807831e-01 3.81580091395807392918583062477039e-16
            -6.65617413000813118451048921997426e-01 -1.02810922095908599538383043636713e-01
            -6.42122645328199959102732918836409e-01 -2.03212043316386231639469883702986e-01
            -6.03577067087010532553392749832710e-01 -2.98850046476068609280218879575841e-01
            -5.50884153961501588092630754545098e-01 -3.87483257839905448349782091099769e-01
            -4.85278983174892264429445276618935e-01 -4.67034190055555409326615290410700e-01
            -4.08299284326056666216686608095188e-01 -5.35638236696126757152569552999921e-01
            -3.21749396311044211227425648758071e-01 -5.91687377054458285563498520787107e-01
            -2.27657975148644109442130911702407e-01 -6.33867866785598588208472392580006e-01
            -1.28230444002711885254086610075319e-01 -6.61191030960775694147457670624135e-01
            -2.57972999324400376064403417331050e-02 -6.73016437769763387066745963238645e-01
            7.72405109834707059857095146071515e-02 -6.69066909699708833869635782320984e-01
            1.78467869787949623416878353054926e-01 -6.49435020341109670027890388155356e-01
            2.75512092986951728779132508861949e-01 -6.14580924541313189379820869362447e-01
            3.66098546239561228876624454642297e-01 -5.65321572764905133645640944450861e-01
            4.48103959859053935232964249735232e-01 -5.02811562467234240969560232770164e-01
            5.19606196454755031588490510330303e-01 -4.28516075308649824204820788509096e-01
            5.78929304203347205870500147284474e-01 -3.44176534538213840797027387452545e-01
            6.24682799739137428751689640193945e-01 -2.51769787508705489287308409984689e-01
            6.55794259905631449214524764101952e-01 -1.53461770050169671320006159476179e-01
            6.71534458445377402391329724196112e-01 -5.15567387698232723614033545800339e-02
            6.15464816509917356235348506743321e-01 5.23837758991355303961334755058488e-02
            5.97759014312897685172742967552040e-01 1.55644341839689170914340365925455e-01
            5.62856773611193794693008385365829e-01 2.54427303446454811108878857339732e-01
            5.11762168323444011086564842116786e-01 3.45890854767691269255891484135645e-01
            4.45945097216063068845670613882248e-01 4.27403755959155196020304856574512e-01
            3.67298997591970766141145077199326e-01 4.96621029263733970715577470400603e-01
            2.78086374546758885450969955854816e-01 5.51551419752027149989714871480828e-01
            1.80873712816424558891270635285764e-01 5.90614680101196554140585703862598e-01
            7.84576436843014840549770383404393e-02 6.12687031433295725690868493984453e-01
            -2.62155090091463656432058115797190e-02 6.17133492387529125622336323431227e-01
            -1.30134489238858452875291504824418e-01 6.03826146377894557026877464522840e-01
            -2.30309737148436610709723026957363e-01 5.73147821520465283740008999302518e-01
            -3.23859393244137150347228271130007e-01 5.25981077365504146037267219071509e-01
            -4.08092204245516843030827658367343e-01 4.63682815266074299653809021037887e-01
            -4.80584945542359198711324097530451e-01 3.88045242796616063341019753352157e-01
            -5.39252132954755269977908938017208e-01 3.01244315204094725846317714967881e-01
            -5.82406018315930418260961687337840e-01 2.05777137137295201840814229399257e-01
            -6.08805142914124464148528659279691e-01 1.04390125492546378960234676469554e-01
            -6.17690051999412625960417244641576e-01 7.56452145046242857397139771951122e-17
            -6.08805142914124464148528659279691e-01 -1.04390125492546226304568790510530e-01
            -5.82406018315930418260961687337840e-01 -2.05777137137295063062936151254689e-01
            -5.39252132954755492022513863048516e-01 -3.01244315204094392779410327420919e-01
            -4.80584945542359143200172866272624e-01 -3.88045242796616174363322215867811e-01
            -4.08092204245517009564281352140824e-01 -4.63682815266074244142657789780060e-01
            -3.23859393244137483414135658676969e-01 -5.25981077365503923992662294040201e-01
            -2.30309737148436721732025489473017e-01 -5.73147821520465172717706536786864e-01
            -1.30134489238858341852989042308764e-01 -6.03826146377894557026877464522840e-01
            -2.62155090091466536073028237296967e-02 -6.17133492387529014600033860915573e-01
            7.84576436843010677213428039067367e-02 -6.12687031433295725690868493984453e-01
            1.80873712816424281335514478996629e-01 -5.90614680101196554140585703862598e-01
            2.78086374546758885450969955854816e-01 -5.51551419752027149989714871480828e-01
            3.67298997591970877163447539714980e-01 -4.96621029263733915204426239142776e-01
            4.45945097216062957823368151366594e-01 -4.27403755959155362553758550347993e-01
            5.11762168323443678019657454569824e-01 -3.45890854767691657833950102940435e-01
            5.62856773611193683670705922850175e-01 -2.54427303446454977642332551113213e-01
            5.97759014312897685172742967552040e-01 -1.55644341839689115403189134667628e-01
            6.15464816509917245213046044227667e-01 -5.23837758991358010129957278877555e-02
            5.56484007084037224366568352706963e-01 5.31377798569519985139031348353456e-02
            5.36371225163081888354099646676332e-01 1.57492801757690731312422371956927e-01
            4.96872589663136521309638737875503e-01 2.56155623459414005793632895802148e-01
            4.39415684183860288936074312005076e-01 3.45560313522346895798165178348427e-01
            3.66077150991781230526811441450263e-01 4.22475553505967160727863074498600e-01
            2.79507635758145633886329051165376e-01 4.84121426236563623390907196153421e-01
            1.82835986318168775000003734021448e-01 5.28269889256897773321952627156861e-01
            7.95561679581376635095324445501319e-02 5.53325302085716397293424506642623e-01
            -2.65990175934746019004162320698015e-02 5.58382096822144458059256066917442e-01
            -1.31792845346194092970293354483147e-01 5.43257507729057453893517504184274e-01
            -2.32223336285193232564338927659264e-01 5.08498176863011797088631738006370e-01
            -3.24260670798844019557805040676612e-01 4.55360397006059791635834699263796e-01
            -4.04578379816887601094776982790790e-01 3.85764705971366583803217054082779e-01
            -4.70273572069661860428624322594260e-01 3.02226473362730618799076864888775e-01
            -5.18971852141997813667728678410640e-01 2.07764988563369529250834943923110e-01
            -5.48913137309949950015663944213884e-01 1.05794335750930834638694477689569e-01
            -5.59015271516291156750355639815098e-01 6.84596262936914560402549670155129e-17
            -5.48913137309950061037966406729538e-01 -1.05794335750930459938423666699236e-01
            -5.18971852141997813667728678410640e-01 -2.07764988563369418228532481407456e-01
            -4.70273572069662026962078016367741e-01 -3.02226473362730285732169477341813e-01
            -4.04578379816887712117079445306445e-01 -3.85764705971366528292065822824952e-01
            -3.24260670798844130580107503192266e-01 -4.55360397006059736124683468005969e-01
            -2.32223336285193149297612080772524e-01 -5.08498176863011797088631738006370e-01
            -1.31792845346194092970293354483147e-01 -5.43257507729057453893517504184274e-01
            -2.65990175934748655783845805444798e-02 -5.58382096822144458059256066917442e-01
            7.95561679581373998315640960754536e-02 -5.53325302085716508315726969158277e-01
            1.82835986318168775000003734021448e-01 -5.28269889256897884344255089672515e-01
            2.79507635758145633886329051165376e-01 -4.84121426236563623390907196153421e-01
            3.66077150991780952971055285161128e-01 -4.22475553505967382772467999529908e-01
            4.39415684183860122402620618231595e-01 -3.45560313522347117842770103379735e-01
            4.96872589663136465798487506617676e-01 -2.56155623459414116815935358317802e-01
            5.36371225163081888354099646676332e-01 -1.57492801757690814579149218843668e-01
            5.56484007084037224366568352706963e-01 -5.31377798569524356642190809907333e-02
            4.94702892947368577658551203057868e-01 5.38021818923959949110269462835276e-02
            4.71571135495924664837730233557522e-01 1.58890815448729905146052487907582e-01
            4.26389235862364490703413366645691e-01 2.56549891069138780164138324835221e-01
            3.61269849457478586796099762068479e-01 3.42212978917879218077047198676155e-01
            2.79257886414559730603457410325063e-01 4.11874568214827929679699991538655e-01
            1.84188134975744655097429358647787e-01 4.62277360467755249473498224688228e-01
            8.05059510558724239492889296343492e-02 4.91064577129594559412595344838337e-01
            -2.69406016594339811631719783235894e-02 4.96890159943931486452584067592397e-01
            -1.33127441783473743353027884950279e-01 4.79481711133037780125931703878450e-01
            -2.33089390690242481696259346790612e-01 4.39653230415209816950294907655916e-01
            -3.22152338748586619665559283021139e-01 3.79267053282636157351959127481678e-01
            -3.96151801493654864838589446662809e-01 3.01146770263620744412236263087834e-01
            -4.51627646291983930737501395924482e-01 2.08945198967673634316000175203953e-01
            -4.85985884297776615792230359147652e-01 1.06973582393907765131224607557670e-01
            -4.97619962488321077032082939695101e-01 6.09408694253148318979785569442830e-17
            -4.85985884297776615792230359147652e-01 -1.06973582393907640231134337227559e-01
            -4.51627646291983875226350164666655e-01 -2.08945198967673717582727022090694e-01
            -3.96151801493655086883194371694117e-01 -3.01146770263620466856480106798699e-01
            -3.22152338748586508643256820505485e-01 -3.79267053282636212863110358739505e-01
            -2.33089390690242787007591118708660e-01 -4.39653230415209650416841213882435e-01
            -1.33127441783473965397632809981587e-01 -4.79481711133037724614780472620623e-01
            -2.69406016594343246384202217313941e-02 -4.96890159943931430941432836334570e-01
            8.05059510558723129269864671186951e-02 -4.91064577129594614923746576096164e-01
            1.84188134975744433052824433616479e-01 -4.62277360467755360495800687203882e-01
            2.79257886414559675092306179067236e-01 -4.11874568214827985190851222796482e-01
            3.61269849457478586796099762068479e-01 -3.42212978917879218077047198676155e-01
            4.26389235862364490703413366645691e-01 -2.56549891069138780164138324835221e-01
            4.71571135495924664837730233557522e-01 -1.58890815448729849634901256649755e-01
            4.94702892947368522147399971800041e-01 -5.38021818923963557335099494594033e-02
            4.30201378400855649619671794425813e-01 5.43470727400390818395692349440651e-02
            4.03170243625934676678923551662592e-01 1.59626391765308461856420763069764e-01
            3.50806439687560700502189092730987e-01 2.54875797531160519504567218973534e-01
            2.76400176967781352477260270461557e-01 3.34110419570516292697703875091975e-01
            1.84626674600372714385443373430462e-01 3.92351655176087388277039735839935e-01
            8.12523992584110038572831058445445e-02 4.25939993318494358742754002378206e-01
            -2.72272631543780535556820154852176e-02 4.32764955182983246384509357085335e-01
            -1.33996136488307993062107925652526e-01 4.12397703315154240399920126947109e-01
            -2.32345539763360087182064717126195e-01 3.66117987055375571081583530030912e-01
            -3.16095818267958295066932805639226e-01 2.96833731181139759414122636371758e-01
            -3.79984633991680920139799582102569e-01 2.08898320298693540575385441115941e-01
            -4.19997617675977930051800512956106e-01 1.07837059677600335949598786555725e-01
            -4.33620606398505081813254946609959e-01 5.31032087670263526345880268400932e-17
            -4.19997617675977985562951744213933e-01 -1.07837059677600044516054822452134e-01
            -3.79984633991680920139799582102569e-01 -2.08898320298693623842112288002681e-01
            -3.16095818267958517111537730670534e-01 -2.96833731181139537369517711340450e-01
            -2.32345539763359837381884176465974e-01 -3.66117987055375682103885992546566e-01
            -1.33996136488308187351137235054921e-01 -4.12397703315154184888768895689282e-01
            -2.72272631543779702889551685984770e-02 -4.32764955182983246384509357085335e-01
            8.12523992584107956904659886276932e-02 -4.25939993318494414253905233636033e-01
            1.84626674600372353562960370254586e-01 -3.92351655176087499299342198355589e-01
            2.76400176967781130432655345430248e-01 -3.34110419570516459231157568865456e-01
            3.50806439687560644991037861473160e-01 -2.54875797531160575015718450231361e-01
            4.03170243625934676678923551662592e-01 -1.59626391765308434100845147440850e-01
            4.30201378400855594108520563167986e-01 -5.43470727400392483730229287175462e-02
            3.63019490874152861437096362351440e-01 5.47163843916073505679875665919099e-02
            3.30763616025188278424451482351287e-01 1.59287362302729801344369775506493e-01
            2.69117942360164841275604885595385e-01 2.49704959052178765421814432556857e-01
            1.83559958511802984171268349200545e-01 3.17935174377677876034198334309622e-01
            8.16918668100574535406721565777843e-02 3.57915454224188411824769673330593e-01
            -2.74349057566143014752491069430107e-02 3.66093375276779597893295203903108e-01
            -1.34123966550710155276604496066284e-01 3.41742293361713245225530499737943e-01
            -2.28895524323442733916067481914070e-01 2.87025908970105936290906356589403e-01
            -3.03328710268573942254732855872135e-01 2.06806012974049713282198581509874e-01
            -3.50809809170222197671762387471972e-01 1.08210495172009785180833318918303e-01
            -3.67119917023605912831385467143264e-01 4.49592231286200880992745959315090e-17
            -3.50809809170222308694064849987626e-01 -1.08210495172009535380652778258082e-01
            -3.03328710268573886743581624614308e-01 -2.06806012974049796548925428396615e-01
            -2.28895524323442817182794328800810e-01 -2.87025908970105880779755125331576e-01
            -1.34123966550710072009877649179543e-01 -3.41742293361713245225530499737943e-01
            -2.74349057566145512754296476032323e-02 -3.66093375276779597893295203903108e-01
            8.16918668100573702739453096910438e-02 -3.57915454224188411824769673330593e-01
            1.83559958511802706615512192911410e-01 -3.17935174377678042567652028083103e-01
            2.69117942360164896786756116853212e-01 -2.49704959052178682155087585670117e-01
            3.30763616025188222913300251093460e-01 -1.59287362302729884611096622393234e-01
            3.63019490874152805925945131093613e-01 -5.47163843916076558793193385099585e-02
            2.93131775226473878515065507599502e-01 5.47958254116015092138880504535337e-02
            2.53542704682899355805858476742287e-01 1.56986996378817300623609298781957e-01
            1.79711286943272818827921355477883e-01 2.37976203590097135087688684507157e-01
            8.16088640873397219710483341259533e-02 2.86825405834868152332717272656737e-01
            -2.75152880739153865574664337145805e-02 2.96937247667200143741439433142659e-01
            -1.32923348113313521956513341137907e-01 2.66946068815986814470875287952367e-01
            -2.20379373436310366241031033496256e-01 2.00902344171943331163632251445961e-01
            -2.78071943212468974948592403961811e-01 1.07725644709159795731068243185291e-01
            -2.98209356207954523476644226320786e-01 3.65201133555864379240326552951260e-17
            -2.78071943212469085970894866477465e-01 -1.07725644709159615319826741597353e-01
            -2.20379373436310310729879802238429e-01 -2.00902344171943386674783482703788e-01
            -1.32923348113313855023420728684869e-01 -2.66946068815986647937421594178886e-01
            -2.75152880739153934963603376218089e-02 -2.96937247667200143741439433142659e-01
            8.16088640873396525821092950536695e-02 -2.86825405834868152332717272656737e-01
            1.79711286943272763316770124220056e-01 -2.37976203590097218354415531393897e-01
            2.53542704682899244783556014226633e-01 -1.56986996378817439401487376926525e-01
            2.93131775226473878515065507599502e-01 -5.47958254116014259471612035667931e-02
            2.20375683215061762831865621592442e-01 5.43177274630604542404732626437180e-02
            1.69890270005377014284064784988004e-01 1.50509645626971916287928365818516e-01
            8.04850433371619433664534426497994e-02 2.12221617815602670020780351478606e-01
            -2.73583368096773915656427789144800e-02 2.25316174910424077415527222001401e-01
            -1.28934251697119722779305561743968e-01 1.86793511687532526321930959056772e-01
            -2.00972883346927061465336805667903e-01 1.05478706042873918158342405604344e-01
            -2.26971049407752811788441249518655e-01 -7.29994570746964547859305644218320e-17
            -2.00972883346927200243214883812470e-01 -1.05478706042873696113737480573036e-01
            -1.28934251697119778290456793001795e-01 -1.86793511687532498566355343427858e-01
            -2.73583368096775511602025687807327e-02 -2.25316174910424077415527222001401e-01
            8.04850433371619433664534426497994e-02 -2.12221617815602670020780351478606e-01
            1.69890270005376931017337938101264e-01 -1.50509645626971971799079597076343e-01
            2.20375683215061762831865621592442e-01 -5.43177274630604681182610704581748e-02
            1.44223340759860346738108205499884e-01 5.24930031230206942116645052465174e-02
            7.67396367544313090514052078106033e-02 1.32916949813055018658758399396902e-01
            -2.66513961544583601048774568198496e-02 1.51147578478209060337533742313099e-01
            -1.17571944605401934591526469375822e-01 9.86545753551884008203387566027232e-02
            -1.53479273508862590347234799992293e-01 1.87957901038089721934814066791904e-17
            -1.17571944605402003980465508448106e-01 -9.86545753551883175536119097159826e-02
            -2.66513961544583635743244087734638e-02 -1.51147578478209060337533742313099e-01
            7.67396367544311980291027452949493e-02 -1.32916949813055074169909630654729e-01
            1.44223340759860346738108205499884e-01 -5.24930031230206733949827935248322e-02
            6.29428428224284020053858057508478e-02 4.57306521440512120380006422237784e-02
            -2.40420266096252784049358552920239e-02 7.39937494967731201889193926035659e-02
            -7.78016324256062263842181891959626e-02 9.52795201184575953626112202502534e-18
            -2.40420266096252957521706150600949e-02 -7.39937494967731201889193926035659e-02
            6.29428428224283881275979979363910e-02 -4.57306521440512328546823539454635e-02
            -0.00000000000000000000000000000000e+00 0.00000000000000000000000000000000e+00
            ];
        
    case   39
        
        % DEGREE.             :          39
        % CARDIN.             :         820
        % LEBESGUE CONST.     : 4.68188e+02
        % ABS.DET.VAND.MATRIX : Inf
        % CONDITIONING VAND.  : 1.08768e+04
        % POINTS OUT DISK     : 0.00000e+00
        
        pts=[
            9.99209397227301843180669038702035e-01 3.97565150969256334012591480586707e-02
            9.92892073701973409960430672072107e-01 1.19018191801904774096421135709534e-01
            9.80297366804636194359545697807334e-01 1.97527397177952673823497775629221e-01
            9.61504904327420417686766995757353e-01 2.74787770751025284265978143594111e-01
            9.36633498268727882063444667437579e-01 3.50310847563824245831654025096213e-01
            9.05840393665523269106643056147732e-01 4.23619146408527991187753514168435e-01
            8.69320274439582485470623396395240e-01 4.94249188616722956446380976558430e-01
            8.27304032543057288329180209984770e-01 5.61754428320770715643561743490864e-01
            7.80057308185212128215368920791661e-01 6.25708075660559970287977193947881e-01
            7.27878810369494089194120078900596e-01 6.85705795086413161243399372324347e-01
            6.71098428359036769386136711545987e-01 7.41368261698618136179561588505749e-01
            6.10075146010524482775849719473626e-01 7.92343559461574309388254278019303e-01
            5.45194772162667651294043480447726e-01 8.38309406130276602020501286460785e-01
            4.76867501428506090910275361238746e-01 8.78975190822433471993235798436217e-01
            4.05525320812993805841273342593922e-01 9.14083811354034714291572072397685e-01
            3.31619278552067853205187475396087e-01 9.43413299722134501834602815506514e-01
            2.55616632440474722542944618908223e-01 9.66778225458037154815826852427563e-01
            1.77997895677550255211230023633107e-01 9.84030867978420653585658328665886e-01
            9.92537989080615468129309419964557e-02 9.95062150522427413257275929936441e-01
            1.98821876650702965283468159896074e-02 9.99802329770065556502345316403080e-01
            -5.96151251698195730477358722509962e-02 9.98221436781932869308775480021723e-01
            -1.38735531989068183733593286888208e-01 9.90329466472501862561728103173664e-01
            -2.16978808106318060699990724060626e-01 9.76176314419050838999680763663491e-01
            -2.93850274337920935874279848576407e-01 9.55851461405760827183542005514028e-01
            -3.68863924524007735783470707247034e-01 9.29483407697387131740640597854508e-01
            -4.41545498215911547124079561399412e-01 8.97238860619212430513869094284019e-01
            -5.11435479103422130364720032957848e-01 8.59321680579661073551278605009429e-01
            -5.78092000224848523437515268597053e-01 8.15971592199160822289627503778320e-01
            -6.41093637592219822707306775555480e-01 7.67462668693908223183086647622986e-01
            -7.00042074569425243346643128461437e-01 7.14101599096749861672606130014174e-01
            -7.54564620158230225932527446275344e-01 6.56225749270375469102134502463741e-01
            -8.04316565270764782802359604829689e-01 5.94201028971710565329544806445483e-01
            -8.48983362091363824575296348484699e-01 5.28419578452619664865608228865312e-01
            -8.88282612749131894602783177106176e-01 4.59297289222977855871477004257031e-01
            -9.21965854728206579693505773320794e-01 3.87271174650641147874097214298672e-01
            -9.49820131727782679398330856201937e-01 3.12796607022227002303793597093318e-01
            -9.71669340040409834635681818326702e-01 2.36344438532904876915097247547237e-01
            -9.87375341936333361658739704580512e-01 1.58398024407215176623253682919312e-01
            -9.96838839014695832219103976967745e-01 7.94501669717143227389399839921680e-02
            -1.00000000000000000000000000000000e+00 1.22464679914735320717376402945840e-16
            -9.96838839014695832219103976967745e-01 -7.94501669717140729387594433319464e-02
            -9.87375341936333472681042167096166e-01 -1.58398024407214954578648757888004e-01
            -9.71669340040410056680286743358010e-01 -2.36344438532904682626067938144843e-01
            -9.49820131727782790420633318717591e-01 -3.12796607022226780259188672062010e-01
            -9.21965854728206690715808235836448e-01 -3.87271174650640925829492289267364e-01
            -8.88282612749132005625085639621830e-01 -4.59297289222977633826872079225723e-01
            -8.48983362091364157642203736031661e-01 -5.28419578452619109754095916287042e-01
            -8.04316565270764893824662067345344e-01 -5.94201028971710343284939881414175e-01
            -7.54564620158230336954829908790998e-01 -6.56225749270375358079832039948087e-01
            -7.00042074569425132324340665945783e-01 -7.14101599096749972694908592529828e-01
            -6.41093637592219933729609238071134e-01 -7.67462668693907890116179260076024e-01
            -5.78092000224848745482120193628361e-01 -8.15971592199160711267325041262666e-01
            -5.11435479103422352409324957989156e-01 -8.59321680579660962528976142493775e-01
            -4.41545498215911769168684486430720e-01 -8.97238860619212319491566631768364e-01
            -3.68863924524008346406134251083131e-01 -9.29483407697386798673733210307546e-01
            -2.93850274337921213430036004865542e-01 -9.55851461405760716161239542998374e-01
            -2.16978808106318088455566339689540e-01 -9.76176314419050838999680763663491e-01
            -1.38735531989067989444563977485814e-01 -9.90329466472501862561728103173664e-01
            -5.96151251698202738760201668810623e-02 -9.98221436781932980331077942537377e-01
            1.98821876650700536670601792366142e-02 -9.99802329770065556502345316403080e-01
            9.92537989080617411019602513988502e-02 -9.95062150522427413257275929936441e-01
            1.77997895677549783366444557941577e-01 -9.84030867978420764607960791181540e-01
            2.55616632440474500498339693876915e-01 -9.66778225458037154815826852427563e-01
            3.31619278552067853205187475396087e-01 -9.43413299722134501834602815506514e-01
            4.05525320812993361752063492531306e-01 -9.14083811354034825313874534913339e-01
            4.76867501428505757843367973691784e-01 -8.78975190822433916082445648498833e-01
            5.45194772162667540271741017932072e-01 -8.38309406130276602020501286460785e-01
            6.10075146010523927664337406895356e-01 -7.92343559461574753477464128081920e-01
            6.71098428359036436319229323999025e-01 -7.41368261698618358224166513537057e-01
            7.27878810369493978171817616384942e-01 -6.85705795086413272265701834840002e-01
            7.80057308185211684126159070729045e-01 -6.25708075660560525399489506526152e-01
            8.27304032543056955262272822437808e-01 -5.61754428320771270755074056069134e-01
            8.69320274439582485470623396395240e-01 -4.94249188616723067468683439074084e-01
            9.05840393665523269106643056147732e-01 -4.23619146408527991187753514168435e-01
            9.36633498268727660018839742406271e-01 -3.50310847563824800943166337674484e-01
            9.61504904327420195642162070726044e-01 -2.74787770751025561821734299883246e-01
            9.80297366804636194359545697807334e-01 -1.97527397177952701579073391258135e-01
            9.92892073701973298938128209556453e-01 -1.19018191801905412474660295174544e-01
            9.99209397227301843180669038702035e-01 -3.97565150969260081015299590490031e-02
            9.87499190610889310271147678577108e-01 4.13884788918244400646173630775593e-02
            9.80572593305943485120224067941308e-01 1.23875126233628257699237451561203e-01
            9.66767983799392660593241544120247e-01 2.05492878569058540216829555902223e-01
            9.46182191508327052886784258589614e-01 2.85669246007756449934333886631066e-01
            9.18959610974797169724581635819050e-01 3.63841848938779965916268110959209e-01
            8.85291189041848558538561064779060e-01 4.39462362719505672536968177155359e-01
            8.45413085498613159352032653259812e-01 5.12000363779026135269134556438075e-01
            7.99605016589068795518358001572778e-01 5.80947050158390543295183761074441e-01
            7.48188293003563820171564202610170e-01 6.45818810390773379026541078928858e-01
            6.91523566115185950309296458726749e-01 7.06160615688440018722360491665313e-01
            6.30008298269506439304166178771993e-01 7.61549211642754686479861447878648e-01
            5.64073974871804328934388195193605e-01 8.11596087049748948771821233094670e-01
            4.94183077826967909196298478491371e-01 8.55950199037073367058781059313333e-01
            4.20825841561227209641771196402260e-01 8.94300435377522018320917140954407e-01
            3.44516814379884461772007853141986e-01 9.26377796717773649426419524388621e-01
            2.65791249280656283193735589520657e-01 9.51957283415578836560655417997623e-01
            1.85201349538473586386899683020602e-01 9.70859473750587897988850727415411e-01
            1.03312395396264536384656196332799e-01 9.82951782438806320740809496783186e-01
            2.06987790302041591017356836346153e-02 9.88149390623097700903088025370380e-01
            -6.20600243987006611190437865843705e-02 9.86415840816525557599447893153410e-01
            -1.44383521346514609451361366154742e-01 9.77763292625429381033086428942624e-01
            -2.25694271631499909780416146531934e-01 9.62252437458522180691034009214491e-01
            -3.05421938762100664277454598050099e-01 9.39992072820265978094766978756525e-01
            -3.83007290437645531167021317742183e-01 9.11138339174547895460420932067791e-01
            -4.57906121161128443208809812858817e-01 8.75893624731514108816554653458297e-01
            -5.29593069449760478484279246913502e-01 8.34505145839689710385300713824108e-01
            -5.97565302868297898442051518941298e-01 7.87263212940919832050212789908983e-01
            -6.61346045037291885293484483554494e-01 7.34499194251207354611210575967561e-01
            -7.20487919876826699017158261995064e-01 6.76583191450765952801305047614733e-01
            -7.74576089628282171695161650859518e-01 6.13921443686649470627969549241243e-01
            -8.23231164643147717008275776606752e-01 5.46953478097019885062479715998052e-01
            -8.66111864528817165798102450935403e-01 4.76149026844071454611651006416650e-01
            -9.02917411985332929447167771286331e-01 4.02004732280415999490230660740053e-01
            -9.33389642542037267780585807486204e-01 3.25040663359814741006914573517861e-01
            -9.57314815395841955947275891958270e-01 2.45796667727138679060416848187742e-01
            -9.74525112649390790053871569398325e-01 1.64828585075018879679831229623233e-01
            -9.84899816433031372042705697822385e-01 8.27043483277732499603374094476749e-02
            -9.88366155653936040437201882014051e-01 1.21039944890716732844521811449042e-16
            -9.84899816433031372042705697822385e-01 -8.27043483277730001601568687874533e-02
            -9.74525112649390679031569106882671e-01 -1.64828585075019073968860539025627e-01
            -9.57314815395842066969578354473924e-01 -2.45796667727138457015811923156434e-01
            -9.33389642542037156758283344970550e-01 -3.25040663359814907540368267291342e-01
            -9.02917411985333040469470233801985e-01 -4.02004732280415777445625735708745e-01
            -8.66111864528817276820404913451057e-01 -4.76149026844071232567046081385342e-01
            -8.23231164643147605985973314091098e-01 -5.46953478097020107107084641029360e-01
            -7.74576089628282282717464113375172e-01 -6.13921443686649248583364624209935e-01
            -7.20487919876827143106368112057680e-01 -6.76583191450765508712095197552117e-01
            -6.61346045037291774271182021038840e-01 -7.34499194251207465633513038483215e-01
            -5.97565302868298453553563831519568e-01 -7.87263212940919387961002939846367e-01
            -5.29593069449760367461976784397848e-01 -8.34505145839689710385300713824108e-01
            -4.57906121161129053831473356694914e-01 -8.75893624731513775749647265911335e-01
            -3.83007290437645753211626242773491e-01 -9.11138339174547784438118469552137e-01
            -3.05421938762100886322059523081407e-01 -9.39992072820265867072464516240871e-01
            -2.25694271631500159580596687192156e-01 -9.62252437458522180691034009214491e-01
            -1.44383521346515691918810375682369e-01 -9.77763292625429270010783966426970e-01
            -6.20600243987006888746194022132840e-02 -9.86415840816525557599447893153410e-01
            2.06987790302034790901331007262343e-02 -9.88149390623097700903088025370380e-01
            1.03312395396264730673685505735193e-01 -9.82951782438806320740809496783186e-01
            1.85201349538473114542114217329072e-01 -9.70859473750588009011153189931065e-01
            2.65791249280656061149130664489348e-01 -9.51957283415578836560655417997623e-01
            3.44516814379884239727402928110678e-01 -9.26377796717773760448721986904275e-01
            4.20825841561227154130619965144433e-01 -8.94300435377522018320917140954407e-01
            4.94183077826967354084786165913101e-01 -8.55950199037073700125688446860295e-01
            5.64073974871804328934388195193605e-01 -8.11596087049748948771821233094670e-01
            6.30008298269505995214956328709377e-01 -7.61549211642755019546768835425610e-01
            6.91523566115186172353901383758057e-01 -7.06160615688439796677755566634005e-01
            7.48188293003563598126959277578862e-01 -6.45818810390773712093448466475820e-01
            7.99605016589068684496055539057124e-01 -5.80947050158390765339788686105749e-01
            8.45413085498613159352032653259812e-01 -5.12000363779026246291437018953729e-01
            8.85291189041848558538561064779060e-01 -4.39462362719505728048119408413186e-01
            9.18959610974796836657674248272087e-01 -3.63841848938780743072385348568787e-01
            9.46182191508327163909086721105268e-01 -2.85669246007756172378577730341931e-01
            9.66767983799392549570939081604593e-01 -2.05492878569059067572766252851579e-01
            9.80572593305943485120224067941308e-01 -1.23875126233627799732239793684130e-01
            9.87499190610889310271147678577108e-01 -4.13884788918247453759491349956079e-02
            9.66161641605232879292941561288899e-01 4.27784332818988838331719648522267e-02
            9.58600116789303569042601793626091e-01 1.28000500604122324777023322894820e-01
            9.43536246341423745498389052954735e-01 2.12220790459625607837779170949943e-01
            9.21087925472198643106480631104205e-01 2.94780164890200147009835518474574e-01
            8.91430842728988315215588045248296e-01 3.75032484852789838036812852806179e-01
            8.54797104994817091849768075917382e-01 4.52349667133570443322554410769953e-01
            8.11473420937312228673476965923328e-01 5.26126599950684892270658110646764e-01
            7.61798857124645789618000435439171e-01 5.95785878774376387312372571614105e-01
            7.06162184369914180948057946807239e-01 6.60782325300309225646344657434383e-01
            6.44998835072412735058833277435042e-01 7.20607254208978198484203403495485e-01
            5.78787495368727755717941363400314e-01 7.74792454318036893923249408544507e-01
            5.08046358764693062326500694325659e-01 8.22913852969622272581773358979262e-01
            4.33329070568613194947005240464932e-01 8.64594834973882009343526533484692e-01
            3.55220394866065714012393073062412e-01 8.99509190133468639061220528674312e-01
            2.74331637948079409827784047593013e-01 9.27383666280626406397402661241358e-01
            1.91295864010568333890560666077363e-01 9.48000107845891837321516959491419e-01
            1.06762940568655775863682322324166e-01 9.61197163221212402817172915092669e-01
            2.13944523622491555858715628346545e-02 9.66871547555047117228355091356207e-01
            -6.41414764415630805904910971548816e-02 9.64978851096369272255515170400031e-01
            -1.49175411225991982888672282570042e-01 9.55533886761180561997264248930151e-01
            -2.33041846158079490880510320494068e-01 9.38610574201359848522940865223063e-01
            -3.15084412674167646528644581849221e-01 9.14341361283162790130063513061032e-01
            -3.94661016453844715190513170455233e-01 8.82916187503089422428104171558516e-01
            -4.71148862678587743157976319707814e-01 8.44580997453794002360893955483334e-01
            -5.43949330245632634017738382681273e-01 7.99635815974184649412848102656426e-01
            -6.12492656789746847678657104552258e-01 7.48432400048267498782195161766140e-01
            -6.76242397846244847059438143332954e-01 6.91371485829820331403539057646412e-01
            -7.34699625256266197759202896122588e-01 6.28899652338649528537928290461423e-01
            -7.87406831956089070523319151106989e-01 5.61505826374266159284331934031798e-01
            -8.33951512590215937592574846348725e-01 4.89717456000767104029591791913845e-01
            -8.73969391925073613158758689678507e-01 4.14096382550595720761776874496718e-01
            -9.07147275796621466170677194895688e-01 3.35234443454339559043120289061335e-01
            -9.33225502279326546428706024016719e-01 2.53748840310396406305670780056971e-01
            -9.51999973892795781083009387657512e-01 1.70277308445630881639232256929972e-01
            -9.63323754941284193797912394074956e-01 8.54731257717708386989485802587296e-02
            -9.67108221484737629047856444231002e-01 1.18436598787037343684079274079939e-16
            -9.63323754941284193797912394074956e-01 -8.54731257717706027765558474129648e-02
            -9.51999973892795892105311850173166e-01 -1.70277308445630659594627331898664e-01
            -9.33225502279326657451008486532373e-01 -2.53748840310396184261065855025663e-01
            -9.07147275796621355148374732380034e-01 -3.35234443454339725576573982834816e-01
            -8.73969391925073946225666077225469e-01 -4.14096382550595110139113330660621e-01
            -8.33951512590215826570272383833071e-01 -4.89717456000767326074196716945153e-01
            -7.87406831956089181545621613622643e-01 -5.61505826374265937239727009000489e-01
            -7.34699625256266419803807821153896e-01 -6.28899652338649417515625827945769e-01
            -6.76242397846244736037135680817300e-01 -6.91371485829820553448143982677720e-01
            -6.12492656789746958700959567067912e-01 -7.48432400048267276737590236734832e-01
            -5.43949330245633189129250695259543e-01 -7.99635815974184205323638252593810e-01
            -4.71148862678587188046464007129543e-01 -8.44580997453794224405498880514642e-01
            -3.94661016453845325813176714291330e-01 -8.82916187503089089361196784011554e-01
            -3.15084412674167813062098275622702e-01 -9.14341361283162679107761050545378e-01
            -2.33041846158080129258749479959079e-01 -9.38610574201359626478335940191755e-01
            -1.49175411225992621266911442035052e-01 -9.55533886761180450974961786414497e-01
            -6.41414764415631083460667127837951e-02 -9.64978851096369272255515170400031e-01
            2.13944523622487045577678088648099e-02 -9.66871547555047117228355091356207e-01
            1.06762940568655331774472472261550e-01 -9.61197163221212402817172915092669e-01
            1.91295864010568306134985050448449e-01 -9.48000107845891837321516959491419e-01
            2.74331637948079409827784047593013e-01 -9.27383666280626406397402661241358e-01
            3.55220394866066102590451691867202e-01 -8.99509190133468528038918066158658e-01
            4.33329070568613361480458934238413e-01 -8.64594834973881898321224070969038e-01
            5.08046358764692396192685919231735e-01 -8.22913852969622605648680746526225e-01
            5.78787495368727644695638900884660e-01 -7.74792454318037004945551871060161e-01
            6.44998835072412290969623427372426e-01 -7.20607254208978531551110791042447e-01
            7.06162184369913736858848096744623e-01 -6.60782325300309558713252044981346e-01
            7.61798857124645678595697972923517e-01 -5.95785878774376498334675034129759e-01
            8.11473420937312006628872040892020e-01 -5.26126599950685003292960573162418e-01
            8.54797104994817202872070538433036e-01 -4.52349667133570276789100716996472e-01
            8.91430842728988315215588045248296e-01 -3.75032484852789838036812852806179e-01
            9.21087925472198643106480631104205e-01 -2.94780164890200424565591674763709e-01
            9.43536246341423856520691515470389e-01 -2.12220790459625247015296167774068e-01
            9.58600116789303680064904256141745e-01 -1.28000500604122185999145244750252e-01
            9.66161641605232879292941561288899e-01 -4.27784332818998622172124157714279e-02
            9.38555954877792641966038900136482e-01 4.40406465093102772456745697127189e-02
            9.30307891399417385969172755721956e-01 1.31734908742872525166944797092583e-01
            9.13884248721083869426706769445445e-01 2.18271479861715217429818380878714e-01
            8.89429358405181225144531254045432e-01 3.02889873367319317765122832497582e-01
            8.57158130907110571428120238124393e-01 3.84846459775001425995810677704867e-01
            8.17354166934475823147465689544333e-01 4.63421001656562969728270218183752e-01
            7.70367265153867775140383855614346e-01 5.37922983112706809549763420363888e-01
            7.16610348147605158430906158173457e-01 6.07697678051587697467539328499697e-01
            6.56555833635233843104117568145739e-01 6.72131903945249797871497321466450e-01
            5.90731482849620626041087234625593e-01 7.30659410499729045085359757649712e-01
            5.19715762552263149665066066518193e-01 7.82765855882998184966936605633236e-01
            4.44132761446590751397422991431085e-01 8.27993326779478899801745228614891e-01
            3.64646705663997539037524120431044e-01 8.65944362548724644312869713758118e-01
            2.81956121520718028250485076569021e-01 8.96285448123820160937214041041443e-01
            1.96787696843442272420787730879965e-01 9.18749944953781483292232223902829e-01
            1.09889894810568239380543786865019e-01 9.33140434232728632757414288789732e-01
            2.20263764308750512044277058976149e-02 9.39330451823450984782937212003162e-01
            -6.60307105368771324327425986666640e-02 9.37265599628791634678748323494801e-01
            -1.53507517246217750628289877568022e-01 9.26964023644081480668432959646452e-01
            -2.39635294374451079946197751269210e-01 9.08516254489479813116759032709524e-01
            -3.23657147919345966613491327734664e-01 8.82084411823629177540340151608689e-01
            -4.04834690810843722541534361880622e-01 8.47900779630265333253191784024239e-01
            -4.82454531883176718221051260115928e-01 8.06265764898217551781556267087581e-01
            -5.55834545182087302883644497342175e-01 7.57545257633988056156226775783580e-01
            -6.24329864512237042717401891422924e-01 7.02167415407219608347588746255497e-01
            -6.87338550544521531548980419756845e-01 6.40618900686577785741349089221330e-01
            -7.44306880680536075978181997925276e-01 5.73440604032478207230383304704446e-01
            -7.94734215186679970877037249010755e-01 5.01222890731394032926004911132623e-01
            -8.38177396834137611314474725077162e-01 4.24600412644490665670105045137461e-01
            -8.74254645380539985310974770982284e-01 3.44246530864247779479825339876697e-01
            -9.02648912668459812991272883664351e-01 2.60867398192971444714771678263787e-01
            -9.23110668856020888384250611125026e-01 1.75195753446574398193291699499241e-01
            -9.35460095294119997610948757937877e-01 8.79844821195145954106919816695154e-02
            -9.39588664779180460229213167622220e-01 1.15066425083695890784718478269811e-16
            -9.35460095294119997610948757937877e-01 -8.79844821195143594882992488237505e-02
            -9.23110668856020999406553073640680e-01 -1.75195753446574148393111158839019e-01
            -9.02648912668459924013575346180005e-01 -2.60867398192971222670166753232479e-01
            -8.74254645380539985310974770982284e-01 -3.44246530864247557435220414845389e-01
            -8.38177396834137944381382112624124e-01 -4.24600412644490055047441501301364e-01
            -7.94734215186679859854734786495101e-01 -5.01222890731394254970609836163931e-01
            -7.44306880680536187000484460440930e-01 -5.73440604032478096208080842188792e-01
            -6.87338550544521642571282882272499e-01 -6.40618900686577563696744164190022e-01
            -6.24329864512237264762006816454232e-01 -7.02167415407219497325286283739842e-01
            -5.55834545182087413905946959857829e-01 -7.57545257633987834111621850752272e-01
            -4.82454531883176940265656185147236e-01 -8.06265764898217440759253804571927e-01
            -4.04834690810843556008080668107141e-01 -8.47900779630265333253191784024239e-01
            -3.23657147919346632747306102828588e-01 -8.82084411823628955495735226577381e-01
            -2.39635294374451274235227060671605e-01 -9.08516254489479813116759032709524e-01
            -1.53507517246217778383865493196936e-01 -9.26964023644081480668432959646452e-01
            -6.60307105368769520215010970787262e-02 -9.37265599628791634678748323494801e-01
            2.20263764308748187514819250054643e-02 -9.39330451823450984782937212003162e-01
            1.09889894810568017335938861833711e-01 -9.33140434232728743779716751305386e-01
            1.96787696843442466709817040282360e-01 -9.18749944953781483292232223902829e-01
            2.81956121520717362116670301475096e-01 -8.96285448123820382981818966072751e-01
            3.64646705663997316992919195399736e-01 -8.65944362548724755335172176273772e-01
            4.44132761446590751397422991431085e-01 -8.27993326779478899801745228614891e-01
            5.19715762552262705575856216455577e-01 -7.82765855882998518033843993180199e-01
            5.90731482849620848085692159656901e-01 -7.30659410499728823040754832618404e-01
            6.56555833635233732081815105630085e-01 -6.72131903945249797871497321466450e-01
            7.16610348147604825363998770626495e-01 -6.07697678051588252579051641077967e-01
            7.70367265153867997184988780645654e-01 -5.37922983112706476482856032816926e-01
            8.17354166934475712125163227028679e-01 -4.63421001656563302795177605730714e-01
            8.57158130907110238361212850577431e-01 -3.84846459775002203151927915314445e-01
            8.89429358405181336166833716561086e-01 -3.02889873367319151231669138724101e-01
            9.13884248721083869426706769445445e-01 -2.18271479861715606007876999683504e-01
            9.30307891399417385969172755721956e-01 -1.31734908742872719455974106494978e-01
            9.38555954877792641966038900136482e-01 -4.40406465093102009178416267332068e-02
            9.05879260727605828407149601844139e-01 4.52105543333977191733374922932853e-02
            8.96876225650846681247685410198756e-01 1.35182340199518413736967659133370e-01
            8.78959631704707589072711471089860e-01 2.23810623235474820402757245574321e-01
            8.52307542049199007294646435184404e-01 3.10214575746498077979396157388692e-01
            8.17184837125280338909760757815093e-01 3.93535476433899245041203585060430e-01
            7.73940582154034828477051632944494e-01 4.72945244753132654214056174168945e-01
            7.23004557969678551820891243551159e-01 5.47654670750279182200870309316088e-01
            6.64882989664542289887094739242457e-01 6.16921258585135023899681527836947e-01
            6.00153515496672729234717280633049e-01 6.80056605788453394367820692423265e-01
            5.29459446061309346731604819069616e-01 7.36433244914960649651902713230811e-01
            4.53503370781168091419033316924470e-01 7.85490879596730473544141659658635e-01
            3.73040175257108697071117831001175e-01 8.26741953020210806890588628448313e-01
            2.88869538875883791195775529558887e-01 8.59776493484883164164500612969277e-01
            2.01827987237124639730012631844147e-01 8.84266188886207449293408444646047e-01
            1.12780578386105168053887837231741e-01 8.99967649628820032248199822788592e-01
            2.26123054782446826493913505373712e-02 9.06724827541677824704891008877894e-01
            -6.77806986804711242289300798802287e-02 9.04470566754891125427207043685485e-01
            -1.57500067803920118514326986769447e-01 8.93227271124928945411625136330258e-01
            -2.45654130493604738738611104054144e-01 8.73106681575028353847756079630926e-01
            -3.31366772069609960560399031237466e-01 8.44308765563697161127265644608997e-01
            -4.13786141791903538944552565226331e-01 8.07119729718272727048145043227123e-01
            -4.92093118935701956395689649070846e-01 7.61909175384874903791398992325412e-01
            -5.65509453581236609664983916445635e-01 7.09126425364178802901449216733454e-01
            -6.33305501211102628289495442004409e-01 6.49296058339553616711725680943346e-01
            -6.94807474245278666735714523383649e-01 5.83012695378431033965682672715047e-01
            -7.49404138444809020391801368532469e-01 5.10935090320992046919457152398536e-01
            -7.96552887632279493779208223713795e-01 4.33779582788545003957381140935468e-01
            -8.35785136355783664363627849525074e-01 3.52312978878540739025027050956851e-01
            -8.66710976901666652061351214797469e-01 2.67344930301072758460634304356063e-01
            -8.89023054372556464919341578934109e-01 1.79719887696429714285528689288185e-01
            -9.02499621318417877269268956297310e-01 9.03087081052502960165639933620696e-02
            -9.07006741562336404882671558880247e-01 1.11076290285938584731128726368075e-16
            -9.02499621318417877269268956297310e-01 -9.03087081052500739719590683307615e-02
            -8.89023054372556575941644041449763e-01 -1.79719887696429492240923764256877e-01
            -8.66710976901666874105956139828777e-01 -2.67344930301072147837970760519966e-01
            -8.35785136355783553341325387009420e-01 -3.52312978878540905558480744730332e-01
            -7.96552887632279493779208223713795e-01 -4.33779582788544781912776215904159e-01
            -7.49404138444809131414103831048124e-01 -5.10935090320992046919457152398536e-01
            -6.94807474245278888780319448414957e-01 -5.83012695378430922943380210199393e-01
            -6.33305501211102850334100367035717e-01 -6.49296058339553505689423218427692e-01
            -5.65509453581236831709588841476943e-01 -7.09126425364178580856844291702146e-01
            -4.92093118935701845373387186555192e-01 -7.61909175384874903791398992325412e-01
            -4.13786141791904094056064877804602e-01 -8.07119729718272393981237655680161e-01
            -3.31366772069610737716516268847045e-01 -8.44308765563696828060358257062035e-01
            -2.45654130493604377916128100878268e-01 -8.73106681575028464870058542146580e-01
            -1.57500067803920146269902602398361e-01 -8.93227271124928945411625136330258e-01
            -6.77806986804715405625643143139314e-02 -9.04470566754891125427207043685485e-01
            2.26123054782444606047864255060631e-02 -9.06724827541677824704891008877894e-01
            1.12780578386104543553436485581187e-01 -8.99967649628820032248199822788592e-01
            2.01827987237124417685407706812839e-01 -8.84266188886207449293408444646047e-01
            2.88869538875883902218077992074541e-01 -8.59776493484883053142198150453623e-01
            3.73040175257108364004210443454213e-01 -8.26741953020211028935193553479621e-01
            4.53503370781168313463638241955778e-01 -7.85490879596730362521839197142981e-01
            5.29459446061308902642394969007000e-01 -7.36433244914960871696507638262119e-01
            6.00153515496672174123204968054779e-01 -6.80056605788453949479333005001536e-01
            6.64882989664542400909397201758111e-01 -6.16921258585134912877379065321293e-01
            7.23004557969678440798588781035505e-01 -5.47654670750279293223172771831742e-01
            7.73940582154034939499354095460149e-01 -4.72945244753132543191753711653291e-01
            8.17184837125280227887458295299439e-01 -3.93535476433899411574657278833911e-01
            8.52307542049198785250041510153096e-01 -3.10214575746498688602059701224789e-01
            8.78959631704707478050409008574206e-01 -2.23810623235475097958513401863456e-01
            8.96876225650846681247685410198756e-01 -1.35182340199518358225816427875543e-01
            9.05879260727605828407149601844139e-01 -4.52105543333981216291839189125312e-02
            8.68822261843466780995015597000020e-01 4.63062403612670286934260843736411e-02
            8.58978158453019169371600582962856e-01 1.38394052877473111573536357354897e-01
            8.39401489297041836223911559500266e-01 2.28913805475119774834880104208423e-01
            8.10314065859512266953856851614546e-01 3.16839873187417686573041919473326e-01
            7.72045460270722183615532685507787e-01 4.01176018533712486213715919802780e-01
            7.25029271123351470862417045282200e-01 4.80966679288216847343306881157332e-01
            6.69798210627156054286501785099972e-01 5.55307795381852042915227229968878e-01
            6.06978068766769518482817602489376e-01 6.23357052264074118497205745370593e-01
            5.37280622851125211347778076742543e-01 6.84343424663304444877098831057083e-01
            4.61495572792133879058695811181678e-01 7.37575912611341477642667996406090e-01
            3.80481593489133185226336308915052e-01 7.82451370749111085878269022941822e-01
            2.95156605699169849454932545995689e-01 8.18461342204589215043597505427897e-01
            2.06487375628039204755737046070863e-01 8.45197819612330758509699535352411e-01
            1.15478561082874339738246760589391e-01 8.62357867999951399617941660835641e-01
            2.31613282977483452007572140018965e-02 8.69747057162412517961058711080113e-01
            -6.94183315917881460510585611700662e-02 8.67281664633932747321409806318115e-01
            -1.61211454046231966730218232441985e-01 8.54989624296980887940833326865686e-01
            -2.51177986309503054052072457125178e-01 8.33010209880224783418611878005322e-01
            -3.38298571622256905033765406187740e-01 8.01592456931534247388526637223549e-01
            -4.21586098941279963092654270440107e-01 7.61092341145715445271946464345092e-01
            -5.00096887302040604694752801151481e-01 7.11968745017646842399017259594984e-01
            -5.72941378101091913777054287493229e-01 6.54778258520252398611205535416957e-01
            -6.39294214150499140458805413800292e-01 5.90168872717706571862095188407693e-01
            -6.98403591304574855591624782391591e-01 5.18872637767752609150306852825452e-01
            -7.49599776701253661670421024609823e-01 4.41697368500904130605988484603586e-01
            -7.92302697103034359038531420083018e-01 3.59517491555626900190389960698667e-01
            -8.26028511358543382492314322007587e-01 2.73264137775123316931313866007258e-01
            -8.50395092516114003977634183684131e-01 1.83914592122818687514040902897250e-01
            -8.65126357474839235983665730600478e-01 9.24812206532206609876922698276758e-02
            -8.70055395116421825818520119355526e-01 1.06551055471021163190398692098659e-16
            -8.65126357474839235983665730600478e-01 -9.24812206532200781206043416204921e-02
            -8.50395092516114003977634183684131e-01 -1.83914592122818854047494596670731e-01
            -8.26028511358543493514616784523241e-01 -2.73264137775123039375557709718123e-01
            -7.92302697103034692105438807629980e-01 -3.59517491555626289567726416862570e-01
            -7.49599776701253772692723487125477e-01 -4.41697368500903964072534790830105e-01
            -6.98403591304574744569322319875937e-01 -5.18872637767752609150306852825452e-01
            -6.39294214150499695570317726378562e-01 -5.90168872717706127772885338345077e-01
            -5.72941378101092135821659212524537e-01 -6.54778258520252287588903072901303e-01
            -5.00096887302040382650147876120172e-01 -7.11968745017646953421319722110638e-01
            -4.21586098941279796559200576666626e-01 -7.61092341145715556294248926860746e-01
            -3.38298571622257460145277718766010e-01 -8.01592456931534025343921712192241e-01
            -2.51177986309503054052072457125178e-01 -8.33010209880224783418611878005322e-01
            -1.61211454046231800196764538668504e-01 -8.54989624296980887940833326865686e-01
            -6.94183315917889509627514144085580e-02 -8.67281664633932747321409806318115e-01
            2.31613282977483243840755022802114e-02 -8.69747057162412517961058711080113e-01
            1.15478561082874117693641835558083e-01 -8.62357867999951510640244123351295e-01
            2.06487375628038455355195424090198e-01 -8.45197819612330869532001997868065e-01
            2.95156605699169682921478852222208e-01 -8.18461342204589326065899967943551e-01
            3.80481593489132963181731383883744e-01 -7.82451370749111085878269022941822e-01
            4.61495572792133657014090886150370e-01 -7.37575912611341477642667996406090e-01
            5.37280622851125100325475614226889e-01 -6.84343424663304444877098831057083e-01
            6.06978068766769296438212677458068e-01 -6.23357052264074340541810670401901e-01
            6.69798210627156276331106710131280e-01 -5.55307795381851709848319842421915e-01
            7.25029271123351359840114582766546e-01 -4.80966679288217235921365499962121e-01
            7.72045460270721961570927760476479e-01 -4.01176018533712874791774538607569e-01
            8.10314065859512377976159314130200e-01 -3.16839873187417353506134531926364e-01
            8.39401489297041725201609096984612e-01 -2.28913805475120246679665569899953e-01
            8.58978158453019280393903045478510e-01 -1.38394052877472889528931432323589e-01
            8.68822261843466780995015597000020e-01 -4.63062403612668344043967749712465e-02
            8.27849751143664214225736941443756e-01 4.73381614875441752987583754475054e-02
            8.17057463604481726271444586018333e-01 1.41397359133254768570608916888887e-01
            7.95613582498866600545284200052265e-01 2.33613225963272080898391891423671e-01
            7.63797661611220091160134870733600e-01 3.22783587127474291822437635346432e-01
            7.22024470126492623478497989708558e-01 4.07745970599594165229007103334880e-01
            6.70838585479550775225732195394812e-01 4.87392761777853067428623035084456e-01
            6.10907293955488817083221420034533e-01 5.60685642935174088918870438646991e-01
            5.43011891592421247487720847857418e-01 6.26669129278655367976114121120190e-01
            4.68037498792786110790586917573819e-01 6.84483025155073088185986307507847e-01
            3.86961521425283061503819226345513e-01 7.33373638016719175958257892489200e-01
            3.00840908844624443929660628782585e-01 7.72703603956386375628540008619893e-01
            2.10798374940302291058458195038838e-01 8.01960196720619800103690977266524e-01
            1.18007761844066916268047862104140e-01 8.20762011880545983011359112424543e-01
            2.36787371025821286041335156369314e-02 8.28863939021884599256395631527994e-01
            -7.09589761889964920626994171470869e-02 8.26160357134047673710597337048966e-01
            -1.64671630708183303060110347360023e-01 8.12686511541538592062750012701144e-01
            -2.56237538688286636823221442682552e-01 7.88618054427247083815188943844987e-01
            -3.44462998486777249862456073969952e-01 7.54268754937619134715021118609002e-01
            -4.28197856311730351563937801984139e-01 7.10086408721985251624175816687057e-01
            -5.06350500235436706830682851432357e-01 6.56647000231456723362555294443155e-01
            -5.77902091025286113179504354775418e-01 5.94647193880749380667793957400136e-01
            -6.41919844271277462155467219417915e-01 5.24895251962128717160283031262225e-01
            -6.97569190657313376036086083331611e-01 4.48300497710351075753010263724718e-01
            -7.44124655848545368819202394661261e-01 3.65861460883667721777356973689166e-01
            -7.80979318158797730653475355211413e-01 2.78652860401373048127027232112596e-01
            -8.07652720702914383998916036944138e-01 1.87811593739118820600708659185329e-01
            -8.23797134887020887639152988413116e-01 9.45219157316602859308929396320309e-02
            -8.29202093582528054760416580393212e-01 1.01547968975212702788592865656797e-16
            -8.23797134887020887639152988413116e-01 -9.45219157316600777640758224151796e-02
            -8.07652720702914383998916036944138e-01 -1.87811593739118626311679349782935e-01
            -7.80979318158797730653475355211413e-01 -2.78652860401372881593573538339115e-01
            -7.44124655848545368819202394661261e-01 -3.65861460883667832799659436204820e-01
            -6.97569190657313598080691008362919e-01 -4.48300497710350576152649182404275e-01
            -6.41919844271277573177769681933569e-01 -5.24895251962128495115678106230916e-01
            -5.77902091025286335224109279806726e-01 -5.94647193880749269645491494884482e-01
            -5.06350500235437150919892701494973e-01 -6.56647000231456279273345444380539e-01
            -4.28197856311730851164298883304582e-01 -7.10086408721985029579570891655749e-01
            -3.44462998486777305373607305227779e-01 -7.54268754937619134715021118609002e-01
            -2.56237538688286803356675136456033e-01 -7.88618054427246972792886481329333e-01
            -1.64671630708183691638168966164812e-01 -8.12686511541538481040447550185490e-01
            -7.09589761889970471742117297253571e-02 -8.26160357134047562688294874533312e-01
            2.36787371025819239067633503736943e-02 -8.28863939021884599256395631527994e-01
            1.18007761844066708101230744887289e-01 -8.20762011880546094033661574940197e-01
            2.10798374940301735946945882460568e-01 -8.01960196720620022148295902297832e-01
            3.00840908844624554951963091298239e-01 -7.72703603956386264606237546104239e-01
            3.86961521425282894970365532572032e-01 -7.33373638016719286980560355004855e-01
            4.68037498792785833234830761284684e-01 -6.84483025155073199208288770023501e-01
            5.43011891592421469532325772888726e-01 -6.26669129278655367976114121120190e-01
            6.10907293955488928105523882550187e-01 -5.60685642935173977896567976131337e-01
            6.70838585479550997270337120426120e-01 -4.87392761777852734361715647537494e-01
            7.22024470126492401433893064677250e-01 -4.07745970599594498295914490881842e-01
            7.63797661611219758093227483186638e-01 -3.22783587127474846933949947924702e-01
            7.95613582498866600545284200052265e-01 -2.33613225963272164165118738310412e-01
            8.17057463604481726271444586018333e-01 -1.41397359133255046126365073178022e-01
            8.27849751143664214225736941443756e-01 -4.73381614875446471435438411390351e-02
            7.83301485443077982750992305227555e-01 4.83123819263840403870347017800668e-02
            7.71427433377329663244381663389504e-01 1.44204779316078585127414157796011e-01
            7.47859327771407622620358779386152e-01 2.37911179245599430087665382416162e-01
            7.12954437082293335237181963748299e-01 3.28011088211059453900730886743986e-01
            6.67241883872747854056228788977023e-01 4.13138683435332332294365187408403e-01
            6.11414623852616578858487628167495e-01 4.92003517349110797152178520263988e-01
            5.46318941376629285677779535035370e-01 5.63410079460646806559509514045203e-01
            4.72941620636237347596875224553514e-01 6.26275919076171083688109320064541e-01
            3.92394987017142260476987303263741e-01 6.79648054149020630632094253087416e-01
            3.05900045380292862073901005715015e-01 7.22717417516049676073919272312196e-01
            2.14767970872814573102260737869074e-01 7.54831121531105875277489758445881e-01
            1.20380232849319521171160829453584e-01 7.75502355176228230781987349473638e-01
            2.41676532046811894105520224229622e-02 7.84417763620452235251434558449546e-01
            -7.24112834273907407522941070965317e-02 7.81442198359630135762188274384243e-01
            -1.67892538814701591798339563865738e-01 7.66620765929991732079429311852437e-01
            -2.60828714453811894014023664567503e-01 7.40178144139034377424479771434562e-01
            -3.49810992655954167140919253142783e-01 7.02515176178984290800144663080573e-01
            -4.33490492787123760098921820826945e-01 6.54202794252600083879656267527025e-01
            -5.10598718923517713719206767564174e-01 5.95973364822955709030338766751811e-01
            -5.79966788956705836532989906118019e-01 5.28709586684392607303095701354323e-01
            -6.40543153654902552851524433208397e-01 4.53431110148570681861457387640257e-01
            -6.91409537077429026119546051631914e-01 3.71279080185119791934766908525489e-01
            -7.31794856701936002885133802919881e-01 2.83498837827117489140960060467478e-01
            -7.61086912249444025313493966677925e-01 1.91421042070458985451253397513938e-01
            -7.78841666016530043137322536495049e-01 9.64414984398788005526270694645063e-02
            -7.84789974034284742998579531558789e-01 9.61090529704021293305506869303840e-17
            -7.78841666016530043137322536495049e-01 -9.64414984398786062635977600621118e-02
            -7.61086912249444025313493966677925e-01 -1.91421042070459124229131475658505e-01
            -7.31794856701936113907436265435535e-01 -2.83498837827117322607506366693997e-01
            -6.91409537077429137141848514147568e-01 -3.71279080185119625401313214752008e-01
            -6.40543153654902663873826895724051e-01 -4.53431110148570515328003693866776e-01
            -5.79966788956705947555292368633673e-01 -5.28709586684392385258490776323015e-01
            -5.10598718923517602696904305048520e-01 -5.95973364822955820052641229267465e-01
            -4.33490492787123926632375514600426e-01 -6.54202794252600083879656267527025e-01
            -3.49810992655954056118616790627129e-01 -7.02515176178984290800144663080573e-01
            -2.60828714453812060547477358340984e-01 -7.40178144139034377424479771434562e-01
            -1.67892538814701952620822567041614e-01 -7.66620765929991621057126849336782e-01
            -7.24112834273907685078697227254452e-02 -7.81442198359630135762188274384243e-01
            2.41676532046809985909696649741818e-02 -7.84417763620452235251434558449546e-01
            1.20380232849319673826826715412608e-01 -7.75502355176228230781987349473638e-01
            2.14767970872814573102260737869074e-01 -7.54831121531105875277489758445881e-01
            3.05900045380293139629657162004150e-01 -7.22717417516049565051616809796542e-01
            3.92394987017142482521592228295049e-01 -6.79648054149020519609791790571762e-01
            4.72941620636237070041119068264379e-01 -6.26275919076171194710411782580195e-01
            5.46318941376629507722384460066678e-01 -5.63410079460646695537207051529549e-01
            6.11414623852616467836185165651841e-01 -4.92003517349110852663329751521815e-01
            6.67241883872747632011623863945715e-01 -4.13138683435332720872423806213192e-01
            7.12954437082293446259484426263953e-01 -3.28011088211059398389579655486159e-01
            7.47859327771407511598056316870498e-01 -2.37911179245599596621119076189643e-01
            7.71427433377329663244381663389504e-01 -1.44204779316078363082809232764703e-01
            7.83301485443077982750992305227555e-01 -4.83123819263840889592920291306655e-02
            7.35438873339410048579622980469139e-01 4.92318399831719807901997398857930e-02
            7.22314949221797952816359611460939e-01 1.46816976598692305877591479656985e-01
            6.96301297723364021052816497103777e-01 2.41782160788650196669991032649705e-01
            6.57862133071372645609642404451733e-01 3.32432736591408872772746008195099e-01
            6.07683403069679384245205255865585e-01 4.17151042334216237694732853924506e-01
            5.46660548343920638103554665576667e-01 4.94425277844077804001443610104616e-01
            4.75882523182335814837529142096173e-01 5.62876482557659429950547291809926e-01
            3.96612363120695976537177784848609e-01 6.21283143105208268686112660361687e-01
            3.10264646043245939655008669433300e-01 6.68602991245573763379184129007626e-01
            2.18380249006848381476686427049572e-01 7.03991603167663071438653332734248e-01
            1.22598851253399157568146904395689e-01 7.26817468253354803664478822611272e-01
            2.46296740949126513609002131488523e-02 7.36673258399439867538660564605379e-01
            -7.37790201812855428453730155524681e-02 7.33383096797273426048491273832042e-01
            -1.70871126094491093683203075670463e-01 7.17005696458591579300900775706396e-01
            -2.64914032714528624445904370077187e-01 6.87833312480425895785174361662939e-01
            -3.54229542144845199747038577697822e-01 6.46386526745973299945546841627220e-01
            -4.37223817003733472574822371825576e-01 5.93404958128557757923715598735726e-01
            -5.12415822490165595581856905482709e-01 5.29834063975313518390919398370897e-01
            -5.78463755484904473824769866041606e-01 4.56808268398427919088078397180652e-01
            -6.34188989058954266653245213092305e-01 3.75630718449983802553759915099363e-01
            -6.78597105099031261410402748879278e-01 2.87750029431942555557810692334897e-01
            -7.10895639722352146172568154725013e-01 1.94734434321763516528847048903117e-01
            -7.30508224813397166741424371139146e-01 9.82437986177682465172011916365591e-02
            -7.37084873326586120789727374358336e-01 -2.37064575906103547953103339574031e-16
            -7.30508224813397277763726833654800e-01 -9.82437986177677330390523025016591e-02
            -7.10895639722352146172568154725013e-01 -1.94734434321763349995393355129636e-01
            -6.78597105099031372432705211394932e-01 -2.87750029431942389024356998561416e-01
            -6.34188989058954377675547675607959e-01 -3.75630718449983636020306221325882e-01
            -5.78463755484904584847072328557260e-01 -4.56808268398427752554624703407171e-01
            -5.12415822490165706604159367998363e-01 -5.29834063975313407368616935855243e-01
            -4.37223817003733306041368678052095e-01 -5.93404958128557757923715598735726e-01
            -3.54229542144845088724736115182168e-01 -6.46386526745973299945546841627220e-01
            -2.64914032714528957512811757624149e-01 -6.87833312480425784762871899147285e-01
            -1.70871126094491593283564156990906e-01 -7.17005696458591468278598313190741e-01
            -7.37790201812858759122804030994303e-02 -7.33383096797273426048491273832042e-01
            2.46296740949123113550989216946618e-02 -7.36673258399439867538660564605379e-01
            1.22598851253398977156905402807752e-01 -7.26817468253354803664478822611272e-01
            2.18380249006848048409779039502610e-01 -7.03991603167663182460955795249902e-01
            3.10264646043245773121554975659819e-01 -6.68602991245573874401486591523280e-01
            3.96612363120695810003724091075128e-01 -6.21283143105208379708415122877341e-01
            4.75882523182335759326377910838346e-01 -5.62876482557659540972849754325580e-01
            5.46660548343920638103554665576667e-01 -4.94425277844077804001443610104616e-01
            6.07683403069679384245205255865585e-01 -4.17151042334216237694732853924506e-01
            6.57862133071372312542735016904771e-01 -3.32432736591409483395409552031197e-01
            6.96301297723364021052816497103777e-01 -2.41782160788650168914415417020791e-01
            7.22314949221797952816359611460939e-01 -1.46816976598692222610864632770244e-01
            7.35438873339410048579622980469139e-01 -4.92318399831725150850303407423780e-02
            6.84469793361181855217978409200441e-01 5.00967318121437465983092351962114e-02
            6.69881508058070784805693165253615e-01 1.49222470573307369745563732976734e-01
            6.41015861425629940306691878504353e-01 2.45167791446826099921452168928226e-01
            5.98488074606730813265187407523626e-01 3.35887786493770934548308559897123e-01
            5.43204553542791845899273539544083e-01 4.19448916523255554977822612272575e-01
            4.76343570504793645259411505321623e-01 4.94070221123375841187908008578233e-01
            3.99330151265480604028113020831370e-01 5.58161276740374745486406027339399e-01
            3.13805703149074133317952828292619e-01 6.10356093795476062346949674974894e-01
            2.21593031283885716353765360508987e-01 6.49542230381193630428526830655755e-01
            1.24657488675671376809894752568653e-01 6.74884502029222455021795212815050e-01
            2.50650881204615427755300061107846e-02 6.85842782217375490638744395255344e-01
            -7.50615312712775151204880330624292e-02 6.82183514228662524203627981478348e-01
            -1.73588344442063641226425829700020e-01 6.63984689007224182510924492817139e-01
            -2.68415423426509369697612328309333e-01 6.31634182916761210968559225875651e-01
            -3.57521693670115658925112711585825e-01 5.85821490829253166410239828110207e-01
            -4.39008009724510706028866025008028e-01 5.27523030738830112085224754991941e-01
            -5.11137632235480809939076607406605e-01 4.57981333107434829265969256084645e-01
            -5.72373243527064312630159292893950e-01 3.78678558485247174214549659154727e-01
            -6.21409712858801421830889921693597e-01 2.91304907831809012375146039630636e-01
            -6.57201913021563055572471512277843e-01 1.97722598817016037564542330073891e-01
            -6.78986995409516236321678661624901e-01 9.99261758845719078037106442025106e-02
            -6.86300648813737312892158115573693e-01 8.40475892822495140820912848287094e-17
            -6.78986995409516236321678661624901e-01 -9.99261758845717273924691426145728e-02
            -6.57201913021563055572471512277843e-01 -1.97722598817015898786664251929324e-01
            -6.21409712858801532853192384209251e-01 -2.91304907831808845841692345857155e-01
            -5.72373243527064534674764217925258e-01 -3.78678558485246785636491040349938e-01
            -5.11137632235480920961379069922259e-01 -4.57981333107434662732515562311164e-01
            -4.39008009724510539495412331234547e-01 -5.27523030738830223107527217507595e-01
            -3.57521693670116158525473792906268e-01 -5.85821490829252944365634903078899e-01
            -2.68415423426509369697612328309333e-01 -6.31634182916761210968559225875651e-01
            -1.73588344442063668982001445328933e-01 -6.63984689007224182510924492817139e-01
            -7.50615312712778343096076127949345e-02 -6.82183514228662524203627981478348e-01
            2.50650881204612201169634744246650e-02 -6.85842782217375490638744395255344e-01
            1.24657488675670904965109286877123e-01 -6.74884502029222566044097675330704e-01
            2.21593031283885688598189744880074e-01 -6.49542230381193630428526830655755e-01
            3.13805703149073966784499134519137e-01 -6.10356093795476173369252137490548e-01
            3.99330151265480437494659327057889e-01 -5.58161276740374745486406027339399e-01
            4.76343570504793367703655349032488e-01 -4.94070221123376118743664164867369e-01
            5.43204553542791956921576002059737e-01 -4.19448916523255443955520149756921e-01
            5.98488074606730813265187407523626e-01 -3.35887786493770934548308559897123e-01
            6.41015861425629829284389415988699e-01 -2.45167791446826266454905862701708e-01
            6.69881508058070895827995627769269e-01 -1.49222470573307036678656345429772e-01
            6.84469793361181855217978409200441e-01 -5.00967318121441490541556618154573e-02
            6.30562831283687064143350653466769e-01 5.09042943348755119736814833686367e-02
            6.14231585172851368703561547590652e-01 1.51394488520148473575943626201479e-01
            5.81992063647042034979506297531771e-01 2.47963644976614633330669335009588e-01
            5.34679253379136132373616874247091e-01 3.38110673277494722110958491612109e-01
            4.73518531302796807924693212044076e-01 4.19500812741850914733277022605762e-01
            4.00093927993552700428381285746582e-01 4.90026101509828837521354216733016e-01
            3.16307102108943749563252367806854e-01 5.47859971647567500774300697230501e-01
            2.24328088428187716329986756136350e-01 5.91504556297232864103818883450003e-01
            1.26539095091263237291556720265362e-01 6.19829483641844425356737247057026e-01
            2.54728056594028459680423281952244e-02 6.32101152941575872290513871121220e-01
            -7.62532160587871959966932422503305e-02 6.28001734407575562535441804357106e-01
            -1.76004319535025405274453191850625e-01 6.07637400826548712551300468476256e-01
            -2.71197003586121088147820046287961e-01 5.71535577741351663583202480367618e-01
            -3.59365827697565920484379375920980e-01 5.20631283406476241815141747792950e-01
            -4.38227265637825880162381508853287e-01 4.56242912306400238975356842274778e-01
            -5.05738847588254714082722784951329e-01 3.80038089430961123493801778749912e-01
            -5.60152059038538818747099412576063e-01 2.93990479664081205690706610766938e-01
            -6.00057626394060017460674316680524e-01 2.00328670899993482867884608822351e-01
            -6.24422016421740222469338732480537e-01 1.01478454787403957193525627644703e-01
            -6.32614204217887610148807198129361e-01 7.74728960290586117989228566987191e-17
            -6.24422016421740222469338732480537e-01 -1.01478454787403804537859741685679e-01
            -6.00057626394060017460674316680524e-01 -2.00328670899993344090006530677783e-01
            -5.60152059038538818747099412576063e-01 -2.93990479664081039157252916993457e-01
            -5.05738847588254936127327709982637e-01 -3.80038089430961012471499316234258e-01
            -4.38227265637825991184683971368941e-01 -4.56242912306400072441903148501297e-01
            -3.59365827697566087017833069694461e-01 -5.20631283406476130792839285277296e-01
            -2.71197003586120977125517583772307e-01 -5.71535577741351774605504942883272e-01
            -1.76004319535025405274453191850625e-01 -6.07637400826548712551300468476256e-01
            -7.62532160587874874302372063539224e-02 -6.28001734407575562535441804357106e-01
            2.54728056594025510650514121380183e-02 -6.32101152941575872290513871121220e-01
            1.26539095091263070758103026491881e-01 -6.19829483641844425356737247057026e-01
            2.24328088428187549796533062362869e-01 -5.91504556297232975126121345965657e-01
            3.16307102108943360985193749002065e-01 -5.47859971647567722818905622261809e-01
            4.00093927993552256339171435683966e-01 -4.90026101509829115077110373022151e-01
            4.73518531302796585880088287012768e-01 -4.19500812741851136777881947637070e-01
            5.34679253379136021351314411731437e-01 -3.38110673277494944155563416643417e-01
            5.81992063647042034979506297531771e-01 -2.47963644976614716597396181896329e-01
            6.14231585172851368703561547590652e-01 -1.51394488520148529087094857459306e-01
            6.30562831283687064143350653466769e-01 -5.09042943348754425847424442963529e-02
            5.73855541444041161724953781231306e-01 5.16479335416415719084426427798462e-02
            5.55411352172117456227340426266892e-01 1.53283793544835095223888288273884e-01
            5.19115785047399080909258373139892e-01 2.49992986301172170904294489446329e-01
            4.66135409461366612138277787380503e-01 3.38667198782875322748964208585676e-01
            3.98173058277753455502789847741951e-01 4.16456368839397517156442063424038e-01
            3.17413097383209663604475281317718e-01 4.80860288539979696675885634249425e-01
            2.26451218370402967972054852907604e-01 5.29808962913723813237254489649786e-01
            1.28211010874488468003207231049601e-01 5.61729141291154032700205789296888e-01
            2.58499959966967778057789217882600e-02 5.75594882875209545858297133236192e-01
            -7.73418590218762913579553242016118e-02 5.70960531322608821902520048752194e-01
            -1.78047883054392674928578799153911e-01 5.47975038505409295375159217655892e-01
            -2.73031301627254752162343720556237e-01 5.07377177075282403961864474695176e-01
            -3.59239269514913583947191000333987e-01 4.50471795702624189239315910526784e-01
            -4.33900991697307558681018235802185e-01 3.79087880166655455393964757604408e-01
            -4.94616778991624927996895166870672e-01 2.95519768247583691778146430806373e-01
            -5.39435176037110108993033463775646e-01 2.02453407822559300344167354523961e-01
            -5.66915682676021326358295482350513e-01 1.02880028290899053211582270250801e-01
            -5.76175052813947763397095513937529e-01 7.05610934177158315590445440562625e-17
            -5.66915682676021326358295482350513e-01 -1.02880028290898900555916384291777e-01
            -5.39435176037110108993033463775646e-01 -2.02453407822559161566289276379393e-01
            -4.94616778991625150041500091901980e-01 -2.95519768247583358711239043259411e-01
            -4.33900991697307669703320698317839e-01 -3.79087880166655344371662295088754e-01
            -3.59239269514913694969493462849641e-01 -4.50471795702624078217013448011130e-01
            -2.73031301627254863184646183071891e-01 -5.07377177075282403961864474695176e-01
            -1.78047883054392813706456877298479e-01 -5.47975038505409295375159217655892e-01
            -7.73418590218764301358334023461794e-02 -5.70960531322608710880217586236540e-01
            2.58499959966966390279008436436925e-02 -5.75594882875209656880599595751846e-01
            1.28211010874488329225329152905033e-01 -5.61729141291154032700205789296888e-01
            2.26451218370402829194176774763037e-01 -5.29808962913723813237254489649786e-01
            3.17413097383209441559870356286410e-01 -4.80860288539979863209339328022907e-01
            3.98173058277753344480487385226297e-01 -4.16456368839397572667593294681865e-01
            4.66135409461366556627126556122676e-01 -3.38667198782875433771266671101330e-01
            5.19115785047398969886955910624238e-01 -2.49992986301172309682172567590897e-01
            5.55411352172117456227340426266892e-01 -1.53283793544835234001766366418451e-01
            5.73855541444041161724953781231306e-01 -5.16479335416417176252146248316421e-02
            5.14458602156634747792907091934467e-01 5.23153265342814963179129961190483e-02
            4.93396606538022974852708557591541e-01 1.54804183987741122985326569505560e-01
            4.52134895876104836442976875332533e-01 2.50955339960023393608423702971777e-01
            3.92362729453424430303698500210885e-01 3.36832354828341840047301047889050e-01
            3.16527186786257574979686069127638e-01 4.08919413513866625287107581243617e-01
            2.27732983901696134365622015138797e-01 4.64265263364142810598167443458806e-01
            1.29615365898709616887529705309134e-01 5.00604038783438842763473530794727e-01
            2.61912795866713343784226708521601e-02 5.16448026036463669896647843415849e-01
            -7.83050807889903027758649045608763e-02 5.11148570423489267966488114325330e-01
            -1.79595621956694012633093393560557e-01 4.84922632279970344804098658642033e-01
            -2.73533497259901337006482435754151e-01 4.38843904594919287376342253992334e-01
            -3.56272879046466706132179069754784e-01 3.74798855893783033899069323524600e-01
            -4.24426407304584252244694653199986e-01 2.95409497995359371369517020866624e-01
            -4.75203868579666510729708761573420e-01 2.03926040539863573375356509131962e-01
            -5.06526427641013521352419957111124e-01 1.04093827024373433709492076104652e-01
            -5.17111735240409209346523766726023e-01 6.33279231363700763676970876238581e-17
            -5.06526427641013521352419957111124e-01 -1.04093827024373308809401805774542e-01
            -4.75203868579666566240859992831247e-01 -2.03926040539863462353054046616307e-01
            -4.24426407304584363266997115715640e-01 -2.95409497995359260347214558350970e-01
            -3.56272879046466983687935226043919e-01 -3.74798855893782811854464398493292e-01
            -2.73533497259901448028784898269805e-01 -4.38843904594919231865191022734507e-01
            -1.79595621956694262433273934220779e-01 -4.84922632279970233781796196126379e-01
            -7.83050807889904276759551748909871e-02 -5.11148570423489267966488114325330e-01
            2.61912795866714349923842775069716e-02 -5.16448026036463669896647843415849e-01
            1.29615365898709394842924780277826e-01 -5.00604038783438842763473530794727e-01
            2.27732983901695829054290243220748e-01 -4.64265263364142977131621137232287e-01
            3.16527186786257352935081144096330e-01 -4.08919413513866791820561275017099e-01
            3.92362729453424485814849731468712e-01 -3.36832354828341618002696122857742e-01
            4.52134895876104725420674412816879e-01 -2.50955339960023615653028628003085e-01
            4.93396606538022919341557326333714e-01 -1.54804183987741456052233957052522e-01
            5.14458602156634747792907091934467e-01 -5.23153265342813852956105336033943e-02
            4.52456136056299862424623370316112e-01 5.28845376733474217822994489779376e-02
            4.28064108647599084189749873985420e-01 1.55802593905419728415040481195319e-01
            3.80595034341441540437500634652679e-01 2.50321291972052550889316080429126e-01
            3.12607983220584084715909511942300e-01 3.31345104395220635407071085865027e-01
            2.27768154808744460737557346874382e-01 3.94506016474958809414630422907067e-01
            1.30649286215575921588083474489395e-01 4.36399007092455659684304691836587e-01
            2.64870807852183622055353140467560e-02 4.54765614279925456386877158365678e-01
            -7.91030500261953734009168215379759e-02 4.48615689489872682127469261104125e-01
            -1.80428714935635864380358839298424e-01 4.18280776759577699319692101198598e-01
            -2.72027421120663914777537684130948e-01 3.65396239086230367743013403014629e-01
            -3.48961058621403641399894013375160e-01 2.92813095584452842690126317393151e-01
            -4.07082115126659926929164612374734e-01 2.04444322307872961008712309194379e-01
            -4.43257269436159950792841755173868e-01 1.05053902697235079788384837229387e-01
            -4.55536309617488810452812231233111e-01 5.57871083468455279796875490573907e-17
            -4.43257269436159950792841755173868e-01 -1.05053902697234968766082374713733e-01
            -4.07082115126659926929164612374734e-01 -2.04444322307872849986409846678725e-01
            -3.48961058621403641399894013375160e-01 -2.92813095584452898201277548650978e-01
            -2.72027421120663970288688915388775e-01 -3.65396239086230256720710940498975e-01
            -1.80428714935635892135934454927337e-01 -4.18280776759577699319692101198598e-01
            -7.91030500261954844232192840536300e-02 -4.48615689489872626616318029846298e-01
            2.64870807852180464858626862678648e-02 -4.54765614279925511898028389623505e-01
            1.30649286215575921588083474489395e-01 -4.36399007092455659684304691836587e-01
            2.27768154808744460737557346874382e-01 -3.94506016474958809414630422907067e-01
            3.12607983220584140227060743200127e-01 -3.31345104395220635407071085865027e-01
            3.80595034341441318392895709621371e-01 -2.50321291972052883956223467976088e-01
            4.28064108647598917656296180211939e-01 -1.55802593905420061481947868742282e-01
            4.52456136056299862424623370316112e-01 -5.28845376733473315766786981839687e-02
            3.87900704972246879176367428954109e-01 5.33157247152526159172936104369001e-02
            3.59131884212103069664578924857778e-01 1.55992990746838755544700916289003e-01
            3.03727894518997565409534900027211e-01 2.47100970275180020774286049345392e-01
            2.25797796352080248905025428030058e-01 3.19882601249932341236359434333281e-01
            1.31121308585914336797273449519707e-01 3.68940003055505172380179601532291e-01
            2.67201532020044305038020127085474e-02 3.90634812622659310932249354664236e-01
            -7.96627137083310704612770791754883e-02 3.83358025172948757575142053610762e-01
            -1.80137361575585269735100268917449e-01 3.47649326742431041825653892374248e-01
            -2.67252045408373550827718645450659e-01 2.86157068137272041496999008813873e-01
            -3.34545867629978399548917877837084e-01 2.03441848869851976688849504171230e-01
            -3.77027953294976181375375290372176e-01 1.05638278356285239545364618152234e-01
            -3.91547600452203936605144463101169e-01 4.79507515607618267762191105110344e-17
            -3.77027953294976125864224059114349e-01 -1.05638278356285308934303657224518e-01
            -3.34545867629978566082371571610565e-01 -2.03441848869851699133093347882095e-01
            -2.67252045408373495316567414192832e-01 -2.86157068137272097008150240071700e-01
            -1.80137361575585519535280809577671e-01 -3.47649326742430930803351429858594e-01
            -7.96627137083310010723380401032045e-02 -3.83358025172948757575142053610762e-01
            2.67201532020043402981812619145785e-02 -3.90634812622659310932249354664236e-01
            1.31121308585914253530546602632967e-01 -3.68940003055505172380179601532291e-01
            2.25797796352080193393874196772231e-01 -3.19882601249932396747510665591108e-01
            3.03727894518997509898383668769384e-01 -2.47100970275180159552164127489959e-01
            3.59131884212103014153427693599951e-01 -1.55992990746838922078154610062484e-01
            3.87900704972246879176367428954109e-01 -5.33157247152525187727789557357028e-02
            3.20797853019639145344399366877042e-01 5.35316937095495423704072379678109e-02
            2.86034427953402281552541808196111e-01 1.54794091485408291664072066851077e-01
            2.20274734336972616288718995747331e-01 2.39282147571019537801717547154112e-01
            1.30644855340468740712012163385225e-01 2.97840270122243622186175571187050e-01
            2.68575791040285213884253323612938e-02 3.24122777937765282896265262024826e-01
            -7.98401325666109606959963684857939e-02 3.15281553480645349019084733299678e-01
            -1.77885927026358692248919624034897e-01 2.72274680606544861038997851210297e-01
            -2.56655021108250724903854234071332e-01 1.99762621311761950915197871836426e-01
            -3.07611561240089204094516617260524e-01 1.05603182361413125422977543621528e-01
            -3.25233615626403294029955759469885e-01 3.98296306351995371798772113613275e-17
            -3.07611561240089204094516617260524e-01 -1.05603182361413180934128774879355e-01
            -2.56655021108250891437307927844813e-01 -1.99762621311761784381744178062945e-01
            -1.77885927026358636737768392777070e-01 -2.72274680606544916550149082468124e-01
            -7.98401325666110300849354075580777e-02 -3.15281553480645293507933502041851e-01
            2.68575791040285109800844765004513e-02 -3.24122777937765282896265262024826e-01
            1.30644855340468463156256007096090e-01 -2.97840270122243733208478033702704e-01
            2.20274734336972644044294611376245e-01 -2.39282147571019537801717547154112e-01
            2.86034427953402226041390576938284e-01 -1.54794091485408485953101376253471e-01
            3.20797853019639200855550598134869e-01 -5.35316937095494868592560067099839e-02
            2.51064457588484057914968161639990e-01 5.33653978625572567029422543782857e-02
            2.07653132022442010740093110143789e-01 1.50868831487815963088294779481657e-01
            1.28336693460238376873761012575414e-01 2.22285673548525269938025417104654e-01
            2.68296746965012503083336525833147e-02 2.55267303250746646625657376716845e-01
            -7.93164385622036338663320975683746e-02 2.44110897190266629142030296861776e-01
            -1.71748019026280313026333601555962e-01 1.90745499327709400194663658112404e-01
            -2.34482806718943281865108474448789e-01 1.04398471762930655781786981606274e-01
            -2.56673386920476698236370793893002e-01 1.45419305758901083532465428559838e-16
            -2.34482806718943254109532858819875e-01 -1.04398471762930697415150405049644e-01
            -1.71748019026280451804211679700529e-01 -1.90745499327709289172361195596750e-01
            -7.93164385622036893774833288262016e-02 -2.44110897190266601386454681232863e-01
            2.68296746965011323471372861604323e-02 -2.55267303250746702136808607974672e-01
            1.28336693460238376873761012575414e-01 -2.22285673548525269938025417104654e-01
            2.07653132022441982984517494514876e-01 -1.50868831487816018599446010739484e-01
            2.51064457588484057914968161639990e-01 -5.33653978625571734362154074915452e-02
            1.78406588040365993164115820945881e-01 5.23849007633926250226963361456001e-02
            1.21763756898264116634855724896624e-01 1.40522866431822407440321853755449e-01
            2.64617932825575649657956489591015e-02 1.84045814895276937939172512415098e-01
            -7.72416027302641333696087144744524e-02 1.69135517535068335970294128856040e-01
            -1.56421335639312208964923911480582e-01 1.00525888411935923616447041695210e-01
            -1.85938399703222567715954482991947e-01 1.05344123608502499105539611828583e-16
            -1.56421335639312236720499527109496e-01 -1.00525888411935881983083618251840e-01
            -7.72416027302642999030624082479335e-02 -1.69135517535068252703567281969299e-01
            2.64617932825575198629852735621171e-02 -1.84045814895276965694748128044012e-01
            1.21763756898264005612553262380970e-01 -1.40522866431822490707048700642190e-01
            1.78406588040365993164115820945881e-01 -5.23849007633926458393780478672852e-02
            1.01893923312161863159452934723959e-01 4.90695272778579050232394820341142e-02
            2.51657208008557210787703439791585e-02 1.10258226957404600887535650599602e-01
            -7.05127827606463752907473008235684e-02 8.84202328800770265271324888090021e-02
            -1.13093722704742383200482436222956e-01 1.38499865514021110188099999933306e-17
            -7.05127827606464030463229164524819e-02 -8.84202328800770126493446809945453e-02
            2.51657208008555927092331216954335e-02 -1.10258226957404614765323458414059e-01
            1.01893923312161890915028550352872e-01 -4.90695272778578356343004429618304e-02
            1.90994571192794095060296655219645e-02 3.30812301275750370033179592610395e-02
            -3.81989142385588120731654271367006e-02 4.67801780531553013738715975998470e-18
            1.90994571192794095060296655219645e-02 -3.30812301275750370033179592610395e-02
            ];
        
    case   40
        
        % DEGREE.             :          40
        % CARDIN.             :         861
        % LEBESGUE CONST.     : 5.58546e+02
        % ABS.DET.VAND.MATRIX : Inf
        % CONDITIONING VAND.  : 2.35881e+04
        % POINTS OUT DISK     : 0.00000e+00
        
        pts=[
            9.99247952504230041448352039878955e-01 3.87753712568167097085591876748367e-02
            9.93238357741943023171415916294791e-01 1.16092914125230234345664825923450e-01
            9.81255310627384691457564258598723e-01 1.92712260548089681089223290655355e-01
            9.63370878615880332773713234928437e-01 2.68172612760637307793842865066836e-01
            9.39692620785908427905042117345147e-01 3.42020143325668712908083080037613e-01
            9.10362940966146672039371878781822e-01 4.13810724505139115869667421065969e-01
            8.75558231302090872461008075333666e-01 4.83112599296638522972102691710461e-01
            8.35487811412936487442948418902233e-01 5.49508978070806008986437518615276e-01
            7.90392669518759194424717406946002e-01 6.12600545193202838945012445037719e-01
            7.40544013109004639616728127293754e-01 6.72007860555522418266605200187769e-01
            6.86241637868733600491566448908998e-01 7.27373641573048734798589975980576e-01
            6.27812124672098681443799250700977e-01 7.78364911924159907918863154918654e-01
            5.65606875486538651642831609933637e-01 8.24675004109106768446224577928660e-01
            5.00000000000000111022302462515654e-01 8.66025403784438596588302061718423e-01
            4.31386065681253538794948099166504e-01 9.02167424781037619041512698458973e-01
            3.60177724804710497341631025847164e-01 9.32883704732000440529304796655197e-01
            2.86803232711090316797708510421216e-01 9.57989512315488900284776718763169e-01
            2.11703872229410838823326912461198e-01 9.77333858250635456599297867796849e-01
            1.35331299750131167636268969545199e-01 9.90800403364845316822595577832544e-01
            5.81448289104758986312049273692537e-02 9.98308158271268175631973917916184e-01
            -1.93913317718240885145775109776878e-02 9.99811970448501230457338806445478e-01
            -9.68108707031790499675238947929756e-02 9.95302795793165828719395449297735e-01
            -1.73648177666930303431058746355120e-01 9.84807753012208020315654266596539e-01
            -2.49441144057981262216472373438592e-01 9.68389960527805904177967022405937e-01
            -3.23733942058320789403325079547358e-01 9.46148156875750490080179133656202e-01
            -3.96079766039156788703934353179648e-01 9.18216106880273996715402518020710e-01
            -4.66043519702538600046892725004000e-01 8.84761797176657927010978710313793e-01
            -5.33204432801691385890308083617128e-01 8.45986425919840967502238981978735e-01
            -5.97158591702785956911725406826008e-01 8.02123192755043956658767001499655e-01
            -6.57521368569063513476180560246576e-01 7.53435896327660836746531458629761e-01
            -7.13929734557898876268211552087450e-01 7.00217347767168707406426619854756e-01
            -7.66044443118978235496285833505681e-01 6.42787609686539140874117492785444e-01
            -8.13552070262967497171757713658735e-01 5.81492071288026823872030490747420e-01
            -8.56166899530266367612796329922276e-01 5.16699371151863040552143502281979e-01
            -8.93632640323412164029548421240179e-01 4.48799180200462333178990093074390e-01
            -9.25723969268890334305410760862287e-01 3.78199858171642644411036826568306e-01
            -9.52247885338415311906601345981471e-01 3.05325997695113260377297592640389e-01
            -9.73044870579823806266972496814560e-01 2.30615870742440332019640436556074e-01
            -9.87989849476808901229674120259006e-01 1.54518792807840615877168488623283e-01
            -9.96992941167792023904326015326660e-01 7.74924206719310726398930455616210e-02
            -1.00000000000000000000000000000000e+00 1.22464679914735320717376402945840e-16
            -9.96992941167792023904326015326660e-01 -7.74924206719312808067101627784723e-02
            -9.87989849476809012251976582774660e-01 -1.54518792807840393832563563591975e-01
            -9.73044870579823917289274959330214e-01 -2.30615870742439638130250045833236e-01
            -9.52247885338415311906601345981471e-01 -3.05325997695113038332692667609081e-01
            -9.25723969268890445327713223377941e-01 -3.78199858171642366855280670279171e-01
            -8.93632640323412497096455808787141e-01 -4.48799180200461722556326549238293e-01
            -8.56166899530266478635098792437930e-01 -5.16699371151862818507538577250671e-01
            -8.13552070262967608194060176174389e-01 -5.81492071288026601827425565716112e-01
            -7.66044443118978124473983370990027e-01 -6.42787609686539251896419955301099e-01
            -7.13929734557899098312816477118758e-01 -7.00217347767168485361821694823448e-01
            -6.57521368569064068587692872824846e-01 -7.53435896327660392657321608567145e-01
            -5.97158591702786178956330331857316e-01 -8.02123192755043734614162076468347e-01
            -5.33204432801691274868005621101474e-01 -8.45986425919841078524541444494389e-01
            -4.66043519702539654758766118902713e-01 -8.84761797176657371899466397735523e-01
            -3.96079766039156844215085584437475e-01 -9.18216106880273996715402518020710e-01
            -3.23733942058321011447930004578666e-01 -9.46148156875750379057876671140548e-01
            -2.49441144057981289972047989067505e-01 -9.68389960527805904177967022405937e-01
            -1.73648177666930331186634361984034e-01 -9.84807753012208020315654266596539e-01
            -9.68108707031790638453117026074324e-02 -9.95302795793165828719395449297735e-01
            -1.93913317718243313758641477306810e-02 -9.99811970448501230457338806445478e-01
            5.81448289104758708756293117403402e-02 -9.98308158271268175631973917916184e-01
            1.35331299750130279457849269419967e-01 -9.90800403364845427844898040348198e-01
            2.11703872229410811067751296832284e-01 -9.77333858250635456599297867796849e-01
            2.86803232711090316797708510421216e-01 -9.57989512315488900284776718763169e-01
            3.60177724804710497341631025847164e-01 -9.32883704732000440529304796655197e-01
            4.31386065681253538794948099166504e-01 -9.02167424781037619041512698458973e-01
            4.99999999999999333866185224906076e-01 -8.66025403784439040677511911781039e-01
            5.65606875486538651642831609933637e-01 -8.24675004109106657423922115413006e-01
            6.27812124672098681443799250700977e-01 -7.78364911924159907918863154918654e-01
            6.86241637868733045380054136330727e-01 -7.27373641573049178887799826043192e-01
            7.40544013109004639616728127293754e-01 -6.72007860555522307244302737672115e-01
            7.90392669518758861357810019399039e-01 -6.12600545193203394056524757615989e-01
            8.35487811412936487442948418902233e-01 -5.49508978070805897964135056099622e-01
            8.75558231302090872461008075333666e-01 -4.83112599296638356438648997936980e-01
            9.10362940966146338972464491234859e-01 -4.13810724505139837514633427417721e-01
            9.39692620785908427905042117345147e-01 -3.42020143325668601885780617521959e-01
            9.63370878615880110729108309897128e-01 -2.68172612760638029438808871418587e-01
            9.81255310627384358390656871051760e-01 -1.92712260548090319467462450120365e-01
            9.93238357741943023171415916294791e-01 -1.16092914125230040056635516521055e-01
            9.99247952504230041448352039878955e-01 -3.87753712568174035979495783976745e-02
            9.88011463388356325765471410704777e-01 4.03331558830099523582646270369878e-02
            9.81436410109923884625970913475612e-01 1.20731057151130721782905652617046e-01
            9.68330059447819913032162730814889e-01 2.00325513153133072385969626338920e-01
            9.48779632003304618237393697199877e-01 2.78586835916484476527443803206552e-01
            9.22915232645428074143012509011896e-01 3.54994209250404202382611629218445e-01
            8.90908984684591342961823556834133e-01 4.29039154691684354592240424608462e-01
            8.52973884420314409915420128527330e-01 5.00228915344969382594797480123816e-01
            8.09362383686005437688493202585960e-01 5.68089735098594950102324219187722e-01
            7.60364709823659667975448428478558e-01 6.32170011393348385553281332249753e-01
            7.06306934268784214481229355442338e-01 6.92043300562989127655555421370082e-01
            6.47548802598791328755112317594467e-01 7.47311155746490873852394543064293e-01
            5.84481340485535905138192447338952e-01 7.97605778486161431928280762804206e-01
            5.17524251483982178356768599769566e-01 8.42592466365697179142557615705300e-01
            4.47123123974294101046211835637223e-01 8.81971840399540463195648953842465e-01
            3.73746465844679631729263746819925e-01 9.15481837350635818673083576868521e-01
            2.97882586648695435460609814981581e-01 9.42899453718033964122469114954583e-01
            2.20036347985731323140257131854014e-01 9.64042229788398152834361098939553e-01
            1.40725803730364418253628855381976e-01 9.78769463875292400345529131300282e-01
            6.04787524692949884919102032654337e-02 9.86983148665691256695708943880163e-01
            -2.01707749111658084240072952297851e-02 9.88628623442477261207272931642365e-01
            -1.00686069112536191738627167069353e-01 9.83694937842494954161054465657799e-01
            -1.80531314135994935821116769147920e-01 9.72214924729411511528098799317377e-01
            -2.59175153049448880882010826098849e-01 9.54264981696425484969381614064332e-01
            -3.36094224080249026620492713846033e-01 9.29964562652889403793210476578679e-01
            -4.10776643501438554206828257520101e-01 8.99475382878251239482381151901791e-01
            -4.82725412133501952105518739699619e-01 8.63000342833550093679662040813128e-01
            -5.51461722791903752316500231245300e-01 8.20782177892326103574305307120085e-01
            -6.16528146669905408039369376638206e-01 7.73101842976755659897492023446830e-01
            -6.77491677451802831733118637203006e-01 7.20276642849000614532428699021693e-01
            -7.33946612898517258827268960885704e-01 6.62658120500366654148649558919715e-01
            -7.85517254729059644091648806352168e-01 6.00629717690696840470820916380035e-01
            -8.31860408830604414198717222461710e-01 5.34604223206723405681373151310254e-01
            -8.72667669158687986374900447117398e-01 4.65021025820797795358174653301830e-01
            -9.07667470128551423513840745727066e-01 3.92343190231103144949287298004492e-01
            -9.36626893839300755928434227826074e-01 3.17054375442490488090641065355157e-01
            -9.59353220104109505328437990101520e-01 2.39655616095597850945253526333545e-01
            -9.75695208971265048880638914852170e-01 1.60661988163982860644551919904188e-01
            -9.85544107201095309633842589391861e-01 8.05991812084983494379741841839859e-02
            -9.88834372000834349591968930326402e-01 1.21097284855770496148143438515664e-16
            -9.85544107201095309633842589391861e-01 -8.05991812084980996377936435237643e-02
            -9.75695208971265159902941377367824e-01 -1.60661988163982194510737144810264e-01
            -9.59353220104109505328437990101520e-01 -2.39655616095598045234282835735939e-01
            -9.36626893839300755928434227826074e-01 -3.17054375442490266046036140323849e-01
            -9.07667470128551534536143208242720e-01 -3.92343190231102978415833604231011e-01
            -8.72667669158688097397202909633052e-01 -4.65021025820797573313569728270522e-01
            -8.31860408830604303176414759946056e-01 -5.34604223206723516703675613825908e-01
            -7.85517254729059755113951268867822e-01 -6.00629717690696618426215991348727e-01
            -7.33946612898517147804966498370050e-01 -6.62658120500366765170952021435369e-01
            -6.77491677451803053777723562234314e-01 -7.20276642849000392487823773990385e-01
            -6.16528146669905630083974301669514e-01 -7.73101842976755437852887098415522e-01
            -5.51461722791903974361105156276608e-01 -8.20782177892325881529700382088777e-01
            -4.82725412133502118638972433473100e-01 -8.63000342833549982657359578297473e-01
            -4.10776643501438776251433182551409e-01 -8.99475382878251128460078689386137e-01
            -3.36094224080248860087039020072552e-01 -9.29964562652889403793210476578679e-01
            -2.59175153049449491504674369934946e-01 -9.54264981696425262924776689033024e-01
            -1.80531314135994741532087459745526e-01 -9.72214924729411511528098799317377e-01
            -1.00686069112536857872441942163277e-01 -9.83694937842494843138752003142145e-01
            -2.01707749111653955598200127496966e-02 -9.88628623442477261207272931642365e-01
            6.04787524692945235860186414811324e-02 -9.86983148665691367718011406395817e-01
            1.40725803730363946408843389690446e-01 -9.78769463875292511367831593815936e-01
            2.20036347985731101095652206822706e-01 -9.64042229788398152834361098939553e-01
            2.97882586648695213416004889950273e-01 -9.42899453718034075144771577470237e-01
            3.73746465844678854573146509210346e-01 -9.15481837350636151739990964415483e-01
            4.47123123974294045535060604379396e-01 -8.81971840399540463195648953842465e-01
            5.17524251483981512222953824675642e-01 -8.42592466365697512209465003252262e-01
            5.84481340485535905138192447338952e-01 -7.97605778486161320905978300288552e-01
            6.47548802598791661822019705141429e-01 -7.47311155746490762830092080548638e-01
            7.06306934268783770392019505379722e-01 -6.92043300562989571744765271432698e-01
            7.60364709823659890020053353509866e-01 -6.32170011393348052486373944702791e-01
            8.09362383686005104621585815038998e-01 -5.68089735098595394191534069250338e-01
            8.52973884420314298893117666011676e-01 -5.00228915344969604639402405155124e-01
            8.90908984684591231939521094318479e-01 -4.29039154691684632147996580897598e-01
            9.22915232645428074143012509011896e-01 -3.54994209250404368916065322991926e-01
            9.48779632003304618237393697199877e-01 -2.78586835916484587549746265722206e-01
            9.68330059447819913032162730814889e-01 -2.00325513153133072385969626338920e-01
            9.81436410109923884625970913475612e-01 -1.20731057151131540572386313669995e-01
            9.88011463388356325765471410704777e-01 -4.03331558830097927637048371707351e-02
            9.67512576314384920017630520305829e-01 4.16631267528653967402441082867881e-02
            9.60349451702219303328433852584567e-01 1.24680921044763456939641343979019e-01
            9.46076235746359905931512912502512e-01 2.06775621419262117806070477854519e-01
            9.24798602343984699203360833053011e-01 2.87339427437197036940830230378197e-01
            8.96674083648416386793655874498654e-01 3.65775872865606976880314959998941e-01
            8.61910903756173407685992060578428e-01 4.41504241705037658860533156257588e-01
            8.20766437088611411354577285237610e-01 5.13963867607627133970993327238830e-01
            7.73545302881754937018854434427340e-01 5.82618284854584667087351590453181e-01
            7.20597109892050169399624337529531e-01 6.46959200160681313640509415563429e-01
            6.62313868015450224469020668038866e-01 7.06510255899896133513493623468094e-01
            5.99127085983297336113650999322999e-01 7.60830556890617182297376075439388e-01
            5.31504576622647828543222203734331e-01 8.09517934629309987570877638063394e-01
            4.59946993333773368473060827454901e-01 8.52211924805412301964224752737209e-01
            3.84984123427549507212575008452404e-01 8.88596436052972893371304508036701e-01
            3.07170965765561299054553501264309e-01 9.18402090180535424224217422306538e-01
            2.27083621742709740320975697613903e-01 9.41408216553019983052763564046472e-01
            1.45315030034043751738792593641847e-01 9.57444485859900273894140809716191e-01
            6.24705766842612794653710750480968e-02 9.66392171173825142993507597566349e-01
            -2.08363869587598164734298933353784e-02 9.68185026963249817377743511315202e-01
            -1.03989085282748611183123443879595e-01 9.62809779551174527156831572938245e-01
            -1.86371884801883408444567180595186e-01 9.50306225388804604037318313203286e-01
            -2.67374852091730619285669945384143e-01 9.30766936416549395261199606466107e-01
            -3.46398269522920243534969131360413e-01 9.04336574693764161381182020704728e-01
            -4.22857075360653145157385779384640e-01 8.71210821371474319896321958367480e-01
            -4.96185195357088437706494232770638e-01 8.31634927937596857283608642319450e-01
            -5.65839733767025676591799765446922e-01 7.85901900460728830566381475364324e-01
            -6.31304992758055294466146278864471e-01 7.34350330275731377760450868663611e-01
            -6.92096290456886809039360741735436e-01 6.77361887171946230878916139772628e-01
            -7.47763549364361512772347850841470e-01 6.15358493643612503021245174750220e-01
            -7.97894628571789499282829183357535e-01 5.48799201123334245977503087488003e-01
            -8.42118375108039551868444050342077e-01 4.78176791325885253147731646095053e-01
            -8.80107371826284845539589696272742e-01 4.04014127864798178180194554443005e-01
            -9.11580361486004187021592315431917e-01 3.26860285153106167044256835652050e-01
            -9.36304329083187059090676029882161e-01 2.47286483248492061637335837076535e-01
            -9.54096227011899333803057743352838e-01 1.65881858739834103788624020126008e-01
            -9.64824330284713926886297485907562e-01 8.32491029860221859459912252532376e-02
            -9.68409211778431977535319674643688e-01 1.18595924146926791745295183594606e-16
            -9.64824330284713926886297485907562e-01 -8.32491029860219500235984924074728e-02
            -9.54096227011899333803057743352838e-01 -1.65881858739833881744019095094700e-01
            -9.36304329083187170112978492397815e-01 -2.47286483248491867348306527674140e-01
            -9.11580361486004187021592315431917e-01 -3.26860285153105944999651910620742e-01
            -8.80107371826284734517287233757088e-01 -4.04014127864798289202497016958660e-01
            -8.42118375108039662890746512857731e-01 -4.78176791325885031103126721063745e-01
            -7.97894628571789721327434108388843e-01 -5.48799201123334023932898162456695e-01
            -7.47763549364361734816952775872778e-01 -6.15358493643612391998942712234566e-01
            -6.92096290456887031083965666766744e-01 -6.77361887171946008834311214741319e-01
            -6.31304992758055405488448741380125e-01 -7.34350330275731155715845943632303e-01
            -5.65839733767025898636404690478230e-01 -7.85901900460728719544079012848670e-01
            -4.96185195357089048329157776606735e-01 -8.31634927937596524216701254772488e-01
            -4.22857075360652590045873466806370e-01 -8.71210821371474541940926883398788e-01
            -3.46398269522920632113027750165202e-01 -9.04336574693764050358879558189074e-01
            -2.67374852091731063374879795446759e-01 -9.30766936416549395261199606466107e-01
            -1.86371884801884074578381955689110e-01 -9.50306225388804381992713388171978e-01
            -1.03989085282749055272333293942211e-01 -9.62809779551174416134529110422591e-01
            -2.08363869587602709709805992588372e-02 -9.68185026963249817377743511315202e-01
            6.24705766842608214983734171710239e-02 -9.66392171173825142993507597566349e-01
            1.45315030034043279894007127950317e-01 -9.57444485859900384916443272231845e-01
            2.27083621742710128899034316418692e-01 -9.41408216553019872030461101530818e-01
            3.07170965765560854965343651201692e-01 -9.18402090180535535246519884822192e-01
            3.84984123427549063123365158389788e-01 -8.88596436052973115415909433068009e-01
            4.59946993333773757051119446259690e-01 -8.52211924805412079919619827705901e-01
            5.31504576622647384454012353671715e-01 -8.09517934629310320637785025610356e-01
            5.99127085983297003046743611776037e-01 -7.60830556890617404341981000470696e-01
            6.62313868015450446513625593070174e-01 -7.06510255899895911468888698436785e-01
            7.20597109892049725310414487466915e-01 -6.46959200160681757729719265626045e-01
            7.73545302881755048041156896942994e-01 -5.82618284854584445042746665421873e-01
            8.20766437088611078287669897690648e-01 -5.13963867607627578060203177301446e-01
            8.61910903756173074619084673031466e-01 -4.41504241705038269483196700093686e-01
            8.96674083648416497815958337014308e-01 -3.65775872865606754835710034967633e-01
            9.24798602343984588181058370537357e-01 -2.87339427437197647563493774214294e-01
            9.46076235746359794909210449986858e-01 -2.06775621419262728428734021690616e-01
            9.60349451702219414350736315100221e-01 -1.24680921044763248772824226762168e-01
            9.67512576314384920017630520305829e-01 -4.16631267528660559351649794734840e-02
            9.40977500862934634895395902276505e-01 4.28726437955141287394766891338804e-02
            9.33180264942212067680316067708191e-01 1.28262675157873623499327209174226e-01
            9.17650403453243557194696222722996e-01 2.12589881599220847929743172244343e-01
            8.94516601719253623414829235116486e-01 2.95155501329230740559239620779408e-01
            8.63970553707098964935084950411692e-01 3.75275369619856913327993197526666e-01
            8.26265373590686968974239334784215e-01 4.52285588009737282710887029679725e-01
            7.81713498367216264028911609784700e-01 5.25548025575931054831357869261410e-01
            7.30684098905819645608517021173611e-01 5.94455606687717019731564960238757e-01
            6.73600020881476968526158088934608e-01 6.58437341426460376325735524005722e-01
            6.10934280942582730311585237359395e-01 7.16963056987903968320097192190588e-01
            5.43206147146026774308325002493802e-01 7.69547790860996672179794586554635e-01
            4.70976836138538690335053615854122e-01 8.15755809379990481922106937417993e-01
            3.94844862738803981105917273453088e-01 8.55204218350825384753477464983007e-01
            3.15441080455183930908447109686676e-01 8.87566135833008029720758713665418e-01
            2.33423454034864141792837699540542e-01 9.12573400786317545652082117157988e-01
            1.49471607360743941050884586729808e-01 9.30018795137639631143144924863009e-01
            6.42811918739021465052374537663127e-02 9.39757760855180035441946984064998e-01
            -2.14418778133282986186891605484561e-02 9.41709597801843378839237175270682e-01
            -1.06987273348158384855821623204974e-01 9.35858132441983903149207435490098e-01
            -1.91646138641781205169678514721454e-01 9.22251851860415916561919402738567e-01
            -2.74716963674170255860218503585202e-01 9.01003501983158816557306636241265e-01
            -3.55511397427036079932349821319804e-01 8.72289153329185440455262323666830e-01
            -4.33359951777150753660095006125630e-01 8.36346742034651979835757629189175e-01
            -5.07617549085783936746452127408702e-01 7.93474098239137837218493132240837e-01
            -5.77668867515175543658756396325771e-01 7.44026478171311955733813192637172e-01
            -6.42933439779072801734116637817351e-01 6.88413620383937940871987848368008e-01
            -7.02870463077472251711697026621550e-01 6.27096350531185176002679781959159e-01
            -7.56983280358940469056960864691064e-01 5.60582762822126823287760544189950e-01
            -8.04823495777358344227536690596025e-01 4.89424009792106318172955070622265e-01
            -8.45994690241118285634058793220902e-01 4.14209735279249202655194039834896e-01
            -8.80155706266563364614796682872111e-01 3.35563188449922666922731195882079e-01
            -9.07023474916341165830147019732976e-01 2.54136059359857224837497824410093e-01
            -9.26375361397766439175427422014764e-01 1.70603078845104172422963983990485e-01
            -9.38051009884830810925393507204717e-01 8.56564274898289623738634190885932e-02
            -9.41953672277077158625502306676935e-01 1.15356054969921754555390864547269e-16
            -9.38051009884830810925393507204717e-01 -8.56564274898287403292584940572851e-02
            -9.26375361397766550197729884530418e-01 -1.70603078845103506289149208896561e-01
            -9.07023474916341165830147019732976e-01 -2.54136059359857002792892899378785e-01
            -8.80155706266563475637099145387765e-01 -3.35563188449922444878126270850771e-01
            -8.45994690241118285634058793220902e-01 -4.14209735279248980610589114803588e-01
            -8.04823495777358677294444078142988e-01 -4.89424009792105707550291526786168e-01
            -7.56983280358940469056960864691064e-01 -5.60582762822127045332365469221259e-01
            -7.02870463077472362733999489137204e-01 -6.27096350531184953958074856927851e-01
            -6.42933439779073356845628950395621e-01 -6.88413620383937385760475535789737e-01
            -5.77668867515175765703361321357079e-01 -7.44026478171311733689208267605864e-01
            -5.07617549085784158791057052440010e-01 -7.93474098239137726196190669725183e-01
            -4.33359951777151364282758549961727e-01 -8.36346742034651868813455166673521e-01
            -3.55511397427036301976954746351112e-01 -8.72289153329185329432959861151176e-01
            -2.74716963674170866482882047421299e-01 -9.01003501983158594512701711209957e-01
            -1.91646138641781232925254130350368e-01 -9.22251851860415916561919402738567e-01
            -1.06987273348158620778214356050739e-01 -9.35858132441983792126904972974444e-01
            -2.14418778133289508747161278279236e-02 -9.41709597801843378839237175270682e-01
            6.42811918739021326274496459518559e-02 -9.39757760855180035441946984064998e-01
            1.49471607360743496961674736667192e-01 -9.30018795137639742165447387378663e-01
            2.33423454034863503414598540075531e-01 -9.12573400786317656674384579673642e-01
            3.15441080455183708863842184655368e-01 -8.87566135833008029720758713665418e-01
            3.94844862738803592527858654648298e-01 -8.55204218350825606798082390014315e-01
            4.70976836138538690335053615854122e-01 -8.15755809379990481922106937417993e-01
            5.43206147146026663286022539978148e-01 -7.69547790860996894224399511585943e-01
            6.10934280942582397244677849812433e-01 -7.16963056987904412409307042253204e-01
            6.73600020881476968526158088934608e-01 -6.58437341426460376325735524005722e-01
            7.30684098905819312541609633626649e-01 -5.94455606687717352798472347785719e-01
            7.81713498367215819939701759722084e-01 -5.25548025575931720965172644355334e-01
            8.26265373590686857951936872268561e-01 -4.52285588009737449244340723453206e-01
            8.63970553707098742890480025380384e-01 -3.75275369619857301906051816331455e-01
            8.94516601719253623414829235116486e-01 -2.95155501329230685048088389521581e-01
            9.17650403453243446172393760207342e-01 -2.12589881599221125485499328533479e-01
            9.33180264942211956658013605192536e-01 -1.28262675157874206366415137381409e-01
            9.40977500862934634895395902276505e-01 -4.28726437955142050673096321133926e-02
            9.09557132881466445795126674056519e-01 4.39951553229280881152085669327789e-02
            9.01064842998548609642739393166266e-01 1.31574695057381840790355909120990e-01
            8.84159553455227231744117943890160e-01 2.17925757314951867860131073939556e-01
            8.58999104385086531543436194624519e-01 3.02242105493363444335130907347775e-01
            8.25818412121981149098814967146609e-01 3.83736500567474991818528451403836e-01
            7.84927275849522376738320872391341e-01 4.61648051327946062905027702072402e-01
            7.36707485089570401903813490207540e-01 5.35249318617448177626272354245884e-01
            6.81609255036337402522406136995414e-01 6.03853107234078367859808622597484e-01
            6.20147023018422172135899472777965e-01 6.66818882087805486769127583102090e-01
            5.52894645336081791420212994125905e-01 7.23558748704022258735335526580457e-01
            4.80480039319571228251248840024346e-01 7.73542942235856290089657250064192e-01
            4.03579320634216143215411420896999e-01 8.16304773735806787904323300608667e-01
            3.22910490570613550875833652753499e-01 8.51444987504705319558695464365883e-01
            2.39226732260037322497225886763772e-01 8.78635488834605737906713329721242e-01
            1.53309378406474711153961720810912e-01 8.97622407340671446540625311172334e-01
            6.59606161936887869234880099611473e-02 9.08228467280557727470124973478960e-01
            -2.20040025203794009645008600273286e-02 9.10354642730252239246624412771780e-01
            -1.09763175791569550510118347119715e-01 9.03981082162448323913395142881200e-01
            -1.96497519864467951045128302212106e-01 8.89167293794905111425919130851980e-01
            -2.81397219537759424312639566778671e-01 8.66051589978253044677103389403783e-01
            -3.63669589190570186065798452546005e-01 8.34849795810841732723872610222315e-01
            -4.42546473874532886316757185340975e-01 7.95853234037947276924285233690171e-01
            -5.17291421369569404120625222276431e-01 7.49426005049793286794113100768300e-01
            -5.87206558239846354574353881616844e-01 6.96001587374307617572810613637557e-01
            -6.51639105690011266602823525317945e-01 6.36078790404902894017880043975310e-01
            -7.09987474384924710513189438643167e-01 5.70217097151565655011040689714719e-01
            -7.61706881327192442121543081157142e-01 4.99031440498736988953254467560328e-01
            -8.06314436349228058631410931411665e-01 4.23186461742656394591222124290653e-01
            -8.43393650728640698055471602856414e-01 3.43390305014654784176997281974764e-01
            -8.72598325831219323589493797044270e-01 2.60388005530199861947693307229201e-01
            -8.93655785474300912163414523092797e-01 1.74954533395829531228216069393966e-01
            -9.06369421830821253571741635823855e-01 8.78875579220686486969782436062815e-02
            -9.10620531103621733137742921826430e-01 1.11518851865391324457356178592989e-16
            -9.06369421830821253571741635823855e-01 -8.78875579220684266523733185749734e-02
            -8.93655785474300912163414523092797e-01 -1.74954533395829309183611144362658e-01
            -8.72598325831219212567191334528616e-01 -2.60388005530200028481147001002682e-01
            -8.43393650728641031122378990403377e-01 -3.43390305014654173554333738138666e-01
            -8.06314436349228169653713393927319e-01 -4.23186461742656228057768430517172e-01
            -7.61706881327192664166148006188450e-01 -4.99031440498736822419800773786847e-01
            -7.09987474384924821535491901158821e-01 -5.70217097151565543988738227199065e-01
            -6.51639105690011377625125987833599e-01 -6.36078790404902782995577581459656e-01
            -5.87206558239846021507446494069882e-01 -6.96001587374307950639718001184519e-01
            -5.17291421369569626165230147307739e-01 -7.49426005049793175771810638252646e-01
            -4.42546473874533385917118266661419e-01 -7.95853234037946832835075383627554e-01
            -3.63669589190570019532344758772524e-01 -8.34849795810841732723872610222315e-01
            -2.81397219537759646357244491809979e-01 -8.66051589978252933654800926888129e-01
            -1.96497519864468755956821155450598e-01 -8.89167293794904889381314205820672e-01
            -1.09763175791569383976664653346234e-01 -9.03981082162448323913395142881200e-01
            -2.20040025203796230091057850586367e-02 -9.10354642730252239246624412771780e-01
            6.59606161936887591679123943322338e-02 -9.08228467280557727470124973478960e-01
            1.53309378406474905442991030213307e-01 -8.97622407340671446540625311172334e-01
            2.39226732260036933919167267958983e-01 -8.78635488834605848929015792236896e-01
            3.22910490570613550875833652753499e-01 -8.51444987504705319558695464365883e-01
            4.03579320634215588103899108318728e-01 -8.16304773735807120971230688155629e-01
            4.80480039319570895184341452477383e-01 -7.73542942235856512134262175095500e-01
            5.52894645336081569375608069094596e-01 -7.23558748704022480779940451611765e-01
            6.20147023018421728046689622715348e-01 -6.66818882087805930858337433164706e-01
            6.81609255036337513544708599511068e-01 -6.03853107234078034792901235050522e-01
            7.36707485089570290881511027691886e-01 -5.35249318617448399670877279277192e-01
            7.84927275849521932649111022328725e-01 -4.61648051327946784549993708424154e-01
            8.25818412121981371143419892177917e-01 -3.83736500567474714262772295114701e-01
            8.58999104385086420521133732108865e-01 -3.02242105493363721890887063636910e-01
            8.84159553455227009699513018858852e-01 -2.17925757314952700527399542806961e-01
            9.01064842998548609642739393166266e-01 -1.31574695057381618745750984089682e-01
            9.09557132881466334772824211540865e-01 -4.39951553229284350599037622941978e-02
            8.73915870600857624950208446534816e-01 4.50478301662593227927544603517163e-02
            8.64652144967719138435313652735204e-01 1.34665972292429880763364735685172e-01
            8.46222891497698137541760843305383e-01 2.22856621611336069843645191213000e-01
            8.18823464862237115902132700284710e-01 3.08684935300937213220606736285845e-01
            7.82744305799850215166202360705938e-01 3.91241111884543302235073269912391e-01
            7.38367862372040439922216137347277e-01 4.69650035352800254706551186245633e-01
            6.86164535918707185757625666155946e-01 5.43080551611092365860145037004258e-01
            6.26687694686919982700601394753903e-01 6.10754278919711568462957984593231e-01
            5.60567807989838629012524506833870e-01 6.71953858933937886455112220573938e-01
            4.88505763075150645224908885211335e-01 7.26030560880950637248076873220270e-01
            4.11265435545885738033433653981774e-01 7.72411158267406139366073603014229e-01
            3.29665592088994374719845836807508e-01 8.10604005222868240210232215758879e-01
            2.44571211344778993712623105238890e-01 8.40204248068343484412423549656523e-01
            1.56884314918127903970557213142456e-01 8.60898116865992935053952805901645e-01
            6.75344057251044960210606404871214e-02 8.72466251458530739348873339622514e-01
            -2.25313849691944519115782696871975e-02 8.74786026741461553157819253101479e-01
            -1.12358337377668773826577819363592e-01 8.67832852519693997983551980723860e-01
            -2.00994263458463884308713431892102e-01 8.51680434169725830706454416940687e-01
            -2.87499600345091366193628346081823e-01 8.26499991344316842223349794949172e-01
            -3.70957369946548765060612140587182e-01 7.92558443001576073960734447609866e-01
            -4.50482899143202830671839365095366e-01 7.50215577997603411120053351623937e-01
            -5.25233197541938090502355862554396e-01 6.99920241235109874544662034168141e-01
            -5.94415893384034776936175603623269e-01 6.42205575795790628568227020878112e-01
            -6.57297632882930193964909904025262e-01 5.77683371491026997901485628972296e-01
            -7.13211853956793873088315649511060e-01 5.07037579737691701531332455488155e-01
            -7.61565851952416772441267767135287e-01 4.31017063502981079281539678049739e-01
            -8.01847062461981008318900876474800e-01 3.50427659170669703048162091363338e-01
            -8.33628494633295358262614627165021e-01 2.66123634474972781127632970310515e-01
            -8.56573257379051100635081184009323e-01 1.78998633050045929948623779637273e-01
            -8.70438130506155705035098435473628e-01 8.99762015851511276487428858672502e-02
            -8.75076142910285903475653412897373e-01 1.07165919742529340814668330908976e-16
            -8.70438130506155705035098435473628e-01 -8.99762015851509194819257686503988e-02
            -8.56573257379051211657383646524977e-01 -1.78998633050045347081535851430090e-01
            -8.33628494633295469284917089680675e-01 -2.66123634474972614594179276537034e-01
            -8.01847062461981008318900876474800e-01 -3.50427659170669869581615785136819e-01
            -7.61565851952416661418965304619633e-01 -4.31017063502981190303842140565393e-01
            -7.13211853956794206155223037058022e-01 -5.07037579737691146419820142909884e-01
            -6.57297632882930304987212366540916e-01 -5.77683371491026886879183166456642e-01
            -5.94415893384034887958478066138923e-01 -6.42205575795790406523622095846804e-01
            -5.25233197541937979480053400038742e-01 -6.99920241235110096589266959199449e-01
            -4.50482899143203274761049215157982e-01 -7.50215577997603078053145964076975e-01
            -3.70957369946548987105217065618490e-01 -7.92558443001575962938431985094212e-01
            -2.87499600345091366193628346081823e-01 -8.26499991344316842223349794949172e-01
            -2.00994263458464661464830669501680e-01 -8.51680434169725719684151954425033e-01
            -1.12358337377668607293124125590111e-01 -8.67832852519693997983551980723860e-01
            -2.25313849691948578368716482600576e-02 -8.74786026741461553157819253101479e-01
            6.75344057251042878542435232702701e-02 -8.72466251458530739348873339622514e-01
            1.56884314918127709681527903740061e-01 -8.60898116865992935053952805901645e-01
            2.44571211344778993712623105238890e-01 -8.40204248068343484412423549656523e-01
            3.29665592088994374719845836807508e-01 -8.10604005222868240210232215758879e-01
            4.11265435545885404966526266434812e-01 -7.72411158267406361410678528045537e-01
            4.88505763075150367669152728922199e-01 -7.26030560880950970314984260767233e-01
            5.60567807989838517990222044318216e-01 -6.71953858933938108499717145605246e-01
            6.26687694686919871678298932238249e-01 -6.10754278919711679485260447108885e-01
            6.86164535918706741668415816093329e-01 -5.43080551611092920971657349582529e-01
            7.38367862372040550944518599862931e-01 -4.69650035352800143684248723729979e-01
            7.82744305799849993121597435674630e-01 -3.91241111884543746324283119975007e-01
            8.18823464862237337946737625316018e-01 -3.08684935300936769131396886223229e-01
            8.46222891497698026519458380789729e-01 -2.22856621611336264132674500615394e-01
            8.64652144967719027413011190219549e-01 -1.34665972292430685675057588923664e-01
            8.73915870600857624950208446534816e-01 -4.50478301662592187093459017432906e-02
            8.34501061545745659309147868043510e-01 4.60407065514442312426091064025968e-02
            8.24371349103675932212809129850939e-01 1.37563247845192082596810223549255e-01
            8.04234885206511318500588458846323e-01 2.27415957658213180314632495537808e-01
            7.74336099248386200422089586936636e-01 3.14508145811083827947385316292639e-01
            7.35037921988863640621048034518026e-01 3.97782631117832796707745046660420e-01
            6.86817380065152471857459204329643e-01 4.76228574133443216531702546490123e-01
            6.30259805534929329340343429066706e-01 5.48893747375396534593505748489406e-01
            5.66051730738070690840402221510885e-01 6.14896094075387145139188760367688e-01
            4.94972554724046664986758514714893e-01 6.73434435153625998715654077386716e-01
            4.17885082403264607187054480164079e-01 7.23798194447561105135946490918286e-01
            3.35725051264240847981312754200189e-01 7.65376024143920696829468397481833e-01
            2.49489772788076186182948390523961e-01 7.97663225713011514450556660449365e-01
            1.60226026438066743162735861005785e-01 8.20267876265187267925682590430370e-01
            6.90173531750265384365761178742105e-02 8.32915585963815652270625378150726e-01
            -2.30290972621742251469356688176049e-02 8.35452828746196751730224150378490e-01
            -1.14796005654654073580012152433483e-01 8.27848805921992725309621619089739e-01
            -2.05169446045276732126794172472728e-01 8.10195820027607149782511442026589e-01
            -2.93052407290806504747138205857482e-01 7.82708154398429556408700591418892e-01
            -3.77378109291137353586975677899318e-01 7.45719472059419352660825097700581e-01
            -4.57122952254608028166416033855057e-01 6.99678765507975031212595240504015e-01
            -5.31318941812869094398763536446495e-01 6.45144906553237529323041599127464e-01
            -5.99065439161234447595916208229028e-01 5.82779862369394052734605793375522e-01
            -6.59540093593732001941987164173042e-01 5.13340660110908952873387534054928e-01
            -7.12008824726689470985263596958248e-01 4.37670197628363788489025409944588e-01
            -7.55834733240178913149520667502657e-01 3.56687011830372380227771600402775e-01
            -7.90485831972996044747503674443578e-01 2.71374128889790899865630535714445e-01
            -8.15541503526146738245472533890279e-01 1.82767131637624424822519131339504e-01
            -8.30697605988287679501524962688563e-01 9.19415889902948368916923982396838e-02
            -8.35770164806528992329504035296850e-01 1.02352325715317155381930589423988e-16
            -8.30697605988287679501524962688563e-01 -9.19415889902946287248752810228325e-02
            -8.15541503526146738245472533890279e-01 -1.82767131637624230533489821937110e-01
            -7.90485831972996155769806136959232e-01 -2.71374128889790733332176841940964e-01
            -7.55834733240179135194125592533965e-01 -3.56687011830371880627410519082332e-01
            -7.12008824726689359962961134442594e-01 -4.37670197628363955022479103718069e-01
            -6.59540093593732223986592089204350e-01 -5.13340660110908952873387534054928e-01
            -5.99065439161234558618218670744682e-01 -5.82779862369393941712303330859868e-01
            -5.31318941812869316443368461477803e-01 -6.45144906553237418300739136611810e-01
            -4.57122952254608250211020958886365e-01 -6.99678765507974920190292777988361e-01
            -3.77378109291137520120429371672799e-01 -7.45719472059419241638522635184927e-01
            -2.93052407290806726791743130888790e-01 -7.82708154398429445386398128903238e-01
            -2.05169446045276732126794172472728e-01 -8.10195820027607149782511442026589e-01
            -1.14796005654654101335587768062396e-01 -8.27848805921992725309621619089739e-01
            -2.30290972621742459636173805392900e-02 -8.35452828746196751730224150378490e-01
            6.90173531750257890360344958935457e-02 -8.32915585963815652270625378150726e-01
            1.60226026438066715407160245376872e-01 -8.20267876265187267925682590430370e-01
            2.49489772788076186182948390523961e-01 -7.97663225713011514450556660449365e-01
            3.35725051264240292869800441621919e-01 -7.65376024143920918874073322513141e-01
            4.17885082403264607187054480164079e-01 -7.23798194447561105135946490918286e-01
            4.94972554724046109875246202136623e-01 -6.73434435153626331782561464933679e-01
            5.66051730738070690840402221510885e-01 -6.14896094075387256161491222883342e-01
            6.30259805534929551384948354098015e-01 -5.48893747375396312548900823458098e-01
            6.86817380065152138790551816782681e-01 -4.76228574133443771643214859068394e-01
            7.35037921988863751643350497033680e-01 -3.97782631117832685685442584144766e-01
            7.74336099248386089399787124420982e-01 -3.14508145811084438570048860128736e-01
            8.04234885206511096455983533815015e-01 -2.27415957658213790937296039373905e-01
            8.24371349103676043235111592366593e-01 -1.37563247845191943818932145404688e-01
            8.34501061545745659309147868043510e-01 -4.60407065514448141096970346097805e-02
            7.91639953702911070010372895922046e-01 4.69797569780117385551676534305443e-02
            7.80527064049101770848437809036113e-01 1.40279778126961268691630380089919e-01
            7.58457285352468257855207411921583e-01 2.31610578688074247866168775544793e-01
            7.25740428928359659899172129371436e-01 3.19690074421056513731542736422853e-01
            6.82835767724736752981584686494898e-01 4.03281822278452717345231803847128e-01
            6.30345589136721118350692449894268e-01 4.81212377355716092175441644940292e-01
            5.69006740211797978901131500606425e-01 5.52387765485445547675169564172393e-01
            4.99680283932458280116151172478567e-01 6.15808840236674481793954782915534e-01
            4.23339411779397434276717149259639e-01 6.70585308740606067523515321227023e-01
            3.41055782256389161677390120530617e-01 7.15948229450944828577974021754926e-01
            2.53984477153995746867565230786568e-01 7.51260806397666125455714336567326e-01
            1.63347786733200772690821622745716e-01 7.76027328406561300866428609879222e-01
            7.04180514494357479016173329000594e-02 7.89900127797511397709229186148150e-01
            -2.35001989184067498761532277740116e-02 7.92684460876618590674524966743775e-01
            -1.17088558006506318620587592249649e-01 7.84341241710785785912207757064607e-01
            -2.09033250401478853941483748712926e-01 7.64987590808539064113347194506787e-01
            -2.98043574167350666659359603727353e-01 7.34895191004820147462339718913427e-01
            -3.82870019471484634987490380808595e-01 6.94486473629519429628942361887312e-01
            -4.62321808963672087333662830133107e-01 6.44328688497585067018746940448182e-01
            -5.35283613679913283789346678531729e-01 5.85125940965048663144898455357179e-01
            -6.00731209816240396826003689056961e-01 5.17709307833243759233710079570301e-01
            -6.57745856585799759663757413363783e-01 4.43025170852258343145990693301428e-01
            -7.05527193325593438011367197759682e-01 3.62121931595658752556232684582938e-01
            -7.43404474805776760426567761896877e-01 2.76135294200519354479439471106161e-01
            -7.70845987022392709064888549619354e-01 1.86272322570835285882040466276521e-01
            -7.87466511296456950219635473331437e-01 9.37944958462227362794294549530605e-02
            -7.93032731899800058528171575744636e-01 9.71184996740171220643458906406214e-17
            -7.87466511296456950219635473331437e-01 -9.37944958462228889350953409120848e-02
            -7.70845987022392820087191012135008e-01 -1.86272322570834758526103769327165e-01
            -7.43404474805776760426567761896877e-01 -2.76135294200519187945985777332680e-01
            -7.05527193325593438011367197759682e-01 -3.62121931595658586022778990809456e-01
            -6.57745856585799870686059875879437e-01 -4.43025170852258232123688230785774e-01
            -6.00731209816240729892911076603923e-01 -5.17709307833243315144500229507685e-01
            -5.35283613679913616856254066078691e-01 -5.85125940965048219055688605294563e-01
            -4.62321808963672253867116523906589e-01 -6.44328688497585067018746940448182e-01
            -3.82870019471484468454036687035114e-01 -6.94486473629519429628942361887312e-01
            -2.98043574167350833192813297500834e-01 -7.34895191004820036440037256397773e-01
            -2.09033250401478881697059364341840e-01 -7.64987590808539064113347194506787e-01
            -1.17088558006506693320858403239981e-01 -7.84341241710785674889905294548953e-01
            -2.35001989184069441651825371764062e-02 -7.92684460876618590674524966743775e-01
            7.04180514494351927901050203217892e-02 -7.89900127797511397709229186148150e-01
            1.63347786733201105757729010292678e-01 -7.76027328406561189844126147363568e-01
            2.53984477153995968912170155817876e-01 -7.51260806397666125455714336567326e-01
            3.41055782256388828610482732983655e-01 -7.15948229450944828577974021754926e-01
            4.23339411779397434276717149259639e-01 -6.70585308740606067523515321227023e-01
            4.99680283932457836026941322415951e-01 -6.15808840236674814860862170462497e-01
            5.69006740211797867878829038090771e-01 -5.52387765485445769719774489203701e-01
            6.30345589136721118350692449894268e-01 -4.81212377355716092175441644940292e-01
            6.82835767724736530936979761463590e-01 -4.03281822278452994900987960136263e-01
            7.25740428928359659899172129371436e-01 -3.19690074421056569242693967680680e-01
            7.58457285352468368877509874437237e-01 -2.31610578688074081332715081771312e-01
            7.80527064049101770848437809036113e-01 -1.40279778126961518491810920750140e-01
            7.91639953702911070010372895922046e-01 -4.69797569780117177384859417088592e-02
            7.45584616406190225923467096436070e-01 4.78681205749411087246869556111051e-02
            7.33342137617599920673683300265111e-01 1.42818368508368431779587126584374e-01
            7.09058201203666249590185088891303e-01 2.35423542779315264628081649789237e-01
            6.73131548728940543036003418819746e-01 3.24163068986460911613534108255408e-01
            6.26152094833811623253438938263571e-01 4.07579846562820646838076754647773e-01
            5.68891240852420598805849749624031e-01 4.84304174326771752490117250999901e-01
            5.02289208424080091397456726554083e-01 5.53076240937589003188179503922584e-01
            4.27439601079950826090225746156648e-01 6.12766810962829033826437807874754e-01
            3.45571447303294310149368584461627e-01 6.62395766892912352119537899852730e-01
            2.58029019915756330227907255903119e-01 7.01148202643533280387089234864106e-01
            1.66249763154798613218332548058243e-01 7.28387804291035889647787371359300e-01
            7.17406898790620695116615479491884e-02 7.43667298329447334914732437027851e-01
            -2.39463635411104464045806139438355e-02 7.46735795889081566123479660745943e-01
            -1.19240218333970707242919218060706e-01 7.37542912324842370175304040458286e-01
            -2.12576152038360943752337561818422e-01 7.16239594530703627128787047695369e-01
            -3.02421591203266226788315407247865e-01 6.83175642395883020441260669031180e-01
            -3.87301276201510225050128610746469e-01 6.38893965100332250628412111836951e-01
            -4.65821484952046949157278277198202e-01 5.84121666561011054774610329332063e-01
            -5.36692917798001101203908547176979e-01 5.19758106405673103722619998734444e-01
            -5.98751867771388779360108856053557e-01 4.46860132512642449498230234894436e-01
            -6.50979328629359033087098396208603e-01 3.66624727597869459749801990255946e-01
            -6.92517726908530195650826044584392e-01 2.80369354791827174455676185971242e-01
            -7.22685003257549252175806486775400e-01 1.89510324931331880504714604285255e-01
            -7.40985811832784668773399516794598e-01 9.55395407747601788095437314041192e-02
            -7.47119653863384192149510454328265e-01 9.14957692683871917982727583656390e-17
            -7.40985811832784668773399516794598e-01 -9.55395407747600122760900376306381e-02
            -7.22685003257549252175806486775400e-01 -1.89510324931331713971260910511774e-01
            -6.92517726908530195650826044584392e-01 -2.80369354791827007922222492197761e-01
            -6.50979328629359255131703321239911e-01 -3.66624727597869015660592140193330e-01
            -5.98751867771388890382411318569211e-01 -4.46860132512642393987079003636609e-01
            -5.36692917798001212226211009692634e-01 -5.19758106405672992700317536218790e-01
            -4.65821484952047115690731970971683e-01 -5.84121666561010832730005404300755e-01
            -3.87301276201510613628187229551258e-01 -6.38893965100332028583807186805643e-01
            -3.02421591203266559855222794794827e-01 -6.83175642395883020441260669031180e-01
            -2.12576152038360943752337561818422e-01 -7.16239594530703627128787047695369e-01
            -1.19240218333970388053799638328201e-01 -7.37542912324842370175304040458286e-01
            -2.39463635411104602823684217582922e-02 -7.46735795889081566123479660745943e-01
            7.17406898790615421557248509998317e-02 -7.43667298329447334914732437027851e-01
            1.66249763154798446684878854284761e-01 -7.28387804291035889647787371359300e-01
            2.58029019915756330227907255903119e-01 -7.01148202643533280387089234864106e-01
            3.45571447303294143615914890688146e-01 -6.62395766892912463141840362368384e-01
            4.27439601079950826090225746156648e-01 -6.12766810962829033826437807874754e-01
            5.02289208424079758330549339007121e-01 -5.53076240937589336255086891469546e-01
            5.68891240852420043694337437045760e-01 -4.84304174326772418623932026093826e-01
            6.26152094833811734275741400779225e-01 -4.07579846562820369282320598358638e-01
            6.73131548728940432013700956304092e-01 -3.24163068986461078146987802028889e-01
            7.09058201203666138567882626375649e-01 -2.35423542779315791984018346738594e-01
            7.33342137617599920673683300265111e-01 -1.42818368508368709335343282873509e-01
            7.45584616406190225923467096436070e-01 -4.78681205749417748585017307050293e-02
            6.96535883157942570242937563307351e-01 4.87065337134923934114816290730232e-02
            6.82978604490097174206653107830789e-01 1.45171583864604963887146027445851e-01
            6.56127924162500097970962542603957e-01 2.38811034266022181871136353947804e-01
            6.16506460125531674520971137098968e-01 3.27802299528976548437242399813840e-01
            5.64885399107924346395748216309585e-01 4.10413265901188539785948705684859e-01
            5.02269486344299131985735584748909e-01 4.85036004890804561817674311896553e-01
            4.29877469352054841777999172336422e-01 5.50218069765499251388973789289594e-01
            3.49118376397246799047735521526192e-01 6.04690765775986460717206227855058e-01
            2.61564091362133432916436959203565e-01 6.47393843856195583263968273968203e-01
            1.68918758813400571305862740700832e-01 6.77496137165326417495236910326639e-01
            7.29856147666048393762849855193053e-02 6.94411738804968203808698490320239e-01
            -2.43681112517162463959596863105617e-02 6.97811405830416786599812439817470e-01
            -1.21247539702838705300003141474008e-01 6.87628967590085737882077410176862e-01
            -2.15767022710677491836861463525565e-01 6.64062613661971390399685333250090e-01
            -3.06086846052803729367752794132684e-01 6.27571036318953945354337520257104e-01
            -3.90449037105138785364033537916839e-01 5.78864502605461628270688834163593e-01
            -4.67211581779419626858640413047397e-01 5.18891029797366343245812458917499e-01
            -5.34880384459661240015293515170924e-01 4.48817933324063611522092287486885e-01
            -5.92138348873815223427641285525169e-01 3.70009106301440182651418808745802e-01
            -6.37871013874529046994155123684322e-01 2.83998472903779775045052247151034e-01
            -6.71188245157699370224690937902778e-01 1.92460132274522244255621217234875e-01
            -6.91441560714188274694436131539987e-01 9.71757740906965122862359862665471e-02
            -6.98236752794493487073168580536731e-01 8.55093404356818171426625730804275e-17
            -6.91441560714188274694436131539987e-01 -9.71757740906963596305701003075228e-02
            -6.71188245157699481246993400418432e-01 -1.92460132274521772410835751543345e-01
            -6.37871013874529269038760048715631e-01 -2.83998472903779386466993628346245e-01
            -5.92138348873815334449943748040823e-01 -3.70009106301440071629116346230148e-01
            -5.34880384459661351037595977686578e-01 -4.48817933324063500499789824971231e-01
            -4.67211581779419793392094106820878e-01 -5.18891029797366121201207533886191e-01
            -3.90449037105139173942092156721628e-01 -5.78864502605461406226083909132285e-01
            -3.06086846052803895901206487906165e-01 -6.27571036318953834332035057741450e-01
            -2.15767022710677658370315157299046e-01 -6.64062613661971279377382870734436e-01
            -1.21247539702838719177790949288465e-01 -6.87628967590085737882077410176862e-01
            -2.43681112517168847741988457755724e-02 -6.97811405830416675577509977301816e-01
            7.29856147666045063093775979723432e-02 -6.94411738804968203808698490320239e-01
            1.68918758813400265994530968782783e-01 -6.77496137165326528517539372842293e-01
            2.61564091362133432916436959203565e-01 -6.47393843856195583263968273968203e-01
            3.49118376397246799047735521526192e-01 -6.04690765775986460717206227855058e-01
            4.29877469352054952800301634852076e-01 -5.50218069765499140366671326773940e-01
            5.02269486344298909941130659717601e-01 -4.85036004890804783862279236927861e-01
            5.64885399107924235373445753793931e-01 -4.10413265901188706319402399458340e-01
            6.16506460125531674520971137098968e-01 -3.27802299528976548437242399813840e-01
            6.56127924162500097970962542603957e-01 -2.38811034266022098604409507061064e-01
            6.82978604490097174206653107830789e-01 -1.45171583864605352465204646250641e-01
            6.96535883157942570242937563307351e-01 -4.87065337134920187112108180826908e-02
            6.44657189261009233582910837867530e-01 4.94932492068411722385690154624172e-02
            6.29546971130827803797558317455696e-01 1.47319667807647936008663691609399e-01
            5.99680705576609573981272660603281e-01 2.41693038257403763902075866099040e-01
            5.55758432549472325412409645650769e-01 3.30401328739926058997156133045792e-01
            4.98809652902380051830988350047846e-01 4.11365292111964986343508599020424e-01
            4.30169197762713062527240026611253e-01 4.82687201693953127357161747568171e-01
            3.51445941221993074510265842036461e-01 5.42695332374936278974075776204700e-01
            2.64485089690796648653758893487975e-01 5.89983144432284944969069329090416e-01
            1.71324931824414800063394181961485e-01 6.23442251630666022244042778766016e-01
            7.41490627643474203845030956472328e-02 6.42288400855973717895608388062101e-01
            -2.47647974810850761417935217423292e-02 6.46079854343622139722924657689873e-01
            -1.23098191863229802778256782858080e-01 6.34727743637347630034639678342501e-01
            -2.18546268961289896770594509689545e-01 6.08498152590502661141158569080289e-01
            -3.08871806746125132647762256965507e-01 5.68005880586054723302424918074394e-01
            -3.91957651168435394772870949964272e-01 5.14200032160129549829719053377630e-01
            -4.65856340455257256216725636477349e-01 4.48341770796108707308746943454025e-01
            -5.28835751963332656444549684238154e-01 3.71974758321491016932469619860058e-01
            -5.79419701665786046618222826509736e-01 2.86888972783002904609617189635173e-01
            -6.16422544654559811938554503285559e-01 1.95078752878298705697446280282747e-01
            -6.38976965652152117947082388127455e-01 9.86960523472112521981003396831511e-02
            -6.46554308146620515529434669588227e-01 3.66307858224655635988219177612925e-16
            -6.38976965652152117947082388127455e-01 -9.86960523472110995424344537241268e-02
            -6.16422544654559811938554503285559e-01 -1.95078752878298816719748742798402e-01
            -5.79419701665786157640525289025391e-01 -2.86888972783002738076163495861692e-01
            -5.28835751963332878489154609269463e-01 -3.71974758321490628354411001055269e-01
            -4.65856340455257422750179330250830e-01 -4.48341770796108651797595712196198e-01
            -3.91957651168435283750568487448618e-01 -5.14200032160129660852021515893284e-01
            -3.08871806746124966114308563192026e-01 -5.68005880586054834324727380590048e-01
            -2.18546268961289896770594509689545e-01 -6.08498152590502661141158569080289e-01
            -1.23098191863230246867466632920696e-01 -6.34727743637347630034639678342501e-01
            -2.47647974810852322669063596549677e-02 -6.46079854343622139722924657689873e-01
            7.41490627643474065067152878327761e-02 -6.42288400855973717895608388062101e-01
            1.71324931824414494752062410043436e-01 -6.23442251630666133266345241281670e-01
            2.64485089690796537631456430972321e-01 -5.89983144432284944969069329090416e-01
            3.51445941221993241043719535809942e-01 -5.42695332374936167951773313689046e-01
            4.30169197762712840482635101579945e-01 -4.82687201693953349401766672599479e-01
            4.98809652902379607741778499985230e-01 -4.11365292111965430432718449083040e-01
            5.55758432549472103367804720619461e-01 -3.30401328739926392064063520592754e-01
            5.99680705576609462958970198087627e-01 -2.41693038257403902679953944243607e-01
            6.29546971130827803797558317455696e-01 -1.47319667807647852741936844722659e-01
            6.44657189261009233582910837867530e-01 -4.94932492068414428554312678443239e-02
            5.90082785612951243869872541836230e-01 5.02234466931358522479023065443471e-02
            5.73107178231889946573573979549110e-01 1.49225502959645262013310684778844e-01
            5.39644320786710096626848098821938e-01 2.43934613200194994053759955932037e-01
            4.90656878760438175390845572110265e-01 3.31626168749607430630277349337121e-01
            4.27554131668958947720682317594765e-01 4.09777443214339121002609545030282e-01
            3.52151430655211705733620419778163e-01 4.76140166717707202792553289327770e-01
            2.66617974142009883653514634715975e-01 5.28805204530826244990748818963766e-01
            1.73414403942866057750649133595289e-01 5.66257479402805685708699456881732e-01
            7.52220170770963869610881147309556e-02 5.87419557574763939733486495242687e-01
            -2.51343702635993676564041265919514e-02 5.91682644587392614354826037015300e-01
            -1.24767687533844359726309392044641e-01 5.78924099189121132980062611750327e-01
            -2.20811665597697409646471555788594e-01 5.49510961501632921866189462889452e-01
            -3.10503294073092239724331875549979e-01 5.04289393943831765199092842522077e-01
            -3.91262308109928735877502958828700e-01 4.44560338679654998284007660913630e-01
            -4.60765417911933927719303483172553e-01 3.72042091880635583667213950320729e-01
            -5.17013145554097053313569176680176e-01 2.88820871473542295504444155085366e-01
            -5.58387346322133715226243566576159e-01 1.97290800448991748838878379501693e-01
            -5.83697759789764791804600463365205e-01 1.00085032301980070279512347042328e-01
            -5.92216251444080521437740571855102e-01 7.25255736734037265294664104980499e-17
            -5.83697759789764791804600463365205e-01 -1.00085032301979931501634268897760e-01
            -5.58387346322133715226243566576159e-01 -1.97290800448991610061000301357126e-01
            -5.17013145554097275358174101711484e-01 -2.88820871473541962437536767538404e-01
            -4.60765417911933816697001020656899e-01 -3.72042091880635750200667644094210e-01
            -3.91262308109928846899805421344354e-01 -4.44560338679654942772856429655803e-01
            -3.10503294073092572791239263096941e-01 -5.04289393943831654176790380006423e-01
            -2.20811665597697520668774018304248e-01 -5.49510961501632810843887000373797e-01
            -1.24767687533844248704006929528987e-01 -5.78924099189121132980062611750327e-01
            -2.51343702635996417427133309274723e-02 -5.91682644587392503332523574499646e-01
            7.52220170770959706274538802972529e-02 -5.87419557574763939733486495242687e-01
            1.73414403942865807950468592935067e-01 -5.66257479402805796731001919397386e-01
            2.66617974142009883653514634715975e-01 -5.28805204530826244990748818963766e-01
            3.52151430655211816755922882293817e-01 -4.76140166717707091770250826812116e-01
            4.27554131668958781187228623821284e-01 -4.09777443214339232024912007545936e-01
            4.90656878760437953346240647078957e-01 -3.31626168749607763697184736884083e-01
            5.39644320786709985604545636306284e-01 -2.43934613200195160587213649705518e-01
            5.73107178231889946573573979549110e-01 -1.49225502959645206502159453521017e-01
            5.90082785612951132847570079320576e-01 -5.02234466931361089869767511117971e-02
            5.32922247892866018936786076665157e-01 5.08879046457962960769982885267382e-02
            5.13661049338644315476187784952344e-01 1.50824492476347493674637689764495e-01
            4.75834802130513878637430025264621e-01 2.45309890179421313805008253439155e-01
            4.20810645397902305386850230206619e-01 3.30929149302726099968197104317369e-01
            3.50577295529168109222695193238906e-01 4.04587766742741938852390148895211e-01
            2.67673168779775705328205503974459e-01 4.63623528149530783615261952945730e-01
            1.75094636295043293294781960867113e-01 5.05902727289675224753295879054349e-01
            7.61877274499831586007658756898309e-02 5.29897283748871572583993838634342e-01
            -2.54728043703072899728301337063385e-02 5.34739971739477404355511680478230e-01
            -1.26212682671910159104555759768118e-01 5.20255763900011714007121099712094e-01
            -2.22390905777813341348547737652552e-01 4.86968157240028176602208986878395e-01
            -3.10531342115052733099389570270432e-01 4.36080252594231887464104602258885e-01
            -3.87448366666734100860480793926399e-01 3.69431271423664164821332178689772e-01
            -4.50361997760206522745107804439613e-01 2.89430081560056229328381505183643e-01
            -4.96998372847885283576374604308512e-01 1.98968134446145500371372349945887e-01
            -5.25671931824211347006325922848191e-01 1.01314960546933438556571616118163e-01
            -5.35346337559551299634108545433264e-01 6.55610178727563030809800168940418e-17
            -5.25671931824211458028628385363845e-01 -1.01314960546933091611876420756744e-01
            -4.96998372847885339087525835566339e-01 -1.98968134446145361593494271801319e-01
            -4.50361997760206744789712729470921e-01 -2.89430081560055896261474117636681e-01
            -3.87448366666734156371632025184226e-01 -3.69431271423664109310180947431945e-01
            -3.10531342115052844121692032786086e-01 -4.36080252594231831952953371001058e-01
            -2.22390905777813258081820890765812e-01 -4.86968157240028232113360218136222e-01
            -1.26212682671910186860131375397032e-01 -5.20255763900011714007121099712094e-01
            -2.54728043703075432424576263201743e-02 -5.34739971739477404355511680478230e-01
            7.61877274499829088005853350296093e-02 -5.29897283748871683606296301149996e-01
            1.75094636295043293294781960867113e-01 -5.05902727289675335775598341570003e-01
            2.67673168779775705328205503974459e-01 -4.63623528149530783615261952945730e-01
            3.50577295529167831666939036949771e-01 -4.04587766742742216408146305184346e-01
            4.20810645397902083342245305175311e-01 -3.30929149302726377523953260606504e-01
            4.75834802130513823126278794006794e-01 -2.45309890179421452582886331583722e-01
            5.13661049338644315476187784952344e-01 -1.50824492476347549185788921022322e-01
            5.32922247892866018936786076665157e-01 -5.08879046457967124106325229604408e-02
            4.73261822880819860159817835665308e-01 5.14703249978158625110857826712163e-02
            4.51132626035650019513667530191015e-01 1.52004279801707276043032379675424e-01
            4.07908968994954546083420154900523e-01 2.45430683422693807216319328290410e-01
            3.45611941922312038144582402310334e-01 3.27381021063447963381776162350434e-01
            2.67154484565466643353204290178837e-01 3.94023386017146426407720127826906e-01
            1.76205180431223684678343488485552e-01 4.42241655366223063161612572002923e-01
            7.70167178980086380990499606014055e-02 4.69781196426672542632019258235232e-01
            -2.57729607661830173448436198668787e-02 4.75354290866509543445062035971205e-01
            -1.27357524429536794752237938155304e-01 4.58700346983776818809985797997797e-01
            -2.22986991798287070842832235939568e-01 4.20598084684901951657565177811193e-01
            -3.08189835262790701175816820978071e-01 3.62829123407357234665226997094578e-01
            -3.78982064558806175380567538013565e-01 2.88094675574891878611083484429400e-01
            -4.32053513724364013359746650166926e-01 1.99889240906778536954746527953830e-01
            -4.64922620781161533010106268193340e-01 1.02337207494799353746373071771814e-01
            -4.76052462814611776487083716347115e-01 5.82996124812128722306628167301851e-17
            -4.64922620781161533010106268193340e-01 -1.02337207494799228846282801441703e-01
            -4.32053513724363957848595418909099e-01 -1.99889240906778620221473374840571e-01
            -3.78982064558806341914021231787046e-01 -2.88094675574891656566478559398092e-01
            -3.08189835262790590153514358462417e-01 -3.62829123407357290176378228352405e-01
            -2.22986991798287376154164007857617e-01 -4.20598084684901785124111484037712e-01
            -1.27357524429536989041267247557698e-01 -4.58700346983776763298834566739970e-01
            -2.57729607661833434728571035066125e-02 -4.75354290866509487933910804713378e-01
            7.70167178980085270767474980857514e-02 -4.69781196426672598143170489493059e-01
            1.76205180431223462633738563454244e-01 -4.42241655366223174183915034518577e-01
            2.67154484565466587842053058921010e-01 -3.94023386017146481918871359084733e-01
            3.45611941922312038144582402310334e-01 -3.27381021063447963381776162350434e-01
            4.07908968994954546083420154900523e-01 -2.45430683422693807216319328290410e-01
            4.51132626035650019513667530191015e-01 -1.52004279801707220531881148417597e-01
            4.73261822880819860159817835665308e-01 -5.14703249978162094557809780326352e-02
            4.11161887046528395917022180583444e-01 5.19418256313168708038219278932957e-02
            3.85327073535750852517622888626647e-01 1.52561780960862924949594798817998e-01
            3.35280742860875780042562155358610e-01 2.43595718509656028460952370551240e-01
            2.64167490035734697784164382028393e-01 3.19323641182102713198531773741706e-01
            1.76455622271580347959485379760736e-01 3.74987285088875577088174395612441e-01
            7.76563988017193312929364878982597e-02 4.07089098766749812874365943571320e-01
            -2.60222618051105421266289141613015e-02 4.13612007200132636430822685724706e-01
            -1.28065847999540766144477288435155e-01 3.94146152062575361174623367332970e-01
            -2.22062585970917741873265072172217e-01 3.49914644622778048255185012749280e-01
            -3.02106314976678669292908807619824e-01 2.83696713165288660896123928978341e-01
            -3.63167593143149225465293739034678e-01 1.99653073856097401650444567167142e-01
            -4.01409715795457311404703659718507e-01 1.03064497643885422117904226979590e-01
            -4.14429789722669750240413577557774e-01 5.07530115455178143041238662210208e-17
            -4.01409715795457366915854890976334e-01 -1.03064497643885144562148070690455e-01
            -3.63167593143149225465293739034678e-01 -1.99653073856097484917171414053882e-01
            -3.02106314976678891337513732651132e-01 -2.83696713165288438851519003947033e-01
            -2.22062585970917519828660147140909e-01 -3.49914644622778159277487475264934e-01
            -1.28065847999540932677930982208636e-01 -3.94146152062575305663472136075143e-01
            -2.60222618051104623293490192281752e-02 -4.13612007200132636430822685724706e-01
            7.76563988017191370039071784958651e-02 -4.07089098766749868385517174829147e-01
            1.76455622271580014892577992213774e-01 -3.74987285088875688110476858128095e-01
            2.64167490035734531250710688254912e-01 -3.19323641182102879731985467515187e-01
            3.35280742860875724531410924100783e-01 -2.43595718509656111727679217437981e-01
            3.85327073535750852517622888626647e-01 -1.52561780960862897194019183189084e-01
            4.11161887046528340405870949325617e-01 -5.19418256313170303983817177595483e-02
            3.46647571946267774034566855334560e-01 5.22487146609015018494659443604178e-02
            3.15846413941028580918413126710220e-01 1.52103616395375729197780856338795e-01
            2.56980915987971292313574167565093e-01 2.38443444317394531717368977297156e-01
            1.75281535907207880464753202431893e-01 3.03596525819992524297674663102953e-01
            7.80076221507383094078136309690308e-02 3.41773723692074982150046480455785e-01
            -2.61976111646355785955719852609036e-02 3.49582826364834065024922438169597e-01
            -1.28075071761708764173093300087203e-01 3.26329960796112539256341733562294e-01
            -2.18572500184559009861473555247358e-01 2.74081246135211065162451404830790e-01
            -2.89648802776392988445053333634860e-01 1.97479209969458280315990350572974e-01
            -3.34988538138709490699085336018470e-01 1.03330279374680575332767773488740e-01
            -3.50563071814415705418355173605960e-01 4.29315943796787878473190350218835e-17
            -3.34988538138709601721387798534124e-01 -1.03330279374680339410375040642975e-01
            -2.89648802776392932933902102377033e-01 -1.97479209969458363582717197459715e-01
            -2.18572500184559093128200402134098e-01 -2.74081246135211009651300173572963e-01
            -1.28075071761708680906366453200462e-01 -3.26329960796112539256341733562294e-01
            -2.61976111646358179874116700602826e-02 -3.49582826364834065024922438169597e-01
            7.80076221507382400188745918967470e-02 -3.41773723692074982150046480455785e-01
            1.75281535907207630664572661771672e-01 -3.03596525819992635319977125618607e-01
            2.56980915987971347824725398822920e-01 -2.38443444317394476206217746039329e-01
            3.15846413941028525407261895452393e-01 -1.52103616395375812464507703225536e-01
            3.46647571946267718523415624076733e-01 -5.22487146609017932830099084640096e-02
            2.79683787010191697852690140280174e-01 5.22819607380520523509659369665314e-02
            2.41910941793101241792385280859889e-01 1.49784913712136813490616304989089e-01
            1.71466683412049208934391231196059e-01 2.27058584102538568716411759851326e-01
            7.78648993065075983865952480300621e-02 2.73666734534844247050955345912371e-01
            -2.62529709146796068341966901016349e-02 2.83314676028493916959405396482907e-01
            -1.26825231941105481814346944702265e-01 2.54699400623680849431451633790857e-01
            -2.10269042631014951849621752444364e-01 1.91685559826539647643173225333157e-01
            -2.65314853972618336364064361987403e-01 1.02783522008470268316315809897787e-01
            -2.84528424124862233668409317033365e-01 3.48446823870953098637357343324030e-17
            -2.65314853972618391875215593245230e-01 -1.02783522008470087905074308309850e-01
            -2.10269042631014896338470521186537e-01 -1.91685559826539675398748840962071e-01
            -1.26825231941105787125678716620314e-01 -2.54699400623680682897997940017376e-01
            -2.62529709146796137730905940088633e-02 -2.83314676028493916959405396482907e-01
            7.78648993065075289976562089577783e-02 -2.73666734534844247050955345912371e-01
            1.71466683412049125667664384309319e-01 -2.27058584102538624227562991109153e-01
            2.41910941793101130770082818344235e-01 -1.49784913712136952268494383133657e-01
            2.79683787010191697852690140280174e-01 -5.22819607380519760231329939870193e-02
            2.10106661924383458783793798829720e-01 5.17866410399041854351054325888981e-02
            1.61973757737270906975624029655592e-01 1.43496227754150162958524106215918e-01
            7.67346176479360292388420816678263e-02 2.02332558006931062521971398382448e-01
            -2.60834985921506619377385760571997e-02 2.14816937591979312260903611786489e-01
            -1.22926199645009726069133648707066e-01 1.78089345599444198731120536649541e-01
            -1.91607989780495924225789394768071e-01 1.00563630739350415299604435404035e-01
            -2.16394698583867950425485560117522e-01 -6.95978432125333675526538006766402e-17
            -1.91607989780496063003667472912639e-01 -1.00563630739350193254999510372727e-01
            -1.22926199645009767702497072150436e-01 -1.78089345599444170975544921020628e-01
            -2.60834985921508111239575100626098e-02 -2.14816937591979312260903611786489e-01
            7.67346176479360292388420816678263e-02 -2.02332558006931062521971398382448e-01
            1.61973757737270823708897182768851e-01 -1.43496227754150218469675337473745e-01
            2.10106661924383458783793798829720e-01 -5.17866410399041993128932404033549e-02
            1.37406150305911994857765989763720e-01 5.00117487164597959714562591670983e-02
            7.31122854785179049352805691341928e-02 1.26634193106273218454305151681183e-01
            -2.53916302768180078552884282316882e-02 1.44003091159372570428942594844557e-01
            -1.12014520029093941899667186135048e-01 9.39913424429128091519558552136004e-02
            -1.46224570957035782114985522639472e-01 1.79073452779228904773325113267415e-17
            -1.12014520029094011288606225207332e-01 -9.39913424429127258852290083268599e-02
            -2.53916302768180113247353801853023e-02 -1.44003091159372570428942594844557e-01
            7.31122854785177939129781066185387e-02 -1.26634193106273273965456382939010e-01
            1.37406150305911994857765989763720e-01 -5.00117487164597751547745474454132e-02
            5.99282677951143427641511607362190e-02 4.35404351828446306571507307126012e-02
            -2.28905614108279517604493946691946e-02 7.04499040108043650398883528396254e-02
            -7.40754127685727681296157243195921e-02 9.07162171425516250242854578184557e-18
            -2.28905614108279691076841544372655e-02 -7.04499040108043511621005450251687e-02
            5.99282677951143358252572568289906e-02 -4.35404351828446445349385385270580e-02
            -0.00000000000000000000000000000000e+00 0.00000000000000000000000000000000e+00
            ];
        
    case   41
        
        % DEGREE.             :          41
        % CARDIN.             :         903
        % LEBESGUE CONST.     : 6.79097e+02
        % ABS.DET.VAND.MATRIX : Inf
        % CONDITIONING VAND.  : 2.84811e+04
        % POINTS OUT DISK     : 0.00000e+00
        
        pts=[
            9.99283754816331470927082136768149e-01 3.78414767176702901418927638133027e-02
            9.93559947963184919572654507646803e-01 1.13307677601269848888243529927422e-01
            9.82145119704202707033857677743072e-01 1.88124862368633738451961789905909e-01
            9.65104653141933277460395856905961e-01 2.61864484960806720437176409177482e-01
            9.42536154525672520421153421921190e-01 3.34104171497389690337342926795827e-01
            9.14568894171707280627003910922213e-01 4.04430139595876925184825267933775e-01
            8.81363066014648866008940331084887e-01 4.72439568479671001544062391985790e-01
            8.43108870031084478569027851335704e-01 5.37742906299011891313455180352321e-01
            8.00025422791334483996195103827631e-01 5.99966101448695665609989191580098e-01
            7.52359502379581268627362078404985e-01 6.58752745101793713011772979371017e-01
            7.00384134871350760853658812266076e-01 7.13766112687138853942769856075756e-01
            6.44397030464877174082971578172874e-01 7.64691092617174494883158786251443e-01
            5.84718878224047111658023823110852e-01 8.11235991218592356055694381211651e-01
            5.21691509200484571096012587076984e-01 8.53134203527276646639165846863762e-01
            4.55675938456241602647622812582995e-01 8.90145740377396577081015038857004e-01
            3.87050297202217119529876754313591e-01 9.22058603037613555564178113854723e-01
            3.16207666896823891278245355351828e-01 9.48689997520616445925156767771114e-01
            2.43553827710992154553792943261215e-01 9.69887381610527121722498122835532e-01
            1.69504934256096556621784543494869e-01 9.85529338610899197092862777935807e-01
            9.44851318880313567616369141433097e-02 9.95526272808558987392757444467861e-01
            1.89241272410193006603407184229582e-02 9.99820922669737766064201878180029e-01
            -5.67452730930739640546889290817489e-02 9.98388688828951265108457846508827e-01
            -1.32089641641702310037587153601635e-01 9.91237774991937325985702500474872e-01
            -2.06677412684953015764577344270947e-01 9.78409140945572741721036891249241e-01
            -2.80081354224906764471825226792134e-01 9.59976267943922767500453119282611e-01
            -3.51881015131832952658186286498676e-01 9.36044737814272775899837597535225e-01
            -4.21665133450183915453379768223385e-01 9.06751628193982694980945780116599e-01
            -4.89033992069833167715131594377453e-01 8.72264727362193847959304093819810e-01
            -5.53601708269484515945180191920372e-01 8.32781573163761001943328210472828e-01
            -6.14998444017953560525313605467090e-01 7.88528321530365894354019928869093e-01
            -6.72872524372918889845607282040874e-01 7.39758451079820744666903920006007e-01
            -7.26892451843143772016730963514419e-01 6.86751311213501081098797840240877e-01
            -7.76748805176085355128634546417743e-01 6.29810522028271480010630511969794e-01
            -8.22156011694809785161908166628564e-01 5.69262235208066291747286413738038e-01
            -8.62853983032422888754808809608221e-01 5.05453265856580680193133048305754e-01
            -8.98609604894682223452662128693191e-01 4.38749105971765029909903432780993e-01
            -9.29218072317565146889251082029659e-01 3.69531830940757144432495806540828e-01
            -9.54504062771555084054853068664670e-01 2.98197911046665653511666960184812e-01
            -9.74322740393213315712728217476979e-01 2.25155940522694192340580343625334e-01
            -9.88560585591888529854998068913119e-01 1.50824297161374021314372839697171e-01
            -9.97136045279652050155050346802454e-01 7.56287458844568521998397159222804e-02
            -1.00000000000000000000000000000000e+00 -3.21624529935327320103979552447107e-16
            -9.97136045279652050155050346802454e-01 -7.56287458844566023996591752620589e-02
            -9.88560585591888640877300531428773e-01 -1.50824297161373327424982448974333e-01
            -9.74322740393213426735030679992633e-01 -2.25155940522693970295975418594026e-01
            -9.54504062771555195077155531180324e-01 -2.98197911046665431467062035153504e-01
            -9.29218072317565368933856007060967e-01 -3.69531830940756533809832262704731e-01
            -8.98609604894682112430359666177537e-01 -4.38749105971765196443357126554474e-01
            -8.62853983032422999777111272123875e-01 -5.05453265856580458148528123274446e-01
            -8.22156011694809896184210629144218e-01 -5.69262235208066069702681488706730e-01
            -7.76748805176085688195541933964705e-01 -6.29810522028270924899118199391523e-01
            -7.26892451843143883039033426030073e-01 -6.86751311213500859054192915209569e-01
            -6.72872524372918778823304819525220e-01 -7.39758451079820966711508845037315e-01
            -6.14998444017953449503011142951436e-01 -7.88528321530366005376322391384747e-01
            -5.53601708269485071056692504498642e-01 -8.32781573163760557854118360410212e-01
            -4.89033992069833001181677900603972e-01 -8.72264727362193958981606556335464e-01
            -4.21665133450184526076043312059483e-01 -9.06751628193982361914038392569637e-01
            -3.51881015131832786124732592725195e-01 -9.36044737814272886922140060050879e-01
            -2.80081354224907430605640001886059e-01 -9.59976267943922656478150656766957e-01
            -2.06677412684953487609362809962477e-01 -9.78409140945572630698734428733587e-01
            -1.32089641641701893703952919167932e-01 -9.91237774991937437008004962990526e-01
            -5.67452730930744289605804908660502e-02 -9.98388688828951265108457846508827e-01
            1.89241272410186102403972796537346e-02 -9.99820922669737766064201878180029e-01
            9.44851318880308849168514484517800e-02 -9.95526272808558987392757444467861e-01
            1.69504934256096306821604002834647e-01 -9.85529338610899197092862777935807e-01
            2.43553827710991710464583093198598e-01 -9.69887381610527232744800585351186e-01
            3.16207666896823669233640430320520e-01 -9.48689997520616556947459230286768e-01
            3.87050297202216897485271829282283e-01 -9.22058603037613666586480576370377e-01
            4.55675938456241380603017887551687e-01 -8.90145740377396688103317501372658e-01
            5.21691509200484349051407662045676e-01 -8.53134203527276757661468309379416e-01
            5.84718878224046889613418898079544e-01 -8.11235991218592245033391918695997e-01
            6.44397030464876952038366653141566e-01 -7.64691092617174716927763711282751e-01
            7.00384134871350760853658812266076e-01 -7.13766112687138964965072318591410e-01
            7.52359502379581157605059615889331e-01 -6.58752745101793824034075441886671e-01
            8.00025422791334483996195103827631e-01 -5.99966101448695665609989191580098e-01
            8.43108870031084367546725388820050e-01 -5.37742906299012002335757642867975e-01
            8.81363066014648866008940331084887e-01 -4.72439568479671001544062391985790e-01
            9.14568894171707280627003910922213e-01 -4.04430139595876925184825267933775e-01
            9.42536154525672409398850959405536e-01 -3.34104171497390523004611395663233e-01
            9.65104653141933388482698319421615e-01 -2.61864484960806664926025177919655e-01
            9.82145119704202484989252752711764e-01 -1.88124862368634515608079027515487e-01
            9.93559947963184808550352045131149e-01 -1.13307677601270570533209536279173e-01
            9.99283754816331470927082136768149e-01 -3.78414767176709909701770584433689e-02
            9.88474408393098413760924358939519e-01 3.93293916663047665727148682890402e-02
            9.82224954923530679806731313874479e-01 1.17739521921891743261312512913719e-01
            9.69765559041370295290107605978847e-01 1.95405265011223044924193459337403e-01
            9.51174993058943152313133850839222e-01 2.71835593100401284871736606874038e-01
            9.26570792520006403236720871063881e-01 3.46547289046927609046377938284422e-01
            8.96108513102196524435782976070186e-01 4.19068001454057703636379983436200e-01
            8.59980747143951340660805726656690e-01 4.88939231028416132485148182240664e-01
            8.18415906013737926016915480431635e-01 5.55719229360150834828857568936655e-01
            7.71676776019838528419825252058217e-01 6.18985791798612794423206651117653e-01
            7.20058856990700713041064773278777e-01 6.78338926766091754316789774748031e-01
            6.63888494029879483449008148454595e-01 7.33403384633358745858799920824822e-01
            6.03520814257219151421907099575037e-01 7.83831030168639641964034581178566e-01
            5.39337481580860922392162137839478e-01 8.29303043560640884557244589814218e-01
            4.71744283695131549904999701539055e-01 8.69531936100046309867650506930659e-01
            4.01168566560087258565658885345329e-01 9.04263367775700932504889806295978e-01
            3.28056532582763071825837641881662e-01 9.33277755294050770373814884806052e-01
            2.52870419581889160909327074477915e-01 9.56391660355425221595737639290746e-01
            1.76085578371575679490490529133240e-01 9.73458949410027973847547855257289e-01
            9.81874674404163011454116372078715e-02 9.84371717561290271447660416015424e-01
            1.96685837266202326323316640355188e-02 9.89060970775369585616942913475214e-01
            -5.89746511062013978321516560754390e-02 9.87497062083644627783485248073703e-01
            -1.37245029206625762663307455113681e-01 9.79689879020396947595372694195248e-01
            -2.14647700043540085035331799190317e-01 9.65688781110636162985372266120976e-01
            -2.90693299010528594106261834895122e-01 9.45582287803289567307274410268292e-01
            -3.64901041346474053206350163236493e-01 9.19497518822746218170038901007501e-01
            -4.36801761811616784392242607282242e-01 8.87599390477030070201180933509022e-01
            -5.05940880901257883373034474061569e-01 8.50089573003802168038589570642216e-01
            -5.71881278843748064311114376323530e-01 8.07205215546187293540469909203239e-01
            -6.34206059212424233528793138248147e-01 7.59217446819535735080819449649425e-01
            -6.92521184679049439658626852178713e-01 7.06429660948387438956785899790702e-01
            -7.46457968244666592028124796343036e-01 6.49175599311135553826090927032055e-01
            -7.95675404197514479776032203517389e-01 5.87817240519576511559307618881576e-01
            -8.39862324060931864089241116744233e-01 5.22742511873578119541150499571813e-01
            -8.78739363900652770134058755502338e-01 4.54362836759790167384664982819231e-01
            -9.12060730553546084031779628276126e-01 3.83110533500528205319568542108755e-01
            -9.39615755611131864277751901681768e-01 3.09436082098143994123518041305942e-01
            -9.61230227333087605678940690268064e-01 2.33805276155412161687152661215805e-01
            -9.76767492069962384171333269478055e-01 1.56696277978398801344894764042692e-01
            -9.86129318231547369322242957423441e-01 7.85965954804096478270025727397297e-02
            -9.89256517338616081502777888090350e-01 1.21148982749439437550978965357075e-16
            -9.86129318231547369322242957423441e-01 -7.85965954804094119046098398939648e-02
            -9.76767492069962495193635731993709e-01 -1.56696277978398579300289839011384e-01
            -9.61230227333087605678940690268064e-01 -2.33805276155411911886972120555583e-01
            -9.39615755611131975300054364197422e-01 -3.09436082098143772078913116274634e-01
            -9.12060730553546195054082090791781e-01 -3.83110533500527983274963617077447e-01
            -8.78739363900652881156361218017992e-01 -4.54362836759789945340060057787923e-01
            -8.39862324060932197156148504291195e-01 -5.22742511873577564429638186993543e-01
            -7.95675404197514590798334666033043e-01 -5.87817240519576289514702693850268e-01
            -7.46457968244666592028124796343036e-01 -6.49175599311135442803788464516401e-01
            -6.92521184679049328636324389663059e-01 -7.06429660948387549979088362306356e-01
            -6.34206059212424455573398063279456e-01 -7.59217446819535735080819449649425e-01
            -5.71881278843748286355719301354839e-01 -8.07205215546187182518167446687585e-01
            -5.05940880901258105417639399092877e-01 -8.50089573003802057016287108126562e-01
            -4.36801761811617006436847532313550e-01 -8.87599390477029959178878470993368e-01
            -3.64901041346474663829013707072590e-01 -9.19497518822745885103131513460539e-01
            -2.90693299010528871662017991184257e-01 -9.45582287803289456284971947752638e-01
            -2.14647700043540112790907414819230e-01 -9.65688781110636162985372266120976e-01
            -1.37245029206625568374278145711287e-01 -9.79689879020396947595372694195248e-01
            -5.89746511062020778437542389838200e-02 -9.87497062083644516761182785558049e-01
            1.96685837266199932404919792361397e-02 -9.89060970775369585616942913475214e-01
            9.81874674404164954344409466102661e-02 -9.84371717561290271447660416015424e-01
            1.76085578371575207645705063441710e-01 -9.73458949410028084869850317772944e-01
            2.52870419581888938864722149446607e-01 -9.56391660355425221595737639290746e-01
            3.28056532582763071825837641881662e-01 -9.33277755294050770373814884806052e-01
            4.01168566560086814476449035282712e-01 -9.04263367775701043527192268811632e-01
            4.71744283695131161326941082734265e-01 -8.69531936100046420889952969446313e-01
            5.39337481580860811369859675323823e-01 -8.29303043560640884557244589814218e-01
            6.03520814257218596310394786996767e-01 -7.83831030168640086053244431241183e-01
            6.63888494029879150382100760907633e-01 -7.33403384633358967903404845856130e-01
            7.20058856990700602018762310763123e-01 -6.78338926766091865339092237263685e-01
            7.71676776019838084330615401995601e-01 -6.18985791798613349534718963695923e-01
            8.18415906013737592950008092884673e-01 -5.55719229360151389940369881514926e-01
            8.59980747143951340660805726656690e-01 -4.88939231028416243507450644756318e-01
            8.96108513102196524435782976070186e-01 -4.19068001454057703636379983436200e-01
            9.26570792520006181192115946032573e-01 -3.46547289046928164157890250862692e-01
            9.51174993058943152313133850839222e-01 -2.71835593100401617938643994421000e-01
            9.69765559041370295290107605978847e-01 -1.95405265011223072679769074966316e-01
            9.82224954923530679806731313874479e-01 -1.17739521921892381639551672378730e-01
            9.88474408393098413760924358939519e-01 -3.93293916663051343340917753721442e-02
            9.68742682255691600623492831800831e-01 4.06023482726558387900794855340791e-02
            9.61947648380324760175597020861460e-01 1.21522248517581851756652611129539e-01
            9.48405242910001722300705750967609e-01 2.01589757502772082276010223722551e-01
            9.28210456088891855408462561172200e-01 2.80243259181121362466626578680007e-01
            9.01504939836611063341820226924028e-01 3.56931055750818848615324441198027e-01
            8.68476014161781884048707524925703e-01 4.31115237419034125210259844607208e-01
            8.29355353246763238317385003028903e-01 5.02275455452625640972996734490152e-01
            7.84417360419717435426889551308705e-01 5.69912572050633836617805627611233e-01
            7.33977243412423319135484689468285e-01 6.33552161437324734549747518030927e-01
            6.78388803404512907846424241142813e-01 6.92747837618132855652675061719492e-01
            6.18041953362402418648002822010312e-01 7.47084385456684429982487927190959e-01
            5.53359983079985684462087647261797e-01 7.96180673110647552093155354668852e-01
            4.84796590104861757630771990079666e-01 8.39692325397764061101213428628398e-01
            4.12832697376022017543562014907366e-01 8.77314139340318432935816872486612e-01
            3.37973079894973216230624757372425e-01 9.08782224944739924765713112719823e-01
            2.60742824091783897966223548792186e-01 9.33875856200301890375214952655369e-01
            1.81683644721051529291599990756367e-01 9.52419019313495485157261555286823e-01
            1.01350085122119626390713165164925e-01 9.64281647318326218254469495150261e-01
            2.03056274959915149247446919389404e-02 9.69380532402626671206746777897933e-01
            -6.08812595174475293391402885845309e-02 9.67679909551074080020782730571227e-01
            -1.41641108238496293836305994773284e-01 9.59191707411076621703216460446129e-01
            -2.21407446354248055309099640908244e-01 9.43975464621881199533959261316340e-01
            -2.99620770314855511262663867455558e-01 9.22137912193798925386545306537300e-01
            -3.75732469848930661360242311275215e-01 8.93832224866852875777567533077672e-01
            -4.49208676070422363579837110592052e-01 8.59256946700033497066328891378362e-01
            -5.19534006185268792954445871146163e-01 8.18654598427377644398461598029826e-01
            -5.86215178531394043304203478328418e-01 7.72309976349271121165429576649331e-01
            -6.48784472595146155526890652254224e-01 7.20548154691026843110535082814749e-01
            -7.06803009734643383765728685830254e-01 6.63732205440760059111937607667642e-01
            -7.59863831598114325416304382088128e-01 6.02260651660257773087892019248102e-01
            -8.07594754644334167359431830846006e-01 5.36564672132039954810522885964019e-01
            -8.49660980742754534666971721890150e-01 4.67105076950000863700296349634300e-01
            -8.85767445541836728750695328926668e-01 3.94369075267692659192420023828163e-01
            -9.15660888133474681893630986451171e-01 3.18866857876170861629816499771550e-01
            -9.39131627496296639279194096161518e-01 2.41128018582168951455813044049137e-01
            -9.56015033257375579367476348124910e-01 1.61697839488055439272073954271036e-01
            -9.66192680456007590983347199653508e-01 8.11334662296710334983274037767842e-02
            -9.69593180209723737306148905190639e-01 1.18740918461894108476162967530440e-16
            -9.66192680456007590983347199653508e-01 -8.11334662296707975759346709310194e-02
            -9.56015033257375468345173885609256e-01 -1.61697839488055605805527648044517e-01
            -9.39131627496296750301496558677172e-01 -2.41128018582168701655632503388915e-01
            -9.15660888133474570871328523935517e-01 -3.18866857876171028163270193545031e-01
            -8.85767445541836839772997791442322e-01 -3.94369075267692437147815098796855e-01
            -8.49660980742754645689274184405804e-01 -4.67105076950000641655691424602992e-01
            -8.07594754644334056337129368330352e-01 -5.36564672132040176855127810995327e-01
            -7.59863831598114436438606844603783e-01 -6.02260651660257551043287094216794e-01
            -7.06803009734643827854938535892870e-01 -6.63732205440759615022727757605026e-01
            -6.48784472595146044504588189738570e-01 -7.20548154691026954132837545330403e-01
            -5.86215178531394598415715790906688e-01 -7.72309976349270677076219726586714e-01
            -5.19534006185268681932143408630509e-01 -8.18654598427377755420764060545480e-01
            -4.49208676070422974202500654428150e-01 -8.59256946700033163999421503831400e-01
            -3.75732469848930883404847236306523e-01 -8.93832224866852764755265070562018e-01
            -2.99620770314855733307268792486866e-01 -9.22137912193798814364242844021646e-01
            -2.21407446354248305109280181568465e-01 -9.43975464621881199533959261316340e-01
            -1.41641108238497376303755004300911e-01 -9.59191707411076510680913997930475e-01
            -6.08812595174475570947159042134444e-02 -9.67679909551074080020782730571227e-01
            2.03056274959908453214829648914019e-02 -9.69380532402626671206746777897933e-01
            1.01350085122119806801954666752863e-01 -9.64281647318326218254469495150261e-01
            1.81683644721051085202390140693751e-01 -9.52419019313495596179564017802477e-01
            2.60742824091783675921618623760878e-01 -9.33875856200301890375214952655369e-01
            3.37973079894972994186019832341117e-01 -9.08782224944740035788015575235477e-01
            4.12832697376021962032410783649539e-01 -8.77314139340318432935816872486612e-01
            4.84796590104861202519259677501395e-01 -8.39692325397764394168120816175360e-01
            5.53359983079985684462087647261797e-01 -7.96180673110647552093155354668852e-01
            6.18041953362401974558792971947696e-01 -7.47084385456684763049395314737922e-01
            6.78388803404513129891029166174121e-01 -6.92747837618132633608070136688184e-01
            7.33977243412423097090879764436977e-01 -6.33552161437325067616654905577889e-01
            7.84417360419717324404587088793050e-01 -5.69912572050634058662410552642541e-01
            8.29355353246763127295082540513249e-01 -5.02275455452625751995299197005806e-01
            8.68476014161781884048707524925703e-01 -4.31115237419034180721411075865035e-01
            9.01504939836610730274912839377066e-01 -3.56931055750819625771441678807605e-01
            9.28210456088891966430765023687854e-01 -2.80243259181121084910870422390872e-01
            9.48405242910001611278403288451955e-01 -2.01589757502772609631946920671908e-01
            9.61947648380324760175597020861460e-01 -1.21522248517581393789654953252466e-01
            9.68742682255691600623492831800831e-01 -4.06023482726561371625173535448994e-02
            9.43193886967652939112838339497102e-01 4.17614972775194118193020642593183e-02
            9.35812115972595282009649508836446e-01 1.24957651494030971828230747178168e-01
            9.21106346349091498204586514475523e-01 2.07175842663756160089150171188521e-01
            8.99191670683264665520084690797376e-01 2.87772601965248286948195755030611e-01
            8.70239601025215359086928401666228e-01 3.66117150479848274535754626413109e-01
            8.34476726574684746218224518088391e-01 4.41596335891964508757467910982086e-01
            7.92182940313345351768248292501085e-01 5.13619431237285484215249198314268e-01
            7.43689248462727103827774044475518e-01 5.81622758142212092913325705012539e-01
            6.89375179911738245053243190341163e-01 6.45074098371395177053955194423907e-01
            6.29665815888526547716708137159003e-01 7.03476859157034617453518876573071e-01
            5.65028463123520841016045324067818e-01 7.56373959710593068983541797933867e-01
            4.95968996540669782024934875153122e-01 8.03351408499699437548713376600062e-01
            4.23027900100269305116995610660524e-01 8.44041543293199802988624469435308e-01
            3.46776036779159135825523208040977e-01 8.78125908616611328127987690095324e-01
            2.67810180793924101916303470716230e-01 9.05337748097987837780920017394237e-01
            1.86748347033513895087963874175330e-01 9.25464092198211796258533468062524e-01
            1.04224954254799065389569534545444e-01 9.38347424986393341406198942422634e-01
            2.08858598956251223510705017361033e-02 9.43886916915596563271151353546884e-01
            -6.26166946353279435522054541252146e-02 9.42039213950754850124269523803378e-01
            -1.45629188631907047213331907187239e-01 9.32818776872776367348194526130101e-01
            -2.27501936776089763725394732318819e-01 9.16297768103326748523329570161877e-01
            -3.07594173806473913934667052672012e-01 8.92605486936038694523176673101261e-01
            -3.85279069375227933846872474532574e-01 8.61927357594228005233105704974150e-01
            -4.59948633845452037327561356505612e-01 8.24503478034939729646168871113332e-01
            -5.31018476634428804317167305271141e-01 7.80626740856896650377905189088779e-01
            -5.97932379862281870863682797789807e-01 7.30640541018795275363117980305105e-01
            -6.60166651511029156651488847273868e-01 6.74936088308163650850701742456295e-01
            -7.17234224024675404152162627724465e-01 6.13949345594350881505363304313505e-01
            -7.68688466273226511660254800517578e-01 5.48157616827974591977579166268697e-01
            -8.14126679046848100718136720388429e-01 4.78075811490353830279786961909849e-01
            -8.53193246723180198642921823193319e-01 4.04252414728679621003237798504415e-01
            -8.85582420441745954420298403420020e-01 3.27265194716072072012025273579638e-01
            -9.11040711003332392969866759813158e-01 2.47716680832261254563420038721233e-01
            -9.29368872766669462670563461870188e-01 1.66229448054248524213605264776561e-01
            -9.40423463015718441582180275872815e-01 8.34412444629958338637720771657769e-02
            -9.44117964593413461216186988167465e-01 1.15621104335683805188179620696629e-16
            -9.40423463015718441582180275872815e-01 -8.34412444629956118191671521344688e-02
            -9.29368872766669573692865924385842e-01 -1.66229448054248329924575955374166e-01
            -9.11040711003332503992169222328812e-01 -2.47716680832261032518815113689925e-01
            -8.85582420441745843397995940904366e-01 -3.27265194716072238545478967353120e-01
            -8.53193246723180531709829210740281e-01 -4.04252414728679065891725485926145e-01
            -8.14126679046847989695834257872775e-01 -4.78075811490353996813240655683330e-01
            -7.68688466273226622682557263033232e-01 -5.48157616827974369932974241237389e-01
            -7.17234224024675626196767552755773e-01 -6.13949345594350770483060841797851e-01
            -6.60166651511029045629186384758214e-01 -6.74936088308163872895306667487603e-01
            -5.97932379862281870863682797789807e-01 -7.30640541018795053318513055273797e-01
            -5.31018476634429359428679617849411e-01 -7.80626740856896317310997801541816e-01
            -4.59948633845451537727200275185169e-01 -8.24503478034939840668471333628986e-01
            -3.85279069375228544469536018368672e-01 -8.61927357594227783188500779942842e-01
            -3.07594173806474135979271977703320e-01 -8.92605486936038583500874210585607e-01
            -2.27501936776090402103633891783829e-01 -9.16297768103326637501027107646223e-01
            -1.45629188631907685591571066652250e-01 -9.32818776872776256325892063614447e-01
            -6.26166946353279713077810697541281e-02 -9.42039213950754850124269523803378e-01
            2.08858598956246782618606516734872e-02 -9.43886916915596563271151353546884e-01
            1.04224954254798635178147492297285e-01 -9.38347424986393341406198942422634e-01
            1.86748347033513867332388258546416e-01 -9.25464092198211796258533468062524e-01
            2.67810180793924101916303470716230e-01 -9.05337748097987837780920017394237e-01
            3.46776036779159524403581826845766e-01 -8.78125908616611217105685227579670e-01
            4.23027900100269471650449304434005e-01 -8.44041543293199691966322006919654e-01
            4.95968996540669060379968868801370e-01 -8.03351408499699881637923226662679e-01
            5.65028463123520729993742861552164e-01 -7.56373959710593180005844260449521e-01
            6.29665815888526103627498287096387e-01 -7.03476859157034839498123801604379e-01
            6.89375179911737800964033340278547e-01 -6.45074098371395621143165044486523e-01
            7.43689248462726992805471581959864e-01 -5.81622758142212203935628167528193e-01
            7.92182940313345129723643367469776e-01 -5.13619431237285706259854123345576e-01
            8.34476726574684857240526980604045e-01 -4.41596335891964342224014217208605e-01
            8.70239601025215359086928401666228e-01 -3.66117150479848274535754626413109e-01
            8.99191670683264665520084690797376e-01 -2.87772601965248564503951911319746e-01
            9.21106346349091609226888976991177e-01 -2.07175842663755771511091552383732e-01
            9.35812115972595393031951971352100e-01 -1.24957651494030833050352669033600e-01
            9.43193886967652939112838339497102e-01 -4.17614972775203624477668995496060e-02
            9.12936357362680861449177882604999e-01 4.28384766951293433079328565327160e-02
            9.04913439828451848789825362473493e-01 1.28138964011882211524451236073219e-01
            8.88938110447758389476291540631792e-01 2.12313361505508002569087011579541e-01
            8.65150760989610079221279193006922e-01 2.94621941544240817378863539488520e-01
            8.33760435536348043505938676389633e-01 3.74341373367196361687803118911688e-01
            7.95042993396732566857565416285070e-01 4.50771079741106139859851964502013e-01
            7.49338684844418567720936152909417e-01 5.23239393658234464012934950005729e-01
            6.97049160986317306587523034977494e-01 5.91109460970191791240324619138846e-01
            6.38633944038226708528327435487881e-01 6.53784837085090941855014534667134e-01
            5.74606389027075947772971176163992e-01 7.10714728544065255100292688439367e-01
            5.05529172408490601320352197944885e-01 7.61398833413990838714369147055550e-01
            4.32009347245869590459221853961935e-01 8.05391737958862652391189840273000e-01
            3.54693008406235743557033401884837e-01 8.42306830951722429468020436615916e-01
            2.74259614655314010178699390962720e-01 8.71819701228022436723108512524050e-01
            1.91416017549466382918765816611995e-01 8.93670988622603745810124564741272e-01
            1.06890249598801070907150290167920e-01 9.07668663236153361317803955898853e-01
            2.14251262912935024063099120894549e-02 9.13689713000864212055773805332137e-01
            -6.42282817964277552569285489880713e-02 9.11681224714910087847385966597358e-01
            -1.49317249434317012024564519379055e-01 9.01660849045565204740171338926302e-01
            -2.33094011715296062225988293903356e-01 8.83716645414506785094488350296160e-01
            -3.14822335440145095741826253288309e-01 8.58006308128449801664316964888712e-01
            -3.93783989161330394423998768616002e-01 8.24755780555910367191074783477234e-01
            -4.69285055026788244791902116048732e-01 7.84257269528758516052846516686259e-01
            -5.40662026954961905111929354461608e-01 7.36866677418073767746875546436058e-01
            -6.07287641550101064957800645061070e-01 6.83000474451310735091169590305071e-01
            -6.68576390515539742409600876271725e-01 6.23132038756965322967573683854425e-01
            -7.23989666121659158903867137269117e-01 5.57787496300560903250698174815625e-01
            -7.73040494509981357396100065670907e-01 4.87541097270746071057345716326381e-01
            -8.15297815236947887029828052618541e-01 4.13010169547989636207319108507363e-01
            -8.50390269448598190571431132411817e-01 3.34849693604966969218139638542198e-01
            -8.78009463395528211293594722519629e-01 2.53746546514619975010162988837692e-01
            -8.97912678608251080270008515071822e-01 1.70413465649740331064876386335527e-01
            -9.09925004915833390839452476939186e-01 8.55827851213094847881990290261456e-02
            -9.13940877562766429420548774942290e-01 1.11925477031716490225948967506518e-16
            -9.09925004915833390839452476939186e-01 -8.55827851213092627435941039948375e-02
            -8.97912678608251191292310977587476e-01 -1.70413465649740109020271461304219e-01
            -8.78009463395528322315897185035283e-01 -2.53746546514619752965558063806384e-01
            -8.50390269448598301593733594927471e-01 -3.34849693604966747173534713510890e-01
            -8.15297815236948220096735440165503e-01 -4.13010169547989025584655564671266e-01
            -7.73040494509981246373797603155253e-01 -4.87541097270746237590799410099862e-01
            -7.23989666121659269926169599784771e-01 -5.57787496300560681206093249784317e-01
            -6.68576390515539853431903338787379e-01 -6.23132038756965100922968758823117e-01
            -6.07287641550101287002405570092378e-01 -6.83000474451310624068867127789417e-01
            -5.40662026954962127156534279492917e-01 -7.36866677418073656724573083920404e-01
            -4.69285055026788466836507041080040e-01 -7.84257269528758405030544054170605e-01
            -3.93783989161330227890545074842521e-01 -8.24755780555910367191074783477234e-01
            -3.14822335440145650853338565866579e-01 -8.58006308128449690642014502373058e-01
            -2.33094011715296284270593218934664e-01 -8.83716645414506785094488350296160e-01
            -1.49317249434317039780140135007969e-01 -9.01660849045565204740171338926302e-01
            -6.42282817964275748456870474001335e-02 -9.11681224714910087847385966597358e-01
            2.14251262912932803617049870581468e-02 -9.13689713000864212055773805332137e-01
            1.06890249598800848862545365136612e-01 -9.07668663236153472340106418414507e-01
            1.91416017549466549452219510385476e-01 -8.93670988622603745810124564741272e-01
            2.74259614655313399556035847126623e-01 -8.71819701228022547745410975039704e-01
            3.54693008406235577023579708111356e-01 -8.42306830951722540490322899131570e-01
            4.32009347245869590459221853961935e-01 -8.05391737958862652391189840273000e-01
            5.05529172408490046208839885366615e-01 -7.61398833413991171781276534602512e-01
            5.74606389027076169817576101195300e-01 -7.10714728544065033055687763408059e-01
            6.38633944038226597506024972972227e-01 -6.53784837085090941855014534667134e-01
            6.97049160986316862498313184914878e-01 -5.91109460970192346351836931717116e-01
            7.49338684844418789765541077940725e-01 -5.23239393658234130946027562458767e-01
            7.95042993396732455835262953769416e-01 -4.50771079741106472926759352048975e-01
            8.33760435536347821461333751358325e-01 -3.74341373367197083332769125263439e-01
            8.65150760989610190243581655522576e-01 -2.94621941544240650845409845715039e-01
            8.88938110447758389476291540631792e-01 -2.12313361505508363391570014755416e-01
            9.04913439828451848789825362473493e-01 -1.28138964011882405813480545475613e-01
            9.12936357362680861449177882604999e-01 -4.28384766951292739189938174604322e-02
            8.78610131671090144322988635394722e-01 4.38496086817180413808259231700504e-02
            8.69878109450074377129169533873210e-01 1.31113028933796726960281375795603e-01
            8.52500847767903913165810081409290e-01 2.17073388999286048806069970851240e-01
            8.26651049658244541085139189817710e-01 3.00876376200513329095542758295778e-01
            7.92585622028228020674589515692787e-01 3.81689118800571880463223806145834e-01
            7.50643122402189000297312304610386e-01 4.58708463456826309734282176577835e-01
            7.01240394184883930606133617402520e-01 5.31168957319663848082313961640466e-01
            6.44868423884460528761053410562454e-01 5.98350455446807427684063895867439e-01
            5.82087461467954314642270219337661e-01 6.59585277927291935284870305622462e-01
            5.13521452345413242923655161575880e-01 7.14264845584386631749396201485069e-01
            4.39851836320092504095669028174598e-01 7.61845728308870095979443703981815e-01
            3.61810775133541706605200261037680e-01 8.01855045911601060915074867807562e-01
            2.80173875913276970717191716175876e-01 8.33895167819290072941385005833581e-01
            1.95752482840693936561038412946800e-01 8.57647664905778261967839171120431e-01
            1.09385613648079263460211052461091e-01 8.72876474183754913482857773487922e-01
            2.19316210834431708776026681562143e-02 8.79430244904780611392425271333195e-01
            -6.57403377847221859209270178325824e-02 8.77243842751022517845171933004167e-01
            -1.52758939640873975251977867628739e-01 8.66338997169367797113181950408034e-01
            -2.38259354524988586909728383034235e-01 8.46824085414418337158792837726651e-01
            -3.21391840901244951744786249037134e-01 8.18893055446643258754590988246491e-01
            -4.01330190771170214336649451070116e-01 7.82823498390413874403748195618391e-01
            -4.77279940899919485897129334261990e-01 7.38973889708695708122832002118230e-01
            -5.48486268548829203339778359804768e-01 6.87780026512846531794309612450888e-01
            -6.14241493242915104211476773343747e-01 6.29750696415132260597147251246497e-01
            -6.73892110017370371544132012786577e-01 5.65462620968854690062244117143564e-01
            -7.26845284243505695975784419715637e-01 4.95554723950450803915401820631814e-01
            -7.72574743485632042805377750482876e-01 4.20721781447954135124689400981879e-01
            -8.10626007832963124677405630791327e-01 3.41707516864091009889392580589629e-01
            -8.40620906725154326544213745364686e-01 2.59297209458971111839531431542127e-01
            -8.62261337381231340870613166771363e-01 1.74309889891998137656514700211119e-01
            -8.75332227478954782995401728840079e-01 8.75902003272145401879811288381461e-02
            -8.79703672640185230235942981380504e-01 1.07732628689697386651719179227665e-16
            -8.75332227478954782995401728840079e-01 -8.75902003272143181433762038068380e-02
            -8.62261337381231451892915629287018e-01 -1.74309889891997915611909775179811e-01
            -8.40620906725154548588818670395995e-01 -2.59297209458970556728019118963857e-01
            -8.10626007832963013655103168275673e-01 -3.41707516864091176422846274363110e-01
            -7.72574743485632153827680212998530e-01 -4.20721781447953968591235707208398e-01
            -7.26845284243505918020389344746945e-01 -4.95554723950450748404250589373987e-01
            -6.73892110017370482566434475302231e-01 -5.65462620968854468017639192112256e-01
            -6.14241493242915326256081698375056e-01 -6.29750696415132149574844788730843e-01
            -5.48486268548829425384383284836076e-01 -6.87780026512846309749704687419580e-01
            -4.77279940899919374874826871746336e-01 -7.38973889708695708122832002118230e-01
            -4.01330190771170769448161763648386e-01 -7.82823498390413541336840808071429e-01
            -3.21391840901245728900903486646712e-01 -8.18893055446642925687683600699529e-01
            -2.38259354524988253842820995487273e-01 -8.46824085414418448181095300242305e-01
            -1.52758939640874003007553483257652e-01 -8.66338997169367797113181950408034e-01
            -6.57403377847225883767734444518283e-02 -8.77243842751022517845171933004167e-01
            2.19316210834429557718916470321346e-02 -8.79430244904780611392425271333195e-01
            1.09385613648078666715335316439450e-01 -8.72876474183755024505160236003576e-01
            1.95752482840693714516433487915492e-01 -8.57647664905778261967839171120431e-01
            2.80173875913277137250645409949357e-01 -8.33895167819289961919082543317927e-01
            3.61810775133541373538292873490718e-01 -8.01855045911601282959679792838870e-01
            4.39851836320092726140273953205906e-01 -7.61845728308869984957141241466161e-01
            5.13521452345412909856747774028918e-01 -7.14264845584386853794001126516378e-01
            5.82087461467953759530757906759391e-01 -6.59585277927292379374080155685078e-01
            6.44868423884460750805658335593762e-01 -5.98350455446807205639458970836131e-01
            7.01240394184883819583831154886866e-01 -5.31168957319663959104616424156120e-01
            7.50643122402189000297312304610386e-01 -4.58708463456826198711979714062181e-01
            7.92585622028227909652287053177133e-01 -3.81689118800572102507828731177142e-01
            8.26651049658244208018231802270748e-01 -3.00876376200513939718206302131875e-01
            8.52500847767903802143507618893636e-01 -2.17073388999286354117401742769289e-01
            8.69878109450074377129169533873210e-01 -1.31113028933796671449130144537776e-01
            8.78610131671090144322988635394722e-01 -4.38496086817184230199906380676111e-02
            8.40646320926566326114937055535847e-01 4.48045271227796929047748619723279e-02
            8.31121462205241967602376007562270e-01 1.33905928173057325869521605454793e-01
            8.12179665217846347147201413463335e-01 2.21490121551040169967095039282867e-01
            7.84035548093004575065378958242945e-01 3.06564743348887724927465114888037e-01
            7.47007994923559737188156759657431e-01 3.88165864107536284777211221808102e-01
            7.01516542682381394335777713422431e-01 4.65368910522636847204580590187106e-01
            6.48076627700823859612455635215156e-01 5.37299141229534482633312109101098e-01
            5.87293745569134828521384861232946e-01 6.03141557972457831304780029313406e-01
            5.19856590629473758191636534320423e-01 6.62150139860415043457919637148734e-01
            4.46529252793826769707408175236196e-01 7.13656296081982444157176814769628e-01
            3.68142560099989413213705802263576e-01 7.57076441306353986604449346486945e-01
            2.85584665097916023945856522914255e-01 7.91918607938327578921189342509024e-01
            1.99790981726440886045992328945431e-01 8.17788020307739893510756701289210e-01
            1.11733586699579875989307709005516e-01 8.34391567635552555692868281767005e-01
            2.24102054889363105916189056188159e-02 8.41541125096100794955589208257152e-01
            -6.71670923045604717493972657393897e-02 8.39155685346538060542798120877706e-01
            -1.55983360103638446503282466437668e-01 8.27262276372400684465446829563007e-01
            -2.43032274104953621707281286035141e-01 8.05995655249730380553785380470799e-01
            -3.27327535329890506599070931770257e-01 7.75596781293557691050466473825509e-01
            -4.07914044786092833128066104109166e-01 7.36410085892579835409321731276577e-01
            -4.83878725120686636884670406288933e-01 6.88879569963899096585180359397782e-01
            -5.54360866151534681378620916802902e-01 6.33543773245217600731393758906052e-01
            -6.18561877057523079592726844566641e-01 5.71029672424420708942705005028984e-01
            -6.75754334731664796365180336579215e-01 5.02045577243174889758847712073475e-01
            -7.25290225775564456611732566670980e-01 4.27373105064530467434025240436313e-01
            -7.66608288750157740309987275395542e-01 3.47858324835876531189171600999543e-01
            -7.99240373492082101236633207008708e-01 2.64402170789697688046970824871096e-01
            -8.22816745442091934670258979167556e-01 1.77950234498725046172751262929523e-01
            -8.37070274885353238225604854960693e-01 8.94820509455763191120070132456021e-02
            -8.41839463637852669641858938121004e-01 1.03095600454002089819891900640438e-16
            -8.37070274885353349247907317476347e-01 -8.94820509455757362449190850384184e-02
            -8.22816745442091823647956516651902e-01 -1.77950234498725212706204956703004e-01
            -7.99240373492082212258935669524362e-01 -2.64402170789697466002365899839788e-01
            -7.66608288750158073376894662942505e-01 -3.47858324835875976077659288421273e-01
            -7.25290225775564567634035029186634e-01 -4.27373105064530300900571546662832e-01
            -6.75754334731664685342877874063561e-01 -5.02045577243175000781150174589129e-01
            -6.18561877057523523681936694629258e-01 -5.71029672424420264853495154966367e-01
            -5.54360866151534903423225841834210e-01 -6.33543773245217489709091296390397e-01
            -4.83878725120686470351216712515452e-01 -6.88879569963899096585180359397782e-01
            -4.07914044786092722105763641593512e-01 -7.36410085892579946431624193792231e-01
            -3.27327535329891061710583244348527e-01 -7.75596781293557469005861548794201e-01
            -2.43032274104953621707281286035141e-01 -8.05995655249730380553785380470799e-01
            -1.55983360103638279969828772664187e-01 -8.27262276372400684465446829563007e-01
            -6.71670923045612489055145033489680e-02 -8.39155685346538060542798120877706e-01
            2.24102054889362897749371938971308e-02 -8.41541125096100794955589208257152e-01
            1.11733586699579667822490591788664e-01 -8.34391567635552666715170744282659e-01
            1.99790981726440136645450706964766e-01 -8.17788020307740115555361626320519e-01
            2.85584665097915801901251597882947e-01 -7.91918607938327689943491805024678e-01
            3.68142560099989246680252108490095e-01 -7.57076441306353986604449346486945e-01
            4.46529252793826603173954481462715e-01 -7.13656296081982555179479277285282e-01
            5.19856590629473536147031609289115e-01 -6.62150139860415154480222099664388e-01
            5.87293745569134606476779936201638e-01 -6.03141557972458053349384954344714e-01
            6.48076627700824192679363022762118e-01 -5.37299141229534149566404721554136e-01
            7.01516542682381172291172788391123e-01 -4.65368910522637235782639208991895e-01
            7.47007994923559626165854297141777e-01 -3.88165864107536673355269840612891e-01
            7.84035548093004686087681420758599e-01 -3.06564743348887391860557727341074e-01
            8.12179665217846236124898950947681e-01 -2.21490121551040641811880504974397e-01
            8.31121462205242078624678470077924e-01 -1.33905928173057103824916680423485e-01
            8.40646320926566326114937055535847e-01 -4.48045271227795055546394564771617e-02
            7.99360469083107538779131573392078e-01 4.57090853985754816402042877143685e-02
            7.88939582904326086598700840113452e-01 1.36531368364519178904004093055846e-01
            7.68233662734794986448605413897894e-01 2.25573756146013854051446401172143e-01
            7.37512641909547794760726446838817e-01 3.11675445045545895794703028514050e-01
            6.97177015916787934379783564509125e-01 3.93713967872747427900748107276740e-01
            6.47752621326720845473801091429777e-01 4.70619827020814895934819332978805e-01
            5.89883780707697868983530042896746e-01 5.41390437003400282200971105339704e-01
            5.24324902896173838939830602612346e-01 6.05103194689680878859405765979318e-01
            4.51930648123803846427648522876552e-01 6.60927506847111545518203001847723e-01
            3.73644786214289592596315969785792e-01 7.08135618194437377326266869204119e-01
            2.90487893100416783020989441865822e-01 7.46112098804744605651251276867697e-01
            2.03544046056003263833744654220936e-01 7.74361867175735629764687928400235e-01
            1.13946691090749521735325799909333e-01 7.92516644374242296144927877321607e-01
            2.28638667481231329381419214996640e-02 8.00339755115328621570824907394126e-01
            -6.85170230633431048827830522895965e-02 7.97729213186578411942662114597624e-01
            -1.59004688695896456707146171538625e-01 7.84719050994342248728230515553150e-01
            -2.47419485044967302211915693987976e-01 7.61478875899274876282163404539460e-01
            -3.32608790027141110190456174677820e-01 7.28311659125007615500635438365862e-01
            -4.13462030771724164956992808583891e-01 6.85649786064913668859333029104164e-01
            -4.88925161636515115404222342476714e-01 6.34049419477257791832869315840071e-01
            -5.58014405304706917476664784771856e-01 5.74183249053100031034091443871148e-01
            -6.19829077826703933595808848622255e-01 5.06831721877427421318884626089130e-01
            -6.73563330412823568771329973969841e-01 4.32872868107860853115198551677167e-01
            -7.18516654904657992020133860933129e-01 3.53270854508775766777972648924333e-01
            -7.54103015970206347340365482523339e-01 2.69063415063026889484376624750439e-01
            -7.79858490970654294471842149505392e-01 1.81348322522470351003676114487462e-01
            -7.95447317901448180954560029931599e-01 9.12690772613179435168717645865399e-02
            -8.00666272563506975501468332367949e-01 9.80533387880141111428165345880814e-17
            -7.95447317901448180954560029931599e-01 -9.12690772613177492278424551841454e-02
            -7.79858490970654405494144612021046e-01 -1.81348322522470184470222420713981e-01
            -7.54103015970206458362667945038993e-01 -2.69063415063026722950922930976958e-01
            -7.18516654904657992020133860933129e-01 -3.53270854508775877800275111439987e-01
            -6.73563330412823901838237361516804e-01 -4.32872868107860409025988701614551e-01
            -6.19829077826704044618111311137909e-01 -5.06831721877427199274279701057822e-01
            -5.58014405304707139521269709803164e-01 -5.74183249053099920011788981355494e-01
            -4.88925161636515559493432192539331e-01 -6.34049419477257458765961928293109e-01
            -4.13462030771724609046202658646507e-01 -6.85649786064913446814728104072856e-01
            -3.32608790027141165701607405935647e-01 -7.28311659125007615500635438365862e-01
            -2.47419485044967468745369387761457e-01 -7.61478875899274765259860942023806e-01
            -1.59004688695896789774053559085587e-01 -7.84719050994342137705928053037496e-01
            -6.85170230633436461165075570534100e-02 -7.97729213186578300920359652081970e-01
            2.28638667481229351796656601436553e-02 -8.00339755115328621570824907394126e-01
            1.13946691090749313568508682692482e-01 -7.92516644374242407167230339837261e-01
            2.03544046056002708722232341642666e-01 -7.74361867175735851809292853431543e-01
            2.90487893100416949554443135639303e-01 -7.46112098804744494628948814352043e-01
            3.73644786214289426062862276012311e-01 -7.08135618194437377326266869204119e-01
            4.51930648123803568871892366587417e-01 -6.60927506847111656540505464363378e-01
            5.24324902896174060984435527643654e-01 -6.05103194689680878859405765979318e-01
            5.89883780707697868983530042896746e-01 -5.41390437003400171178668642824050e-01
            6.47752621326721178540708478976740e-01 -4.70619827020814562867911945431842e-01
            6.97177015916787823357481101993471e-01 -3.93713967872747760967655494823703e-01
            7.37512641909547572716121521807509e-01 -3.11675445045546395395064109834493e-01
            7.68233662734794986448605413897894e-01 -2.25573756146013937318173248058883e-01
            7.88939582904326086598700840113452e-01 -1.36531368364519456459760249344981e-01
            7.99360469083107538779131573392078e-01 -4.57090853985759396072019455914415e-02
            7.54995843935962085424762335605919e-01 4.65665497167214309515159698094067e-02
            7.43550876542279470804430729913292e-01 1.38993747723785865400003558534081e-01
            7.20834435794244998696456150355516e-01 2.29313942197782644205616975341400e-01
            6.87190879777734298095026588271139e-01 3.16157971057822617666488440590911e-01
            6.43130210507605104552908414916601e-01 3.98209367350316201239479596551973e-01
            5.89320342817019171555159573472338e-01 4.74224315546057317849459877834306e-01
            5.26576979449406956668155999068404e-01 5.43050506515769915161229164368706e-01
            4.55851245836358887064676537193009e-01 6.03644605361909114549234800506383e-01
            3.78215272005605007699102770857280e-01 6.55088067312190935886917486641323e-01
            2.94845940182666133022593157875235e-01 6.96601061922026532080565175419906e-01
            2.07007044455959993145555131377478e-01 7.27554294509147658764902644179529e-01
            1.16030132946663838700018800409453e-01 7.47478545619521428378106975287665e-01
            2.32943228965009942188491010028883e-02 7.56071783915977846390887862071395e-01
            -6.97946053438473490437843338440871e-02 7.53203744665407293190639848035062e-01
            -1.61825518511886340400351969037729e-01 7.38917904419330251464259617932839e-01
            -2.51403321775135524251965080111404e-01 7.13430821953693783399330641259439e-01
            -3.37170106946709180473220612839214e-01 6.77128855458575262815656969905831e-01
            -4.17825736989252849440390491508879e-01 6.30562305741853790230777576653054e-01
            -4.92147554767143891041314418544061e-01 5.74437074229907862488175851467531e-01
            -5.59008917282358464007074871915393e-01 5.09603962221547912569974414509488e-01
            -6.17396274433886782517788560653571e-01 4.37045773607584731035302638701978e-01
            -6.66424533404106012035583717079135e-01 3.57862416565661534129105803003768e-01
            -7.05350475763682926988451526995050e-01 2.73254230073464110528647097453359e-01
            -7.33584023905367033080437977332622e-01 1.84503787993377688092522248552996e-01
            -7.50697186019024909064967232552590e-01 9.29564565601175979425718765014608e-02
            -7.56430544011210237442810466745868e-01 9.26360244500619649907698485999520e-17
            -7.50697186019024909064967232552590e-01 -9.29564565601174036535425670990662e-02
            -7.33584023905367033080437977332622e-01 -1.84503787993377826870400326697563e-01
            -7.05350475763682926988451526995050e-01 -2.73254230073463943995193403679878e-01
            -6.66424533404106123057886179594789e-01 -3.57862416565661367595652109230286e-01
            -6.17396274433886893540091023169225e-01 -4.37045773607584564501848944928497e-01
            -5.59008917282358575029377334431047e-01 -5.09603962221547690525369489478180e-01
            -4.92147554767143724507860724770580e-01 -5.74437074229907973510478313983185e-01
            -4.17825736989253015973844185282360e-01 -6.30562305741853679208475114137400e-01
            -3.37170106946709013939766919065733e-01 -6.77128855458575373837959432421485e-01
            -2.51403321775135690785418773884885e-01 -7.13430821953693783399330641259439e-01
            -1.61825518511886701222834972213604e-01 -7.38917904419330251464259617932839e-01
            -6.97946053438473629215721416585438e-02 -7.53203744665407293190639848035062e-01
            2.32943228965008103381606474613363e-02 -7.56071783915977846390887862071395e-01
            1.16030132946663991355684686368477e-01 -7.47478545619521428378106975287665e-01
            2.07007044455959993145555131377478e-01 -7.27554294509147658764902644179529e-01
            2.94845940182666410578349314164370e-01 -6.96601061922026421058262712904252e-01
            3.78215272005605229743707695888588e-01 -6.55088067312190935886917486641323e-01
            4.55851245836358609508920380903874e-01 -6.03644605361909336593839725537691e-01
            5.26576979449407178712760924099712e-01 -5.43050506515769804138926701853052e-01
            5.89320342817019060532857110956684e-01 -4.74224315546057428871762340349960e-01
            6.43130210507604771486001027369639e-01 -3.98209367350316534306386984098935e-01
            6.87190879777734298095026588271139e-01 -3.16157971057822562155337209333084e-01
            7.20834435794244887674153687839862e-01 -2.29313942197782810739070669114881e-01
            7.43550876542279470804430729913292e-01 -1.38993747723785671110974249131687e-01
            7.54995843935962085424762335605919e-01 -4.65665497167214795237732971600053e-02
            7.07746558048159002396459982264787e-01 4.73780575892771907420275567801582e-02
            6.95116803952962380996893898554845e-01 1.41288710207743889446518892327731e-01
            6.70082674023602331558890909946058e-01 2.32678062445361710786073672352359e-01
            6.33090902901737861974140741949668e-01 3.19915269146396397115239551567356e-01
            5.84801609619389872740669034101302e-01 4.01443580290580304126279997944948e-01
            5.26076517759176742750071298360126e-01 4.75808121234103764685130499856314e-01
            4.57963577976566837968164236372104e-01 5.41681854982100974282843708351720e-01
            3.81678267295606610254310453456128e-01 5.97889263195261255745549533457961e-01
            2.98581898892630259734204400956514e-01 6.43427323342442458731227361568017e-01
            2.10157329430378514434352155149099e-01 6.77483407661501613183929748629453e-01
            1.17982497445721812301400177602773e-01 6.99449784520961292955121280101594e-01
            2.37022649990892564364486361228046e-02 7.08934463405371362298978965554852e-01
            -7.10009349279692864032043075894762e-02 7.05768189995343409037786841508932e-01
            -1.64437121489194676415834805993654e-01 6.90007466514889755693218376109144e-01
            -2.54938923721857946258495530855726e-01 6.61933543447897454470307820884045e-01
            -3.40891334821089186934983672472299e-01 6.22047400616580814514122721448075e-01
            -4.20760531974572582480931259851786e-01 5.71060807184684660064988293015631e-01
            -4.93121247466967616013278075115522e-01 5.09883620119896185940433497307822e-01
            -5.56682202616055388233462508651428e-01 4.39607547774700901932476426736685e-01
            -6.10309150671413336297632667992730e-01 3.61486668324970228383108405978419e-01
            -6.53045117474547853753108483942924e-01 2.76915050715202004649739819797105e-01
            -6.84127478685423118243136286764638e-01 1.87401877465181693205309443328588e-01
            -7.03001568831875922604979223251576e-01 9.45445132721623171523361861545709e-02
            -7.09330579328107724279561807634309e-01 -2.28138114145156046745108215020370e-16
            -7.03001568831876033627281685767230e-01 -9.45445132721618175519751048341277e-02
            -6.84127478685423118243136286764638e-01 -1.87401877465181526671855749555107e-01
            -6.53045117474547964775410946458578e-01 -2.76915050715201893627437357281451e-01
            -6.10309150671413336297632667992730e-01 -3.61486668324970061849654712204938e-01
            -5.56682202616055499255764971167082e-01 -4.39607547774700735399022732963203e-01
            -4.93121247466967727035580537631176e-01 -5.09883620119896074918131034792168e-01
            -4.20760531974572415947477566078305e-01 -5.71060807184684771087290755531285e-01
            -3.40891334821089075912681209956645e-01 -6.22047400616580814514122721448075e-01
            -2.54938923721858279325402918402688e-01 -6.61933543447897454470307820884045e-01
            -1.64437121489195148260620271685184e-01 -6.90007466514889644670915913593490e-01
            -7.10009349279696194701116951364384e-02 -7.05768189995343409037786841508932e-01
            2.37022649990889233695412485758425e-02 -7.08934463405371362298978965554852e-01
            1.17982497445721631890158676014835e-01 -6.99449784520961292955121280101594e-01
            2.10157329430378209123020383231051e-01 -6.77483407661501613183929748629453e-01
            2.98581898892630093200750707183033e-01 -6.43427323342442569753529824083671e-01
            3.81678267295606443720856759682647e-01 -5.97889263195261366767851995973615e-01
            4.57963577976566782457013005114277e-01 -5.41681854982101085305146170867374e-01
            5.26076517759176631727768835844472e-01 -4.75808121234103764685130499856314e-01
            5.84801609619389872740669034101302e-01 -4.01443580290580304126279997944948e-01
            6.33090902901737528907233354402706e-01 -3.19915269146397007737903095403453e-01
            6.70082674023602331558890909946058e-01 -2.32678062445361683030498056723445e-01
            6.95116803952962380996893898554845e-01 -1.41288710207743806179792045440990e-01
            7.07746558048159002396459982264787e-01 -4.73780575892776972812825420078298e-02
            6.57771006102323529951547698146896e-01 4.81426324523335502636456340042059e-02
            6.43751759096529707626643812545808e-01 1.43401820729121109998516203631880e-01
            6.16012060995351884429283018107526e-01 2.35604648164170094037928038233076e-01
            5.75143135303533448166035668691620e-01 3.22785971568661622654872189741582e-01
            5.22016032217601400056139482330764e-01 4.03087672394102813910876648151316e-01
            4.57763063703200578924423780335928e-01 4.74798259303214953419569610559847e-01
            3.83753670231409826918422822927823e-01 5.36389345636381742465914612694178e-01
            3.01565233532655962989110776106827e-01 5.86548224319789479608289184398018e-01
            2.12949457443700057579505369176331e-01 6.24205845937649939081381944561144e-01
            1.19795033381579166253949608744733e-01 6.48559603664466410855027334037004e-01
            2.40873861651035060804648679777529e-02 6.59090439436073594059450897475472e-01
            -7.21336418681603891434050979114545e-02 6.55573906771112602243078981700819e-01
            -1.66817266559842941608948763132503e-01 6.38084954458107977970371393894311e-01
            -2.57945470834636259027661253639963e-01 6.06996329152163172082623532332946e-01
            -3.43576015230675491096690166159533e-01 5.62970630927150605948838801850798e-01
            -4.21883833361647364590396591665922e-01 5.06946191105510868268879676179495e-01
            -4.91199930038226206807649987240438e-01 4.40117073355198451523051517142449e-01
            -5.50046953002906846563746512401849e-01 3.63907624295674025916014215908945e-01
            -5.97170680128469300029792066197842e-01 2.79942116022589226886907454172615e-01
            -6.31566750985101288407008723879699e-01 1.90010127568049635993219226293149e-01
            -6.52502073039239793850185833434807e-01 9.60284031305219110130622084398055e-02
            -6.59530446248164814448955439729616e-01 8.07691849938040550168063650426337e-17
            -6.52502073039239793850185833434807e-01 -9.60284031305217444796085146663245e-02
            -6.31566750985101288407008723879699e-01 -1.90010127568049497215341148148582e-01
            -5.97170680128469411052094528713496e-01 -2.79942116022589060353453760399134e-01
            -5.50046953002907068608351437433157e-01 -3.63907624295673692849106828361982e-01
            -4.91199930038226262318801218498265e-01 -4.40117073355198284989597823368968e-01
            -4.21883833361647198056942897892441e-01 -5.06946191105510979291182138695149e-01
            -3.43576015230675935185900016222149e-01 -5.62970630927150383904233876819490e-01
            -2.57945470834636259027661253639963e-01 -6.06996329152163172082623532332946e-01
            -1.66817266559842969364524378761416e-01 -6.38084954458107977970371393894311e-01
            -7.21336418681606805769490620150464e-02 -6.55573906771112602243078981700819e-01
            2.40873861651031938302391921524759e-02 -6.59090439436073594059450897475472e-01
            1.19795033381578708286951950867660e-01 -6.48559603664466410855027334037004e-01
            2.12949457443700029823929753547418e-01 -6.24205845937649939081381944561144e-01
            3.01565233532655796455657082333346e-01 -5.86548224319789590630591646913672e-01
            3.83753670231409715896120360412169e-01 -5.36389345636381742465914612694178e-01
            4.57763063703200301368667624046793e-01 -4.74798259303215286486476998106809e-01
            5.22016032217601511078441944846418e-01 -4.03087672394102758399725416893489e-01
            5.75143135303533448166035668691620e-01 -3.22785971568661678166023420999409e-01
            6.16012060995351773406980555591872e-01 -2.35604648164170232815806116377644e-01
            6.43751759096529818648946275061462e-01 -1.43401820729120776931608816084918e-01
            6.57771006102323529951547698146896e-01 -4.81426324523339319028103489017667e-02
            6.05199972010815323564258960686857e-01 4.88567926593137871749128464671230e-02
            5.89525610632650187703518440685002e-01 1.45305012711357234289621942480153e-01
            5.58582845602651367755697719985619e-01 2.37989909259387094619953018082015e-01
            5.13173078281609407191865557251731e-01 3.24510992167944878339369552122662e-01
            4.54472397790486037916224404398235e-01 4.02627410837132326815179794721189e-01
            3.84001120919953309318373158021132e-01 4.70315991056083626542516640256508e-01
            3.03584416724099415141324698197423e-01 5.25823634152303154287722009030404e-01
            2.15305035600646815785452758973406e-01 5.67712721326421365652947770286119e-01
            1.21449367149667586396333263110137e-01 5.94898347223953849471911325963447e-01
            2.44482238839286956932905781059162e-02 6.06676418414106466414636997797061e-01
            -7.31861155383430883603068650700152e-02 6.02741889039790423865383672819007e-01
            -1.68924973011068790818001161824213e-01 5.83196661345087297156908334727632e-01
            -2.60288762415012864259722391579999e-01 5.48546946460654161192849187500542e-01
            -3.44911209595802403793385337849031e-01 4.99690153801340408712405860569561e-01
            -4.20600637621581230352063585087308e-01 4.37891648633730035111710776618565e-01
            -4.85396730064308168373088392399950e-01 3.64751979780403468023308732881560e-01
            -5.37621302165537939821149393537780e-01 2.82165426246161699097569908190053e-01
            -5.75921764940153568801406436250545e-01 1.92270936386821550412307146871171e-01
            -5.99306156520599930814796607592143e-01 9.73967302703375864547652440705860e-02
            -6.07168833448198941304951858910499e-01 7.43567368424369288573702870614857e-17
            -5.99306156520600041837099070107797e-01 -9.73967302703374337990993581115617e-02
            -5.75921764940153679823708898766199e-01 -1.92270936386821411634429068726604e-01
            -5.37621302165537939821149393537780e-01 -2.82165426246161532564116214416572e-01
            -4.85396730064308334906542086173431e-01 -3.64751979780403357001006270365906e-01
            -4.20600637621581341374366047602962e-01 -4.37891648633729868578257082845084e-01
            -3.44911209595802514815687800364685e-01 -4.99690153801340353201254629311734e-01
            -2.60288762415012753237419929064345e-01 -5.48546946460654161192849187500542e-01
            -1.68924973011068790818001161824213e-01 -5.83196661345087297156908334727632e-01
            -7.31861155383433659160630213591503e-02 -6.02741889039790423865383672819007e-01
            2.44482238839284146680874698631669e-02 -6.06676418414106577436939460312715e-01
            1.21449367149667433740667377151112e-01 -5.94898347223953960494213788479101e-01
            2.15305035600646677007574680828839e-01 -5.67712721326421365652947770286119e-01
            3.03584416724099082074417310650460e-01 -5.25823634152303265310024471546058e-01
            3.84001120919952920740314539216342e-01 -4.70315991056083904098272796545643e-01
            4.54472397790485871382770710624754e-01 -4.02627410837132548859784719752497e-01
            5.13173078281609185147260632220423e-01 -3.24510992167945100383974477153970e-01
            5.58582845602651256733395257469965e-01 -2.37989909259387205642255480597669e-01
            5.89525610632650187703518440685002e-01 -1.45305012711357262045197558109066e-01
            6.05199972010815323564258960686857e-01 -4.88567926593137177859738073948392e-02
            5.50141334787058289279570999497082e-01 4.95136163120291072914369578938931e-02
            5.32459339629204220223357424401911e-01 1.46949440567879507923976234451402e-01
            4.97663663186663551840638319845311e-01 2.39662188893475819329026421655726e-01
            4.46872667130277512193003985885298e-01 3.24671997273329959732279803574784e-01
            3.81718815864269145343712352769217e-01 3.99246580519810101428390680666780e-01
            3.04296207777095262247968321389635e-01 4.60989050167202818464318170299521e-01
            2.17093269196211774429983165646263e-01 5.07914952439167843856182571471436e-01
            1.22912774318425191411030539256899e-01 5.38516050225923081917756007896969e-01
            2.47817617410768485652905468441531e-02 5.51808799065935051686437873286195e-01
            -7.41457570491311918070564956906310e-02 5.47365959074175734144773741718382e-01
            -1.70690170200448021464723069584579e-01 5.25330326783561063486160946922610e-01
            -2.61748460837182617133578332868638e-01 4.86410145546890104739645721565466e-01
            -3.44393940575259238645600134987035e-01 4.31856342012741312164081364244339e-01
            -4.15970315694968839626000089992885e-01 3.63422320313721181062049936372205e-01
            -4.74177062606726318350069959706161e-01 2.83307606214936891220190773310605e-01
            -5.17143368572116957082585031457711e-01 1.94087152546129626529136658064090e-01
            -5.43488261164618791099201189354062e-01 9.86285780990487498387508935593360e-02
            -5.52364993859658870434259370085783e-01 6.76452021691278617071742471343818e-17
            -5.43488261164618791099201189354062e-01 -9.86285780990486110608728154147684e-02
            -5.17143368572116957082585031457711e-01 -1.94087152546129515506834195548436e-01
            -4.74177062606726540394674884737469e-01 -2.83307606214936558153283385763643e-01
            -4.15970315694968950648302552508540e-01 -3.63422320313721070039747473856551e-01
            -3.44393940575259349667902597502689e-01 -4.31856342012741201141778901728685e-01
            -2.61748460837182728155880795384292e-01 -4.86410145546890049228494490307639e-01
            -1.70690170200448160242601147729147e-01 -5.25330326783561063486160946922610e-01
            -7.41457570491313167071467660207418e-02 -5.47365959074175623122471279202728e-01
            2.47817617410767132568594206531998e-02 -5.51808799065935051686437873286195e-01
            1.22912774318425066510940268926788e-01 -5.38516050225923081917756007896969e-01
            2.17093269196211663407680703130609e-01 -5.07914952439167843856182571471436e-01
            3.04296207777095095714514627616154e-01 -4.60989050167202929486620632815175e-01
            3.81718815864269034321409890253562e-01 -3.99246580519810156939541911924607e-01
            4.46872667130277456681852754627471e-01 -3.24671997273330070754582266090438e-01
            4.97663663186663496329487088587484e-01 -2.39662188893475958106904499800294e-01
            5.32459339629204220223357424401911e-01 -1.46949440567879646701854312595970e-01
            5.50141334787058289279570999497082e-01 -4.95136163120292460693150360384607e-02
            4.92682074905447409118863788535236e-01 5.01008701540153825182422053785558e-02
            4.72511612871132524738015945331426e-01 1.48251474951338474417283919137844e-01
            4.32996469888116408686329350530286e-01 2.40332646945345090871981597047125e-01
            3.75754400552955780678843211717322e-01 3.22574572135522319449307815375505e-01
            3.03128901909889725274638294649776e-01 3.91610256441568271856823457710561e-01
            2.18093270406499145641632253500575e-01 4.44613370836645038775003513364936e-01
            1.24128874787795134837509181124915e-01 4.79413961589816695063603901871829e-01
            2.50826284507555223590724580162714e-02 4.94587288426752536008024208058487e-01
            -7.49905036421420617687161325193301e-02 4.89512153563958274382628133025719e-01
            -1.71993515704919996966992812303943e-01 4.64396333619019718863540902020759e-01
            -2.61955093026358665220243437943282e-01 4.20268073211466031136041010540794e-01
            -3.41192198060881413113065718789585e-01 3.58933988507233237008620108099421e-01
            -4.06460854418410899580038631029311e-01 2.82905104140561136638609696092317e-01
            -4.55088955638927983304853341905982e-01 1.95294051570436250075957218541589e-01
            -4.85085661544905510922376379312482e-01 9.96876375829410105167127653658099e-02
            -4.95222903472089415188861494243611e-01 6.06473143601553015603821288119649e-17
            -4.85085661544905510922376379312482e-01 -9.96876375829408856166224950356991e-02
            -4.55088955638928038816004573163809e-01 -1.95294051570436139053654756025935e-01
            -4.06460854418411010602341093544965e-01 -2.82905104140561025616307233576663e-01
            -3.41192198060881635157670643820893e-01 -3.58933988507233014964015183068113e-01
            -2.61955093026358776242545900458936e-01 -4.20268073211465975624889779282967e-01
            -1.71993515704920219011597737335251e-01 -4.64396333619019607841238439505105e-01
            -7.49905036421421866688064028494409e-02 -4.89512153563958274382628133025719e-01
            2.50826284507556195035871127174687e-02 -4.94587288426752536008024208058487e-01
            1.24128874787794912792904256093607e-01 -4.79413961589816750574755133129656e-01
            2.18093270406498840330300481582526e-01 -4.44613370836645205308457207138417e-01
            3.03128901909889503230033369618468e-01 -3.91610256441568438390277151484042e-01
            3.75754400552955836189994442975149e-01 -3.22574572135522152915854121602024e-01
            4.32996469888116297664026888014632e-01 -2.40332646945345340672162137707346e-01
            4.72511612871132469226864714073599e-01 -1.48251474951338779728615691055893e-01
            4.92682074905447409118863788535236e-01 -5.01008701540152784348336467701301e-02
            4.32887315517734183600850883522071e-01 5.05972705892604457389438721293118e-02
            4.09550248289467844209355007478734e-01 1.49064099813698947016860074654687e-01
            3.64134221167785765427282740347437e-01 2.39494844833376824277948458075116e-01
            2.99087623930318236009640031625167e-01 3.17014360777157389037483881111257e-01
            2.17917135470821365927918122906704e-01 3.77443550475332456617394427667023e-01
            1.24998677832344320948187998965295e-01 4.17524660669760849796006141332327e-01
            2.53415091172237115502152704493710e-02 4.35096908335252163801953884103568e-01
            -7.56818269138112981186949923539942e-02 4.29212969051752990523596054117661e-01
            -1.72625136066412276925063906674040e-01 4.00190047509037638562290339905303e-01
            -2.60262179451321740142333283074549e-01 3.49592776919777248334497699033818e-01
            -3.33868421375656476701720976052457e-01 2.80148869238053932484433516947320e-01
            -3.89475730285009480446944962750422e-01 1.95602063501875395035156657286279e-01
            -4.24086301762662487568888991518179e-01 1.00510299892603571780824722736725e-01
            -4.35834270941642620833533783297753e-01 5.33743044867402924801900953475689e-17
            -4.24086301762662487568888991518179e-01 -1.00510299892603460758522260221071e-01
            -3.89475730285009535958096194008249e-01 -1.95602063501875284012854194770625e-01
            -3.33868421375656476701720976052457e-01 -2.80148869238053987995584748205147e-01
            -2.60262179451321851164635745590203e-01 -3.49592776919777137312195236518164e-01
            -1.72625136066412304680639522302954e-01 -4.00190047509037638562290339905303e-01
            -7.56818269138114091409974548696482e-02 -4.29212969051752935012444822859834e-01
            2.53415091172234097083304504849366e-02 -4.35096908335252163801953884103568e-01
            1.24998677832344320948187998965295e-01 -4.17524660669760849796006141332327e-01
            2.17917135470821365927918122906704e-01 -3.77443550475332456617394427667023e-01
            2.99087623930318291520791262882994e-01 -3.17014360777157333526332649853430e-01
            3.64134221167785598893829046573956e-01 -2.39494844833377101833704614364251e-01
            4.09550248289467677675901313705253e-01 -1.49064099813699252328191846572736e-01
            4.32887315517734183600850883522071e-01 -5.05972705892603624722170252425713e-02
            3.70794705497146270811725798921543e-01 5.09645592048445505994891391310375e-02
            3.43294558463330123920798087056028e-01 1.49113869405654991817655741215276e-01
            2.90333824496394443670510554511566e-01 2.36204086063210055845829060672258e-01
            2.15840358955430189347168834501645e-01 3.05776126219249766435837045719381e-01
            1.25339001394681875956038652475399e-01 3.52670149926306464305270083059440e-01
            2.55418234882680283970302070883918e-02 3.73408241971911580847631739743520e-01
            -7.61496746202033475414694407845673e-02 3.66452352939501124762244899102370e-01
            -1.72193499723675397250488572353788e-01 3.32318369297533888762075093836756e-01
            -2.55466520685487863406848418890149e-01 2.73537852460149888411677920885268e-01
            -3.19792758489625239537446077520144e-01 1.94470284458206493782839174855326e-01
            -3.60401430351112050942674613907002e-01 1.00979745100352014119948762527201e-01
            -3.74280776850293928070811944053276e-01 4.58361755352097264346352649664929e-17
            -3.60401430351111995431523382649175e-01 -1.00979745100352083508887801599485e-01
            -3.19792758489625406070899771293625e-01 -1.94470284458206243982658634195104e-01
            -2.55466520685487807895697187632322e-01 -2.73537852460149943922829152143095e-01
            -1.72193499723675619295093497385096e-01 -3.32318369297533777739772631321102e-01
            -7.61496746202032642747425938978267e-02 -3.66452352939501124762244899102370e-01
            2.55418234882679381914094562944229e-02 -3.73408241971911580847631739743520e-01
            1.25339001394681792689311805588659e-01 -3.52670149926306464305270083059440e-01
            2.15840358955430161591593218872731e-01 -3.05776126219249821946988276977208e-01
            2.90333824496394332648208091995912e-01 -2.36204086063210194623707138816826e-01
            3.43294558463330068409646855798201e-01 -1.49113869405655158351109434988757e-01
            3.70794705497146270811725798921543e-01 -5.09645592048444534549744844298402e-02
            3.06399111952083136323210510454373e-01 5.11289687867479761274047689312283e-02
            2.73196013900003364938129379879683e-01 1.47846289244507628213298744412896e-01
            2.10387888668935707503493404146866e-01 2.28542170191080806773697986500338e-01
            1.24780971196142620449620608269470e-01 2.84471960800302514638104867117363e-01
            2.56520993179881993950797181014423e-02 3.09574800419545603791249277492170e-01
            -7.62565755546019130584056711086305e-02 3.01130406865375732650136342272162e-01
            -1.69901667223167601727951137036143e-01 2.60053861207653391751648541685427e-01
            -2.45135276952108932535523422302504e-01 1.90796444536669190794597739113669e-01
            -2.93804675757562194782224196387688e-01 1.00863272588267605112122282662313e-01
            -3.10635779095424613416298598167486e-01 3.80419112569856025781295568337169e-17
            -2.93804675757562194782224196387688e-01 -1.00863272588267660623273513920140e-01
            -2.45135276952109071313401500447071e-01 -1.90796444536669052016719660969102e-01
            -1.69901667223167573972375521407230e-01 -2.60053861207653391751648541685427e-01
            -7.62565755546019824473447101809143e-02 -3.01130406865375677138985111014335e-01
            2.56520993179881889867388622405997e-02 -3.09574800419545603791249277492170e-01
            1.24780971196142370649440067609248e-01 -2.84471960800302625660407329633017e-01
            2.10387888668935735259069019775779e-01 -2.28542170191080806773697986500338e-01
            2.73196013900003253915826917364029e-01 -1.47846289244507794746752438186377e-01
            3.06399111952083191834361741712200e-01 -5.11289687867479275551474415806297e-02
            2.39612550834620963158272388682235e-01 5.09312199383904137817147272926377e-02
            1.98181363983628594516162024774530e-01 1.43987189192216091804255029273918e-01
            1.22482818878696747555423485209758e-01 2.12146465352159169226453627743467e-01
            2.56058816681610026955162595641013e-02 2.43623690362580774815270956423774e-01
            -7.56985451049318330829507317503158e-02 2.32976166057567157796626133858808e-01
            -1.63914005729689005175231386601808e-01 1.82044946119176792587168733916769e-01
            -2.23787245651789590272784380431403e-01 9.96365011703646552554403115209425e-02
            -2.44965637757393439599695739161689e-01 1.38786234930165714169115239224882e-16
            -2.23787245651789562517208764802490e-01 -9.96365011703646968888037349643128e-02
            -1.63914005729689143953109464746376e-01 -1.82044946119176681564866271401115e-01
            -7.56985451049318885941019630081428e-02 -2.32976166057567130041050518229895e-01
            2.56058816681608882037668450948331e-02 -2.43623690362580802570846572052687e-01
            1.22482818878696747555423485209758e-01 -2.12146465352159169226453627743467e-01
            1.98181363983628566760586409145617e-01 -1.43987189192216147315406260531745e-01
            2.39612550834620963158272388682235e-01 -5.09312199383903305149878804058972e-02
            1.70147620286948214607392060315760e-01 4.99598490266654968183779317314475e-02
            1.16126953051478867817714046850597e-01 1.34017648013455087374623531104589e-01
            2.52367987360063925073028201495617e-02 1.75525790679424170681599548515806e-01
            -7.36658608634491035571656425418041e-02 1.61305735010648904070862386106455e-01
            -1.49180130136860017442401726839307e-01 9.58722482078533111415907796981628e-02
            -1.77330762148248610721168461168418e-01 1.00467433070046447838634093752506e-16
            -1.49180130136860045197977342468221e-01 -9.58722482078532695082273562547925e-02
            -7.36658608634492562128315285008284e-02 -1.61305735010648820804135539219715e-01
            2.52367987360063474044924447525773e-02 -1.75525790679424170681599548515806e-01
            1.16126953051478770673199392149400e-01 -1.34017648013455170641350377991330e-01
            1.70147620286948214607392060315760e-01 -4.99598490266655176350596434531326e-02
            9.71122365165653089746911064139567e-02 4.67667882820115010655825926733087e-02
            2.39847416909782402971718084927488e-02 1.05084019401052886077962966737687e-01
            -6.72037528274834622399325212427357e-02 8.42708405877520549953629824813106e-02
            -1.07786450760120167124966883420711e-01 1.32000331914834954052765838985822e-17
            -6.72037528274834761177203290571924e-02 -8.42708405877520411175751746668539e-02
            2.39847416909781188665284901162522e-02 -1.05084019401052913833538582366600e-01
            9.71122365165653367302667220428702e-02 -4.67667882820114386155374575082533e-02
            1.81917869975766234580394353770316e-02 3.15090993602735874867804000132310e-02
            -3.63835739951532399771849668468349e-02 4.45570274347052964055947476702012e-18
            1.81917869975766234580394353770316e-02 -3.15090993602735874867804000132310e-02
            ];
        
    case   42
        
        % DEGREE.             :          42
        % CARDIN.             :         946
        % LEBESGUE CONST.     : 8.17887e+02
        % ABS.DET.VAND.MATRIX : Inf
        % CONDITIONING VAND.  : 2.72116e+04
        % POINTS OUT DISK     : 0.00000e+00
        
        pts=[
            9.99317060143022906082421741302824e-01 3.69514993891448886853545729991311e-02
            9.93859136895273609368928191543091e-01 1.10652681891500848099241238742252e-01
            9.82973099683901785361683778319275e-01 1.83749517816570340222881441150093e-01
            9.66718404269187425725817774946336e-01 2.55842777594435577537268500236678e-01
            9.45183828160819583530383170000277e-01 3.26538712840083289457027149182977e-01
            9.18486985745923023571890553284902e-01 3.95451206870542470994678296847269e-01
            8.86773685920061893739330116659403e-01 4.62203883540313165134705286618555e-01
            8.50217135729614215122751375020016e-01 5.26432162877355724894812283309875e-01
            8.09016994374947451262869435595348e-01 5.87785252292473137103456792829093e-01
            7.63398282741102995885285054100677e-01 6.45928062486787357698858613730408e-01
            7.13610154411752350966935409815051e-01 7.00543037593290951470237359899329e-01
            6.59924534878722712782916914875386e-01 7.51331889556873244728762983868364e-01
            6.02634636379256405369631011126330e-01 7.98017227280239493936164762999397e-01
            5.42053356472449454628304010839202e-01 8.40344071637892708892536575149279e-01
            4.78511569101286504679393374317442e-01 8.78081248083697918360712719731964e-01
            4.12356317473903666304124726593727e-01 9.11022649246088223051742716052104e-01
            3.43948918633928069077398959052516e-01 9.38988360615056527613830894551938e-01
            2.73662990072083001091840515073272e-01 9.61825643172819044757204665074823e-01
            2.01882409157010195288606269059528e-01 9.79409767601365888189945962949423e-01
            1.28999216530203408836996459285729e-01 9.91644695510742746336063646594994e-01
            5.54114749159700797909167135912867e-02 9.98463603967433943608966728788801e-01
            -1.84789049591297903363251720065819e-02 9.99829250458052709582545958255650e-01
            -9.22683594633018910879940222002915e-02 9.95734176295034578707543460041052e-01
            -1.65553876184130088766721655701986e-01 9.86200747353402573658343044371577e-01
            -2.37935195042618480298912686521362e-01 9.71281031916113923863065338082379e-01
            -3.09016994374947340240566973079694e-01 9.51056516295153642204240895807743e-01
            -3.78411050042310237451204102399061e-01 9.25637659781556321192397263075691e-01
            -4.45738355776538197616787329025101e-01 8.95163291355062340493020656140288e-01
            -5.10631193180906772788318903621985e-01 8.59799851448372565165811920451233e-01
            -5.72735140080505189530413190368563e-01 8.19740482907221124087016050907550e-01
            -6.31711006253250717534797331609298e-01 7.75203976111130010906435927608982e-01
            -6.87236685969262683926217505359091e-01 7.26433574016224103964134428679245e-01
            -7.39008917220658978486369505844777e-01 6.73695643646557429384813531214604e-01
            -7.86744938033483220962693849287461e-01 6.17278221289792927706230329931714e-01
            -8.30184030815550477733211209852016e-01 5.57489439342885750861000815348234e-01
            -8.69088946305528353697411603207001e-01 4.94655843399778805125066583059379e-01
            -9.03247199346128626373797487758566e-01 4.29120608772609046788204523181776e-01
            -9.32472229404355812398819125519367e-01 3.61241666187152921096981117443647e-01
            -9.56604419500440728008072710508713e-01 2.91389746889324785517061400241801e-01
            -9.75511967980436711656011539162137e-01 2.19946357839668565903323838028882e-01
            -9.89091608371145958322756541747367e-01 1.47301698054637664192512147565139e-01
            -9.97269173385788021413134174508741e-01 7.38525274748738774777123694548209e-02
            -1.00000000000000000000000000000000e+00 1.22464679914735320717376402945840e-16
            -9.97269173385788021413134174508741e-01 -7.38525274748736276775318287945993e-02
            -9.89091608371145958322756541747367e-01 -1.47301698054637414392331606904918e-01
            -9.75511967980436711656011539162137e-01 -2.19946357839668316103143297368661e-01
            -9.56604419500440950052677635540022e-01 -2.91389746889324119383246625147876e-01
            -9.32472229404355701376516663003713e-01 -3.61241666187153087630434811217128e-01
            -9.03247199346128848418402412789874e-01 -4.29120608772608935765902060666122e-01
            -8.69088946305528242675109140691347e-01 -4.94655843399778971658520276832860e-01
            -8.30184030815550699777816134883324e-01 -5.57489439342885528816395890316926e-01
            -7.86744938033483443007298774318770e-01 -6.17278221289792705661625404900406e-01
            -7.39008917220659089508671968360431e-01 -6.73695643646557207340208606183296e-01
            -6.87236685969262905970822430390399e-01 -7.26433574016223992941831966163591e-01
            -6.31711006253251605713217031734530e-01 -7.75203976111129233750318689999403e-01
            -5.72735140080505411575018115399871e-01 -8.19740482907221013064713588391896e-01
            -5.10631193180907327899831216200255e-01 -8.59799851448372232098904532904271e-01
            -4.45738355776538031083333635251620e-01 -8.95163291355062451515323118655942e-01
            -3.78411050042310237451204102399061e-01 -9.25637659781556321192397263075691e-01
            -3.09016994374947562285171898111003e-01 -9.51056516295153531181938433292089e-01
            -2.37935195042619174188303077244200e-01 -9.71281031916113701818460413051071e-01
            -1.65553876184130560611507121393515e-01 -9.86200747353402462636040581855923e-01
            -9.22683594633027931442015301399806e-02 -9.95734176295034467685240997525398e-01
            -1.84789049591300366670587607131893e-02 -9.99829250458052709582545958255650e-01
            5.54114749159696148850251518069854e-02 -9.98463603967433943608966728788801e-01
            1.28999216530203603126025768688123e-01 -9.91644695510742746336063646594994e-01
            2.01882409157010389577635578461923e-01 -9.79409767601365888189945962949423e-01
            2.73662990072082779047235590041964e-01 -9.61825643172819044757204665074823e-01
            3.43948918633927847032794034021208e-01 -9.38988360615056638636133357067592e-01
            4.12356317473903055681461182757630e-01 -9.11022649246088556118650103599066e-01
            4.78511569101285894056729830481345e-01 -8.78081248083698251427620107278926e-01
            5.42053356472449343606001548323547e-01 -8.40344071637892708892536575149279e-01
            6.02634636379256183325026086095022e-01 -7.98017227280239715980769688030705e-01
            6.59924534878722934827521839906694e-01 -7.51331889556873022684158058837056e-01
            7.13610154411752461989237872330705e-01 -7.00543037593290840447934897383675e-01
            7.63398282741102995885285054100677e-01 -6.45928062486787357698858613730408e-01
            8.09016994374947118195962048048386e-01 -5.87785252292473248125759255344747e-01
            8.50217135729613882055843987473054e-01 -5.26432162877356168984022133372491e-01
            8.86773685920061560672422729112441e-01 -4.62203883540313775757368830454652e-01
            9.18486985745923023571890553284902e-01 -3.95451206870542526505829528105096e-01
            9.45183828160819472508080707484623e-01 -3.26538712840083455990480842956458e-01
            9.66718404269187314703515312430682e-01 -2.55842777594435966115327119041467e-01
            9.82973099683901674339381315803621e-01 -1.83749517816570923089969369357277e-01
            9.93859136895273498346625729027437e-01 -1.10652681891500750954726584041055e-01
            9.99317060143022906082421741302824e-01 -3.69514993891450344021265550509270e-02
            9.88912759168614208249437069753185e-01 3.83743186876369032911604506352887e-02
            9.82965321475132047801537282794015e-01 1.14892168395031482597268279732816e-01
            9.71106214678258083949913270771503e-01 1.90719043082978434444640924994019e-01
            9.53406760841663425409819865308236e-01 2.65398911004979531913505752527271e-01
            9.29973406563317617212760524125770e-01 3.38482638648188949304085326730274e-01
            9.00947082793122189237067232170375e-01 4.09530691875206076524307263753144e-01
            8.66502357257596722561743263213430e-01 4.78115779334096213659677232499234e-01
            8.26846384589030480860571969969897e-01 5.43825422238857103529596770385979e-01
            7.82217660473148668209830702835461e-01 6.06264435065372864208654846152058e-01
            7.32884587307997548144555821636459e-01 6.65057302243654890894219988695113e-01
            6.79143860000339105731370636931388e-01 7.19850436552664563194525726430584e-01
            6.21318681607573197744898152450332e-01 7.70314305635465323973676277091727e-01
            5.59756819556519458203069916635286e-01 8.16145413845591805035439847415546e-01
            4.94828514129193652859584062753129e-01 8.57068127505577259661606603913242e-01
            4.26924251794186748742987447258201e-01 8.92836332600323689945298610837199e-01
            3.56452416775096925238841549798963e-01 9.23234914935746164843521910370328e-01
            2.83836834979756258423577719440800e-01 9.48081053860848288472595868370263e-01
            2.09514225061352005186066094211128e-01 9.67225321772627655292353665572591e-01
            1.33931571941059812669294615261606e-01 9.80552582791264004669073983677663e-01
            5.75434385881339258150823923188000e-02 9.87982685200846866280244285007939e-01
            -1.91907677752758756839490672518878e-02 9.89470943491226329058463306864724e-01
            -9.58095586032151336208784186965204e-02 9.85008407101928828986103781062411e-01
            -1.71852139472338655279415320364933e-01 9.74621914251881493740370387968142e-01
            -2.46861181353793979198485430970322e-01 9.58373930531205120431081923015881e-01
            -3.20385571043810601921109082468320e-01 9.36362173225805505261121197690954e-01
            -3.91983124211589151197898672762676e-01 9.08719023634117495369366679369705e-01
            -4.61223244747893446060515998397022e-01 8.75610730910401091620087754563428e-01
            -5.27689514420720762188921071356162e-01 8.37236412222763903834277243731776e-01
            -5.90982197263542730070184916257858e-01 7.93826855239086248694491132482653e-01
            -6.50720643634447037939594338240568e-01 7.45643130142827015305329041439109e-01
            -7.06545579487869335189031971822260e-01 6.92975019526225755051029864262091e-01
            -7.58121267090979045200072050647577e-01 6.36139275603692322391680136206560e-01
            -8.05137524189906916838310735329287e-01 5.75477715226722752461796517309267e-01
            -8.47311589482320437483053865435068e-01 5.11355164157130115398786074365489e-01
            -8.84389823177164191569943341164617e-01 4.44157262961989929284101208395441e-01
            -9.16149232414208425367974086839240e-01 3.74288147725891306993872831299086e-01
            -9.42398812369349414552743837703019e-01 3.02168019528972930931587370650959e-01
            -9.62980694980095308643797125114361e-01 2.28230617308183808544796988826420e-01
            -9.77771098382669845427983545960160e-01 1.52920609300280979647723711423168e-01
            -9.86681071350706040412603670120006e-01 7.66909187547321069544636884529609e-02
            -9.89657028258387083674563200474950e-01 1.21198031191031549528467940851501e-16
            -9.86681071350706040412603670120006e-01 -7.66909187547323151212808056698123e-02
            -9.77771098382669956450286008475814e-01 -1.52920609300280757603118786391860e-01
            -9.62980694980095419666099587630015e-01 -2.28230617308183114655406598103582e-01
            -9.42398812369349414552743837703019e-01 -3.02168019528972708886982445619651e-01
            -9.16149232414208536390276549354894e-01 -3.74288147725891029438116675009951e-01
            -8.84389823177164524636850728711579e-01 -4.44157262961989318661437664559344e-01
            -8.47311589482320548505356327950722e-01 -5.11355164157129893354181149334181e-01
            -8.05137524189907027860613197844941e-01 -5.75477715226722530417191592277959e-01
            -7.58121267090978934177769588131923e-01 -6.36139275603692433413982598722214e-01
            -7.06545579487869557233636896853568e-01 -6.92975019526225533006424939230783e-01
            -6.50720643634447593051106650818838e-01 -7.45643130142826571216119191376492e-01
            -5.90982197263542841092487378773512e-01 -7.93826855239086026649886207451345e-01
            -5.27689514420720651166618608840508e-01 -8.37236412222764014856579706247430e-01
            -4.61223244747894445261238161037909e-01 -8.75610730910400536508575441985158e-01
            -3.91983124211589206709049904020503e-01 -9.08719023634117495369366679369705e-01
            -3.20385571043810823965714007499628e-01 -9.36362173225805394238818735175300e-01
            -2.46861181353793979198485430970322e-01 -9.58373930531205120431081923015881e-01
            -1.71852139472338683034990935993847e-01 -9.74621914251881493740370387968142e-01
            -9.58095586032151474986662265109771e-02 -9.85008407101928828986103781062411e-01
            -1.91907677752761150757887520512668e-02 -9.89470943491226329058463306864724e-01
            5.75434385881338980595067766898865e-02 -9.87982685200846866280244285007939e-01
            1.33931571941058924490874915136374e-01 -9.80552582791264115691376446193317e-01
            2.09514225061351977430490478582215e-01 -9.67225321772627655292353665572591e-01
            2.83836834979756258423577719440800e-01 -9.48081053860848288472595868370263e-01
            3.56452416775096925238841549798963e-01 -9.23234914935746164843521910370328e-01
            4.26924251794186748742987447258201e-01 -8.92836332600323689945298610837199e-01
            4.94828514129192875703466825143551e-01 -8.57068127505577703750816453975858e-01
            5.59756819556519458203069916635286e-01 -8.16145413845591694013137384899892e-01
            6.21318681607573197744898152450332e-01 -7.70314305635465323973676277091727e-01
            6.79143860000338550619858324353117e-01 -7.19850436552665007283735576493200e-01
            7.32884587307997548144555821636459e-01 -6.65057302243654779871917526179459e-01
            7.82217660473148335142923315288499e-01 -6.06264435065373419320167158730328e-01
            8.26846384589030480860571969969897e-01 -5.43825422238856992507294307870325e-01
            8.66502357257596722561743263213430e-01 -4.78115779334096047126223538725753e-01
            9.00947082793121856170159844623413e-01 -4.09530691875206798169273270104895e-01
            9.29973406563317617212760524125770e-01 -3.38482638648188838281782864214620e-01
            9.53406760841663203365214940276928e-01 -2.65398911004980253558471758879023e-01
            9.71106214678257972927610808255849e-01 -1.90719043082979128334031315716857e-01
            9.82965321475132047801537282794015e-01 -1.14892168395031288308238970330422e-01
            9.88912759168614208249437069753185e-01 -3.83743186876375902416569374508981e-02
            9.69906745915785628575633836589986e-01 3.95940749926579557693706590271177e-02
            9.63452176545065097634790163283469e-01 1.18518732941460272489742067136831e-01
            9.50585991897857418564399267779663e-01 1.96654668276751709576899429521291e-01
            9.31393814310218393082152488204883e-01 2.73481899240397730022067435129429e-01
            9.06003364557507517851320244517410e-01 3.48489153285936215098672619205900e-01
            8.74583611893699708339511289523216e-01 4.21177269513019925106789287383435e-01
            8.37343649588878302658656593848718e-01 4.91062520500852750515718980750535e-01
            7.94531303448020698176890164177166e-01 5.57679831434365058662194769567577e-01
            7.46431482571154214511466307158116e-01 6.20585875100377437618703879707027e-01
            6.93364283330302644259290900663473e-01 6.79362022157058986771005493210396e-01
            6.35682859180942250176826746610459e-01 7.33617127043129202412785616616020e-01
            5.73771070484022205349106116045732e-01 7.82990130987033516873907501576468e-01
            5.08040929978593736038305905822199e-01 8.27152464793497577133507547841873e-01
            4.38929860905011404170750211051200e-01 8.65810235417311280237129267334240e-01
            3.66897786025435546086725935310824e-01 8.98706181773056611561401041399222e-01
            2.92424066913734348460707224148791e-01 9.25621386765185127920574359450256e-01
            2.16004313883296994447391625726596e-01 9.46376734145170539491687122790609e-01
            1.38147087782169775138640943623614e-01 9.60834100500590038151926819409709e-01
            5.93705156045171086875988919473457e-02 9.68897274443646261410378883738304e-01
            -1.98011575590380552169822436781033e-02 9.70512596882077915871889217669377e-01
            -9.88410572859986374938401354484085e-02 9.65669318111566865603379028470954e-01
            -1.77223186084347672508698678939254e-01 9.54399669353246049574579501495464e-01
            -2.54425923819072863363288661275874e-01 9.36778648260240820455635457619792e-01
            -3.29935499008104815565900480578421e-01 9.12923519820661333312727947486565e-01
            -4.03249407886763111541483795008389e-01 8.82993035978454132717274660535622e-01
            -4.73879758487404545430621283230721e-01 8.47186379165406400204574310919270e-01
            -5.41356517479969046036103463848121e-01 8.05741836774926722952727686788421e-01
            -6.05230638166242673747774460935034e-01 7.58935215398755524951468487415696e-01
            -6.65077048811546278628270556509960e-01 7.07078005379602081426071435998892e-01
            -7.20497481426998320763743777206400e-01 6.50515307894306782365845265303506e-01
            -7.71123122177270747812372064800002e-01 5.89623538362445853699966846761527e-01
            -8.16617065775813055772403004084481e-01 5.24807921463819049279209139058366e-01
            -8.56676557533949112333004904940026e-01 4.56499794435063110942252251334139e-01
            -8.91035008143379991807364604028407e-01 3.85153736591505979625083000428276e-01
            -9.19463767784045149511484851245768e-01 3.11244544176825954640008831120213e-01
            -9.41773647750950848589468478166964e-01 2.35264070672384306703861511778086e-01
            -9.57816179473788387177535241789883e-01 1.57717953593457776984010365595168e-01
            -9.67484602550774064333438673202181e-01 7.91222495549970677997109191892378e-02
            -9.70714575221507947055954446113901e-01 1.18878249743070237145916602081353e-16
            -9.67484602550774064333438673202181e-01 -7.91222495549968179995303785290162e-02
            -9.57816179473788498199837704305537e-01 -1.57717953593457138605771206130157e-01
            -9.41773647750950848589468478166964e-01 -2.35264070672384500992890821180481e-01
            -9.19463767784045149511484851245768e-01 -3.11244544176825732595403906088904e-01
            -8.91035008143380102829667066544062e-01 -3.85153736591505757580478075396968e-01
            -8.56676557533949223355307367455680e-01 -4.56499794435062888897647326302831e-01
            -8.16617065775812944750100541568827e-01 -5.24807921463819160301511601574020e-01
            -7.71123122177270969856976989831310e-01 -5.89623538362445631655361921730218e-01
            -7.20497481426998320763743777206400e-01 -6.50515307894306893388147727819160e-01
            -6.65077048811546500672875481541269e-01 -7.07078005379601859381466510967584e-01
            -6.05230638166242895792379385966342e-01 -7.58935215398755302906863562384387e-01
            -5.41356517479969157058405926363776e-01 -8.05741836774926500908122761757113e-01
            -4.73879758487404711964074977004202e-01 -8.47186379165406289182271848403616e-01
            -4.03249407886763333586088720039697e-01 -8.82993035978454021694972198019968e-01
            -3.29935499008104704543598018062767e-01 -9.12923519820661333312727947486565e-01
            -2.54425923819073529497103436369798e-01 -9.36778648260240598411030532588484e-01
            -1.77223186084347478219669369536859e-01 -9.54399669353246049574579501495464e-01
            -9.88410572859993036276549105423328e-02 -9.65669318111566754581076565955300e-01
            -1.98011575590376458222419131516290e-02 -9.70512596882077915871889217669377e-01
            5.93705156045166507206012340702728e-02 -9.68897274443646372432681346253958e-01
            1.38147087782169331049431093560997e-01 -9.60834100500590149174229281925363e-01
            2.16004313883296800158362316324201e-01 -9.46376734145170539491687122790609e-01
            2.92424066913734126416102299117483e-01 -9.25621386765185238942876821965910e-01
            3.66897786025434713419457466443419e-01 -8.98706181773056944628308428946184e-01
            4.38929860905011348659598979793373e-01 -8.65810235417311280237129267334240e-01
            5.08040929978593180926793593243929e-01 -8.27152464793497910200414935388835e-01
            5.73771070484022205349106116045732e-01 -7.82990130987033405851605039060814e-01
            6.35682859180942583243734134157421e-01 -7.33617127043129091390483154100366e-01
            6.93364283330302200170081050600857e-01 -6.79362022157059430860215343273012e-01
            7.46431482571154436556071232189424e-01 -6.20585875100377104551796492160065e-01
            7.94531303448020365109982776630204e-01 -5.57679831434365502751404619630193e-01
            8.37343649588878191636354131333064e-01 -4.91062520500852972560323905781843e-01
            8.74583611893699597317208827007562e-01 -4.21177269513020202662545443672570e-01
            9.06003364557507517851320244517410e-01 -3.48489153285936381632126312979381e-01
            9.31393814310218393082152488204883e-01 -2.73481899240397841044369897645083e-01
            9.50585991897857418564399267779663e-01 -1.96654668276751709576899429521291e-01
            9.63452176545065097634790163283469e-01 -1.18518732941461063523647112560866e-01
            9.69906745915785628575633836589986e-01 -3.95940749926578031137047730680933e-02
            9.45289767406829350981922743812902e-01 4.07061658543857243786057154011360e-02
            9.38291172696738562386542525928235e-01 1.21817123353005624109002269506163e-01
            9.24345798423197750892654767085332e-01 2.02026189490381258284656951218494e-01
            9.03556891258270877820280020387145e-01 2.80739524403514517647550974288606e-01
            8.76078364997208591802291266503744e-01 3.57374362100081388593508791018394e-01
            8.42113661034557314799542382388609e-01 4.31363325053946866649567937201937e-01
            8.01914242155252088295469548029359e-01 5.02158624869861291983852424891666e-01
            7.55777730792136392956592771952273e-01 5.69236117917083173090020409290446e-01
            7.04045705533597243608312510332325e-01 6.32099185905441229849088813352864e-01
            6.47101172195206242321319223265164e-01 6.90282412673401624125801845366368e-01
            5.85365728178661282044004110503010e-01 7.43355029966494496029838501272025e-01
            5.19296441112129913975081763055641e-01 7.90924106694756434698945213312982e-01
            4.49382464881442567072866722810431e-01 8.32637458057047363801927986060036e-01
            3.76141418105863656329290733992821e-01 8.68186252994098128787925361393718e-01
            3.00115551870931696054611848012428e-01 8.97307300665623919222468884981936e-01
            2.21867735091140189096492463249888e-01 9.19784999023222749059414127259515e-01
            1.41977287225424270156182160462777e-01 9.35452931052509817355655741266673e-01
            6.10356891985734117955786359743797e-02 9.44195096866467298291070164850680e-01
            -2.03577957165949792461834277901289e-02 9.45946772528023283044262825569604e-01
            -1.01600558634843712857431796692254e-01 9.40694989243436974213352641527308e-01
            -1.82091106563867594081429501784442e-01 9.28478629378710396125029546965379e-01
            -2.61233515647965652828332849821891e-01 9.09388138588153260855051485123113e-01
            -3.38441843179771162386515470643644e-01 8.83564856186404345983476105175214e-01
            -4.13144465715055975163494395019370e-01 8.51199968721594424359011554770404e-01
            -4.84788311172716090968748403611244e-01 8.12533094497035257575134892249480e-01
            -5.52842953586960339507072603737470e-01 7.67850509521136093127324784290977e-01
            -6.16804540195576844752167744445615e-01 7.17483028019998081425967484392459e-01
            -6.76199521789505930691177582048113e-01 6.61803553204624139816303340921877e-01
            -7.30588158705501422574002390319947e-01 6.01224316426013483116719271492912e-01
            -7.79567776504748066734862277371576e-01 5.36193825158464032476501870405627e-01
            -8.22775747233519649803668016829761e-01 4.67193542407154605022867599473102e-01
            -8.59892174193679470484141802444356e-01 3.94734322124500769390920140722301e-01
            -8.90642260345909764218674808944343e-01 3.19352627026224800133036296756472e-01
            -9.14798342810847930905993052874692e-01 2.41606556809099703997389951837249e-01
            -9.32181578405393174158177771460032e-01 1.62071716176056590530407675032620e-01
            -9.42663267735062482266528149921214e-01 8.13369532603501615986019146475883e-02
            -9.46165808039279299102020104328403e-01 1.15871892827797247324792571007392e-16
            -9.42663267735062482266528149921214e-01 -8.13369532603499256762091818018234e-02
            -9.32181578405393174158177771460032e-01 -1.62071716176056396241378365630226e-01
            -9.14798342810847930905993052874692e-01 -2.41606556809099509708360642434855e-01
            -8.90642260345909764218674808944343e-01 -3.19352627026224578088431371725164e-01
            -8.59892174193679359461839339928702e-01 -3.94734322124500935924373834495782e-01
            -8.22775747233519760825970479345415e-01 -4.67193542407154438489413905699621e-01
            -7.79567776504748177757164739887230e-01 -5.36193825158463810431896945374319e-01
            -7.30588158705501644618607315351255e-01 -6.01224316426013372094416808977257e-01
            -6.76199521789506152735782507079421e-01 -6.61803553204624028794000878406223e-01
            -6.16804540195576955774470206961269e-01 -7.17483028019997859381362559361150e-01
            -5.52842953586960561551677528768778e-01 -7.67850509521135982105022321775323e-01
            -4.84788311172716757102563178705168e-01 -8.12533094497034924508227504702518e-01
            -4.13144465715055475563133313698927e-01 -8.51199968721594646403616479801713e-01
            -3.38441843179771550964574089448433e-01 -8.83564856186404234961173642659560e-01
            -2.61233515647966096917542699884507e-01 -9.09388138588153149832749022607459e-01
            -1.82091106563868260215244276878366e-01 -9.28478629378710174080424621934071e-01
            -1.01600558634844156946641646754870e-01 -9.40694989243436863191050179011654e-01
            -2.03577957165954233353932778527451e-02 -9.45946772528023283044262825569604e-01
            6.10356891985729677063687859117636e-02 -9.44195096866467298291070164850680e-01
            1.41977287225423798311396694771247e-01 -9.35452931052509928377958203782327e-01
            2.21867735091140549918975466425763e-01 -9.19784999023222638037111664743861e-01
            3.00115551870931307476553229207639e-01 -8.97307300665624141267073810013244e-01
            3.76141418105863212240080883930204e-01 -8.68186252994098350832530286425026e-01
            4.49382464881442900139774110357394e-01 -8.32637458057047252779625523544382e-01
            5.19296441112129469885871912993025e-01 -7.90924106694756767765852600859944e-01
            5.85365728178660948977096722956048e-01 -7.43355029966494718074443426303333e-01
            6.47101172195206464365924148296472e-01 -6.90282412673401402081196920335060e-01
            7.04045705533596910541405122785363e-01 -6.32099185905441673938298663415480e-01
            7.55777730792136503978895234467927e-01 -5.69236117917082951045415484259138e-01
            8.01914242155251755228562160482397e-01 -5.02158624869861736073062274954282e-01
            8.42113661034556981732634994841646e-01 -4.31363325053947421761080249780207e-01
            8.76078364997208702824593729019398e-01 -3.57374362100081166548903865987086e-01
            9.03556891258270766797977557871491e-01 -2.80739524403515128270214518124703e-01
            9.24345798423197639870352304569678e-01 -2.02026189490381841151744879425678e-01
            9.38291172696738673408844988443889e-01 -1.21817123353005415942185152289312e-01
            9.45289767406829350981922743812902e-01 -4.07061658543863696957387787733751e-02
            9.16129906431334961602885869069723e-01 4.17405422688947938536507820117549e-02
            9.08538565503497874686900104279630e-01 1.24875751527805778362534283587593e-01
            8.93418787889545318314787891722517e-01 2.06976200981570573889101183340244e-01
            8.70895860828563073141594941262156e-01 2.87361580449551234917038300409331e-01
            8.41156416387480176943824972113362e-01 3.65365791361150826777048905569245e-01
            8.04446884968984865516006266261684e-01 4.40342466258348497198937820940046e-01
            7.61071453311598089541689660109114e-01 5.11670324800021725231147229351336e-01
            7.11389543902558929566737333516357e-01 5.78758321886516990950610761501594e-01
            6.55812836689898648323548968619434e-01 6.41050545245487102263837186910678e-01
            5.94801857772739639429460112296510e-01 6.98030821896057362963006198697258e-01
            5.28862163337000090734818513737991e-01 7.49226995320707911396596045960905e-01
            4.58540150457620310220363535336219e-01 7.94214837902875503417021718632895e-01
            3.84418529480317738844519226404373e-01 8.32621566210591246282035626791185e-01
            3.07111495500147102521992792389938e-01 8.64128929997399763962562246888410e-01
            2.27259638947508169071198835808900e-01 8.88475849324131150552830149536021e-01
            1.45524637454095689959032711158216e-01 9.05460577949499634264896030799719e-01
            6.25837729836547090878084986798058e-02 9.14942375062997137469267272535944e-01
            -2.08756803396704208874989916466802e-02 9.16842671507573148126368778321194e-01
            -1.04162151201178415638182173097448e-01 9.11145720828414384939719639078248e-01
            -1.86585501673324327676084521954181e-01 8.97898729753028312927654042141512e-01
            -2.67462745915938604479578089012648e-01 8.77211467021432600432717663352378e-01
            -3.46123709611995511448157003542292e-01 8.49255353807804258536862107575871e-01
            -4.21916583243066412034494305771659e-01 8.14262043270644220172016503056511e-01
            -4.94213323188268549568391563298064e-01 7.72521501001749433257259624951985e-01
            -5.62414855891501863638382019416895e-01 7.24379602279998646707781517761759e-01
            -6.25956041973606325257151183905080e-01 6.70235266039862054299192095641047e-01
            -6.84310359155238634443207956792321e-01 6.10537149303477133521766972990008e-01
            -7.36994265186301733550067183387000e-01 5.45779929467263391629217039735522e-01
            -7.83571204629314066458789511671057e-01 4.76500205249224928483187113670283e-01
            -8.23655226295252673729407888458809e-01 4.03272050262975578771573736958089e-01
            -8.56914181356654314214438272756524e-01 3.26702256062982754336587731813779e-01
            -8.83072475637406872905899035686161e-01 2.47425304078644076044568578254257e-01
            -9.01913353272886464395696748397313e-01 1.66098108101342595288585357593547e-01
            -9.13280692817317829579337740142364e-01 8.33945708898835152966810824182176e-02
            -9.17080300915240398396122145641129e-01 1.12309945507694070712112337122585e-16
            -9.13280692817317829579337740142364e-01 -8.33945708898833071298639652013662e-02
            -9.01913353272886575417999210912967e-01 -1.66098108101341984665921813757450e-01
            -8.83072475637406872905899035686161e-01 -2.47425304078643881755539268851862e-01
            -8.56914181356654425236740735272178e-01 -3.26702256062982532291982806782471e-01
            -8.23655226295252784751710350974463e-01 -4.03272050262975412238120043184608e-01
            -7.83571204629314510547999361733673e-01 -4.76500205249224317860523569834186e-01
            -7.36994265186301622527764720871346e-01 -5.45779929467263613673821964766830e-01
            -6.84310359155238745465510419307975e-01 -6.10537149303476911477162047958700e-01
            -6.25956041973606769346361033967696e-01 -6.70235266039861610209982245578431e-01
            -5.62414855891502085682986944448203e-01 -7.24379602279998424663176592730451e-01
            -4.94213323188268771612996488329372e-01 -7.72521501001749322234957162436331e-01
            -4.21916583243066967146006618349929e-01 -8.14262043270643998127411578025203e-01
            -3.46123709611995733492761928573600e-01 -8.49255353807804147514559645060217e-01
            -2.67462745915939215102241632848745e-01 -8.77211467021432489410415200836724e-01
            -1.86585501673324355431660137583094e-01 -8.97898729753028312927654042141512e-01
            -1.04162151201178637682787098128756e-01 -9.11145720828414273917417176562594e-01
            -2.08756803396710523268442472044626e-02 -9.16842671507573148126368778321194e-01
            6.25837729836546952100206908653490e-02 -9.14942375062997137469267272535944e-01
            1.45524637454095245869822861095599e-01 -9.05460577949499745287198493315373e-01
            2.27259638947507558448535291972803e-01 -8.88475849324131261575132612051675e-01
            3.07111495500146880477387867358630e-01 -8.64128929997399763962562246888410e-01
            3.84418529480317350266460607599583e-01 -8.32621566210591357304338089306839e-01
            4.58540150457620310220363535336219e-01 -7.94214837902875503417021718632895e-01
            5.28862163336999979712516051222337e-01 -7.49226995320708133441200970992213e-01
            5.94801857772739195340250262233894e-01 -6.98030821896057807052216048759874e-01
            6.55812836689898648323548968619434e-01 -6.41050545245487102263837186910678e-01
            7.11389543902558596499829945969395e-01 -5.78758321886517212995215686532902e-01
            7.61071453311597756474782272562152e-01 -5.11670324800022391364962004445260e-01
            8.04446884968984754493703803746030e-01 -4.40342466258348663732391514713527e-01
            8.41156416387479954899220047082053e-01 -3.65365791361151270866258755631861e-01
            8.70895860828563073141594941262156e-01 -2.87361580449551179405887069151504e-01
            8.93418787889545318314787891722517e-01 -2.06976200981570851444857339629380e-01
            9.08538565503497763664597641763976e-01 -1.24875751527806333474046596165863e-01
            9.16129906431334961602885869069723e-01 -4.17405422688948632425898210840387e-02
            8.83044172809548499891718620347092e-01 4.27127270352851209911371199723362e-02
            8.74799427291294895425721733772662e-01 1.27739383881843221457685899622447e-01
            8.58386915222266178027155092422618e-01 2.11573372518595398394936069053074e-01
            8.33959875805540984394781389710261e-01 2.93431957581475999496944950806210e-01
            8.01746377726646364259011079411721e-01 3.72550847517345073978134450953803e-01
            7.62047189737691699207289275364019e-01 4.48191330568292967129195858433377e-01
            7.15232972460567273387255227135029e-01 5.19647171924289219546722051745746e-01
            6.61740817628587163490294642542722e-01 5.86251207647318528515256730315741e-01
            6.02070167078742612964958880183985e-01 6.47381573801313336957719002384692e-01
            5.36778149597838649675907163327793e-01 7.02467512628171752986361298098927e-01
            4.66474379161119667713819580967538e-01 7.50994701559164368198651118291309e-01
            3.91815263130836421989755535832956e-01 7.92510055306179572731650750938570e-01
            3.13497873557562367619055976319942e-01 8.26625956196983313617465682909824e-01
            2.32253438806274331573931135608291e-01 8.53023873256986031599069519870682e-01
            1.48840516274126255513721162060392e-01 8.71457336247129177309034275822341e-01
            6.40379099444153970788207175246498e-02 8.81754236890099352130789611692308e-01
            -2.13626010963731648162333698337534e-02 8.83818435798941481884583026840119e-01
            -1.06563655286563474522409933342715e-01 8.77630660104611881600078504561679e-01
            -1.90769753339353476118134267380810e-01 8.63248683401563465800165886321338e-01
            -2.73194685605319120824674428149592e-01 8.40806786331260158640077406744240e-01
            -3.53068872700079028348341125820298e-01 8.10514502840008255191150965401903e-01
            -4.29646550859655418364013712562155e-01 7.72654663816955245003725849528564e-01
            -5.02212734935800875213374183658743e-01 7.27580756378282345053776225540787e-01
            -5.70089894019688681048307898890926e-01 6.75713623453242595573442486056592e-01
            -6.32644277365454477113360098883277e-01 6.17537534487121120285735287325224e-01
            -6.89291831550157829688885158248013e-01 5.53595663947902827395353142492240e-01
            -7.39503653623227119595640033367090e-01 4.84485019852614773316901164434967e-01
            -7.82810929330802984793535870267078e-01 4.10850869664328433028543940963573e-01
            -8.18809310308112547893699684209423e-01 3.33380715603712574068850926778396e-01
            -8.47162689371205313015877891302807e-01 2.52797875626036672169760777251213e-01
            -8.67606338659170139848697544948664e-01 1.69854729996311626383231896397774e-01
            -8.79949381326845969653049905900843e-01 8.53256965174702813881069118906453e-02
            -8.84076573710496194102859135455219e-01 1.08268154619571822566898639593112e-16
            -8.79949381326845969653049905900843e-01 -8.53256965174700593435019868593372e-02
            -8.67606338659170139848697544948664e-01 -1.69854729996311404338626971366466e-01
            -8.47162689371205201993575428787153e-01 -2.52797875626036838703214471024694e-01
            -8.18809310308112769938304609240731e-01 -3.33380715603712018957338614200125e-01
            -7.82810929330803095815838332782732e-01 -4.10850869664328266495090247190092e-01
            -7.39503653623227341640244958398398e-01 -4.84485019852614551272296239403659e-01
            -6.89291831550157940711187620763667e-01 -5.53595663947902605350748217460932e-01
            -6.32644277365454588135662561398931e-01 -6.17537534487121009263432824809570e-01
            -5.70089894019688347981400511343963e-01 -6.75713623453242928640349873603554e-01
            -5.02212734935801097257979108690051e-01 -7.27580756378282234031473763025133e-01
            -4.29646550859655917964374793882598e-01 -7.72654663816954800914515999465948e-01
            -3.53068872700078917326038663304644e-01 -8.10514502840008366213453427917557e-01
            -2.73194685605319342869279353180900e-01 -8.40806786331260047617774944228586e-01
            -1.90769753339354253274251504990389e-01 -8.63248683401563243755560961290030e-01
            -1.06563655286563294111168431754777e-01 -8.77630660104611992622380967077333e-01
            -2.13626010963733799219443909578331e-02 -8.83818435798941481884583026840119e-01
            6.40379099444153693232451018957363e-02 -8.81754236890099352130789611692308e-01
            1.48840516274126422047174855833873e-01 -8.71457336247129177309034275822341e-01
            2.32253438806273942995872516803502e-01 -8.53023873256986142621371982386336e-01
            3.13497873557562367619055976319942e-01 -8.26625956196983313617465682909824e-01
            3.91815263130835866878243223254685e-01 -7.92510055306179905798558138485532e-01
            4.66474379161119390158063424678403e-01 -7.50994701559164479220953580806963e-01
            5.36778149597838427631302238296485e-01 -7.02467512628171975030966223130235e-01
            6.02070167078742279898051492637023e-01 -6.47381573801313670024626389931655e-01
            6.61740817628587274512597105058376e-01 -5.86251207647318306470651805284433e-01
            7.15232972460567162364952764619375e-01 -5.19647171924289441591326976777054e-01
            7.62047189737691366140381887817057e-01 -4.48191330568293633263010633527301e-01
            8.01746377726646475281313541927375e-01 -3.72550847517344796422378294664668e-01
            8.33959875805540873372478927194607e-01 -2.93431957581476277052701107095345e-01
            8.58386915222266067004852629906964e-01 -2.11573372518596203306628922291566e-01
            8.74799427291294895425721733772662e-01 -1.27739383881842999413080974591139e-01
            8.83044172809548388869416157831438e-01 -4.27127270352854609969384114265267e-02
            8.46448322919711837464262771391077e-01 4.36319576954079246799977909176960e-02
            8.37475760125117929533189453650266e-01 1.30433363480294467473541430990736e-01
            8.19625745933664551223785110778408e-01 2.15852143164274867803698043644545e-01
            7.93087494936343895268748838134343e-01 2.98982836432998888565037987063988e-01
            7.58142319195669989184693804418202e-01 3.78944237257327121159988791987416e-01
            7.15160646267834154699016835365910e-01 4.54888734896458368783811465618783e-01
            6.64598092578457477763720362418098e-01 5.26011298782642744420456892839866e-01
            6.06990633775135512983922581042862e-01 5.91558012045467873640802736190381e-01
            5.42948923252238091485821769310860e-01 6.50834063218238223491596272651805e-01
            4.73151819073017232408773224960896e-01 7.03211111412370470930000010412186e-01
            3.98339187905255298627338333972148e-01 7.48133946887125422797737428481923e-01
            3.19304062250530817923532822533161e-01 7.85126376410979931463884895492811e-01
            2.36884234102416380007838370147510e-01 8.13796271028344175846314101363532e-01
            1.51953374142930891510516744347115e-01 8.33839722724040721679727994342102e-01
            6.54117706159643569341355373580882e-02 8.45044265923869275525248667690903e-01
            -2.18232139520711521107898533955449e-02 8.47291129682548160850785734510282e-01
            -1.08826867023235823728199989091081e-01 8.40556496685281429037672751292121e-01
            -1.94676928231005075264903325660271e-01 8.24911755717220196437722279370064e-01
            -2.78463365569586396297552255418850e-01 8.00522744924580864633867349766660e-01
            -3.59298021959569613414942068629898e-01 7.67647993889039814696673147409456e-01
            -4.36324029933916945900307382544270e-01 7.26635983149852671125756842229748e-01
            -5.08724894646277570053882755019004e-01 6.77921450223446075966649004840292e-01
            -5.75733148919477577543091229017591e-01 6.22020781277594747571413336117985e-01
            -6.36638488588522344358011650911067e-01 5.59526537309579796719560818019090e-01
            -6.90795301901448444148456928814994e-01 4.91101172852207001895408211566973e-01
            -7.37629513164504424516110248077894e-01 4.17470013790958160981858782179188e-01
            -7.76644668087316358828786633239361e-01 3.39413568729166725823631622915855e-01
            -8.07427196321870321860103558719857e-01 2.57759255402653930655532121818396e-01
            -8.29650795411085106856319271173561e-01 1.73372629845891246258560158821638e-01
            -8.43079889676032312451070538372733e-01 8.71482112827101085272829550376628e-02
            -8.47572127376736372816878883895697e-01 1.03797649283843298580999953675891e-16
            -8.43079889676032312451070538372733e-01 -8.71482112827099142382536456352682e-02
            -8.29650795411085217878621733689215e-01 -1.73372629845890691147047846243368e-01
            -8.07427196321870321860103558719857e-01 -2.57759255402653708610927196787088e-01
            -7.76644668087316358828786633239361e-01 -3.39413568729166836845934085431509e-01
            -7.37629513164504424516110248077894e-01 -4.17470013790958327515312475952669e-01
            -6.90795301901448777215364316361956e-01 -4.91101172852206557806198361504357e-01
            -6.36638488588522455380314113426721e-01 -5.59526537309579685697258355503436e-01
            -5.75733148919477688565393691533245e-01 -6.22020781277594525526808411086677e-01
            -5.08724894646277459031580292503349e-01 -6.77921450223446298011253929871600e-01
            -4.36324029933917445500668463864713e-01 -7.26635983149852338058849454682786e-01
            -3.59298021959569779948395762403379e-01 -7.67647993889039703674370684893802e-01
            -2.78463365569586396297552255418850e-01 -8.00522744924580864633867349766660e-01
            -1.94676928231005824665444947640935e-01 -8.24911755717219974393117354338756e-01
            -1.08826867023235657194746295317600e-01 -8.40556496685281429037672751292121e-01
            -2.18232139520715476277423761075624e-02 -8.47291129682548160850785734510282e-01
            6.54117706159641487673184201412369e-02 -8.45044265923869275525248667690903e-01
            1.51953374142930697221487434944720e-01 -8.33839722724040721679727994342102e-01
            2.36884234102416380007838370147510e-01 -8.13796271028344175846314101363532e-01
            3.19304062250530817923532822533161e-01 -7.85126376410979931463884895492811e-01
            3.98339187905255021071582177683013e-01 -7.48133946887125644842342353513232e-01
            4.73151819073016954853017068671761e-01 -7.03211111412370692974604935443494e-01
            5.42948923252237980463519306795206e-01 -6.50834063218238445536201197683113e-01
            6.06990633775135401961620118527208e-01 -5.91558012045467984663105198706035e-01
            6.64598092578457033674510512355482e-01 -5.26011298782643299531969205418136e-01
            7.15160646267834265721319297881564e-01 -4.54888734896458257761509003103129e-01
            7.58142319195669767140088879386894e-01 -3.78944237257327565249198642050033e-01
            7.93087494936344006291051300649997e-01 -2.98982836432998499986979368259199e-01
            8.19625745933664440201482648262754e-01 -2.15852143164275062092727353046939e-01
            8.37475760125117818510886991134612e-01 -1.30433363480295244629658668600314e-01
            8.46448322919711837464262771391077e-01 -4.36319576954078275354831362164987e-02
            8.06646815607348299792533907748293e-01 4.45039449791029551040111300608260e-02
            7.96855215978609310312208435789216e-01 1.32971617331904073955328726697189e-01
            7.77390873476571875322349569614744e-01 2.19825194378422239527282044946332e-01
            7.48490058852113504528347220912110e-01 3.04010391348286168611281254925416e-01
            7.10503588844694333737095348624280e-01 3.84505313990571695459408374517807e-01
            6.63892567742368266969776868791087e-01 4.60332862985713242576224502045079e-01
            6.09222790200355079903715704858769e-01 5.30572594607630176888335427065613e-01
            5.47157873260371907520038803340867e-01 5.94371893663693806608705472172005e-01
            4.78451200938705023535391092082136e-01 6.50956323088184962699642710504122e-01
            4.03936779164815240594776923899190e-01 6.99639024559189248719803799758665e-01
            3.24519112079126259562400491631706e-01 7.39829056028184162130401091417298e-01
            2.41162222578036100628651183797047e-01 7.71038564955995098237906404392561e-01
            1.54877950381852619310407703778765e-01 7.92888710181759881479024443251546e-01
            6.67136696712650190121962623379659e-02 8.05114260541428872208769007556839e-01
            -2.22604246163998764629354809585493e-02 8.07566814414805045352352408372099e-01
            -1.10964307503991985170976874996995e-01 8.00216601120182891015986115235137e-01
            -1.98321234014720071403559131795191e-01 7.83152842290096740107685491238954e-01
            -2.83270809397572431720391250564717e-01 7.56582668841563332762234495021403e-01
            -3.64781860883145958585060952827916e-01 7.20828606687337059000242334150244e-01
            -4.41864954724202119162868029889069e-01 6.76324661708234131651806819718331e-01
            -5.13584406581036545524909797677537e-01 6.23611051509659342073632615210954e-01
            -5.79069639461851637385336744046072e-01 5.63327647911674556091554677550448e-01
            -6.37525751348121394457280075585004e-01 4.96206209771896888938158554083202e-01
            -6.88243164228294457274159867665730e-01 4.23061500424233127848339108822984e-01
            -7.30606237413633174959670668613398e-01 3.44781397555715685143695736769587e-01
            -7.64100740582207671458547793008620e-01 2.62316115574129982146445172475069e-01
            -7.88320095838407786104085062106606e-01 1.76666671292301347140352163478383e-01
            -8.02970313017831394120094046229497e-01 8.88727329399992826974852277999162e-02
            -8.07873558329630259144948922767071e-01 9.89359767324164195905944796651990e-17
            -8.02970313017831394120094046229497e-01 -8.88727329399990884084559183975216e-02
            -7.88320095838407786104085062106606e-01 -1.76666671292301180606898469704902e-01
            -7.64100740582207782480850255524274e-01 -2.62316115574129760101840247443761e-01
            -7.30606237413633285981973131129052e-01 -3.44781397555715185543334655449144e-01
            -6.88243164228294346251857405150076e-01 -4.23061500424233294381792802596465e-01
            -6.37525751348121616501885000616312e-01 -4.96206209771896777915856091567548e-01
            -5.79069639461851859429941669077380e-01 -5.63327647911674445069252215034794e-01
            -5.13584406581036767569514722708846e-01 -6.23611051509659231051330152695300e-01
            -4.41864954724202285696321723662550e-01 -6.76324661708234020629504357202677e-01
            -3.64781860883146125118514646601398e-01 -7.20828606687336947977939871634590e-01
            -2.83270809397572598253844944338198e-01 -7.56582668841563221739932032505749e-01
            -1.98321234014720071403559131795191e-01 -7.83152842290096740107685491238954e-01
            -1.10964307503992012926552490625909e-01 -8.00216601120182891015986115235137e-01
            -2.22604246163998938101702407266202e-02 -8.07566814414805045352352408372099e-01
            6.67136696712642834894424481717579e-02 -8.05114260541428983231071470072493e-01
            1.54877950381852591554832088149851e-01 -7.92888710181759881479024443251546e-01
            2.41162222578036100628651183797047e-01 -7.71038564955995098237906404392561e-01
            3.24519112079125704450888179053436e-01 -7.39829056028184273152703553932952e-01
            4.03936779164815240594776923899190e-01 -6.99639024559189248719803799758665e-01
            4.78451200938704523935030010761693e-01 -6.50956323088185295766550098051084e-01
            5.47157873260371907520038803340867e-01 -5.94371893663693806608705472172005e-01
            6.09222790200355190926018167374423e-01 -5.30572594607629954843730502034305e-01
            6.63892567742367822880567018728470e-01 -4.60332862985713797687736814623349e-01
            7.10503588844694333737095348624280e-01 -3.84505313990571584437105912002153e-01
            7.48490058852113393506044758396456e-01 -3.04010391348286723722793567503686e-01
            7.77390873476571653277744644583436e-01 -2.19825194378422822394369973153516e-01
            7.96855215978609421334510898304870e-01 -1.32971617331903935177450648552622e-01
            8.06646815607348299792533907748293e-01 -4.45039449791035102155234426390962e-02
            7.63874552693419528459628509153845e-01 4.53320233262151858766308976100845e-02
            7.53151428407273892950968274817569e-01 1.35359707740166118616897961146606e-01
            7.31855708994581966031489628221607e-01 2.23487238569583801517381971279974e-01
            7.00286339675105007351874064625008e-01 3.08477498459553245435671442464809e-01
            6.58886485193177828811883500748081e-01 3.89137410462166488667179464755463e-01
            6.08237308756126027198263273021439e-01 4.64334686221614501011600850688410e-01
            5.49049813776762207773174395697424e-01 5.33013720820696201840860339871142e-01
            4.82154862944007389646827732576639e-01 5.94210411159940665726253428147174e-01
            4.08491514732012728217114272410981e-01 6.47065689851784697772529852954904e-01
            3.29093841077624182922534146200633e-01 6.90837584643594571076619104132988e-01
            2.45076411277101918750886966336111e-01 7.24911634081670031015676158858696e-01
            1.57618645876368423941471519356128e-01 7.48809513203137822046073779347353e-01
            6.79482601918631884396759801347798e-02 7.62195748169929854221038567629876e-01
            -2.26759701213123943119853720418178e-02 7.64882425586101200032373981230194e-01
            -1.12981879520324443588741303301504e-01 7.56831830389998350128166748618241e-01
            -2.01701770990205198064160185822402e-01 7.38156975291052175336403706751298e-01
            -2.87590211731118483573510502537829e-01 7.09120014319064795316194249608088e-01
            -3.69441516304845507523424430473824e-01 6.70128562756279522183433527970919e-01
            -4.46106671815443667217238044031546e-01 6.21729975112321753272226487752050e-01
            -5.16509467531637733728189232351724e-01 5.64603661466700379456540304090595e-01
            -5.79661602526403529900278499553679e-01 4.99551550040575831346245649910998e-01
            -6.34676559255602290576803170552012e-01 4.27486829882383900791609221414546e-01
            -6.80782048321027732917798402922926e-01 3.49421131695331343980370775170741e-01
            -7.17330849720680285841467593854759e-01 2.66450326759842870405492476493237e-01
            -7.43809898398869018265600061567966e-01 1.79739143302966308812784745896352e-01
            -7.59847486554943385428373403556179e-01 9.05048162671766437403775285019947e-02
            -7.65218481606018352536580096057151e-01 9.37122364147208154164489114785470e-17
            -7.59847486554943385428373403556179e-01 -9.05048162671767963960434144610190e-02
            -7.43809898398869240310204986599274e-01 -1.79739143302965809212423664575908e-01
            -7.17330849720680285841467593854759e-01 -2.66450326759842703872038782719756e-01
            -6.80782048321027843940100865438581e-01 -3.49421131695331177446917081397260e-01
            -6.34676559255602401599105633067666e-01 -4.27486829882383789769306758898892e-01
            -5.79661602526403862967185887100641e-01 -4.99551550040575442768187031106208e-01
            -5.16509467531638066795096619898686e-01 -5.64603661466700046389632916543633e-01
            -4.46106671815443833750691737805028e-01 -6.21729975112321753272226487752050e-01
            -3.69441516304845340989970736700343e-01 -6.70128562756279522183433527970919e-01
            -2.87590211731118650106964196311310e-01 -7.09120014319064795316194249608088e-01
            -2.01701770990205253575311417080229e-01 -7.38156975291052175336403706751298e-01
            -1.12981879520324804411224306477379e-01 -7.56831830389998239105864286102587e-01
            -2.26759701213125781926738255833698e-02 -7.64882425586101200032373981230194e-01
            6.79482601918626610837392831854231e-02 -7.62195748169929965243341030145530e-01
            1.57618645876368757008378906903090e-01 -7.48809513203137711023771316831699e-01
            2.45076411277102085284340660109592e-01 -7.24911634081670031015676158858696e-01
            3.29093841077623849855626758653671e-01 -6.90837584643594682098921566648642e-01
            4.08491514732012728217114272410981e-01 -6.47065689851784697772529852954904e-01
            4.82154862944006945557617882514023e-01 -5.94210411159940998793160815694137e-01
            5.49049813776761985728569470666116e-01 -5.33013720820696312863162802386796e-01
            6.08237308756126027198263273021439e-01 -4.64334686221614501011600850688410e-01
            6.58886485193177495744976113201119e-01 -3.89137410462166766222935621044599e-01
            7.00286339675105007351874064625008e-01 -3.08477498459553300946822673722636e-01
            7.31855708994581966031489628221607e-01 -2.23487238569583634983928277506493e-01
            7.53151428407273892950968274817569e-01 -1.35359707740166368417078501806827e-01
            7.63874552693419528459628509153845e-01 -4.53320233262151650599491858883994e-02
            7.18319208178554768906565186625812e-01 4.61176232875152997126022569318593e-02
            7.06524426639269287342415282182628e-01 1.37595619763155430081980057366309e-01
            6.83128533547489036337196921522263e-01 2.26814299966320770396421835357614e-01
            6.48515688820966773597831434017280e-01 3.12308695634658961548524302997976e-01
            6.03254234413188150654150376794860e-01 3.92674991154915942193071032306761e-01
            5.48087362154208501685559440375073e-01 4.66593574176495162753042222902877e-01
            4.83920910561349670864217387133976e-01 5.32850703609772158308999223663704e-01
            4.11808490995789255872949752301793e-01 5.90358439221229436277837976376759e-01
            3.32934187393138125710123631506576e-01 6.38172505582014104597021741938079e-01
            2.48593113637954304939725602707767e-01 6.75507797044373248240844986867160e-01
            1.60170147829562597996400086231006e-01 7.01751269154684997886306518921629e-01
            6.91171926219523585777082530512416e-02 7.16472004826437691704654753266368e-01
            -2.30706649776625596914847449170338e-02 7.19428289986878133355219233635580e-01
            -1.14879702896167057435405922660721e-01 7.10571582515402533353210401401157e-01
            -2.04802419269137309099093613440346e-01 6.90047309303835731952858623117208e-01
            -2.91362285579776836286214347637724e-01 6.58192478350887566485027946328046e-01
            -3.73137991216341724509675259469077e-01 6.15530145100131043101043815113371e-01
            -4.48786781353090691304430492891697e-01 5.62760823884079774970246035081800e-01
            -5.17066504947402250103039023088058e-01 5.00750985498214618019119370728731e-01
            -5.76856010825552489862388938490767e-01 4.30518829774477029825874296875554e-01
            -6.27173556953992350493365393049316e-01 3.53217566768178059533056512009352e-01
            -6.67192930616396617793384393735323e-01 2.70116481080772297129755088462844e-01
            -6.96257014803623897059026148781413e-01 1.82580090241793113747803545265924e-01
            -7.13888578056839695484825369931059e-01 9.20457393687430791562320564480615e-02
            -7.19798110594877194046148360939696e-01 8.81498452172328956094399440072557e-17
            -7.13888578056839695484825369931059e-01 -9.20457393687429265005661704890372e-02
            -6.96257014803623897059026148781413e-01 -1.82580090241792974969925467121357e-01
            -6.67192930616396728815686856250977e-01 -2.70116481080772130596301394689362e-01
            -6.27173556953992572537970318080625e-01 -3.53217566768177615443846661946736e-01
            -5.76856010825552600884691401006421e-01 -4.30518829774476974314723065617727e-01
            -5.17066504947402250103039023088058e-01 -5.00750985498214506996816908213077e-01
            -4.48786781353090857837884186665178e-01 -5.62760823884079663947943572566146e-01
            -3.73137991216342113087733878273866e-01 -6.15530145100130821056438890082063e-01
            -2.91362285579777169353121735184686e-01 -6.58192478350887455462725483812392e-01
            -2.04802419269137309099093613440346e-01 -6.90047309303835731952858623117208e-01
            -1.14879702896166752124074150742672e-01 -7.10571582515402533353210401401157e-01
            -2.30706649776625735692725527314906e-02 -7.19428289986878133355219233635580e-01
            6.91171926219518589773471717307984e-02 -7.16472004826437691704654753266368e-01
            1.60170147829562431462946392457525e-01 -7.01751269154684997886306518921629e-01
            2.48593113637954304939725602707767e-01 -6.75507797044373248240844986867160e-01
            3.32934187393137959176669937733095e-01 -6.38172505582014215619324204453733e-01
            4.11808490995789255872949752301793e-01 -5.90358439221229436277837976376759e-01
            4.83920910561349448819612462102668e-01 -5.32850703609772380353604148695013e-01
            5.48087362154207946574047127796803e-01 -4.66593574176495828886856997996802e-01
            6.03254234413188261676452839310514e-01 -3.92674991154915720148466107275453e-01
            6.48515688820966662575528971501626e-01 -3.12308695634659128081977996771457e-01
            6.83128533547488925314894459006609e-01 -2.26814299966321297752358532306971e-01
            7.06524426639269287342415282182628e-01 -1.37595619763155707637736213655444e-01
            7.18319208178554768906565186625812e-01 -4.61176232875159450297353203040984e-02
            6.70134261180083345976754571893252e-01 4.68603524584429859123346773230878e-02
            6.57090860052637171229150681028841e-01 1.39668973917586231037191168979916e-01
            6.31257932764041518325370816455688e-01 2.29759097670526768464327460606000e-01
            5.93138287859449664374267285893438e-01 3.15377221934410534309733975533163e-01
            5.43473880866476077855509174696635e-01 3.94856887309613879821768023248296e-01
            4.83231372974813500054125370297697e-01 4.66651112516387800432937638106523e-01
            4.13583316075735896166776228710660e-01 5.29362504625803365065905836672755e-01
            3.35885330373293433670056629125611e-01 5.81770457723601919219902356417151e-01
            2.51649718779035136417832063671085e-01 6.22854910615898038628301947028376e-01
            1.62516031656055687237838469627604e-01 6.51816201160015484816767639131285e-01
            7.02191548361368877984034497785615e-02 6.68090630778492733377049717091722e-01
            -2.34444579595622440426616606146126e-02 6.71361436210695772253131963225314e-01
            -1.16651751048754456774325660717295e-01 6.61564954949372396875162394280778e-01
            -2.07588550493182644185452545571025e-01 6.38891864358942296320265086251311e-01
            -2.94484874930737550169368432761985e-01 6.03783470357489693292052379547385e-01
            -3.75649386249345795807386139131268e-01 5.56923117899046693501929894409841e-01
            -4.49502309559454471532546904199990e-01 4.99222890441356037527498301642481e-01
            -5.14606181715286825628652422892628e-01 4.31805857278845739433137396190432e-01
            -5.69693829899887260737045835412573e-01 3.55984214276285182432246756434324e-01
            -6.13693035702612910142761393217370e-01 2.73233743468879075599886618874734e-01
            -6.45747404630868881980632068007253e-01 1.85165088643627906428434926056070e-01
            -6.65233034854771032584608292381745e-01 9.34924059900947984624863806857320e-02
            -6.71770660746586756317810795735568e-01 8.22681789444409984756734627474676e-17
            -6.65233034854771032584608292381745e-01 -9.34924059900946458068204947267077e-02
            -6.45747404630869104025236993038561e-01 -1.85165088643627462339225075993454e-01
            -6.13693035702613132187366318248678e-01 -2.73233743468878687021828000069945e-01
            -5.69693829899887260737045835412573e-01 -3.55984214276285071409944293918670e-01
            -5.14606181715287047673257347923936e-01 -4.31805857278845572899683702416951e-01
            -4.49502309559454582554849366715644e-01 -4.99222890441355870994044607869000e-01
            -3.75649386249346184385444757936057e-01 -5.56923117899046471457324969378533e-01
            -2.94484874930737716702822126535466e-01 -6.03783470357489582269749917031731e-01
            -2.07588550493182810718906239344506e-01 -6.38891864358942296320265086251311e-01
            -1.16651751048754484529901276346209e-01 -6.61564954949372396875162394280778e-01
            -2.34444579595628581347721564043241e-02 -6.71361436210695661230829500709660e-01
            7.02191548361365686092838700460561e-02 -6.68090630778492844399352179607376e-01
            1.62516031656055381926506697709556e-01 -6.51816201160015484816767639131285e-01
            2.51649718779035136417832063671085e-01 -6.22854910615898038628301947028376e-01
            3.35885330373293433670056629125611e-01 -5.81770457723601919219902356417151e-01
            4.13583316075736062700229922484141e-01 -5.29362504625803254043603374157101e-01
            4.83231372974813278009520445266389e-01 -4.66651112516388077988693794395658e-01
            5.43473880866476077855509174696635e-01 -3.94856887309614046355221717021777e-01
            5.93138287859449664374267285893438e-01 -3.15377221934410534309733975533163e-01
            6.31257932764041518325370816455688e-01 -2.29759097670526712953176229348173e-01
            6.57090860052637060206848218513187e-01 -1.39668973917586591859674172155792e-01
            6.70134261180083456999057034408906e-01 -4.68603524584426181509577702399838e-02
            6.19446953390332732958256656274898e-01 4.75577453339363215301105469734466e-02
            6.04927641821754957796031249017688e-01 1.41558522759257260359433416851971e-01
            5.76229339041768984230884598218836e-01 2.32241288390541450459281236362585e-01
            5.34024708943984238729285607405473e-01 3.17480515060539647542725560924737e-01
            4.79302992286907036945109439329826e-01 3.95278267541525396566726158198435e-01
            4.13346819729003001064882028003922e-01 4.63811032453661786778553732801811e-01
            3.37702148053169670660622614377644e-01 5.21472459873086324755320219992427e-01
            2.54142024250038234267634607022046e-01 5.66911014812647273686252447078004e-01
            1.64625026799276957811812849286071e-01 5.99061656056494640232301662763348e-01
            7.12493582500432348636465462732303e-02 6.17170799823492544078362698201090e-01
            -2.37963348684158901291674226285977e-02 6.20813983132341151716104832303245e-01
            -1.18284262066397374835169387097267e-01 6.09905812854099949049668794032186e-01
            -2.09999706414634279560971208411502e-01 5.84701967254754428893193107796833e-01
            -2.96792935632009424740118674890255e-01 5.45793203113364655543193748599151e-01
            -3.76629589988198010264142112646368e-01 4.94091508883864993784129637788283e-01
            -4.47638365971500862272591803048272e-01 4.30808728458671352790076980454614e-01
            -5.08154878057117231904271648090798e-01 3.57428156574952693436131312409998e-01
            -5.56760670493177456386035828472814e-01 2.75669771643174632558270786830690e-01
            -5.92316464701339695508863769646268e-01 1.87449920910944173302326021257613e-01
            -6.13988863001058038371127167920349e-01 9.48364029077470443995778737189539e-02
            -6.21269882744860391099450680485461e-01 3.51982868662820593504228819732979e-16
            -6.13988863001058038371127167920349e-01 -9.48364029077468917439119877599296e-02
            -5.92316464701339695508863769646268e-01 -1.87449920910944284324628483773267e-01
            -5.56760670493177567408338290988468e-01 -2.75669771643174521535968324315036e-01
            -5.08154878057117453948876573122106e-01 -3.57428156574952360369223924863036e-01
            -4.47638365971500973294894265563926e-01 -4.30808728458671241767774517938960e-01
            -3.76629589988197954752990881388541e-01 -4.94091508883865049295280869046110e-01
            -2.96792935632009313717816212374601e-01 -5.45793203113364655543193748599151e-01
            -2.09999706414634279560971208411502e-01 -5.84701967254754428893193107796833e-01
            -1.18284262066397805046591429345426e-01 -6.09905812854099838027366331516532e-01
            -2.37963348684160427848333085876220e-02 -6.20813983132341151716104832303245e-01
            7.12493582500432348636465462732303e-02 -6.17170799823492544078362698201090e-01
            1.64625026799276680256056692996935e-01 -5.99061656056494751254604125279002e-01
            2.54142024250038123245332144506392e-01 -5.66911014812647384708554909593659e-01
            3.37702148053169837194076308151125e-01 -5.21472459873086213733017757476773e-01
            4.13346819729002779020277102972614e-01 -4.63811032453661953312007426575292e-01
            4.79302992286906592855899589267210e-01 -3.95278267541525840655936008261051e-01
            5.34024708943984016684680682374164e-01 -3.17480515060539980609632948471699e-01
            5.76229339041768984230884598218836e-01 -2.32241288390541589237159314507153e-01
            6.04927641821754957796031249017688e-01 -1.41558522759257204848282185594144e-01
            6.19446953390332732958256656274898e-01 -4.75577453339365852080788954481250e-02
            5.66363084113650883111290568194818e-01 4.82046025701205541058591563796654e-02
            5.50069849358372775505188201350393e-01 1.43227049060318273321357196437020e-01
            5.17952106546707868872658764303196e-01 2.34129114121882420107567668310367e-01
            4.70933824662720879050681332955719e-01 3.18295710847965096501610560153495e-01
            4.10367634070243569865965582721401e-01 3.93305519492493704802882348303683e-01
            3.37995913800035963081569434507401e-01 4.57000644430780089688681755433208e-01
            2.55900666477412497279431136121275e-01 5.07548692887771824011622356920270e-01
            1.66443622897404580607272350789572e-01 5.43495489541961362967015247704694e-01
            7.21982993297796138421063005807810e-02 5.63806910501775671029633940634085e-01
            -2.41240378584501764802627832295912e-02 5.67898633167111754893596753390739e-01
            -1.19752370400017765783573508997506e-01 5.55652946126668711990248539223103e-01
            -2.11935645277768675009966159450414e-01 5.27422135500933864094008640677202e-01
            -2.98021917511136213985167842110968e-01 4.84018350311902101346106519486057e-01
            -3.75534641784847744716557826905046e-01 4.26690238434388968702393185594701e-01
            -4.42243918148610581919655260207946e-01 3.57087025270079905236997319661896e-01
            -4.96230642178712488821190618182300e-01 2.77211068535461402362329863535706e-01
            -5.35941714118189138638115309731802e-01 1.89360254075999240308547655331495e-01
            -5.60234718729107905588193716539536e-01 9.60618898741175120115087793237763e-02
            -5.68410790498975027063011111749802e-01 6.96102455185386516026303754940955e-17
            -5.60234718729107905588193716539536e-01 -9.60618898741173593558428933647519e-02
            -5.35941714118189138638115309731802e-01 -1.89360254075999101530669577186927e-01
            -4.96230642178712655354644311955781e-01 -2.77211068535461069295422475988744e-01
            -4.42243918148610526408504028950119e-01 -3.57087025270080016259299782177550e-01
            -3.75534641784847911250011520678527e-01 -4.26690238434388913191241954336874e-01
            -2.98021917511136547052075229657930e-01 -4.84018350311901934812652825712576e-01
            -2.11935645277768813787844237594982e-01 -5.27422135500933864094008640677202e-01
            -1.19752370400017654761271046481852e-01 -5.55652946126668711990248539223103e-01
            -2.41240378584504401582311317042695e-02 -5.67898633167111643871294290875085e-01
            7.21982993297792113862598739615350e-02 -5.63806910501775671029633940634085e-01
            1.66443622897404330807091810129350e-01 -5.43495489541961473989317710220348e-01
            2.55900666477412497279431136121275e-01 -5.07548692887771824011622356920270e-01
            3.37995913800036129615023128280882e-01 -4.57000644430780034177530524175381e-01
            4.10367634070243458843663120205747e-01 -3.93305519492493815825184810819337e-01
            4.70933824662720601494925176666584e-01 -3.18295710847965429568517947700457e-01
            5.17952106546707757850356301787542e-01 -2.34129114121882586641021362083848e-01
            5.50069849358372775505188201350393e-01 -1.43227049060318217810205965179193e-01
            5.66363084113650883111290568194818e-01 -4.82046025701207969671457931326586e-02
            5.10969436048759551027842462644912e-01 4.87916652783331045162285022342985e-02
            4.92501669312077172691033410956152e-01 1.44611537926396443998200425085088e-01
            4.56233609045873178544638903986197e-01 2.35204772812112827828912031691289e-01
            4.03476077443677361156204597136821e-01 3.17297094388341194282077140087495e-01
            3.36135869156000965940478408811032e-01 3.87921472263859146156761426027515e-01
            2.56646834763561981773705156228971e-01 4.44525357412223598441158856076072e-01
            1.67881915075962034888945595412224e-01 4.85062937944188532490841225808254e-01
            7.30493055654538037124723359738709e-02 5.08069080079692647622380263783270e-01
            -2.44234961762993946221556029740896e-02 5.12712281900040367510484884405741e-01
            -1.21013569131442302873047367484105e-01 4.98824725993699980008955208177213e-01
            -2.13229896400396218281159121943347e-01 4.66908344814800368993701340514235e-01
            -2.97739539648363304991107725072652e-01 4.18116679536467306110836261723307e-01
            -3.71488100180634772673471388770849e-01 3.54213188067303452744027936205384e-01
            -4.31810112869573714533544261939824e-01 2.77507509087927706215026546487934e-01
            -4.76525383009130998335223239337211e-01 1.90771985691351508851454354953603e-01
            -5.04017784231962973073848388594342e-01 9.71414656803295112341700701108493e-02
            -5.13293669527123852525107849942287e-01 6.28603449408991566534676591896760e-17
            -5.04017784231963084096150851109996e-01 -9.71414656803291642894748747494305e-02
            -4.76525383009131053846374470595038e-01 -1.90771985691351397829151892437949e-01
            -4.31810112869573881066997955713305e-01 -2.77507509087927428659270390198799e-01
            -3.71488100180634828184622620028676e-01 -3.54213188067303397232876704947557e-01
            -2.97739539648363416013410187588306e-01 -4.18116679536467250599685030465480e-01
            -2.13229896400396135014432275056606e-01 -4.66908344814800424504852571772062e-01
            -1.21013569131442316750835175298562e-01 -4.98824725993699980008955208177213e-01
            -2.44234961762996374834422397270828e-02 -5.12712281900040367510484884405741e-01
            7.30493055654535539122917953136493e-02 -5.08069080079692758644682726298925e-01
            1.67881915075962034888945595412224e-01 -4.85062937944188588001992457066081e-01
            2.56646834763561981773705156228971e-01 -4.44525357412223598441158856076072e-01
            3.36135869156000688384722252521897e-01 -3.87921472263859368201366351058823e-01
            4.03476077443677194622750903363340e-01 -3.17297094388341416326682065118803e-01
            4.56233609045873067522336441470543e-01 -2.35204772812112938851214494206943e-01
            4.92501669312077172691033410956152e-01 -1.44611537926396499509351656342915e-01
            5.10969436048759440005540000129258e-01 -4.87916652783335069720749288535444e-02
            4.53333845430529847053691128166975e-01 4.93030268420677902918569657231274e-02
            4.32136458662579381329038596959435e-01 1.45603725787446930395319100171037e-01
            3.90732851372744494078403931780485e-01 2.35096156341923184784903355648567e-01
            3.31059010221093463766095510436571e-01 3.13595751916461940034253075282322e-01
            2.55905217697166620371973522196640e-01 3.77431958668031919401641971489880e-01
            1.68785581611941820634470445838815e-01 4.23619866517777610148698386183241e-01
            7.37737193222427478644931397866458e-02 4.49999780228817591876122605754063e-01
            -2.46877200893641651768817268930434e-02 4.55338204355191844552308566562715e-01
            -1.21994789148022864111453600344248e-01 4.39385520117983208177037113273400e-01
            -2.13597517453589486047249579314666e-01 4.02887657301988721947338945028605e-01
            -2.95212663239616313060054153538658e-01 3.47551215408023139730175898876041e-01
            -3.63023992997867805954115283384454e-01 2.75963664957010634815048888413003e-01
            -4.13860724315728512046064224705333e-01 1.91472360244192313372124658599205e-01
            -4.45345788137743558987580172470189e-01 9.80280207725997415613150565150136e-02
            -4.56006977872730812073598372080596e-01 5.58447485840697711411361240748256e-17
            -4.45345788137743558987580172470189e-01 -9.80280207725996305390125939993595e-02
            -4.13860724315728456534912993447506e-01 -1.91472360244192396638851505485945e-01
            -3.63023992997868027998720208415762e-01 -2.75963664957010412770443963381695e-01
            -2.95212663239616202037751691023004e-01 -3.47551215408023195241327130133868e-01
            -2.13597517453589791358581351232715e-01 -4.02887657301988610925036482512951e-01
            -1.21994789148023058400482909746643e-01 -4.39385520117983152665885882015573e-01
            -2.46877200893644808965543546719346e-02 -4.55338204355191789041157335304888e-01
            7.37737193222426507199784850854485e-02 -4.49999780228817647387273837011890e-01
            1.68785581611941626345441136436420e-01 -4.23619866517777721171000848698895e-01
            2.55905217697166620371973522196640e-01 -3.77431958668031974912793202747707e-01
            3.31059010221093463766095510436571e-01 -3.13595751916461940034253075282322e-01
            3.90732851372744494078403931780485e-01 -2.35096156341923184784903355648567e-01
            4.32136458662579381329038596959435e-01 -1.45603725787446874884167868913210e-01
            4.53333845430529791542539896909148e-01 -4.93030268420681164198704493628611e-02
            3.93501962491766388296809964231215e-01 4.97108583389086269854750810281985e-02
            3.68776786989423843721169760101475e-01 1.46009058963543963960418636816030e-01
            3.20880009694385626151102997027920e-01 2.33132973429743622917342804612417e-01
            2.52821161276123806960214324135450e-01 3.05608285772252519230107736802893e-01
            1.68876629483693252442577659167000e-01 3.58881105571037195556272081375937e-01
            7.43209579760046729068889703739842e-02 3.89604105634413833136875382479047e-01
            -2.49045726546798448786113056030445e-02 3.95846846877110192242099628856522e-01
            -1.22565257392859422447273232137377e-01 3.77217074907651384041429309945670e-01
            -2.12524716245560713057116686286463e-01 3.34885366814386908895784245032701e-01
            -2.89130465565321237431106737858499e-01 2.71511579501948929760146711487323e-01
            -3.47569084386142923559503969954676e-01 1.91077721099663533355084155118675e-01
            -3.84168659365307141317913419698016e-01 9.86377467459854662124030255654361e-02
            -3.96629504603052129851903373491950e-01 4.85731053259528161723912424292981e-17
            -3.84168659365307196829064650955843e-01 -9.86377467459852025344346770907578e-02
            -3.47569084386142923559503969954676e-01 -1.91077721099663588866235386376502e-01
            -2.89130465565321459475711662889807e-01 -2.71511579501948707715541786456015e-01
            -2.12524716245560491012511761255155e-01 -3.34885366814387019918086707548355e-01
            -1.22565257392859602858514733725315e-01 -3.77217074907651328530278078687843e-01
            -2.49045726546797685507783626235323e-02 -3.95846846877110192242099628856522e-01
            7.43209579760044786178596609715896e-02 -3.89604105634413888648026613736874e-01
            1.68876629483692919375670271620038e-01 -3.58881105571037362089725775149418e-01
            2.52821161276123640426760630361969e-01 -3.05608285772252685763561430576374e-01
            3.20880009694385570639951765770093e-01 -2.33132973429743706184069651499158e-01
            3.68776786989423843721169760101475e-01 -1.46009058963543936204843021187116e-01
            3.93501962491766332785658732973388e-01 -4.97108583389087796411409669872228e-02
            3.31487749153179689365344984253170e-01 4.99637390270647671619563823242061e-02
            3.02033607930892955550916667561978e-01 1.45451719606382340321815149764006e-01
            2.45742455191289399518694835933275e-01 2.28015676594314792291484650377242e-01
            1.67616006884937801535429002797173e-01 2.90319440086526936450894709196291e-01
            7.45961407961287792378612948596128e-02 3.26827047281173121984210183654795e-01
            -2.50519197621881933857324042946857e-02 3.34294637068013544833888772700448e-01
            -1.22474007311095797745359448072122e-01 3.12058681323509556904127748566680e-01
            -2.09013741842083933253348959624418e-01 2.62094942296444810558853077964159e-01
            -2.76981688168704720531820839823922e-01 1.88842917461631176756498007307528e-01
            -3.20338595987418095489829283906147e-01 9.88113706868584407150279957932071e-02
            -3.35232013769875547559706774336519e-01 4.10540812634999505023185327060777e-17
            -3.20338595987418151000980515163974e-01 -9.88113706868582186704230707618990e-02
            -2.76981688168704720531820839823922e-01 -1.88842917461631232267649238565355e-01
            -2.09013741842083988764500190882245e-01 -2.62094942296444755047701846706332e-01
            -1.22474007311095728356420408999838e-01 -3.12058681323509556904127748566680e-01
            -2.50519197621884223692312332332222e-02 -3.34294637068013544833888772700448e-01
            7.45961407961286959711344479728723e-02 -3.26827047281173121984210183654795e-01
            1.67616006884937551735248462136951e-01 -2.90319440086527102984348402969772e-01
            2.45742455191289455029846067191102e-01 -2.28015676594314709024757803490502e-01
            3.02033607930892900039765436304151e-01 -1.45451719606382395832966381021834e-01
            3.31487749153179689365344984253170e-01 -4.99637390270650447177125386133412e-02
            2.67249273124838759851940039879992e-01 4.99575472505906018061416773434757e-02
            2.31155777909985205020859666547040e-01 1.43125598171253892720855560583004e-01
            1.63843414010005350434084903099574e-01 2.16963743972571676543736884923419e-01
            7.44030891602759231195918232515396e-02 2.61499733912785581324556005711202e-01
            -2.50857851622982748474033343200063e-02 2.70718735768030405175466057698941e-01
            -1.21186685193569773644206577500881e-01 2.43375672253502484121412408057950e-01
            -2.00920651870845679010102458050824e-01 1.83163375609984024894316689824336e-01
            -2.53519171173197832569456977580558e-01 9.82138501470361524603447378467536e-02
            -2.71878521610386947315873840125278e-01 3.32955161247074903031909412610217e-17
            -2.53519171173197888080608208838385e-01 -9.82138501470359859268910440732725e-02
            -2.00920651870845623498951226792997e-01 -1.83163375609984052649892305453250e-01
            -1.21186685193570065077750541604473e-01 -2.43375672253502345343534329913382e-01
            -2.50857851622982817862972382272346e-02 -2.70718735768030405175466057698941e-01
            7.44030891602758676084405919937126e-02 -2.61499733912785581324556005711202e-01
            1.63843414010005294922933671841747e-01 -2.16963743972571732054888116181246e-01
            2.31155777909985121754132819660299e-01 -1.43125598171254031498733638727572e-01
            2.67249273124838759851940039879992e-01 -4.99575472505905254783087343639636e-02
            2.00623091984091561634784284251509e-01 4.94491509871067408399269993424241e-02
            1.54662759380892578242594481707783e-01 1.37019248397044823839507898810552e-01
            7.32710524918361166823999042208015e-02 1.93199887260167790792309006064897e-01
            -2.49061695111946687641868436458026e-02 2.05120760263027945846658894879511e-01
            -1.17377688231091334425393313267705e-01 1.70050939062763417641832575100125e-01
            -1.82959393131732622750362793340173e-01 9.60244970591934698944669435149990e-02
            -2.06627305965603080828429938264890e-01 -6.64564101529901478058414741937557e-17
            -1.82959393131732733772665255855827e-01 -9.60244970591932617276498262981477e-02
            -1.17377688231091376058756736711075e-01 -1.70050939062763389886256959471211e-01
            -2.49061695111948110115118737439843e-02 -2.05120760263027945846658894879511e-01
            7.32710524918361166823999042208015e-02 -1.93199887260167790792309006064897e-01
            1.54662759380892522731443250449956e-01 -1.37019248397044907106234745697293e-01
            2.00623091984091561634784284251509e-01 -4.94491509871067547177148071568809e-02
            1.31116923958698089469621095304319e-01 4.77226575295111796193303632662719e-02
            6.97658580361304597738936195128190e-02 1.20838010752215382903607121534151e-01
            -2.42294282226876329933151765771981e-02 1.37411915779060644915432476409478e-01
            -1.06887495736010432190177255051822e-01 8.96892582495494861127838248648914e-02
            -1.39531716072260891792211623396724e-01 1.70877069467431590785692454132687e-17
            -1.06887495736010501579116294124105e-01 -8.96892582495494028460569779781508e-02
            -2.42294282226876364627621285308123e-02 -1.37411915779060644915432476409478e-01
            6.97658580361303487515911569971649e-02 -1.20838010752215438414758352791978e-01
            1.31116923958698089469621095304319e-01 -4.77226575295111657415425554518151e-02
            5.71496326174437685452289770182688e-02 4.15216385564552217801725930712564e-02
            -2.18292172152938952767176061797727e-02 6.71834224529326701214060335587419e-02
            -7.06408308042997257203410299553070e-02 8.65100673335954062748158092676773e-18
            -2.18292172152939091545054139942295e-02 -6.71834224529326701214060335587419e-02
            5.71496326174437546674411692038120e-02 -4.15216385564552356579604008857132e-02
            -0.00000000000000000000000000000000e+00 0.00000000000000000000000000000000e+00
            ];
        
    case   43
        
        % DEGREE.             :          43
        % CARDIN.             :         990
        % LEBESGUE CONST.     : 9.81130e+02
        % ABS.DET.VAND.MATRIX : Inf
        % CONDITIONING VAND.  : 5.07726e+04
        % POINTS OUT DISK     : 0.00000e+00
        
        pts=[
            9.99348095389676949196200439473614e-01 3.61024132299364169940147917259310e-02
            9.94137957154359597211623622570187e-01 1.08119018423941767870211094759725e-01
            9.83744843932002788200463783141458e-01 1.79571941118871647447008399467450e-01
            9.68222940602563308942762887454592e-01 2.50088658861063017901926741615171e-01
            9.47653171182802456229410381638445e-01 3.19301530135980005109530566187459e-01
            9.22142776925933160825366030621808e-01 3.86849711080839153698462951069814e-01
            8.91824757215382235564504753710935e-01 4.52381036757426913119672917673597e-01
            8.56857176167589273951818995556096e-01 5.15553857177021734869981628435198e-01
            8.17422338558891792281713151169242e-01 5.76038818505239746947665935294935e-01
            7.73725839372836343699191274936311e-01 6.33520580160423785187617795600090e-01
            7.25995491923130842337741341907531e-01 6.87699458853423317705733097682241e-01
            6.74480140140514050628439690626692e-01 7.38292990997498566052570367901353e-01
            6.19448361215722997918931014282862e-01 7.85037405342672300889717007521540e-01
            5.61187065362382386801698430645047e-01 8.27688998156890565205401344428537e-01
            4.99999999999999888977697537484346e-01 8.66025403784438707610604524234077e-01
            4.36206166155567620634769809839781e-01 8.99846753957506573229352397902403e-01
            3.70138155339914343144869235402439e-01 9.28976719816791418615764541755198e-01
            3.02140415569572717835455932799960e-01 9.53263431208522749038536403531907e-01
            2.32567455574310494315071196069766e-01 9.72580268465123243259995433618315e-01
            1.61781996552764845143101979374478e-01 9.86826522541526141019119222619338e-01
            9.01530811120653946533209932567843e-02 9.95927920065504235225262164021842e-01
            1.80541492505604354856796334161118e-02 9.99837010564641248677730800409336e-01
            -5.41389085854174847978192985920032e-02 9.98533413851123818893995576218003e-01
            -1.26049711220289517576986781932646e-01 9.92023926274604339603513381007360e-01
            -1.97303349026399926779973270640767e-01 9.80342485289180221030846951180138e-01
            -2.67528338529220643948747238027863e-01 9.63549992519223019726837264897767e-01
            -3.36358559150175151497563774682931e-01 9.41733996246508109351225357386284e-01
            -4.03435161989808444005234377982561e-01 9.15008234974012180096281099395128e-01
            -4.68408440699790040717687134019798e-01 8.83512044446022937194129553972743e-01
            -5.30939654689886908478513305453816e-01 8.47409631216086478566751338803442e-01
            -5.90702795164550931161784319556318e-01 8.06889216550070509370584659336600e-01
            -6.47386284781827692214051239716355e-01 7.62162055127636461904216957918834e-01
            -7.00694602073342331927108261879766e-01 7.13461333658160112847212985798251e-01
            -7.50349822156402335160407801595284e-01 6.61040955153200382454770078766160e-01
            -7.96093065705643754270681711204816e-01 6.05174215193765130393899198679719e-01
            -8.37685848629964646683276896510506e-01 5.46152377093697127818927583575714e-01
            -8.74911325418149643518006541853538e-01 4.84283153387619513807749171974137e-01
            -9.07575419670956895501490180322435e-01 4.19889101560264821344503616273869e-01
            -9.35507835925600939042112713650567e-01 3.53305942381102466853803889534902e-01
            -9.58562947497441308897236922348384e-01 2.84880809611699870043111104678246e-01
            -9.76620555710086657441593160910998e-01 2.14970440211024266252692882517294e-01
            -9.89586516555637341063800249685301e-01 1.43939314474119145481623149862571e-01
            -9.97393231517949785391863315453520e-01 7.21577558006163688464340566497413e-02
            -1.00000000000000000000000000000000e+00 1.22464679914735320717376402945840e-16
            -9.97393231517949785391863315453520e-01 -7.21577558006161329240413238039764e-02
            -9.89586516555637341063800249685301e-01 -1.43939314474118895681442609202350e-01
            -9.76620555710086768463895623426652e-01 -2.14970440211023600118878107423370e-01
            -9.58562947497441197874934459832730e-01 -2.84880809611700036576564798451727e-01
            -9.35507835925601050064415176166221e-01 -3.53305942381102244809198964503594e-01
            -9.07575419670957006523792642838089e-01 -4.19889101560264599299898691242561e-01
            -8.74911325418149754540309004369192e-01 -4.84283153387619291763144246942829e-01
            -8.37685848629964979750184284057468e-01 -5.46152377093696572707415270997444e-01
            -7.96093065705643643248379248689162e-01 -6.05174215193765241416201661195373e-01
            -7.50349822156402446182710264110938e-01 -6.61040955153200160410165153734852e-01
            -7.00694602073342776016318111942383e-01 -7.13461333658159668758003135735635e-01
            -6.47386284781827470169446314685047e-01 -7.62162055127636572926519420434488e-01
            -5.90702795164551153206389244587626e-01 -8.06889216550070287325979734305292e-01
            -5.30939654689886353367000992875546e-01 -8.47409631216086811633658726350404e-01
            -4.68408440699789874184233440246317e-01 -8.83512044446023048216432016488397e-01
            -4.03435161989808444005234377982561e-01 -9.15008234974012180096281099395128e-01
            -3.36358559150175373542168699714239e-01 -9.41733996246507998328922894870630e-01
            -2.67528338529221310082562013121787e-01 -9.63549992519222797682232339866459e-01
            -1.97303349026400814958392970765999e-01 -9.80342485289180110008544488664484e-01
            -1.26049711220289517576986781932646e-01 -9.92023926274604339603513381007360e-01
            -5.41389085854179497037108603763045e-02 -9.98533413851123818893995576218003e-01
            1.80541492505606367136028467257347e-02 -9.99837010564641248677730800409336e-01
            9.01530811120651587309282604110194e-02 -9.95927920065504235225262164021842e-01
            1.61781996552764373298316513682948e-01 -9.86826522541526029996816760103684e-01
            2.32567455574310688604100505472161e-01 -9.72580268465123132237692971102661e-01
            3.02140415569572717835455932799960e-01 -9.53263431208522749038536403531907e-01
            3.70138155339914121100264310371131e-01 -9.28976719816791529638067004270852e-01
            4.36206166155567787168223503613262e-01 -8.99846753957506462207049935386749e-01
            5.00000000000000111022302462515654e-01 -8.66025403784438596588302061718423e-01
            5.61187065362382275779395968129393e-01 -8.27688998156890676227703806944191e-01
            6.19448361215722664852023626735900e-01 -7.85037405342672633956624395068502e-01
            6.74480140140513495516927378048422e-01 -7.38292990997499121164082680479623e-01
            7.25995491923130842337741341907531e-01 -6.87699458853423317705733097682241e-01
            7.73725839372836010632283887389349e-01 -6.33520580160424118254525183147052e-01
            8.17422338558891459214805763622280e-01 -5.76038818505240191036875785357552e-01
            8.56857176167589273951818995556096e-01 -5.15553857177021734869981628435198e-01
            8.91824757215382124542202291195281e-01 -4.52381036757427135164277842704905e-01
            9.22142776925932938780761105590500e-01 -3.86849711080839708809975263648084e-01
            9.47653171182802234184805456607137e-01 -3.19301530135980726754496572539210e-01
            9.68222940602563308942762887454592e-01 -2.50088658861063184435380435388652e-01
            9.83744843932002677178161320625804e-01 -1.79571941118872091536218249530066e-01
            9.94137957154359597211623622570187e-01 -1.08119018423941601336757400986244e-01
            9.99348095389676949196200439473614e-01 -3.61024132299365280163172542415850e-02
            9.89339216501007312487558920111042e-01 3.74648909748184141821347736822645e-02
            9.83672371062760397819602076197043e-01 1.12180077421745932886310015419440e-01
            9.72371139363751524342660559341311e-01 1.86252706544151408474263575953955e-01
            9.55500253835720569917100419843337e-01 2.59258497030387502491066697984934e-01
            9.33156349383156835664010486652842e-01 3.30779278323902581337989659004961e-01
            9.05467409867315775606755323678954e-01 4.00405385866319574184046814480098e-01
            8.72592035026253376450711130019045e-01 4.67738007618927476016779110068455e-01
            8.34718532029887994028172215621453e-01 5.32391468421922420262148989422712e-01
            7.92063836873584725672969852894312e-01 5.93995439106797751271926699700998e-01
            7.44872271788419304527906206203625e-01 6.52197057708282734722615714417771e-01
            6.93414145785564595136918342177523e-01 7.06662950625726371534085501480149e-01
            6.37984206350752591774266875290778e-01 7.57081142156890707362038028804818e-01
            5.78899951157369030418919919611653e-01 8.03162841466522059441501824039733e-01
            5.16499809468533022105418694991386e-01 8.44644096754100903723383453325368e-01
            4.51141203644924382309966404136503e-01 8.81287307145854015288932714611292e-01
            3.83198501861871043683294146831031e-01 9.12882583651040802052989420189988e-01
            3.13060873762342595227892161346972e-01 9.39248951387085972974944070301717e-01
            2.41130061328478501048167004228162e-01 9.60235386187317074835334551607957e-01
            1.67818077739895016309290554090694e-01 9.75721679653715812108316640660632e-01
            9.35448473995061785535298781724123e-02 9.85619127699734254299812619137811e-01
            1.87358006445692490404830721217877e-02 9.89871038639270950376669588877121e-01
            -5.61805630797591465386275899618340e-02 9.88453057911514165745359150605509e-01
            -1.30775129626439140517746295699908e-01 9.81373307581661191711930314340862e-01
            -2.04620628073523658230215005460195e-01 9.68672339818464456229207826254424e-01
            -2.77294078093304474652569524550927e-01 9.50422904615080388346370909857797e-01
            -3.48379212745325794742257130565122e-01 9.26729533083697987194682355038822e-01
            -4.17468862815720986869649777872837e-01 8.97727938710793815779709348134929e-01
            -4.84167289045597304397716698076692e-01 8.63584240002571501548800370073877e-01
            -5.48092448889673344858408654545201e-01 8.24494008973202241463695827405900e-01
            -6.08878184821379897506687939312542e-01 7.80681150926038069925994022923987e-01
            -6.66176321650014391373417765862541e-01 7.32396621944311321250609125854680e-01
            -7.19658660836701713492402632255107e-01 6.79916991437416018406736384349642e-01
            -7.69018860385903502141502485756064e-01 6.23542857976376985185140711109852e-01
            -8.13974189544627968473378132330254e-01 5.63597127492456273500920360675082e-01
            -8.54267148258577191377582948916825e-01 5.00423163701222084576158977142768e-01
            -8.89666942109139435856945965497289e-01 4.34382821346281033925151859875768e-01
            -9.19970804282919552008479513460770e-01 3.65854373528074927612863120884867e-01
            -9.45005157001682971618095052690478e-01 2.95230344989817039547119748021942e-01
            -9.64626605760150246382522709609475e-01 2.22915263771312072149655136854562e-01
            -9.78722760676737468799046837375499e-01 1.49323344108976213684414346971607e-01
            -9.87212880252620328391799375822302e-01 7.48761138542022031128198022997822e-02
            -9.90048333851727635490647116967011e-01 -3.18423829988315891113433536140874e-16
            -9.87212880252620328391799375822302e-01 -7.48761138542019671904270694540173e-02
            -9.78722760676737579821349299891153e-01 -1.49323344108975519795023956248770e-01
            -9.64626605760150357404825172125129e-01 -2.22915263771311850105050211823254e-01
            -9.45005157001683082640397515206132e-01 -2.95230344989816817502514822990634e-01
            -9.19970804282919774053084438492078e-01 -3.65854373528074316990199577048770e-01
            -8.89666942109139324834643502981635e-01 -4.34382821346281200458605553649249e-01
            -8.54267148258577302399885411432479e-01 -5.00423163701221862531554052111460e-01
            -8.13974189544628079495680594845908e-01 -5.63597127492456051456315435643774e-01
            -7.69018860385903835208409873303026e-01 -6.23542857976376430073628398531582e-01
            -7.19658660836701713492402632255107e-01 -6.79916991437415796362131459318334e-01
            -6.66176321650014280351115303346887e-01 -7.32396621944311543295214050885988e-01
            -6.08878184821379786484385476796888e-01 -7.80681150926038180948296485439641e-01
            -5.48092448889673899969920967123471e-01 -8.24494008973201797374485977343284e-01
            -4.84167289045597137864263004303211e-01 -8.63584240002571612571102832589531e-01
            -4.17468862815721597492313321708934e-01 -8.97727938710793482712801960587967e-01
            -3.48379212745325628208803436791641e-01 -9.26729533083698098216984817554476e-01
            -2.77294078093305140786384299644851e-01 -9.50422904615080277324068447342142e-01
            -2.04620628073524130075000471151725e-01 -9.68672339818464345206905363738770e-01
            -1.30775129626438751939687676895119e-01 -9.81373307581661302734232776856516e-01
            -5.61805630797596114445191517461353e-02 -9.88453057911514165745359150605509e-01
            1.87358006445685655594335372597925e-02 -9.89871038639270950376669588877121e-01
            9.35448473995057205865322202953394e-02 -9.85619127699734254299812619137811e-01
            1.67818077739894794264685629059386e-01 -9.75721679653715812108316640660632e-01
            2.41130061328478084714532769794459e-01 -9.60235386187317185857637014123611e-01
            3.13060873762342373183287236315664e-01 -9.39248951387086083997246532817371e-01
            3.83198501861870821638689221799723e-01 -9.12882583651040913075291882705642e-01
            4.51141203644924160265361479105195e-01 -8.81287307145854126311235177126946e-01
            5.16499809468532800060813769960077e-01 -8.44644096754101014745685915841023e-01
            5.78899951157368919396617457095999e-01 -8.03162841466522170463804286555387e-01
            6.37984206350752369729661950259469e-01 -7.57081142156890929406642953836126e-01
            6.93414145785564484114615879661869e-01 -7.06662950625726371534085501480149e-01
            7.44872271788419193505603743687971e-01 -6.52197057708282845744918176933425e-01
            7.92063836873584725672969852894312e-01 -5.93995439106797751271926699700998e-01
            8.34718532029887883005869753105799e-01 -5.32391468421922531284451451938367e-01
            8.72592035026253376450711130019045e-01 -4.67738007618927476016779110068455e-01
            9.05467409867315775606755323678954e-01 -4.00405385866319574184046814480098e-01
            9.33156349383156502597103099105880e-01 -3.30779278323903358494106896614539e-01
            9.55500253835720680939402882358991e-01 -2.59258497030387446979915466727107e-01
            9.72371139363751302298055634310003e-01 -1.86252706544152185630380813563534e-01
            9.83672371062760286797299613681389e-01 -1.12180077421746640653488213956734e-01
            9.89339216501007312487558920111042e-01 -3.74648909748191080715251644051023e-02
            9.71033616965075063731660520716105e-01 3.86354579526761582330962596643076e-02
            9.64894429794337593619957260671072e-01 1.15662108053369752647121515565232e-01
            9.52654869370793799809860047389520e-01 1.91957505067150646649309919666848e-01
            9.34392318136219923729868241935037e-01 2.67039284929222298092810206071590e-01
            9.10222237819525825663902196538402e-01 3.40432756453170448640577205878799e-01
            8.80297439450529184412630456790794e-01 4.11673902481479947468301361368503e-01
            8.44807117239424143484427531802794e-01 4.80312313551404912459474871866405e-01
            8.03975652430070075737944534921553e-01 5.45914035528609731251492576120654e-01
            7.58061194689523265566322152153589e-01 6.08064313204929041134505496302154e-01
            7.07354030002725231440763309365138e-01 6.66370212514329707254034929064801e-01
            6.52174745391042698372530139749870e-01 7.20463104788592101357380670378916e-01
            5.92872202057898478599895497609396e-01 7.70000997346437010548925172770396e-01
            5.29821329775920668581079553405289e-01 8.14670695681368184359882889111759e-01
            4.63420756460203808746456388689694e-01 8.54189783578182204593076676246710e-01
            3.94090287914282244585706393991131e-01 8.88308408639210900226146350178169e-01
            3.22268253682677308091797385714017e-01 9.16810861931623644061062350374414e-01
            2.48408735790384638253414095743210e-01 9.39516941768753888197807100368664e-01
            1.72978697890113358726082992689044e-01 9.56283093003180817426311932649696e-01
            9.64550329677242024306593748406158e-02 9.67003314628592347546032215177547e-01
            1.93215482712276662158323858875519e-02 9.71609829952276626841012330260128e-01
            -5.79340934744102253883824005242786e-02 9.70073515101194550069862998498138e-01
            -1.34823457228027993037855480906728e-01 9.62404083152482936469596097595058e-01
            -2.10860423675859415260092077915033e-01 9.48650022724253250139270221552579e-01
            -2.85564262634353194236780382198049e-01 9.28898291414936072563079960673349e-01
            -3.58462672381173019786615441262256e-01 9.03273766029345615002910108159995e-01
            -4.29094765698754376792578568711178e-01 8.71938453067313878896982259902870e-01
            -4.97013983751685928247354695486138e-01 8.35090464466436199764132197742583e-01
            -5.61790919375444564032306971057551e-01 7.92962765074616715565980484825559e-01
            -6.23016031926746927105398299318040e-01 7.45821699771292423442048402648652e-01
            -6.80302236531358239801647869171575e-01 6.93965309549347098005966927303234e-01
            -7.33287351359293460006938403239474e-01 6.37721447203997704455957773461705e-01
            -7.81636387454960335219311673427001e-01 5.77445704541862947500874270190252e-01
            -8.25043666645193796149726495059440e-01 5.13519164215069601198138116160408e-01
            -8.63234754135085324833198683336377e-01 4.46345990394030611714271117307362e-01
            -8.95968193573115634364967263536528e-01 3.76350873511430872309091455463204e-01
            -9.23037033615952795528869501140434e-01 3.03976345232571831811441143145203e-01
            -9.44270136341474497498893470037729e-01 2.29679980627704061202365437566186e-01
            -9.59533259237815072673072336328914e-01 1.53931505235104876261331696696288e-01
            -9.68729903927747160174988039216259e-01 7.72098253049885718812817003708915e-02
            -9.71801926262491622132699831126956e-01 1.19011411840259258311730355394010e-16
            -9.68729903927747160174988039216259e-01 -7.72098253049883220811011597106699e-02
            -9.59533259237815183695374798844568e-01 -1.53931505235104654216726771664980e-01
            -9.44270136341474497498893470037729e-01 -2.29679980627703811402184896905965e-01
            -9.23037033615952795528869501140434e-01 -3.03976345232571609766836218113895e-01
            -8.95968193573115745387269726052182e-01 -3.76350873511430650264486530431896e-01
            -8.63234754135085435855501145852031e-01 -4.46345990394030389669666192276054e-01
            -8.25043666645194129216633882606402e-01 -5.13519164215069046086625803582137e-01
            -7.81636387454960446241614135942655e-01 -5.77445704541862725456269345158944e-01
            -7.33287351359293571029240865755128e-01 -6.37721447203997593433655310946051e-01
            -6.80302236531358128779345406655921e-01 -6.93965309549347209028269389818888e-01
            -6.23016031926747149150003224349348e-01 -7.45821699771292312419745940132998e-01
            -5.61790919375444786076911896088859e-01 -7.92962765074616715565980484825559e-01
            -4.97013983751686150291959620517446e-01 -8.35090464466436088741829735226929e-01
            -4.29094765698754598837183493742486e-01 -8.71938453067313767874679797387216e-01
            -3.58462672381173630409278985098354e-01 -9.03273766029345281936002720613033e-01
            -2.85564262634353471792536538487184e-01 -9.28898291414935961540777498157695e-01
            -2.10860423675859443015667693543946e-01 -9.48650022724253250139270221552579e-01
            -1.34823457228027798748826171504334e-01 -9.62404083152482936469596097595058e-01
            -5.79340934744108915221971756182029e-02 -9.70073515101194439047560535982484e-01
            1.93215482712274302934396530417871e-02 -9.71609829952276626841012330260128e-01
            9.64550329677243828419008764285536e-02 -9.67003314628592347546032215177547e-01
            1.72978697890112914636873142626428e-01 -9.56283093003180928448614395165350e-01
            2.48408735790384416208809170711902e-01 -9.39516941768753888197807100368664e-01
            3.22268253682677308091797385714017e-01 -9.16810861931623644061062350374414e-01
            3.94090287914281856007647775186342e-01 -8.88308408639211011248448812693823e-01
            4.63420756460203364657246538627078e-01 -8.54189783578182426637681601278018e-01
            5.29821329775920557558777090889635e-01 -8.14670695681368184359882889111759e-01
            5.92872202057898034510685647546779e-01 -7.70000997346437454638135022833012e-01
            6.52174745391042365305622752202908e-01 -7.20463104788592323401985595410224e-01
            7.07354030002725120418460846849484e-01 -6.66370212514329818276337391580455e-01
            7.58061194689522821477112302090973e-01 -6.08064313204929596246017808880424e-01
            8.03975652430069853693339609890245e-01 -5.45914035528610286363004888698924e-01
            8.44807117239424143484427531802794e-01 -4.80312313551405023481777334382059e-01
            8.80297439450529184412630456790794e-01 -4.11673902481479947468301361368503e-01
            9.10222237819525603619297271507094e-01 -3.40432756453171003752089518457069e-01
            9.34392318136219923729868241935037e-01 -2.67039284929222631159717593618552e-01
            9.52654869370793799809860047389520e-01 -1.91957505067150674404885535295762e-01
            9.64894429794337482597654798155418e-01 -1.15662108053370363269785059401329e-01
            9.71033616965075063731660520716105e-01 -3.86354579526765259944731667474116e-02
            9.47310789828616162111529774847440e-01 3.97040858378470348788447097376775e-02
            9.40666085279831865051392014720477e-01 1.18833761878734955885761337412987e-01
            9.27423284010459259008030130644329e-01 1.97129904461983612717901337418880e-01
            9.07675274756463479342016853479436e-01 2.74043322403072442394744712146348e-01
            8.81560575613836272523826664837543e-01 3.49034523337359126049506130584632e-01
            8.49262362433677586714964036218589e-01 4.21577497871393258588312846768531e-01
            8.11007183975212209148253350576852e-01 4.91163409160873920544787551989430e-01
            7.67063372829018375043119704059791e-01 5.57304162035513694917199245537631e-01
            7.17739163256701950821536684088642e-01 6.19535826635962183495109911746113e-01
            6.63380529149017239554098068765597e-01 6.77421892548436654912791254901094e-01
            6.04368757267604528315985135122901e-01 7.30556330611642268380023779172916e-01
            5.41117772792312767826672370574670e-01 7.78566440919606250758988608140498e-01
            4.74071235933465839895717408580822e-01 8.21115467043735502983281548949890e-01
            4.03699429974259116349344367336016e-01 8.57904958137201911760882921953453e-01
            3.30495962571423107512202932412038e-01 8.88676862353197649646574518556008e-01
            2.54974303452169925865433697254048e-01 9.13215336893230533732435105775949e-01
            1.77664182792984237657663015852449e-01 9.31348261989271564154080351727316e-01
            9.91078755430449542807025409274502e-02 9.42948448200260802565253470675088e-01
            1.98563977550813390571260441674895e-02 9.47934528554650657206082087213872e-01
            -5.95343583963318587204405218926695e-02 9.46271529281248580112162471777992e-01
            -1.38507523798972270734353173793352e-01 9.37971115125094234699076878314372e-01
            -2.16509158439681659302777916309424e-01 9.23091507527653787334998014557641e-01
            -2.92992136895552368613948601705488e-01 9.01737076245240021243887440505205e-01
            -3.67419986025660672002146611703211e-01 8.74057607270161018853116274840431e-01
            -4.39270647944694392350584166706540e-01 8.40247252189606497196905365854036e-01
            -5.08040141883921436694038220593939e-01 8.00543166351759372112439905322390e-01
            -5.73246099254171137538094171759440e-01 7.55223845391426173989657399943098e-01
            -6.34431147114906779371779066423187e-01 7.04607171783256269748108024941757e-01
            -6.91166116316781486972331549623050e-01 6.49048185124581511473706996184774e-01
            -7.43053051814863585455839256610489e-01 5.88936591787735275183024441503221e-01
            -7.89728004037345443499873454129556e-01 5.24694031409855266012698393751634e-01
            -8.30863581730293399019160460738931e-01 4.56771119393776570127840841450961e-01
            -8.66171248372063051768066088698106e-01 3.85644286164747440714961612684419e-01
            -8.95403346049686077456897237425437e-01 3.11812435353309547192424133754685e-01
            -9.18354832601187109908380534761818e-01 2.35793444344793823308492619617027e-01
            -9.34864719839027635828188067534938e-01 1.58120531741555409022126355012006e-01
            -9.44817202766571773153714275395032e-01 7.93385172175957026352577372563246e-02
            -9.48142471866931901836039742192952e-01 1.16113964330749763117205511842830e-16
            -9.44817202766571773153714275395032e-01 -7.93385172175954667128650044105598e-02
            -9.34864719839027524805885605019284e-01 -1.58120531741555575555580048785487e-01
            -9.18354832601187109908380534761818e-01 -2.35793444344793601263887694585719e-01
            -8.95403346049685966434594774909783e-01 -3.11812435353309713725877827528166e-01
            -8.66171248372063162790368551213760e-01 -3.85644286164747218670356687653111e-01
            -8.30863581730293510041462923254585e-01 -4.56771119393776403594387147677480e-01
            -7.89728004037345332477570991613902e-01 -5.24694031409855488057303318782942e-01
            -7.43053051814863696478141719126143e-01 -5.88936591787735053138419516471913e-01
            -6.91166116316781931061541399685666e-01 -6.49048185124581067384497146122158e-01
            -6.34431147114906779371779066423187e-01 -7.04607171783256380770410487457411e-01
            -5.73246099254171692649606484337710e-01 -7.55223845391425729900447549880482e-01
            -5.08040141883921325671735758078285e-01 -8.00543166351759483134742367838044e-01
            -4.39270647944694947462096479284810e-01 -8.40247252189606164129997978307074e-01
            -3.67419986025660894046751536734519e-01 -8.74057607270160907830813812324777e-01
            -2.92992136895552590658553526736796e-01 -9.01737076245239910221584977989551e-01
            -2.16509158439681881347382841340732e-01 -9.23091507527653787334998014557641e-01
            -1.38507523798973325446226567692065e-01 -9.37971115125094123676774415798718e-01
            -5.95343583963318864760161375215830e-02 -9.46271529281248580112162471777992e-01
            1.98563977550806833316521249344078e-02 -9.47934528554650657206082087213872e-01
            9.91078755430451346919440425153880e-02 -9.42948448200260802565253470675088e-01
            1.77664182792983793568453165789833e-01 -9.31348261989271675176382814242970e-01
            2.54974303452169703820828772222740e-01 -9.13215336893230533732435105775949e-01
            3.30495962571422885467598007380730e-01 -8.88676862353197760668876981071662e-01
            4.03699429974259060838193136078189e-01 -8.57904958137201911760882921953453e-01
            4.74071235933465340295356327260379e-01 -8.21115467043735836050188936496852e-01
            5.41117772792312767826672370574670e-01 -7.78566440919606250758988608140498e-01
            6.04368757267604084226775285060285e-01 -7.30556330611642601446931166719878e-01
            6.63380529149017461598702993796906e-01 -6.77421892548436432868186329869786e-01
            7.17739163256701728776931759057334e-01 -6.19535826635962405539714836777421e-01
            7.67063372829018264020817241544137e-01 -5.57304162035513916961804170568939e-01
            8.11007183975212098125950888061197e-01 -4.91163409160874031567090014505084e-01
            8.49262362433677586714964036218589e-01 -4.21577497871393314099464078026358e-01
            8.81560575613835939456919277290581e-01 -3.49034523337359847694472136936383e-01
            9.07675274756463590364319315995090e-01 -2.74043322403072220350139787115040e-01
            9.27423284010459147985727668128675e-01 -1.97129904461984140073838034368237e-01
            9.40666085279831865051392014720477e-01 -1.18833761878734511796551487350371e-01
            9.47310789828616162111529774847440e-01 -3.97040858378473263123886738412693e-02
            9.19200109414562538390214285755064e-01 4.06991323811752986339129734005837e-02
            9.12006122260823781644489827158395e-01 1.21778871250720080454676974568429e-01
            8.97674450656792632941005649627186e-01 2.01905525338831937087746837278246e-01
            8.76317259364369105512082569475751e-01 2.80451994937538640062513195516658e-01
            8.48101697362566575577602634439245e-01 3.56803547424990818992540653198375e-01
            8.13248589680122035971976401924621e-01 4.30362628381713241410011505649891e-01
            7.72030709140240412047262452688301e-01 5.00553538264131736568174346757587e-01
            7.24770641543414417817814410227584e-01 5.66826938034063143589946776046418e-01
            6.71838260996156622084640730463434e-01 6.28664148481511753097095152043039e-01
            6.13647835144623954306553059723228e-01 6.85581209592737272906504131242400e-01
            5.50654782968599265657871910661925e-01 7.37132668193540951939723981922725e-01
            4.83352110510497257056528042085120e-01 7.82915064224320667030099230032647e-01
            4.12266552434638278157308377558365e-01 8.22570088362068907450463939312613e-01
            3.37954449614327578910177862780984e-01 8.55787386276638861737353636272019e-01
            2.60997395010206745258329874559422e-01 8.82306987574172141286510395730147e-01
            1.81997681916784670441700200171908e-01 9.01921340417910943898505138349719e-01
            1.01573590200786240123065340412722e-01 9.14476935902730603267229980701813e-01
            2.03545474229035634750051286800954e-02 9.19875509470457042304758488171501e-01
            -6.10237972862790953310074826276832e-02 9.18074809963266180723451270750957e-01
            -1.41924548042574150130690213700291e-01 9.09088930296280350873416864487808e-01
            -2.21714546782021737492129886959447e-01 8.92988197161399765988676335837226e-01
            -2.99769328581207639139449838694418e-01 8.69898620625585428101089746633079e-01
            -3.75478008941968421918744525100919e-01 8.40000907931235052394924878171878e-01
            -4.48248064790858380401772365075885e-01 8.03529049216999080584855619235896e-01
            -5.17509971775571120389258794602938e-01 7.60768486227690554635216813039733e-01
            -5.82721661565188342457588532852242e-01 7.12053878345613844302874895220157e-01
            -6.43372764269828811833917825424578e-01 6.57766483427153159091460565832676e-01
            -6.98988602777024459200561068428215e-01 5.98331173943115857127850176766515e-01
            -7.49133907743715354854430188424885e-01 5.34213111775585836049629051558441e-01
            -7.93416224169020578571576152171474e-01 4.65914107695504953188248009610106e-01
            -8.31488982886727900911694177921163e-01 3.93968694013012765697823169830372e-01
            -8.63054212938917486575007842475316e-01 3.18939941137371174573189591683331e-01
            -8.87864873602710158451145616709255e-01 2.41415050787575635737880475062411e-01
            -9.05726787818874834457005817967001e-01 1.62000760342743660435971264632826e-01
            -9.16500161890591580338139010564191e-01 8.13185942994809202177819429380179e-02
            -9.20100679558668810287258565949742e-01 1.12679835211482829849909849047354e-16
            -9.16500161890591580338139010564191e-01 -8.13185942994806981731770179067098e-02
            -9.05726787818874945479308280482655e-01 -1.62000760342743438391366339601518e-01
            -8.87864873602710269473448079224909e-01 -2.41415050787575413693275550031103e-01
            -8.63054212938917375552705379959662e-01 -3.18939941137371341106643285456812e-01
            -8.31488982886728122956299102952471e-01 -3.93968694013012210586310857252101e-01
            -7.93416224169020578571576152171474e-01 -4.65914107695505175232852934641414e-01
            -7.49133907743715465876732650940539e-01 -5.34213111775585614005024126527132e-01
            -6.98988602777024681245165993459523e-01 -5.98331173943115857127850176766515e-01
            -6.43372764269828811833917825424578e-01 -6.57766483427153381136065490863984e-01
            -5.82721661565188453479890995367896e-01 -7.12053878345613622258269970188849e-01
            -5.17509971775571675500771107181208e-01 -7.60768486227690110546006962977117e-01
            -4.48248064790857880801411283755442e-01 -8.03529049216999302629460544267204e-01
            -3.75478008941969032541408068937017e-01 -8.40000907931234719328017490624916e-01
            -2.99769328581207861184054763725726e-01 -8.69898620625585317078787284117425e-01
            -2.21714546782022348114793430795544e-01 -8.92988197161399543944071410805918e-01
            -1.41924548042574760753353757536388e-01 -9.09088930296280239851114401972154e-01
            -6.10237972862791230865830982565967e-02 -9.18074809963266180723451270750957e-01
            2.03545474229031332635830864319360e-02 -9.19875509470457042304758488171501e-01
            1.01573590200785809911643298164563e-01 -9.14476935902730603267229980701813e-01
            1.81997681916784642686124584542995e-01 -9.01921340417910943898505138349719e-01
            2.60997395010206745258329874559422e-01 -8.82306987574172141286510395730147e-01
            3.37954449614327911977085250327946e-01 -8.55787386276638750715051173756365e-01
            4.12266552434638444690762071331847e-01 -8.22570088362068796428161476796959e-01
            4.83352110510496590922713266991195e-01 -7.82915064224321111119309080095263e-01
            5.50654782968599154635569448146271e-01 -7.37132668193541062962026444438379e-01
            6.13647835144623510217343209660612e-01 -6.85581209592737494951109056273708e-01
            6.71838260996156289017733342916472e-01 -6.28664148481512086164002539590001e-01
            7.24770641543414306795511947711930e-01 -5.66826938034063254612249238562072e-01
            7.72030709140240190002657527656993e-01 -5.00553538264131958612779271788895e-01
            8.13248589680122146994278864440275e-01 -4.30362628381713130387709043134237e-01
            8.48101697362566575577602634439245e-01 -3.56803547424990818992540653198375e-01
            8.76317259364369105512082569475751e-01 -2.80451994937538862107118120547966e-01
            8.97674450656792743963308112142840e-01 -2.01905525338831576265263834102370e-01
            9.12006122260823892666792289674049e-01 -1.21778871250719955554586704238318e-01
            9.19200109414562538390214285755064e-01 -4.06991323811762284456960969691863e-02
            8.87296527925431566252711945708143e-01 4.16353575215346952131945101882593e-02
            8.79498934134207988044806825200794e-01 1.24540179545655424475647521376231e-01
            8.63972272086370174370983932021772e-01 2.06350537993936877789735717669828e-01
            8.40852990646274167652052256016759e-01 2.86347480494745565415826149546774e-01
            8.10344262890497324391958500200417e-01 3.63827991040998166560882509656949e-01
            7.72714200615535307115067098493455e-01 4.38111168120108918078159376818803e-01
            7.28293498161694530246279555285582e-01 5.08544208500965932984172468422912e-01
            6.77472526259339402621151293715229e-01 5.74508144092197081675976733095013e-01
            6.20697901436877086389642954600276e-01 6.35423281456014121815201178833377e-01
            5.58468561138647290320591309864540e-01 6.90754296174986626155600788479205e-01
            4.91331379044721350268787318782415e-01 7.40014937302271191832403474109014e-01
            4.19876359125339437827761912558344e-01 7.82772300552415534191652568551945e-01
            3.44731450664803984462736252680770e-01 8.18650632679784773237940953549696e-01
            2.66557029820592150670677256130148e-01 8.47334633611595000601823812758084e-01
            1.86040096213937716784769804689859e-01 8.68572227316289913190416882571299e-01
            1.03888235552459948229930830621015e-01 8.82176777056769223506194066430908e-01
            2.08234013415201889285466307910610e-02 8.88028725560745635370096806582296e-01
            -6.24244296691389213838085936458810e-02 8.86076645694352404980520532262744e-01
            -1.45123672547320309300644680661208e-01 8.76337692405644630433414477010956e-01
            -2.26547563373059535063447356151300e-01 8.58897451966299407821736622281605e-01
            -3.05980546066085712375581806554692e-01 8.33909189836382735983022485015681e-01
            -3.82724560718384620994214628808550e-01 8.01592503761974883857988061208744e-01
            -4.56105178169767755402830289312988e-01 7.62231393942283452780372954293853e-01
            -5.25477526915584580713414197816746e-01 7.16171767225679767321366853138898e-01
            -5.90231960260689803021705301944166e-01 6.63818397267878945733343698520912e-01
            -6.49799413916523405099212595814606e-01 6.05631367366498585269596333091613e-01
            -7.03656406958538815921144760068273e-01 5.42122027232496139781403599045007e-01
            -7.51329642195389335590505197615130e-01 4.73848499230524466963032637067954e-01
            -7.92400165521664590073669387493283e-01 4.01410773579522373033512394613354e-01
            -8.26507047701634078862298338208348e-01 3.25445435617095213398641817548196e-01
            -8.53350556228345658027478748408612e-01 2.46620071464682510953281280308147e-01
            -8.72694789383675950666940934752347e-01 1.65627401256717071698076892971585e-01
            -8.84369749351110789881147411506390e-01 8.31791914911749891148318170053244e-02
            -8.88272836162669165993577280460158e-01 1.08782048557615403380166530345377e-16
            -8.84369749351110789881147411506390e-01 -8.31791914911747670702268919740163e-02
            -8.72694789383676061689243397268001e-01 -1.65627401256716849653471967940277e-01
            -8.53350556228345769049781210924266e-01 -2.46620071464682316664251970905752e-01
            -8.26507047701634189884600800724002e-01 -3.25445435617094991354036892516888e-01
            -7.92400165521664923140576775040245e-01 -4.01410773579521817922000082035083e-01
            -7.51329642195389224568202735099476e-01 -4.73848499230524633496486330841435e-01
            -7.03656406958538926943447222583927e-01 -5.42122027232496028759101136529353e-01
            -6.49799413916523516121515058330260e-01 -6.05631367366498363224991408060305e-01
            -5.90231960260690025066310226975475e-01 -6.63818397267878945733343698520912e-01
            -5.25477526915584691735716660332400e-01 -7.16171767225679545276761928107589e-01
            -4.56105178169767977447435214344296e-01 -7.62231393942283341758070491778199e-01
            -3.82724560718384509971912166292896e-01 -8.01592503761974883857988061208744e-01
            -3.05980546066086322998245350390789e-01 -8.33909189836382513938417559984373e-01
            -2.26547563373059729352476665553695e-01 -8.58897451966299407821736622281605e-01
            -1.45123672547320337056220296290121e-01 -8.76337692405644630433414477010956e-01
            -6.24244296691387479114609959651716e-02 -8.86076645694352404980520532262744e-01
            2.08234013415199703533886577133671e-02 -8.88028725560745635370096806582296e-01
            1.03888235552459740063113713404164e-01 -8.82176777056769223506194066430908e-01
            1.86040096213937911073799114092253e-01 -8.68572227316289913190416882571299e-01
            2.66557029820591595559164943551878e-01 -8.47334633611595222646428737789392e-01
            3.44731450664803817929282558907289e-01 -8.18650632679784884260243416065350e-01
            4.19876359125339437827761912558344e-01 -7.82772300552415534191652568551945e-01
            4.91331379044720906179577468719799e-01 -7.40014937302271524899310861655977e-01
            5.58468561138647401342893772380194e-01 -6.90754296174986404110995863447897e-01
            6.20697901436876975367340492084622e-01 -6.35423281456014121815201178833377e-01
            6.77472526259339069554243906168267e-01 -5.74508144092197525765186583157629e-01
            7.28293498161694752290884480316890e-01 -5.08544208500965599917265080875950e-01
            7.72714200615535196092764635977801e-01 -4.38111168120109251145066764365765e-01
            8.10344262890496991325051112653455e-01 -3.63827991040998888205848516008700e-01
            8.40852990646274278674354718532413e-01 -2.86347480494745454393523687031120e-01
            8.63972272086370174370983932021772e-01 -2.06350537993937266367794336474617e-01
            8.79498934134207988044806825200794e-01 -1.24540179545655604886889022964169e-01
            8.87296527925431566252711945708143e-01 -4.16353575215346327631493750232039e-02
            8.52001126947360187813274023937993e-01 4.25216084658244022898010427979898e-02
            8.43533556969895070842824225110235e-01 1.27142226548890957538162638229551e-01
            8.26682571529619214523165737773525e-01 2.10499248063428567867561014281819e-01
            8.01615643290466750592315747780958e-01 2.91764233479883616784178457237431e-01
            7.68581898647077044195441430929350e-01 3.70129534863332720906470285626710e-01
            7.27909641794760142730069674144033e-01 4.44816322641510941693354652670678e-01
            6.80003091894906486203353779274039e-01 5.15082325963005738245215070492122e-01
            6.25338365763358106086400312051410e-01 5.80229209718457150657400234194938e-01
            5.64458746007587941484473503805930e-01 6.39609514908615284234372211358277e-01
            4.97969281640066763205965116867446e-01 6.92633093382758247003039286937565e-01
            4.26530774829346981391609006095678e-01 7.38772972996149634994367261242587e-01
            3.50853213551234777156651034601964e-01 7.77570594895964584125636065436993e-01
            2.71688715409308445547509336392977e-01 8.08640370885186920979492697370006e-01
            1.89824052752273542132854800001951e-01 8.31673515571341726015930362336803e-01
            1.06072833376886763168123195555381e-01 8.46441115214455974680163308221381e-01
            2.12674145281437874943630816915174e-02 8.52796402774648631961440514714923e-01
            -6.37493694409743266726664501220512e-02 8.50676216548911678927424873108976e-01
            -1.48132583535959816423144275177037e-01 8.40101627900490699474289613135625e-01
            -2.31043589464358045670877572774771e-01 8.21177731842210878454579869867302e-01
            -3.11658380399891576928439462790266e-01 7.94092602555022786248173360945657e-01
            -3.89175770332500392534313959913561e-01 7.59115424222296830691902869148180e-01
            -4.62825356614859462212052676477470e-01 7.16593815756472296563117652112851e-01
            -5.31875176570003382892082299804315e-01 6.66950376006131828710010722716106e-01
            -5.95638982065261002318834471225273e-01 6.10678483778782310587018855585484e-01
            -6.53483059754506712124566547572613e-01 5.48337394420607249223564849671675e-01
            -7.04832529206102509355957863590447e-01 4.80546681685579124554408281255746e-01
            -7.49177056322903878182728476531338e-01 4.07980080133137579245783399528591e-01
            -7.86075925271793263249264782643877e-01 3.31358789251450180923797006471432e-01
            -8.15162418515631537196952649537707e-01 2.51444305852884963936588746946654e-01
            -8.36147461416896442543134071456734e-01 1.69030855976571636745120486011729e-01
            -8.48822495191301373829162457695929e-01 8.49375015132065591672017035307363e-02
            -8.53061549658694184827822937222663e-01 1.04469909626520069431217601965716e-16
            -8.48822495191301373829162457695929e-01 -8.49375015132063510003845863138849e-02
            -8.36147461416896442543134071456734e-01 -1.69030855976571442456091176609334e-01
            -8.15162418515631648219255112053361e-01 -2.51444305852884408825076434368384e-01
            -7.86075925271793152226962320128223e-01 -3.31358789251450291946099468987086e-01
            -7.49177056322903989205030939046992e-01 -4.07980080133137412712329705755110e-01
            -7.04832529206102731400562788621755e-01 -4.80546681685579013532105818740092e-01
            -6.53483059754506934169171472603921e-01 -5.48337394420607027178959924640367e-01
            -5.95638982065261113341136933740927e-01 -6.10678483778782199564716393069830e-01
            -5.31875176570003604936687224835623e-01 -6.66950376006131606665405797684798e-01
            -4.62825356614859351189750213961815e-01 -7.16593815756472296563117652112851e-01
            -3.89175770332500947645826272491831e-01 -7.59115424222296497624995481601218e-01
            -3.11658380399892298573405469142017e-01 -7.94092602555022453181265973398695e-01
            -2.31043589464357712603970185227809e-01 -8.21177731842210989476882332382957e-01
            -1.48132583535959844178719890805951e-01 -8.40101627900490699474289613135625e-01
            -6.37493694409747152507250689268403e-02 -8.50676216548911678927424873108976e-01
            2.12674145281435758580990125210519e-02 -8.52796402774648631961440514714923e-01
            1.06072833376886180301035267348198e-01 -8.46441115214456085702465770737035e-01
            1.89824052752273347843825490599556e-01 -8.31673515571341726015930362336803e-01
            2.71688715409308612080963030166458e-01 -8.08640370885186809957190234854352e-01
            3.50853213551234444089743647055002e-01 -7.77570594895964806170240990468301e-01
            4.26530774829347203436213931126986e-01 -7.38772972996149523972064798726933e-01
            4.97969281640066374627906498062657e-01 -6.92633093382758469047644211968873e-01
            5.64458746007587386372961191227660e-01 -6.39609514908615728323582061420893e-01
            6.25338365763358328131005237082718e-01 -5.80229209718456928612795309163630e-01
            6.80003091894906375181051316758385e-01 -5.15082325963005849267517533007776e-01
            7.27909641794760253752372136659687e-01 -4.44816322641510830671052190155024e-01
            7.68581898647076933173138968413696e-01 -3.70129534863332887439923979400191e-01
            8.01615643290466417525408360233996e-01 -2.91764233479884282917993232331355e-01
            8.26682571529619103500863275257871e-01 -2.10499248063428845423317170570954e-01
            8.43533556969895070842824225110235e-01 -1.27142226548890902027011406971724e-01
            8.52001126947360187813274023937993e-01 -4.25216084658247769900718537883222e-02
            8.13607778463097730536901508457959e-01 4.33634346216792976314025054307422e-02
            8.04389277231937871448508303728886e-01 1.29598978823624977341211206294247e-01
            7.86056724072093371269431827386143e-01 2.14366114810374569499273889050528e-01
            7.58817834136181867954462632042123e-01 2.96704397059969260386225187176024e-01
            7.22981234931285299261105592449894e-01 3.75680899933812817437228659400716e-01
            6.78952969445973719686548975005280e-01 4.50400788096935345006244233445614e-01
            6.27231895520998006254842493945034e-01 5.20017455359896296762656220380450e-01
            5.68404033590620527682801821356406e-01 5.83742117065197296810197258309927e-01
            5.03135926836933422556796813296387e-01 6.40852747332634753441027442022460e-01
            4.32167088989268310950109253099072e-01 6.90702259901028292610192238498712e-01
            3.56301625338147853749859450545046e-01 7.32725839874123763273416898300638e-01
            2.76399121901040489834855407025316e-01 7.66447343299055061649482922803145e-01
            1.93364905969308858990629573781916e-01 7.91484692067588979647041469434043e-01
            1.08139788388249197259582956576196e-01 8.07554203013760796281417242425960e-01
            2.16894037942833330101510824761135e-02 8.14473802157499982001809257781133e-01
            -6.50067304113176036572951943526277e-02 8.12165087675576047310244121035794e-01
            -1.50966312385986983768404456895951e-01 8.00654218225584912715930840931833e-01
            -2.35215385718245101331902446872846e-01 7.80071616557904912170329225773457e-01
            -3.16799374743016448618959657324012e-01 7.50650491773821149088519177894341e-01
            -3.94793900265342057043227441681665e-01 7.12724196973222534623459978320170e-01
            -4.68315253146022958397054480883526e-01 6.66722452230778195314542244886979e-01
            -5.36530407079279014759265464817872e-01 6.13166475695784418675771121343132e-01
            -5.98666457113653849297918441152433e-01 5.52663077982265216192558909824584e-01
            -6.54019376973952515363919246738078e-01 4.85897786762245709191176956665004e-01
            -7.01961995960252660431422100373311e-01 4.13627079463306013273893313453300e-01
            -7.41951105042541469991590474819532e-01 3.36669812077051877619027209220803e-01
            -7.73533611636079365680984665232245e-01 2.55897941193533207115962113675778e-01
            -7.96351673321431974272854859009385e-01 1.72226644384662952447229145036545e-01
            -8.10146752342069453867168249416864e-01 8.66039508766395099703672144642042e-02
            -8.14762544940454302988541712693404e-01 9.97796342726478938978876642485748e-17
            -8.10146752342069564889470711932518e-01 -8.66039508766389548588549018859339e-02
            -7.96351673321431863250552396493731e-01 -1.72226644384663091225107223181112e-01
            -7.73533611636079476703287127747899e-01 -2.55897941193532985071357188644470e-01
            -7.41951105042541692036195399850840e-01 -3.36669812077051322507514896642533e-01
            -7.01961995960252771453724562888965e-01 -4.13627079463305846740439619679819e-01
            -6.54019376973952515363919246738078e-01 -4.85897786762245764702328187922831e-01
            -5.98666457113654293387128291215049e-01 -5.52663077982264883125651522277622e-01
            -5.36530407079279236803870389849180e-01 -6.13166475695784307653468658827478e-01
            -4.68315253146022791863600787110045e-01 -6.66722452230778195314542244886979e-01
            -3.94793900265341946020924979166011e-01 -7.12724196973222645645762440835824e-01
            -3.16799374743017003730471969902283e-01 -7.50650491773821038066216715378687e-01
            -2.35215385718245101331902446872846e-01 -7.80071616557904912170329225773457e-01
            -1.50966312385986817234950763122470e-01 -8.00654218225584912715930840931833e-01
            -6.50067304113183530578368163332925e-02 -8.12165087675576047310244121035794e-01
            2.16894037942833121934693707544284e-02 -8.14473802157499982001809257781133e-01
            1.08139788388248989092765839359345e-01 -8.07554203013760907303719704941614e-01
            1.93364905969308137345663567430165e-01 -7.91484692067589201691646394465351e-01
            2.76399121901040323301401713251835e-01 -7.66447343299055172671785385318799e-01
            3.56301625338147687216405756771564e-01 -7.32725839874123763273416898300638e-01
            4.32167088989268088905504328067764e-01 -6.90702259901028403632494701014366e-01
            5.03135926836933311534494350780733e-01 -6.40852747332634864463329904538114e-01
            5.68404033590620305638196896325098e-01 -5.83742117065197518854802183341235e-01
            6.27231895520998228299447418976342e-01 -5.20017455359895963695748832833488e-01
            6.78952969445973497641944049973972e-01 -4.50400788096935678073151620992576e-01
            7.22981234931285077216500667418586e-01 -3.75680899933813206015287278205506e-01
            7.58817834136181867954462632042123e-01 -2.96704397059968927319317799629061e-01
            7.86056724072093260247129364870489e-01 -2.14366114810375013588483739113144e-01
            8.04389277231937982470810766244540e-01 -1.29598978823624727541030665634025e-01
            8.13607778463097730536901508457959e-01 -4.33634346216791172201610038428043e-02
            7.72343383638438241156620733818272e-01 4.41641925578931116014302915573353e-02
            7.62274706485735142891257964947727e-01 1.31916829883259451028365560887323e-01
            7.42268612785071613124898703972576e-01 2.17949729590307061943832422912237e-01
            7.12585912563212797721234892378561e-01 3.01141321260991579045196431252407e-01
            6.73613565211390263876012340915622e-01 3.80407075272743311344925132289063e-01
            6.25859634877858783674753340164898e-01 4.54713641300671544964728809645749e-01
            5.69946667074739954372830652573612e-01 5.23092319619355539117577791330405e-01
            5.06603572845211513886454213206889e-01 5.84651689585199973997475808573654e-01
            4.36656126293332724763729402184254e-01 6.38589230667777285610497983725509e-01
            3.61016199355740363685640659241471e-01 6.84201784532237899938422742707189e-01
            2.80669874156425247502255615472677e-01 7.20894721783547964832905563525856e-01
            1.96664587918229105678591395189869e-01 7.48189693870020877675131032447098e-01
            1.10095478016793951736573831112764e-01 7.65730869088230070573786179011222e-01
            2.20911051900764682232036761888594e-02 7.73289571393435681834205297491280e-01
            -6.62012589767852349664778444093827e-02 7.70767261541544179692664329195395e-01
            -1.53630588491107056281492759808316e-01 7.58196821698850609294595415121876e-01
            -2.39057108336742846210754009916855e-01 7.35742126772714666316232978715561e-01
            -3.21367153184480225380781348576420e-01 7.03695908051528595805734767054673e-01
            -3.99487685722738794513730908875004e-01 6.62475937004698200993857426510658e-01
            -4.72400285339925174454833722847980e-01 6.12619578992640301251526580017526e-01
            -5.39154424794579645308090221078601e-01 5.54776787887514721830939379287884e-01
            -5.98879861791611789456624137528706e-01 4.89701632930524932696414452948375e-01
            -6.50797983921480804880843606952112e-01 4.18242468286158852741607461211970e-01
            -6.94231959063689618716352924820967e-01 3.41330873448262961389332303951960e-01
            -7.28615558928555229201151632878464e-01 2.59969508676674787572835612081690e-01
            -7.53500540708900157227390081970952e-01 1.75219043787362388497896859007597e-01
            -7.68562490610542825564266422588844e-01 8.81843306992900199947627015717444e-02
            -7.73605053082231708394544966722606e-01 9.47392952061373328004450070131827e-17
            -7.68562490610542825564266422588844e-01 -8.81843306992898257057333921693498e-02
            -7.53500540708900268249692544486606e-01 -1.75219043787362221964443165234115e-01
            -7.28615558928555229201151632878464e-01 -2.59969508676674621039381918308209e-01
            -6.94231959063689618716352924820967e-01 -3.41330873448263127922785997725441e-01
            -6.50797983921481026925448531983420e-01 -4.18242468286158408652397611149354e-01
            -5.98879861791611900478926600044360e-01 -4.89701632930524766162960759174894e-01
            -5.39154424794579867352695146109909e-01 -5.54776787887514499786334454256576e-01
            -4.72400285339925563032892341652769e-01 -6.12619578992639968184619192470564e-01
            -3.99487685722739183091789527679794e-01 -6.62475937004697978949252501479350e-01
            -3.21367153184480280891932579834247e-01 -7.03695908051528595805734767054673e-01
            -2.39057108336743012744207703690336e-01 -7.35742126772714666316232978715561e-01
            -1.53630588491107389348400147355278e-01 -7.58196821698850498272292952606222e-01
            -6.62012589767857623224145413587394e-02 -7.70767261541544179692664329195395e-01
            2.20911051900762774036213187400790e-02 -7.73289571393435681834205297491280e-01
            1.10095478016793757447544521710370e-01 -7.65730869088230181596088641526876e-01
            1.96664587918228606078230313869426e-01 -7.48189693870021099719735957478406e-01
            2.80669874156425414035709309246158e-01 -7.20894721783547853810603101010201e-01
            3.61016199355740197152186965467990e-01 -6.84201784532238010960725205222843e-01
            4.36656126293332447207973245895118e-01 -6.38589230667777396632800446241163e-01
            5.06603572845211624908756675722543e-01 -5.84651689585199862975173346058000e-01
            5.69946667074740065395133115089266e-01 -5.23092319619355539117577791330405e-01
            6.25859634877859005719358265196206e-01 -4.54713641300671211897821422098787e-01
            6.73613565211390041831407415884314e-01 -3.80407075272743699922983751093852e-01
            7.12585912563212575676629967347253e-01 -3.01141321260992134156708743830677e-01
            7.42268612785071613124898703972576e-01 -2.17949729590307145210559269798978e-01
            7.62274706485735142891257964947727e-01 -1.31916829883259700828546101547545e-01
            7.72343383638438241156620733818272e-01 -4.41641925578935487517462377127231e-02
            7.28389428611628697574076340970350e-01 4.49255221906289872735307255879889e-02
            7.17347787353176502556095783802448e-01 1.34095541450032745833809144642146e-01
            6.95431884862521054735395864554448e-01 2.21232808990522389347432863360154e-01
            6.62973943881579486081534469121834e-01 3.05016412659023683495718159974786e-01
            6.20465993709820029522461481974460e-01 3.84176278428225159711217884250800e-01
            5.68552411541627833457823726348579e-01 4.57512423424189795806427127899951e-01
            5.08020154364880793806946712720674e-01 5.23913146443528709994552627904341e-01
            4.39786829495193321015733545209514e-01 5.82371880210438619407398164184997e-01
            3.64886784584367851458353015914327e-01 6.32002449910565422541708358039614e-01
            2.84455427964351248437679942071554e-01 6.72052506697872087393363926821621e-01
            1.99712017014292170236089418722258e-01 7.01914932536243041383272611710709e-01
            1.11941175461517203326700098386937e-01 7.21137043490049367555627668480156e-01
            2.24734197952966355260606690080749e-02 7.29427451951172423072478068206692e-01
            -6.73350100068777213113691004764405e-02 7.26660483778118648778843180480180e-01
            -1.56122709694877764841081102531462e-01 7.12878083387899152967293048277497e-01
            -2.42543748246630636034026906600047e-01 6.88289177921424744077683044451987e-01
            -3.25288070810448082248456103116041e-01 6.53266510121016774625957168609602e-01
            -4.03101357801180559814469006596482e-01 6.08340987930387711024593500042101e-01
            -4.74804039106545894277644492831314e-01 5.54193636471391970488298284180928e-01
            -5.39309175167643095605285452620592e-01 4.91645274397376985664465109948651e-01
            -5.95638933874701681503438521758653e-01 4.21644071119094909771973789247568e-01
            -6.42939413505116630354052631446393e-01 3.45251173522947263361260183955892e-01
            -6.80493587003144995151160401292145e-01 2.63624620065859627260351771838032e-01
            -7.07732171379173102820914209587499e-01 1.78001786092714331388719983806368e-01
            -7.24242257459544402919959793507587e-01 8.96806264874336206416316485956486e-02
            -7.29773569168735813939008494344307e-01 8.93714865584831836642421245104292e-17
            -7.24242257459544402919959793507587e-01 -8.96806264874334402303901470077108e-02
            -7.07732171379173102820914209587499e-01 -1.78001786092714470166598061950936e-01
            -6.80493587003144995151160401292145e-01 -2.63624620065859460726898078064551e-01
            -6.42939413505116741376355093962047e-01 -3.45251173522947096827806490182411e-01
            -5.95638933874701792525740984274307e-01 -4.21644071119094743238520095474087e-01
            -5.39309175167643206627587915136246e-01 -4.91645274397376819131011416175170e-01
            -4.74804039106545783255342030315660e-01 -5.54193636471392081510600746696582e-01
            -4.03101357801180726347922700369963e-01 -6.08340987930387711024593500042101e-01
            -3.25288070810447971226153640600387e-01 -6.53266510121016885648259631125256e-01
            -2.42543748246630774811904984744615e-01 -6.88289177921424744077683044451987e-01
            -1.56122709694878097907988490078424e-01 -7.12878083387899041944990585761843e-01
            -6.73350100068777490669447161053540e-02 -7.26660483778118648778843180480180e-01
            2.24734197952964585842661193737513e-02 -7.29427451951172423072478068206692e-01
            1.11941175461517342104578176531504e-01 -7.21137043490049367555627668480156e-01
            1.99712017014292170236089418722258e-01 -7.01914932536243041383272611710709e-01
            2.84455427964351525993436098360689e-01 -6.72052506697871976371061464305967e-01
            3.64886784584367962480655478429981e-01 -6.32002449910565311519405895523960e-01
            4.39786829495193043459977388920379e-01 -5.82371880210438841452003089216305e-01
            5.08020154364880904829249175236328e-01 -5.23913146443528487949947702873033e-01
            5.68552411541627722435521263832925e-01 -4.57512423424189906828729590415605e-01
            6.20465993709819807477856556943152e-01 -3.84176278428225492778125271797762e-01
            6.62973943881579597103836931637488e-01 -3.05016412659023683495718159974786e-01
            6.95431884862520943713093402038794e-01 -2.21232808990522555880886557133636e-01
            7.17347787353176502556095783802448e-01 -1.34095541450032551544779835239751e-01
            7.28389428611628697574076340970350e-01 -4.49255221906290358457880529385875e-02
            6.81894608676611335695838533865754e-01 4.56474731983080653230366863226664e-02
            6.69726183230394012113606549974065e-01 1.36127839354291679807573700600187e-01
            6.45606478178322507055497680994449e-01 2.24179000992069582531840410410950e-01
            6.09965910228457364183896061149426e-01 3.08229683046244817834491414032527e-01
            5.63440486160204812016161213250598e-01 3.86779999104363170214782030598144e-01
            5.06860453268270449989074677432654e-01 4.58428216915475805759427885277546e-01
            4.41235483580016740745577408233657e-01 5.21895772335365659699846219155006e-01
            3.67736656234214975835783434376935e-01 5.76050085333990602443066109117353e-01
            2.87675559546070547245477655451396e-01 6.19924770912950617862691160553368e-01
            2.02480885682666034153243117543752e-01 6.52736884268678596576762629410950e-01
            1.13672935617392847906792496814887e-01 6.73900892461008038658576424495550e-01
            2.28364893230657388378812555629338e-02 6.83039123262362379840340054215631e-01
            -6.84074746642381048555847655734397e-02 6.79988504727602527388796715968056e-01
            -1.58430705645555308658245508013351e-01 6.64803475216751871279541319381678e-01
            -2.45626736931334771485424539605447e-01 6.37755011941171567890762617025757e-01
            -3.28439553277568851985535047788289e-01 5.99325795368804481455526911304332e-01
            -4.05391358014687397393061019101879e-01 5.50201595779789331963627319055377e-01
            -4.75108944364134311300063018279616e-01 4.91259035679566025134334950053017e-01
            -5.36348200345863279636660081450827e-01 4.23549946449498171396896850637859e-01
            -5.88016309986095442319253834284609e-01 3.48282598390954822864529205617146e-01
            -6.29191254644261066530930293083657e-01 2.66800139113156697945328232890461e-01
            -6.59138266457482191462702303397236e-01 1.80556625032271655939553056668956e-01
            -6.77322940290494002191223898989847e-01 9.10910737002198905853944665977906e-02
            -6.83420770207943784058102210110519e-01 -2.19804883966169261574402989864057e-16
            -6.77322940290494113213526361505501e-01 -9.10910737002194187406090009062609e-02
            -6.59138266457482191462702303397236e-01 -1.80556625032271489406099362895475e-01
            -6.29191254644261066530930293083657e-01 -2.66800139113156586923025770374807e-01
            -5.88016309986095553341556296800263e-01 -3.48282598390954656331075511843665e-01
            -5.36348200345863390658962543966481e-01 -4.23549946449498004863443156864378e-01
            -4.75108944364134366811214249537443e-01 -4.91259035679565858600881256279536e-01
            -4.05391358014687286370758556586225e-01 -5.50201595779789331963627319055377e-01
            -3.28439553277568740963232585272635e-01 -5.99325795368804481455526911304332e-01
            -2.45626736931335076796756311523495e-01 -6.37755011941171567890762617025757e-01
            -1.58430705645555752747455358075968e-01 -6.64803475216751871279541319381678e-01
            -6.84074746642384240447043453059450e-02 -6.79988504727602527388796715968056e-01
            2.28364893230654196487616758304284e-02 -6.83039123262362379840340054215631e-01
            1.13672935617392681373338803041406e-01 -6.73900892461008038658576424495550e-01
            2.02480885682665728841911345625704e-01 -6.52736884268678596576762629410950e-01
            2.87675559546070380712023961677914e-01 -6.19924770912950728884993623069022e-01
            3.67736656234214864813480971861281e-01 -5.76050085333990713465368571633007e-01
            4.41235483580016685234426176975830e-01 -5.21895772335365770722148681670660e-01
            5.06860453268270338966772214917000e-01 -4.58428216915475805759427885277546e-01
            5.63440486160204812016161213250598e-01 -3.86779999104363170214782030598144e-01
            6.09965910228457031116988673602464e-01 -3.08229683046245428457154957868624e-01
            6.45606478178322507055497680994449e-01 -2.24179000992069527020689179153123e-01
            6.69726183230394012113606549974065e-01 -1.36127839354291596540846853713447e-01
            6.81894608676611335695838533865754e-01 -4.56474731983085579845038637358812e-02
            6.32982605338346049350661814969499e-01 4.63283553619935895007131421152735e-02
            6.19491680058449012413746004312998e-01 1.37997657624424230338178176680231e-01
            5.92797365148722943395398488064529e-01 2.26725779399253979384809554176172e-01
            5.53468603586127927407289917027811e-01 3.10621634816200475892600252336706e-01
            5.02343619642732885921532215434127e-01 3.87897129372859472695722615753766e-01
            4.40512053590638830158354721788783e-01 4.56905270064622559544886826188304e-01
            3.69291737911359163604174682404846e-01 5.16175268181143565016100183129311e-01
            2.90200609984431201482379947265144e-01 5.64443886614189094252935774420621e-01
            2.04924359887538015678742908676213e-01 6.00682363563431298558725757175125e-01
            1.15280502839114507018791755399434e-01 6.24118338808136940976112327916780e-01
            2.31796420169456778015426579031555e-02 6.34252315224338558685701627837261e-01
            -6.94152526314736201262789450083801e-02 6.30868304698830262289277470699744e-01
            -1.60530681685359472021801252594742e-01 6.14038431540812612574598006176529e-01
            -2.48224677964500012317117239035724e-01 5.84121395277460986328321723703993e-01
            -3.30628196188156697754578772219247e-01 5.41754825596259204090188177360687e-01
            -4.05984948430278436148910259362310e-01 4.87841692375233226819375431659864e-01
            -4.72688836347466723175614333740668e-01 4.23531060447690621550975720310817e-01
            -5.29318182376735890670715889427811e-01 3.50193599280249678873389029831742e-01
            -5.74666030324524124139884406758938e-01 2.69392369532844511148539368150523e-01
            -6.07765869542500114519611997820903e-01 1.82849509134468818372099008229270e-01
            -6.27912234424026216572656267089769e-01 9.24095289031074684782396388982306e-02
            -6.34675740178768377219853391579818e-01 7.77253613706405893061256178828542e-17
            -6.27912234424026216572656267089769e-01 -9.24095289031073158225737529392063e-02
            -6.07765869542500225541914460336557e-01 -1.82849509134468679594220930084703e-01
            -5.74666030324524124139884406758938e-01 -2.69392369532844400126236905634869e-01
            -5.29318182376736112715320814459119e-01 -3.50193599280249345806481642284780e-01
            -4.72688836347466778686765564998495e-01 -4.23531060447690510528673257795162e-01
            -4.05984948430278325126607796846656e-01 -4.87841692375233282330526662917691e-01
            -3.30628196188157086332637391024036e-01 -5.41754825596259093067885714845033e-01
            -2.48224677964500012317117239035724e-01 -5.84121395277460986328321723703993e-01
            -1.60530681685359499777376868223655e-01 -6.14038431540812612574598006176529e-01
            -6.94152526314738976820351012975152e-02 -6.30868304698830262289277470699744e-01
            2.31796420169453759596578379387211e-02 -6.34252315224338558685701627837261e-01
            1.15280502839114062929581905336818e-01 -6.24118338808136940976112327916780e-01
            2.04924359887537987923167293047300e-01 -6.00682363563431298558725757175125e-01
            2.90200609984431090460077484749490e-01 -5.64443886614189094252935774420621e-01
            3.69291737911358997070720988631365e-01 -5.16175268181143676038402645644965e-01
            4.40512053590638552602598565499648e-01 -4.56905270064622837100642982477439e-01
            5.02343619642732885921532215434127e-01 -3.87897129372859361673420153238112e-01
            5.53468603586127927407289917027811e-01 -3.10621634816200531403751483594533e-01
            5.92797365148722832373096025548875e-01 -2.26725779399254118162687632320740e-01
            6.19491680058449012413746004312998e-01 -1.37997657624423952782422020391095e-01
            6.32982605338346049350661814969499e-01 -4.63283553619939572620900491983775e-02
            5.81756896407631729495335548563162e-01 4.69642719438288780420265311477124e-02
            5.66689698373508243811613738216693e-01 1.39676465857338200082793377987400e-01
            5.36945534819910030854828164592618e-01 2.28771112673813420412827213112905e-01
            4.93294763958985471585805271388381e-01 3.11940707839971909098863989129313e-01
            4.36867917827337526315290006095893e-01 3.87031202527988116290913467310020e-01
            3.69126422100117923541517939156620e-01 4.52097792368663820017360421843478e-01
            2.91824745933691231947193500673166e-01 5.05455286863032426936115371063352e-01
            2.06964962136066604747597352798039e-01 5.45721754931091540541387985285837e-01
            1.16744894532809020959440715614619e-01 5.71854316200881007681289247557288e-01
            2.35011954844226642058480081232119e-02 5.83176151062315684114878422406036e-01
            -7.03511721824005009651159525674302e-02 5.79394029939570676113191893819021e-01
            -1.62381481443469283254543711336737e-01 5.60605907783068291294625851151068e-01
            -2.50206195630219341285993550627609e-01 5.27298387087715481058580735407304e-01
            -3.31550700777412388209341997935553e-01 4.80334115143886741794432282404159e-01
            -4.04308216930038766268040717477561e-01 4.20929441925730118967408088792581e-01
            -4.66594362637509474378560980767361e-01 3.50622917265757394478242758850683e-01
            -5.16795959443407948441517874016427e-01 2.71235443222343775016014433276723e-01
            -5.53612812360146477885791682638228e-01 1.84823113672892863634800164618355e-01
            -5.76091384236184334000085982552264e-01 9.36239625624276650128763321845327e-02
            -5.83649491867382574916689463861985e-01 7.14764482039369261177373075661231e-17
            -5.76091384236184445022388445067918e-01 -9.36239625624275123572104462255083e-02
            -5.53612812360146588908094145153882e-01 -1.84823113672892724856922086473787e-01
            -5.16795959443408059463820336532081e-01 -2.71235443222343663993711970761069e-01
            -4.66594362637509585400863443283015e-01 -3.50622917265757283455940296335029e-01
            -4.04308216930038877290343179993215e-01 -4.20929441925729952433954395019100e-01
            -3.31550700777412554742795691709034e-01 -4.80334115143886630772129819888505e-01
            -2.50206195630219230263691088111955e-01 -5.27298387087715592080883197922958e-01
            -1.62381481443469283254543711336737e-01 -5.60605907783068291294625851151068e-01
            -7.03511721824007646430843010421086e-02 -5.79394029939570676113191893819021e-01
            2.35011954844223935889857557413052e-02 -5.83176151062315684114878422406036e-01
            1.16744894532808868303774829655595e-01 -5.71854316200881007681289247557288e-01
            2.06964962136066465969719274653471e-01 -5.45721754931091651563690447801491e-01
            2.91824745933690898880286113126203e-01 -5.05455286863032648980720296094660e-01
            3.69126422100117534963459320351831e-01 -4.52097792368664097573116578132613e-01
            4.36867917827337304270685081064585e-01 -3.87031202527988282824367161083501e-01
            4.93294763958985305052351577614900e-01 -3.11940707839972131143468914160621e-01
            5.36945534819910030854828164592618e-01 -2.28771112673813503679554059999646e-01
            5.66689698373508243811613738216693e-01 -1.39676465857338227838368993616314e-01
            5.81756896407631729495335548563162e-01 -4.69642719438288155919813959826570e-02
            5.28303440618477004875330749200657e-01 4.75481702628891000905753116967389e-02
            5.11323333347480257771167089231312e-01 1.41116273473653269787675412771932e-01
            4.77908873424455538092558981588809e-01 2.30148783544117607746670728374738e-01
            4.29134029084837886891534708411200e-01 3.11784122344424152739605915485299e-01
            3.66566463957778310156498946525971e-01 3.83398462915750581903040483666700e-01
            2.92217151067224567562163883849280e-01 4.42690061427658598791623489887570e-01
            2.08475738504297430919720568454068e-01 4.87753237118685956108521395435673e-01
            1.18033744171433169212193092789676e-01 5.17139622444018454139325058349641e-01
            2.37980481824108594524069815179246e-02 5.29904714800101483973548965877853e-01
            -7.12025366562934053371591858194734e-02 5.25638233615457806102710947016021e-01
            -1.63914613381222096233358342942665e-01 5.04477307105833938649652736785356e-01
            -2.51358339562685162427158047648845e-01 4.67102064860517585120902595008374e-01
            -3.30723201892272888891000093281036e-01 4.14713777917725179289476500343881e-01
            -3.99458348393085971306248893597513e-01 3.48996248925023955234081540766056e-01
            -4.55354574901121522678693054331234e-01 2.72061693336802357112702566155349e-01
            -4.96615330704842705689117110523512e-01 1.86382851071628996564299995952751e-01
            -5.21914461163255127829074808687437e-01 9.47135106166928503190760579855123e-02
            -5.30438831407231470294050268421415e-01 6.49600217026328523613646007674765e-17
            -5.21914461163255127829074808687437e-01 -9.47135106166927254189857876554015e-02
            -4.96615330704842705689117110523512e-01 -1.86382851071628885541997533437097e-01
            -4.55354574901121689212146748104715e-01 -2.72061693336802024045795178608387e-01
            -3.99458348393086082328551356113167e-01 -3.48996248925023844211779078250402e-01
            -3.30723201892272999913302555796690e-01 -4.14713777917725068267174037828227e-01
            -2.51358339562685273449460510164499e-01 -4.67102064860517529609751363750547e-01
            -1.63914613381222207255660805458319e-01 -5.04477307105833827627350274269702e-01
            -7.12025366562935302372494561495841e-02 -5.25638233615457695080408484500367e-01
            2.37980481824107310828697592341996e-02 -5.29904714800101594995851428393507e-01
            1.18033744171433044312102822459565e-01 -5.17139622444018454139325058349641e-01
            2.08475738504297319897418105938414e-01 -4.87753237118686011619672626693500e-01
            2.92217151067224401028710190075799e-01 -4.42690061427658709813925952403224e-01
            3.66566463957778199134196484010317e-01 -3.83398462915750637414191714924527e-01
            4.29134029084837831380383477153373e-01 -3.11784122344424263761908378000953e-01
            4.77908873424455427070256519073155e-01 -2.30148783544117718768973190890392e-01
            5.11323333347480257771167089231312e-01 -1.41116273473653380809977875287586e-01
            5.28303440618476893853028286685003e-01 -4.75481702628892319295594859340781e-02
            4.72691421326915883760477754549356e-01 4.80680193761093207949208760965121e-02
            4.53339378998908193452166415227111e-01 1.42236147767317577805812334190705e-01
            4.15427569229569859654560559647507e-01 2.30581111556894147174290310431388e-01
            3.60508105965306191453834117055521e-01 3.09486057547201209860787685101968e-01
            2.90829398484918899558948623962351e-01 3.75720607978458076559036271646619e-01
            2.09244101259555781435750532182283e-01 4.26573112573779889000746834426536e-01
            1.19092325943488300254990974735847e-01 4.59961663820118660250813036327600e-01
            2.40648968105404773010214114492555e-02 4.74519330506461001206730543344747e-01
            -7.19477520253365004920809155919414e-02 4.69650120048214825274612849170808e-01
            -1.65014851439793996945581966429017e-01 4.45553378493648788438719066107296e-01
            -2.51326223447884689043974049127428e-01 4.03215629273253550746147766403737e-01
            -3.27348270338441438287446771937539e-01 3.44370184814586699495464472420281e-01
            -3.89968640579553937897117066313513e-01 2.71426184527831793058538778495858e-01
            -4.36623648855969714865921105229063e-01 1.87369964355284968071657658583717e-01
            -4.65403233647121661320511520898435e-01 9.56427958269968209181755014469672e-02
            -4.75129155370202393982026478624903e-01 5.81865399305703885924732712073419e-17
            -4.65403233647121661320511520898435e-01 -9.56427958269967098958730389313132e-02
            -4.36623648855969770377072336486890e-01 -1.87369964355284884804930811696977e-01
            -3.89968640579554048919419528829167e-01 -2.71426184527831682036236315980204e-01
            -3.27348270338441604820900465711020e-01 -3.44370184814586477450859547388973e-01
            -2.51326223447884800066276511643082e-01 -4.03215629273253495234996535145910e-01
            -1.65014851439794191234611275831412e-01 -4.45553378493648677416416603591642e-01
            -7.19477520253366253921711859220522e-02 -4.69650120048214825274612849170808e-01
            2.40648968105405709760891141968386e-02 -4.74519330506461001206730543344747e-01
            1.19092325943488078210386049704539e-01 -4.59961663820118715761964267585427e-01
            2.09244101259555503879994375893148e-01 -4.26573112573780055534200528200017e-01
            2.90829398484918733025494930188870e-01 -3.75720607978458243092489965420100e-01
            3.60508105965306246964985348313348e-01 -3.09486057547201043327333991328487e-01
            4.15427569229569748632258097131853e-01 -2.30581111556894396974470851091610e-01
            4.53339378998908137941015183969284e-01 -1.42236147767317883117144106108753e-01
            4.72691421326915883760477754549356e-01 -4.80680193761092236504062213953148e-02
            4.14971541511581609729120145857451e-01 4.85032169343937585859194427939656e-02
            3.92600318297312289583800293257809e-01 1.42894829823658336964697923576750e-01
            3.49063910302830071596957850488252e-01 2.29582945450181402646805395306728e-01
            2.86709376552096772972078042585053e-01 3.03894185062154764676023432912189e-01
            2.08898266099483975732908902500640e-01 3.61822410497349311597758969583083e-01
            1.19825396050147109372474574229273e-01 4.00244696128391641565258396440186e-01
            2.42927078840990268160382470341574e-02 4.17089686591674169147125894596684e-01
            -7.25496064519136479864513944448845e-02 4.11449264091158173339835002479958e-01
            -1.65480752725338214892403243538865e-01 3.83627505263815282710027076973347e-01
            -2.49490788786243311569990055431845e-01 3.35124288329421593513046673251665e-01
            -3.20050711845398572208409859740641e-01 2.68554434267499697597259000758640e-01
            -3.73356618186929112290783905336866e-01 1.87506741141492822011471730547782e-01
            -4.06534772602243854588977001185413e-01 9.63505110662369740337496182291943e-02
            -4.17796532198967840443515342485625e-01 5.11653185852330074918941587763434e-17
            -4.06534772602243854588977001185413e-01 -9.63505110662368768892349635279970e-02
            -3.73356618186929167801935136594693e-01 -1.87506741141492738744744883661042e-01
            -3.20050711845398516697258628482814e-01 -2.68554434267499753108410232016467e-01
            -2.49490788786243394836716902318585e-01 -3.35124288329421538001895441993838e-01
            -1.65480752725338242647978859167779e-01 -3.83627505263815282710027076973347e-01
            -7.25496064519137451309660491460818e-02 -4.11449264091158117828683771222131e-01
            2.42927078840987388519412348841797e-02 -4.17089686591674224658277125854511e-01
            1.19825396050147109372474574229273e-01 -4.00244696128391641565258396440186e-01
            2.08898266099483975732908902500640e-01 -3.61822410497349311597758969583083e-01
            2.86709376552096828483229273842881e-01 -3.03894185062154709164872201654362e-01
            3.49063910302829905063504156714771e-01 -2.29582945450181680202561551595863e-01
            3.92600318297312123050346599484328e-01 -1.42894829823658642276029695494799e-01
            4.14971541511581609729120145857451e-01 -4.85032169343936822580864998144534e-02
            3.55170112752366762265410216059536e-01 4.88170083628624573712784240342444e-02
            3.28828770284675275803465410717763e-01 1.42830490901267148640130244530155e-01
            2.78099702216497546292117704069824e-01 2.26250889335542909597265293086821e-01
            2.06745251456405848555775150998670e-01 2.92891294336749097304561928467592e-01
            1.20057451192384492810738549906091e-01 3.37809291925513677234960141504416e-01
            2.44655389997175225225145567264917e-02 3.57673519706843801024831464019371e-01
            -7.29408702981650808316871348324639e-02 3.51010738778993691688867784250760e-01
            -1.64937588928310924218934019336302e-01 3.18315097123187340510952481054119e-01
            -2.44701641126906177525768271152629e-01 2.62011480908427962788209697464481e-01
            -3.06317292038639221729567907459568e-01 1.86275671777459128630738405263401e-01
            -3.45214790708234298133305628653034e-01 9.67246482252517164601712806870637e-02
            -3.58509287603583137737928154820111e-01 4.39047251528325948356682556792980e-17
            -3.45214790708234242622154397395207e-01 -9.67246482252517719713225119448907e-02
            -3.06317292038639388263021601233049e-01 -1.86275671777458906586133480232093e-01
            -2.44701641126906149770192655523715e-01 -2.62011480908427962788209697464481e-01
            -1.64937588928311146263538944367610e-01 -3.18315097123187284999801249796292e-01
            -7.29408702981650114427480957601801e-02 -3.51010738778993691688867784250760e-01
            2.44655389997174357863407578861370e-02 -3.57673519706843801024831464019371e-01
            1.20057451192384423421799510833807e-01 -3.37809291925513677234960141504416e-01
            2.06745251456405820800199535369757e-01 -2.92891294336749152815713159725419e-01
            2.78099702216497435269815241554170e-01 -2.26250889335543020619567755602475e-01
            3.28828770284675220292314179459936e-01 -1.42830490901267315173583938303636e-01
            3.55170112752366762265410216059536e-01 -4.88170083628623671656576732402755e-02
            2.93274053113883048649057627699221e-01 4.89387838368401939526108890277101e-02
            2.61493258843193576712593539923546e-01 1.41513074918327791396066572815471e-01
            2.01375612490875821602998030357412e-01 2.18752228530815912010965007539198e-01
            1.19435793860598507554193759006012e-01 2.72286183891438604565138348334585e-01
            2.45532537282379254017783409835829e-02 2.96313706271968568817243294688524e-01
            -7.29900124285628171261208763098693e-02 2.88231040797052140423062382978969e-01
            -1.62623678181994746339000812440645e-01 2.48914069686373279344238085286634e-01
            -2.34634545038048869525226791665773e-01 1.82623396825438266688479416188784e-01
            -2.81219118209146856646185597128351e-01 9.65426452244994848239656448640744e-02
            -2.97329236358071069545871978334617e-01 3.64123297598838575545194491714203e-17
            -2.81219118209146856646185597128351e-01 -9.65426452244995264573290683074447e-02
            -2.34634545038049008303104869810340e-01 -1.82623396825438127910601338044216e-01
            -1.62623678181994690827849581182818e-01 -2.48914069686373307099813700915547e-01
            -7.29900124285628726372721075676964e-02 -2.88231040797052084911911151721142e-01
            2.45532537282379149934374851227403e-02 -2.96313706271968568817243294688524e-01
            1.19435793860598257754013218345790e-01 -2.72286183891438660076289579592412e-01
            2.01375612490875849358573645986326e-01 -2.18752228530815912010965007539198e-01
            2.61493258843193465690291077407892e-01 -1.41513074918327985685095882217865e-01
            2.93274053113883104160208858957049e-01 -4.89387838368401453803535616771114e-02
            2.29192362193770371447953948518261e-01 4.87163404689381906997880378185073e-02
            1.89562920623222996852064170525409e-01 1.37725523565675994630552736452955e-01
            1.17156327951850242063969176342653e-01 2.02920712440806394472048168609035e-01
            2.44923418457762727407089897724290e-02 2.33029066658122174793277281423798e-01
            -7.24065926713727686658828019972134e-02 2.22844578247638397394680964680447e-01
            -1.56785769522397505637556491819851e-01 1.74128237778700234450468542490853e-01
            -2.14055262468999307756689631787594e-01 9.53035430924461524071489293419290e-02
            -2.34312655903700428616787121427478e-01 1.32750746623362123837522396555165e-16
            -2.14055262468999280001114016158681e-01 -9.53035430924461940405123527852993e-02
            -1.56785769522397616659858954335505e-01 -1.74128237778700123428166079975199e-01
            -7.24065926713728241770340332550404e-02 -2.22844578247638369639105349051533e-01
            2.44923418457761651878534792103892e-02 -2.33029066658122202548852897052711e-01
            1.17156327951850242063969176342653e-01 -2.02920712440806394472048168609035e-01
            1.89562920623222969096488554896496e-01 -1.37725523565676050141703967710782e-01
            2.29192362193770371447953948518261e-01 -4.87163404689381143719550948389951e-02
            1.62644678178580331939784286987560e-01 4.77567864486658361089510549390980e-02
            1.11006142049262124249509042783757e-01 1.28107917081874689291254298950662e-01
            2.41239401512230410007386893767034e-02 1.67785689208876348521570776028966e-01
            -7.04174422932133670105514511305955e-02 1.54192690529088960449399792196346e-01
            -1.42601784355426197681282474150066e-01 9.16446020798058758050075311984983e-02
            -1.69511067460851760912987629126292e-01 9.60371546281286377750902817469286e-17
            -1.42601784355426225436858089778980e-01 -9.16446020798058341716441077551281e-02
            -7.04174422932135057884295292751631e-02 -1.54192690529088904938248560938518e-01
            2.41239401512229993673752659333331e-02 -1.67785689208876348521570776028966e-01
            1.11006142049262027104994388082559e-01 -1.28107917081874744802405530208489e-01
            1.62644678178580331939784286987560e-01 -4.77567864486658569256327666607831e-02
            9.27744500386139259173745585940196e-02 4.46778204124236091865363107444864e-02
            2.29133969056428167532235562475762e-02 1.00390151205267758038885972382559e-01
            -6.42019114453944023113152184123464e-02 8.05066505546577909635530545529036e-02
            -1.02971870997724646024096273322357e-01 1.26104172219577666648119444044890e-17
            -6.42019114453944300668908340412600e-02 -8.05066505546577770857652467384469e-02
            2.29133969056427022614741417783080e-02 -1.00390151205267785794461588011472e-01
            9.27744500386139397951623664084764e-02 -4.46778204124235467364911755794310e-02
            1.73694337246242981598332022485920e-02 3.00847417097496010185420090010666e-02
            -3.47388674492485893807725005899556e-02 4.25428428277264636049631314979474e-18
            1.73694337246242981598332022485920e-02 -3.00847417097496010185420090010666e-02
            ];
        
    case   44
        
        % DEGREE.             :          44
        % CARDIN.             :        1035
        % LEBESGUE CONST.     : 1.17262e+03
        % ABS.DET.VAND.MATRIX : Inf
        % CONDITIONING VAND.  : 4.13907e+04
        % POINTS OUT DISK     : 0.00000e+00
        
        pts=[
            9.99377062261978199586565096979029e-01 3.52914639058524715053977161005605e-02
            9.94398216007981949893235196213936e-01 1.05698571419593004283576931356947e-01
            9.84465327861583361368502664845437e-01 1.75579093967320742919469012122136e-01
            9.69627882971888177543462461471790e-01 2.44584890300799911999618529989675e-01
            9.49959800742990800870302336988971e-01 3.12372177013794105615573926115758e-01
            9.25559066571221111807687975669978e-01 3.78603241253703259872054331935942e-01
            8.96547243686828476683103872346692e-01 4.42948123190008036242915068214643e-01
            8.63068867532084116334090140298940e-01 5.05086259857547292817514517082600e-01
            8.25290725692977344962741881317925e-01 5.64708082185086834847709269524785e-01
            7.83401026971852543212548880546819e-01 6.21516557252859258575483636377612e-01
            7.37608463740622277704517273377860e-01 6.75228668095630424339503861119738e-01
            6.88141172245868792956002835126128e-01 7.25576823678982574250539983040653e-01
            6.35245596045538540863617527065799e-01 7.72310192024388886267161069554277e-01
            5.79185258239533484747596503439127e-01 8.15195949841512002009835669014137e-01
            5.20239448610882226908813663612818e-01 8.54020442442126270776725505129434e-01
            4.58701832218090688186862280417699e-01 8.88590248157026918462975118018221e-01
            3.94878986370591267274221536354162e-01 9.18733141953056109407782514608698e-01
            3.29088873276009996615698582900222e-01 9.44298953449555722450270422996255e-01
            2.61659255968440696005217205311055e-01 9.65160315059649609459313523984747e-01
            1.92926065409496916291942625321099e-01 9.81213296529154566094632627937244e-01
            1.23231726897158874733939626366919e-01 9.92377922711878968087262364861090e-01
            5.29234541201632838203217090722319e-02 9.98598572001778372886349188775057e-01
            -1.76484806431285827510446750920892e-02 9.99844253436998564588122917484725e-01
            -8.81324915636019223796893129474483e-02 9.96108761095289008125064356136136e-01
            -1.58177430844303912316206606192281e-01 9.87410705011595224434017836756539e-01
            -2.27434338121106222052603129668569e-01 9.73793418463800408702013555739541e-01
            -2.95558178965684037464711764187086e-01 9.55324742088515477256294161634287e-01
            -3.62209563829682501534534821985289e-01 9.32096685902439547888320703350473e-01
            -4.27056438866375676077780099149095e-01 9.04224970913085068779935227212263e-01
            -4.89775740206228271667043827619636e-01 8.71848452602538737110648980888072e-01
            -5.50055003444841372761686670855852e-01 8.35128429156435481139908461045707e-01
            -6.07593920324899117169081819156418e-01 7.94247837884510698991391564049991e-01
            -6.62105834856800301579937695350964e-01 7.49410343836125147909399402124109e-01
            -7.13319171424379949719707383337663e-01 7.00839325151233261124161799671128e-01
            -7.60978787760967723130534068332054e-01 6.48776760201726143684197722905083e-01
            -8.04847246055325760138998703041580e-01 5.93482022067356229655388233368285e-01
            -8.44705995854881930284818736254238e-01 5.35230586352099413360861035471316e-01
            -8.80356462873091327736574385198765e-01 4.74312658778552276306328394639422e-01
            -9.11621038276541950651221668522339e-01 4.11031729397621670152318529289914e-01
            -9.38343963523229462886376950336853e-01 3.45703060616356416812067209320958e-01
            -9.60392106343779139443483927607303e-01 2.78652116576492525634733965489431e-01
            -9.77655623999714395999660609959392e-01 2.10212941708470879564885080981185e-01
            -9.90048510514454305209142148669343e-01 1.40726496538890577525648950540926e-01
            -9.97509025150763783962304387387121e-01 7.05389590423112639028246917405340e-02
            -1.00000000000000000000000000000000e+00 1.22464679914735320717376402945840e-16
            -9.97509025150763783962304387387121e-01 -7.05389590423110141026441510803124e-02
            -9.90048510514454416231444611184997e-01 -1.40726496538890327725468409880705e-01
            -9.77655623999714395999660609959392e-01 -2.10212941708471073853914390383579e-01
            -9.60392106343779361488088852638612e-01 -2.78652116576491859500919190395507e-01
            -9.38343963523229351864074487821199e-01 -3.45703060616356583345520903094439e-01
            -9.11621038276541839628919206006685e-01 -4.11031729397621836685772223063395e-01
            -8.80356462873091438758876847714419e-01 -4.74312658778552054261723469608114e-01
            -8.44705995854882041307121198769892e-01 -5.35230586352099302338558572955662e-01
            -8.04847246055325871161301165557234e-01 -5.93482022067356007610783308336977e-01
            -7.60978787760967945175138993363362e-01 -6.48776760201725588572685410326812e-01
            -7.13319171424380171764312308368972e-01 -7.00839325151233039079556874639820e-01
            -6.62105834856800523624542620382272e-01 -7.49410343836125036887096939608455e-01
            -6.07593920324898673079871969093801e-01 -7.94247837884511143080601414112607e-01
            -5.50055003444841594806291595887160e-01 -8.35128429156435370117605998530053e-01
            -4.89775740206228493711648752650945e-01 -8.71848452602538626088346518372418e-01
            -4.27056438866375898122385024180403e-01 -9.04224970913084957757632764696609e-01
            -3.62209563829682335001081128211808e-01 -9.32096685902439658910623165866127e-01
            -2.95558178965684481553921614249703e-01 -9.55324742088515366233991699118633e-01
            -2.27434338121106666141812979731185e-01 -9.73793418463800297679711093223887e-01
            -1.58177430844304162116387146852503e-01 -9.87410705011595113411715374240885e-01
            -8.81324915636017142128721957305970e-02 -9.96108761095288897102761893620482e-01
            -1.76484806431283815231214617824662e-02 -9.99844253436998564588122917484725e-01
            5.29234541201625968698252222566225e-02 -9.98598572001778372886349188775057e-01
            1.23231726897158402889154160675389e-01 -9.92377922711879079109564827376744e-01
            1.92926065409496694247337700289791e-01 -9.81213296529154566094632627937244e-01
            2.61659255968439807826797505185823e-01 -9.65160315059649831503918449016055e-01
            3.29088873276010163149152276673703e-01 -9.44298953449555722450270422996255e-01
            3.94878986370590823185011686291546e-01 -9.18733141953056331452387439640006e-01
            4.58701832218090244097652430355083e-01 -8.88590248157027029485277580533875e-01
            5.20239448610882115886511201097164e-01 -8.54020442442126381799027967645088e-01
            5.79185258239533484747596503439127e-01 -8.15195949841512002009835669014137e-01
            6.35245596045538762908222452097107e-01 -7.72310192024388775244858607038623e-01
            6.88141172245868348866792985063512e-01 -7.25576823678983018339749833103269e-01
            7.37608463740622055659912348346552e-01 -6.75228668095630757406411248666700e-01
            7.83401026971852432190246418031165e-01 -6.21516557252859480620088561408920e-01
            8.25290725692977455985044343833579e-01 -5.64708082185086723825406807009131e-01
            8.63068867532083783267182752751978e-01 -5.05086259857547847929026829660870e-01
            8.96547243686828254638498947315384e-01 -4.42948123190008480332124918277259e-01
            9.25559066571221333852292900701286e-01 -3.78603241253702815782844481873326e-01
            9.49959800742990800870302336988971e-01 -3.12372177013794272149027619889239e-01
            9.69627882971888177543462461471790e-01 -2.44584890300799884244042914360762e-01
            9.84465327861583250346200202329783e-01 -1.75579093967321409053283787216060e-01
            9.94398216007981949893235196213936e-01 -1.05698571419593503883938012677390e-01
            9.99377062261978199586565096979029e-01 -3.52914639058519163938854035222903e-02
            9.89738748501854836980839991156245e-01 3.65973245322611245855526362902310e-02
            9.84333138670803409198128974821884e-01 1.09592091701100069478513887588633e-01
            9.73551442575085967945369702647440e-01 1.81988304868489991772406710879295e-01
            9.57452546099991641526116836757865e-01 2.53390561023059512901767220682814e-01
            9.36124375835427624537032897933386e-01 3.23408885801965306772132180412882e-01
            9.09683418851375602542930209892802e-01 3.91660863395629721406265844052541e-01
            8.78274086485910321364656283549266e-01 4.57773725170282252960873847769108e-01
            8.42067925620548329845860280329362e-01 5.21386385600970836406986563815735e-01
            8.01262681750668503966039679653477e-01 5.82151414395485566899424156872556e-01
            7.56081218968189583407024656480644e-01 6.39736934038135807156777445925400e-01
            7.06770302755182378007248189533129e-01 6.93828432389654414791380077076610e-01
            6.53599252236378269742544944165275e-01 7.44130480443439878968092671129853e-01
            5.96858469251501766450473951408640e-01 7.90368345856342857658205502957571e-01
            5.36857852281125813576068139809649e-01 8.32289493441455419109331614890834e-01
            4.73925103888633680870867692647153e-01 8.69664964427730113882830664806534e-01
            4.08403940922457409090640112481196e-01 9.02290626953390906273000382498140e-01
            3.40652217253840539079590143956011e-01 9.29988290963375319186923206871143e-01
            2.71039969303089878227552844691672e-01 9.52606681421622969452300822013058e-01
            1.99947395028962693341867407070822e-01 9.70022264522866217717478320992086e-01
            1.27762777419261008837736426357878e-01 9.82139922391434883053307203226723e-01
            5.48803638237948185341075202359207e-02 9.88893472582110466539973003818886e-01
            -1.83017872879266789432062267906076e-02 9.90246029545690742423857955145650e-01
            -9.13839803840211517549363406942575e-02 9.86190206085068798991244420903968e-01
            -1.63967065868625222480048364559480e-01 9.76748153701542110027844501018990e-01
            -2.35654620098572048503271503250289e-01 9.61971441610994570936554737272672e-01
            -3.06055110511865180455970403272659e-01 9.41940775090720605611238624987891e-01
            -3.74784034042755342941433127634809e-01 9.16765554695188278344630816718563e-01
            -4.41466017144154121432109150191536e-01 8.86583278748147129988410597434267e-01
            -5.05736865947778002627899240906117e-01 8.51558792374464745833506640337873e-01
            -5.67245555364765396966220123431413e-01 8.11883387173217285770476792094996e-01
            -6.25656146262985379813414965610718e-01 7.67773756449311783889299931615824e-01
            -6.80649620250085352068936117575504e-01 7.19470811709795432520309077517595e-01
            -7.31925622041320611543824270484038e-01 6.67238366888747935767867147660581e-01
            -7.79204099895967949862551904516295e-01 6.11361697487053712407600869482849e-01
            -8.22226835162817026869674918998498e-01 5.52145982496545117967912119638640e-01
            -8.60758852580902678042207298858557e-01 4.89914637618172499333724090320175e-01
            -8.94589703632895139051584010303486e-01 4.25007548877600893622030753249419e-01
            -9.23534615941926317894683506892761e-01 3.57779216285597001512286396973650e-01
            -9.47435502434237020175089583062800e-01 2.88596817681904260766145853267517e-01
            -9.66161824755954468102459031797480e-01 2.17838203337205937870635352737736e-01
            -9.79611306228313383215322573960293e-01 1.45889832265977320568950403867348e-01
            -9.87710490447409994452243608975550e-01 7.31446615213585532577766912254447e-02
            -9.90415142477606424975533627730329e-01 1.21290873406227049319019298582902e-16
            -9.87710490447409994452243608975550e-01 -7.31446615213583034575961505652231e-02
            -9.79611306228313383215322573960293e-01 -1.45889832265977070768769863207126e-01
            -9.66161824755954468102459031797480e-01 -2.17838203337205715826030427706428e-01
            -9.47435502434237242219694508094108e-01 -2.88596817681903594632331078173593e-01
            -9.23534615941926206872381044377107e-01 -3.57779216285597168045740090747131e-01
            -8.94589703632895139051584010303486e-01 -4.25007548877600671577425828218111e-01
            -8.60758852580902567019904836342903e-01 -4.89914637618172665867177784093656e-01
            -8.22226835162817248914279844029807e-01 -5.52145982496544895923307194607332e-01
            -7.79204099895968171907156829547603e-01 -6.11361697487053490362995944451541e-01
            -7.31925622041320722566126732999692e-01 -6.67238366888747713723262222629273e-01
            -6.80649620250085574113541042606812e-01 -7.19470811709795321498006615001941e-01
            -6.25656146262986267991834665735951e-01 -7.67773756449311117755485156521900e-01
            -5.67245555364765619010825048462721e-01 -8.11883387173217174748174329579342e-01
            -5.05736865947778446717109090968734e-01 -8.51558792374464412766599252790911e-01
            -4.41466017144153954898655456418055e-01 -8.86583278748147241010713059949921e-01
            -3.74784034042755342941433127634809e-01 -9.16765554695188278344630816718563e-01
            -3.06055110511865402500575328303967e-01 -9.41940775090720494588936162472237e-01
            -2.35654620098572742392661893973127e-01 -9.61971441610994348891949812241364e-01
            -1.63967065868625694324833830251009e-01 -9.76748153701541999005542038503336e-01
            -9.13839803840220399333560408194899e-02 -9.86190206085068687968941958388314e-01
            -1.83017872879269218044928635436008e-02 -9.90246029545690742423857955145650e-01
            5.48803638237943605671098623588477e-02 -9.88893472582110466539973003818886e-01
            1.27762777419261203126765735760273e-01 -9.82139922391434883053307203226723e-01
            1.99947395028962887630896716473217e-01 -9.70022264522866217717478320992086e-01
            2.71039969303089656182947919660364e-01 -9.52606681421622969452300822013058e-01
            3.40652217253840317034985218924703e-01 -9.29988290963375430209225669386797e-01
            4.08403940922456798467976568645099e-01 -9.02290626953391239339907770045102e-01
            4.73925103888633070248204148811055e-01 -8.69664964427730446949738052353496e-01
            5.36857852281125702553765677293995e-01 -8.32289493441455419109331614890834e-01
            5.96858469251501544405869026377331e-01 -7.90368345856343079702810427988879e-01
            6.53599252236378491787149869196583e-01 -7.44130480443439656923487746098544e-01
            7.06770302755182489029550652048783e-01 -6.93828432389654303769077614560956e-01
            7.56081218968189583407024656480644e-01 -6.39736934038135807156777445925400e-01
            8.01262681750668392943737217137823e-01 -5.82151414395485788944029081903864e-01
            8.42067925620547996778952892782399e-01 -5.21386385600971169473893951362697e-01
            8.78274086485909988297748896002304e-01 -4.57773725170282863583537391605205e-01
            9.09683418851375602542930209892802e-01 -3.91660863395629776917417075310368e-01
            9.36124375835427513514730435417732e-01 -3.23408885801965473305585874186363e-01
            9.57452546099991530503814374242211e-01 -2.53390561023059845968674608229776e-01
            9.73551442575085856923067240131786e-01 -1.81988304868490574639494639086479e-01
            9.84333138670803520220431437337538e-01 -1.09592091701100000089574848516349e-01
            9.89738748501854836980839991156245e-01 -3.65973245322612633634307144347986e-02
            9.72091322286366077420893816452008e-01 3.77215703296866558535960223252914e-02
            9.66245050693578244604964311292861e-01 1.12937849026610706570927789016423e-01
            9.54587667673259754330672421929194e-01 1.87474906210722658261857986872201e-01
            9.37189282098554010680402370780939e-01 2.60884467249758000839676697069081e-01
            9.14154529907478141659282755426830e-01 3.32725038405934869789604135803529e-01
            8.85621944810079830823212887480622e-01 4.02564562031241135464654234965565e-01
            8.51763125130404974427733577613253e-01 4.69983015012967575430025135574397e-01
            8.12781701793985233983619309583446e-01 5.34574934842128923762061276647728e-01
            7.68912113667492125301805572235025e-01 5.95951858112702348435618660005275e-01
            7.20418197615808386657931805530097e-01 6.53744656786258704350700554641662e-01
            6.67591601756076458151767383242259e-01 7.07605758171419463309348429902457e-01
            6.10750031451607888755006570136175e-01 7.57211235266918802899738238920690e-01
            5.50235338594443401660782910767011e-01 8.02262754896705509999321748182410e-01
            4.86411465667852427330331011035014e-01 8.42489371920764784640311972907512e-01
            4.19662256953413859150714415591210e-01 8.77649158731072853711907555407379e-01
            3.50389150046343189615072333253920e-01 9.07530660232696573253008409665199e-01
            2.79008761562559104429936951419222e-01 9.31954165559616076741633605706738e-01
            2.05950381557334916138302105537150e-01 9.50772788877017216435660884599201e-01
            1.31653391724393525885616895720887e-01 9.63873352769987423727116038207896e-01
            5.65646229027021857360679746307142e-02 9.71177068905803686504896177211776e-01
            -1.88643322167690967450237593538986e-02 9.72640011876238053112331272131996e-01
            -9.41798350226285274633397648358368e-02 9.68253383370129783180857430124888e-01
            -1.68928929219046369825107944961928e-01 9.58043565087464799034933093935251e-01
            -2.42662064958217099652770798456913e-01 9.42071960076727443755828517168993e-01
            -3.14935802486038807224133506679209e-01 9.20434623449741695644377159624128e-01
            -3.85315479040972574953372031814069e-01 8.93261684694926838545825376058929e-01
            -4.53377822967032828582745196399628e-01 8.60716565063242566857582005468430e-01
            -5.18713499319333193326997388794553e-01 8.22994994733555640387123730761232e-01
            -5.80929571652605392095836123189656e-01 7.80323835668316312386139088630443e-01
            -6.39651865187220614039631527703023e-01 7.32959717239019092893670404009754e-01
            -6.94527217140336716738602262921631e-01 6.81187492826969553938454282615567e-01
            -7.45225600688431910612052888609469e-01 6.25318526681529762711875264358241e-01
            -7.91442109787451220093146275758045e-01 5.65688821338888758738505657674978e-01
            -8.32898792913635444001840824057581e-01 5.02656996863270588704608599073254e-01
            -8.69346324696687267064021398255136e-01 4.36602134063674873765137363079702e-01
            -9.00565505391885623431846852326998e-01 3.67921494657285130802648609460448e-01
            -9.26368579173143191773931448551593e-01 2.97028132090758678618414023731020e-01
            -9.46600363318635507070553103403654e-01 2.24348407388196752210163253948849e-01
            -9.61139181497950856325473978358787e-01 1.50319424965777909131148248889076e-01
            -9.69897595547857149789194863842567e-01 7.53864038343675380016151166273630e-02
            -9.72822931335704632616057097038720e-01 1.19136448899741599397475463403809e-16
            -9.69897595547857149789194863842567e-01 -7.53864038343677461684322338442144e-02
            -9.61139181497950967347776440874441e-01 -1.50319424965777687086543323857768e-01
            -9.46600363318635618092855565919308e-01 -2.24348407388196086076348478854925e-01
            -9.26368579173143191773931448551593e-01 -2.97028132090758456573809098699712e-01
            -9.00565505391885734454149314842653e-01 -3.67921494657284853246892453171313e-01
            -8.69346324696687600130928785802098e-01 -4.36602134063674318653625050501432e-01
            -8.32898792913635555024143286573235e-01 -5.02656996863270366660003674041945e-01
            -7.91442109787451331115448738273699e-01 -5.65688821338888536693900732643669e-01
            -7.45225600688431799589750426093815e-01 -6.25318526681529873734177726873895e-01
            -6.94527217140336938783207187952939e-01 -6.81187492826969331893849357584259e-01
            -6.39651865187221169151143840281293e-01 -7.32959717239018648804460553947138e-01
            -5.80929571652605614140441048220964e-01 -7.80323835668316090341534163599135e-01
            -5.18713499319333082304694926278898e-01 -8.22994994733555751409426193276886e-01
            -4.53377822967033827783467359040515e-01 -8.60716565063242011746069692890160e-01
            -3.85315479040972630464523263071897e-01 -8.93261684694926838545825376058929e-01
            -3.14935802486039029268738431710517e-01 -9.20434623449741584622074697108474e-01
            -2.42662064958217127408346414085827e-01 -9.42071960076727443755828517168993e-01
            -1.68928929219046397580683560590842e-01 -9.58043565087464799034933093935251e-01
            -9.41798350226285413411275726502936e-02 -9.68253383370129783180857430124888e-01
            -1.88643322167693326674164921996635e-02 -9.72640011876238053112331272131996e-01
            5.65646229027021649193862629090290e-02 -9.71177068905803686504896177211776e-01
            1.31653391724392637707197195595654e-01 -9.63873352769987423727116038207896e-01
            2.05950381557334888382726489908237e-01 -9.50772788877017216435660884599201e-01
            2.79008761562559104429936951419222e-01 -9.31954165559616076741633605706738e-01
            3.50389150046343189615072333253920e-01 -9.07530660232696573253008409665199e-01
            4.19662256953413859150714415591210e-01 -8.77649158731072853711907555407379e-01
            4.86411465667851650174213773425436e-01 -8.42489371920765228729521822970128e-01
            5.50235338594443401660782910767011e-01 -8.02262754896705398977019285666756e-01
            6.10750031451607888755006570136175e-01 -7.57211235266918802899738238920690e-01
            6.67591601756076014062557533179643e-01 -7.07605758171419907398558279965073e-01
            7.20418197615808386657931805530097e-01 -6.53744656786258704350700554641662e-01
            7.68912113667491792234898184688063e-01 -5.95951858112702903547130972583545e-01
            8.12781701793985233983619309583446e-01 -5.34574934842128812739758814132074e-01
            8.51763125130404974427733577613253e-01 -4.69983015012967408896571441800916e-01
            8.85621944810079497756305499933660e-01 -4.02564562031241857109620241317316e-01
            9.14154529907478141659282755426830e-01 -3.32725038405934758767301673287875e-01
            9.37189282098553788635797445749631e-01 -2.60884467249758666973491472163005e-01
            9.54587667673259643308369959413540e-01 -1.87474906210723352151248377595039e-01
            9.66245050693578244604964311292861e-01 -1.12937849026610512281898479614028e-01
            9.72091322286366077420893816452008e-01 -3.77215703296873289263047013264440e-02
            9.49209806204592942968645274959272e-01 3.87491729580095312091003734167316e-02
            9.42892971552895753362122377438936e-01 1.15989649521156548694911236907501e-01
            9.30301339741904098623592744843336e-01 1.92458234103685427163199506139790e-01
            9.11518706003847101193571234034607e-01 2.67646040891627745583747355340165e-01
            8.86670065667334972303592621756252e-01 3.41052707435924751244726849108702e-01
            8.55920782334070318064789262280101e-01 4.12189724481971553338155445089797e-01
            8.19475487411361225298378485604189e-01 4.80583686918108543562055956499535e-01
            7.77576718323868210092086883378215e-01 5.45779444208532416027424005733337e-01
            7.30503304467057690274600645352621e-01 6.07343129345018550857560057920637e-01
            6.78568511643580452030732885759789e-01 6.64865046160276529363386543991510e-01
            6.22117957331039139745598731678911e-01 7.17962395788349083680657258810243e-01
            5.61527310654697964231729656603420e-01 7.66281824127907351673627545096679e-01
            4.97199792371434412530106783378869e-01 8.09501773355496334616532294603530e-01
            4.29563491502130745391951904821326e-01 8.47334621839795687492369324900210e-01
            3.59068516469867538010163343642489e-01 8.79528598216123502773200470983284e-01
            2.86183999702632752004660687816795e-01 9.05869456883327206497824590769596e-01
            2.11394975634413118115162433241494e-01 9.26181903772912540340200848731911e-01
            1.35199152881062628628328070590214e-01 9.40330762902147010429132478748215e-01
            5.81036020715785458956581521761109e-02 9.48221875947922954175339782523224e-01
            -1.93786186232723471600802866987578e-02 9.49802728854863054230861507676309e-01
            -9.67318778084321623245145360669994e-02 9.45062801307693600705306380405091e-01
            -1.73441402306413527956152620390640e-01 9.34033636742208295267175799381221e-01
            -2.48996702887862797481943744060118e-01 9.16788632428906291593762034608517e-01
            -3.22894971493157600939127860328881e-01 8.93442551026267017810766901675379e-01
            -3.94644427337085490492540884588379e-01 8.64150756854193069500524870818481e-01
            -4.63767589628832688219972624210641e-01 8.29108181970093283119638272182783e-01
            -5.29804455127866336106023936736165e-01 7.88548028928203859067025405238383e-01
            -5.92315559389606227647107061784482e-01 7.42740218855064138203658785641892e-01
            -6.50884901328796727781877962115686e-01 6.91989595168954307879971565853339e-01
            -7.05122711638093813135697018879000e-01 6.36633894897241758847883374983212e-01
            -7.54668046638497846956283865438309e-01 5.77041501092187214538853368139826e-01
            -7.99191190299986087275385671091499e-01 5.13608991302510475840392700774828e-01
            -8.38395848447292535432495697023114e-01 4.46758498415234517331384722638177e-01
            -8.72021120548760908519625445478596e-01 3.76934901430968694047152212078799e-01
            -8.99843235966334975550751096307067e-01 3.04602864867560996220419156088610e-01
            -9.21677043112236527022673726605717e-01 2.30243746494394829760210541280685e-01
            -9.37377241602234345663191561470740e-01 1.54352393975853152685573377311812e-01
            -9.46839349205728098013423732481897e-01 7.74338517417541977172490419434325e-02
            -9.50000397157754195021084342442919e-01 1.16341494556795791425547814815085e-16
            -9.46839349205728098013423732481897e-01 -7.74338517417539617948563090976677e-02
            -9.37377241602234456685494023986394e-01 -1.54352393975852514307334217846801e-01
            -9.21677043112236527022673726605717e-01 -2.30243746494395024049239850683080e-01
            -8.99843235966334975550751096307067e-01 -3.04602864867560774175814231057302e-01
            -8.72021120548761019541927907994250e-01 -3.76934901430968472002547287047491e-01
            -8.38395848447292646454798159538768e-01 -4.46758498415234295286779797606869e-01
            -7.99191190299985976253083208575845e-01 -5.13608991302510586862695163290482e-01
            -7.54668046638498069000888790469617e-01 -5.77041501092186992494248443108518e-01
            -7.05122711638093702113394556363346e-01 -6.36633894897241869870185837498866e-01
            -6.50884901328796949826482887146994e-01 -6.91989595168954085835366640822031e-01
            -5.92315559389606449691711986815790e-01 -7.42740218855063916159053860610584e-01
            -5.29804455127866558150628861767473e-01 -7.88548028928203637022420480207074e-01
            -4.63767589628832854753426317984122e-01 -8.29108181970093172097335809667129e-01
            -3.94644427337085657025994578361860e-01 -8.64150756854192958478222408302827e-01
            -3.22894971493157434405674166555400e-01 -8.93442551026267017810766901675379e-01
            -2.48996702887863435860182903525128e-01 -9.16788632428906069549157109577209e-01
            -1.73441402306413333667123310988245e-01 -9.34033636742208295267175799381221e-01
            -9.67318778084328145805415033464669e-02 -9.45062801307693600705306380405091e-01
            -1.93786186232719481736808120331261e-02 -9.49802728854863054230861507676309e-01
            5.81036020715780948675543982062663e-02 -9.48221875947923065197642245038878e-01
            1.35199152881062184539118220527598e-01 -9.40330762902147121451434941263869e-01
            2.11394975634412896070557508210186e-01 -9.26181903772912540340200848731911e-01
            2.86183999702632529960055762785487e-01 -9.05869456883327317520127053285250e-01
            3.59068516469866705342894874775084e-01 -8.79528598216123835840107858530246e-01
            4.29563491502130689880800673563499e-01 -8.47334621839795687492369324900210e-01
            4.97199792371433746396292008284945e-01 -8.09501773355496667683439682150492e-01
            5.61527310654697964231729656603420e-01 -7.66281824127907240651325082581025e-01
            6.22117957331039472812506119225873e-01 -7.17962395788348972658354796294589e-01
            6.78568511643580118963825498212827e-01 -6.64865046160276973452596394054126e-01
            7.30503304467057912319205570383929e-01 -6.07343129345018217790652670373674e-01
            7.77576718323867877025179495831253e-01 -5.45779444208532860116633855795953e-01
            8.19475487411361225298378485604189e-01 -4.80583686918108765606660881530843e-01
            8.55920782334070207042486799764447e-01 -4.12189724481971830893911601378932e-01
            8.86670065667334972303592621756252e-01 -3.41052707435924862267029311624356e-01
            9.11518706003847101193571234034607e-01 -2.67646040891627856606049817855819e-01
            9.30301339741904098623592744843336e-01 -1.92458234103685427163199506139790e-01
            9.42892971552895753362122377438936e-01 -1.15989649521157325851028474517079e-01
            9.49209806204592942968645274959272e-01 -3.87491729580093785534344874577073e-02
            9.22087137747703011747546497645089e-01 3.97070118132357152695988133928040e-02
            9.15260327189722611151978526322637e-01 1.18827058616503042354217711817910e-01
            9.01657249390642179243116061115870e-01 1.97067351451703537401627386316250e-01
            8.81378616779187940011297541786917e-01 2.73848626564555275297863090600003e-01
            8.54574565256345897168444025737699e-01 3.48602422257527244653374509653077e-01
            8.21443542641678625670920155243948e-01 4.20775287581360402100472128950059e-01
            7.82230839435100300249814608832821e-01 4.89832879892261152665611234624521e-01
            7.37226772771834681918790010968223e-01 5.55263920937884791761973701795796e-01
            6.86764537015918996587515721330419e-01 6.16583982182636991531410330935614e-01
            6.31217736905707260675058023480233e-01 6.73339071347063056194315322500188e-01
            5.70997621515100139966136794100748e-01 7.25108993607848195672715974069433e-01
            5.06550039509285232597335379978176e-01 7.71510462573275379583037647535093e-01
            4.38352138237208421855939377564937e-01 8.12199938001570642676085753919324e-01
            3.66908831099542143139302652343758e-01 8.46876169252657295949404669954674e-01
            2.92749059346519735491654046199983e-01 8.75282425642498362883259233058197e-01
            2.16421875981979511260888671131397e-01 8.97208397187257977734020641946699e-01
            1.38492380767020611953554976025771e-01 9.12491751664841310720532874256605e-01
            5.95375364190833741839803394668706e-02 9.21019336465871529817661667038919e-01
            -1.98581030181496226427739770770131e-02 9.22728016336021195087369051179849e-01
            -9.91067200083751570494072780093120e-02 9.17605140807346120190857163834153e-01
            -1.77621585518048852314620944525814e-01 9.05688637857924305762935546226799e-01
            -2.54821402952872144709317581146024e-01 8.87066733106375626682904567132937e-01
            -3.30134611874396521891128486458911e-01 8.61877296620249477854258657316677e-01
            -4.03003619633540699496165871096309e-01 8.30306822174280534376578088995302e-01
            -4.72888929591477824576628563590930e-01 7.92589046515730144548683711036574e-01
            -5.39273135363999345237573379563401e-01 7.49003218859284780606344611442182e-01
            -6.01664751517354212673183155857259e-01 6.99872033423574069210815196129261e-01
            -6.59601852354449125215296589885838e-01 6.45559240316074589571826436440460e-01
            -7.12655491851094224919904718262842e-01 5.86466952454580137121809002564987e-01
            -7.60432879422292207216571569006192e-01 5.23032668463843997130879870383069e-01
            -8.02580288006302433601035772881005e-01 4.55726033588831402898478017959860e-01
            -8.38785672936049664372148981783539e-01 3.85045362605636820596544112049742e-01
            -8.68780982208663732357933895400492e-01 3.11513950473229161985955215641297e-01
            -8.92344141048725614240311188041233e-01 2.35676198040659173882360732932284e-01
            -9.09300696072207426112754546920769e-01 1.58093581493642693081014272138418e-01
            -9.19525106878291809131553691258887e-01 7.93404953813246355265320630678616e-02
            -9.22941675506577130505547756911255e-01 1.13027756870882485439476466837574e-16
            -9.19525106878291809131553691258887e-01 -7.93404953813244134819271380365535e-02
            -9.09300696072207426112754546920769e-01 -1.58093581493642498791984962736024e-01
            -8.92344141048725725262613650556887e-01 -2.35676198040658979593331423529889e-01
            -8.68780982208663732357933895400492e-01 -3.11513950473228995452501521867816e-01
            -8.38785672936049553349846519267885e-01 -3.85045362605636987129997805823223e-01
            -8.02580288006302544623338235396659e-01 -4.55726033588831180853873092928552e-01
            -7.60432879422292429261176494037500e-01 -5.23032668463843886108577407867415e-01
            -7.12655491851094446964509643294150e-01 -5.86466952454580026099506540049333e-01
            -6.59601852354449347259901514917146e-01 -6.45559240316074367527221511409152e-01
            -6.01664751517354323695485618372913e-01 -6.99872033423573847166210271097952e-01
            -5.39273135363999456259875842079055e-01 -7.49003218859284669584042148926528e-01
            -4.72888929591478490710443338684854e-01 -7.92589046515729811481776323489612e-01
            -4.03003619633540199895804789775866e-01 -8.30306822174280756421183014026610e-01
            -3.30134611874396910469187105263700e-01 -8.61877296620249366831956194801023e-01
            -2.54821402952872533287376199950813e-01 -8.87066733106375515660602104617283e-01
            -1.77621585518049490692860103990824e-01 -9.05688637857924083718330621195491e-01
            -9.91067200083755872608293202574714e-02 -9.17605140807346009168554701318499e-01
            -1.98581030181500563236429712787867e-02 -9.22728016336021195087369051179849e-01
            5.95375364190829370336643933114829e-02 -9.21019336465871529817661667038919e-01
            1.38492380767020195619920741592068e-01 -9.12491751664841421742835336772259e-01
            2.16421875981979844327796058678359e-01 -8.97208397187257977734020641946699e-01
            2.92749059346519346913595427395194e-01 -8.75282425642498584927864158089506e-01
            3.66908831099541754561244033538969e-01 -8.46876169252657517994009594985982e-01
            4.38352138237208754922846765111899e-01 -8.12199938001570531653783291403670e-01
            5.06550039509284788508125529915560e-01 -7.71510462573275712649945035082055e-01
            5.70997621515099806899229406553786e-01 -7.25108993607848417717320899100741e-01
            6.31217736905707482719662948511541e-01 -6.73339071347062834149710397468880e-01
            6.86764537015918552498305871267803e-01 -6.16583982182637435620620180998230e-01
            7.37226772771834792941092473483877e-01 -5.55263920937884569717368776764488e-01
            7.82230839435099967182907221285859e-01 -4.89832879892261541243669853429310e-01
            8.21443542641678292604012767696986e-01 -4.20775287581360957211984441528330e-01
            8.54574565256346008190746488253353e-01 -3.48602422257527022608769584621768e-01
            8.81378616779187828988995079271263e-01 -2.73848626564555885920526634436101e-01
            9.01657249390642068220813598600216e-01 -1.97067351451704120268715314523433e-01
            9.15260327189722722174280988838291e-01 -1.18827058616502834187400594601058e-01
            9.22087137747703011747546497645089e-01 -3.97070118132363467089440689505864e-02
            8.91297477410163074829085871897405e-01 4.06091317059155965107919428191963e-02
            8.83911905809844578030265438428614e-01 1.21490895063116013941062476533261e-01
            8.69201961781477128177186841639923e-01 2.01365946601853001984849811378808e-01
            8.47289536553984312661214062245563e-01 2.79572416489472563849716379991150e-01
            8.18356203383833524789281455014134e-01 3.55462261286379643809851813784917e-01
            7.82641712981847703645144065376371e-01 4.28406633838071815301162814648706e-01
            7.40442006863310075992501424479997e-01 4.97801094100708496625884436070919e-01
            6.92106765083365216284505549992900e-01 5.63070617721674659961195175128523e-01
            6.38036508677954361523632087482838e-01 6.23674360872463084959349544078577e-01
            5.78679280820374009053352892806288e-01 6.79110141850968962451418065029429e-01
            5.14526934194435514591248193028150e-01 7.28918602317229602505221919273026e-01
            4.46111055348225205019474515211186e-01 7.72687013681297329981134680565447e-01
            3.73998559800549745801845347159542e-01 8.10052697102320085065230159671046e-01
            2.98786994400406014094073725573253e-01 8.40706028759637513658731222676579e-01
            2.21099585865599412848325755476253e-01 8.64393005493270472072708798805252e-01
            1.41580076529884163472061686661618e-01 8.80917349554100170827553029084811e-01
            6.08873900912464058321482696101157e-02 8.90142135023112457403726693883073e-01
            -2.03098284373753913689686356747188e-02 8.91990922422685295067878996633226e-01
            -1.01338753331250128186802328400518e-01 8.86448392118174388620843728858745e-01
            -1.81527953399705316295253965108714e-01 8.73560471261230486739179923461052e-01
            -2.60212955676432822205157435746514e-01 8.53433953222956453998904180480167e-01
            -3.36741751451754223189993808773579e-01 8.26235612670401353696547630534042e-01
            -4.10480199022130509689532118500210e-01 7.92190823619145834122434735036222e-01
            -4.80817278388032620650704984655022e-01 7.51581691913230209856067176588112e-01
            -5.47170154358089910751061779592419e-01 7.04744717607285520166726655588718e-01
            -6.08989006105043806371668324572966e-01 6.52068006621103535280781215988100e-01
            -6.65761583154278802076930787734454e-01 5.93988054771757978400614774727728e-01
            -7.17017450052583327213540087541332e-01 5.30986130831794689299840683816001e-01
            -7.62331884544471982678714994108304e-01 4.63584288584613757322472338273656e-01
            -8.01329396954556405496816751110600e-01 3.92341040922404127311295951585635e-01
            -8.33686841613249129956386695994297e-01 3.17846731832425621888660316471942e-01
            -8.59136094543553774371957842959091e-01 2.40718644620807359357783639097761e-01
            -8.77466275220779801102821693348233e-01 1.61595886908668717740766851420631e-01
            -8.88525493994985260393093540187692e-01 8.11340947850907046046131654293276e-02
            -8.92222110696450187994344105391065e-01 1.09265695199290322116792098007971e-16
            -8.88525493994985260393093540187692e-01 -8.11340947850904964377960482124763e-02
            -8.77466275220779912125124155863887e-01 -1.61595886908668079362527691955620e-01
            -8.59136094543553774371957842959091e-01 -2.40718644620807165068754329695366e-01
            -8.33686841613249129956386695994297e-01 -3.17846731832425399844055391440634e-01
            -8.01329396954556516519119213626254e-01 -3.92341040922403960777842257812154e-01
            -7.62331884544472426767924844170921e-01 -4.63584288584613146699808794437558e-01
            -7.17017450052583216191237625025678e-01 -5.30986130831794911344445608847309e-01
            -6.65761583154278913099233250250109e-01 -5.93988054771757756356009849696420e-01
            -6.08989006105044361483180637151236e-01 -6.52068006621102980169268903409829e-01
            -5.47170154358090132795666704623727e-01 -7.04744717607285298122121730557410e-01
            -4.80817278388032842695309909686330e-01 -7.51581691913230098833764714072458e-01
            -4.10480199022131064801044431078481e-01 -7.92190823619145723100132272520568e-01
            -3.36741751451754445234598733804887e-01 -8.26235612670401242674245168018388e-01
            -2.60212955676433432827820979582611e-01 -8.53433953222956342976601717964513e-01
            -1.81527953399705316295253965108714e-01 -8.73560471261230486739179923461052e-01
            -1.01338753331250350231407253431826e-01 -8.86448392118174277598541266343091e-01
            -2.03098284373760089305260834180444e-02 -8.91990922422685295067878996633226e-01
            6.08873900912463919543604617956589e-02 -8.90142135023112457403726693883073e-01
            1.41580076529883747138427452227916e-01 -8.80917349554100281849855491600465e-01
            2.21099585865598802225662211640156e-01 -8.64393005493270583095011261320906e-01
            2.98786994400405847560620031799772e-01 -8.40706028759637513658731222676579e-01
            3.73998559800549357223786728354753e-01 -8.10052697102320307109835084702354e-01
            4.46111055348225205019474515211186e-01 -7.72687013681297329981134680565447e-01
            5.14526934194435403568945730512496e-01 -7.28918602317229824549826844304334e-01
            5.78679280820373675986445505259326e-01 -6.79110141850969406540627915092045e-01
            6.38036508677954361523632087482838e-01 -6.23674360872463084959349544078577e-01
            6.92106765083364883217598162445938e-01 -5.63070617721674882005800100159831e-01
            7.40442006863309742925594036933035e-01 -4.97801094100709107248547979907016e-01
            7.82641712981847592622841602860717e-01 -4.28406633838071981834616508422187e-01
            8.18356203383833302744676529982826e-01 -3.55462261286380032387910432589706e-01
            8.47289536553984312661214062245563e-01 -2.79572416489472508338565148733323e-01
            8.69201961781477017154884379124269e-01 -2.01365946601853279540605967667943e-01
            8.83911905809844467007962975912960e-01 -1.21490895063116569052574789111532e-01
            8.91297477410163074829085871897405e-01 -4.06091317059156658997309818914800e-02
            8.57228054158236996151742914662464e-01 4.14640048727735327505072859821666e-02
            8.49224346784057115833377338276478e-01 1.24004876376689984751600093204615e-01
            8.33291660494968722261432958475780e-01 2.05387947761168004889853477834549e-01
            8.09578754490025254142437916016206e-01 2.84853367216162778330357241429738e-01
            7.78307029783500636810344985860866e-01 3.61659187531011894201071754650911e-01
            7.39768462043273511419272381317569e-01 4.35088293455634600448433957353700e-01
            6.94322875492683677656202689831844e-01 5.04455097212405889628428212745348e-01
            6.42394583328709134484313381108223e-01 5.69111939644513897818001169071067e-01
            5.84468426023969755966902539512375e-01 6.28455137235005678597588030243060e-01
            5.21085244501868993793891604582313e-01 6.81930618537130883716201878996799e-01
            4.52836830450611793619231093543931e-01 7.29039097390153933986312040360644e-01
            3.80360400923663355410297981507028e-01 7.69340734619711086317295212211320e-01
            3.04332648815808237685587300802581e-01 8.02459244697673379498326085013105e-01
            2.25463424763917841264770913767279e-01 8.28085409018738727304764779546531e-01
            1.44489109462811460282694042689400e-01 8.45979962991234346603164340194780e-01
            6.21657382771169525481624873464170e-02 8.55975829986143743610682577127591e-01
            -2.07380576572268292279144219492082e-02 8.57979681286574535903355354093947e-01
            -1.03448227934789624415934383705462e-01 8.51972807472843207676760357571766e-01
            -1.85192529980729519989424147752288e-01 8.38011293107284505055076806456782e-01
            -2.65207739271643705425418602317222e-01 8.16225493087805009650992360548116e-01
            -3.42746775357304467313213081069989e-01 7.86818815559323092578836167376721e-01
            -4.17085677149533706753459227911662e-01 7.50065822746725063829842383711366e-01
            -4.87530362351820845123739900373039e-01 7.06309667441348931760103369015269e-01
            -5.53423107918717405162567501974991e-01 6.55958889075827888959224765130784e-01
            -6.14148691038696292743281901493901e-01 5.99483599301484315624577448033961e-01
            -6.69140133303781858842285146238282e-01 5.37411092682504754058925300341798e-01
            -7.17883994434181049726362289220560e-01 4.70320923488665720846313433867181e-01
            -7.59925166131835472249633767205523e-01 3.98839494553271112220471650289255e-01
            -7.94871121303980077144046845205594e-01 3.23634208718670490778634984962991e-01
            -8.22395578982846431337350168178091e-01 2.45407237475742445731441421230556e-01
            -8.42241550723146992218914874683833e-01 1.64888964977875779327476379876316e-01
            -8.54223740033948297778465530427638e-01 8.28311686409176073375704163481714e-02
            -8.58230272442079833439265712513588e-01 1.05102895607755395327286170201208e-16
            -8.54223740033948297778465530427638e-01 -8.28311686409173991707532991313201e-02
            -8.42241550723146992218914874683833e-01 -1.64888964977875585038447070473921e-01
            -8.22395578982846320315047705662437e-01 -2.45407237475742640020470730632951e-01
            -7.94871121303980299188651770236902e-01 -3.23634208718669880155971441126894e-01
            -7.59925166131835583271936229721177e-01 -3.98839494553270945687017956515774e-01
            -7.17883994434181160748664751736214e-01 -4.70320923488665498801708508835873e-01
            -6.69140133303781969864587608753936e-01 -5.37411092682504532014320375310490e-01
            -6.14148691038696292743281901493901e-01 -5.99483599301484204602274985518306e-01
            -5.53423107918716961073357651912374e-01 -6.55958889075828222026132152677746e-01
            -4.87530362351821011657193594146520e-01 -7.06309667441348820737800906499615e-01
            -4.17085677149534206353820309232106e-01 -7.50065822746724730762934996164404e-01
            -3.42746775357304300779759387296508e-01 -7.86818815559323203601138629892375e-01
            -2.65207739271643871958872296090703e-01 -8.16225493087804898628689898032462e-01
            -1.85192529980730297145541385361867e-01 -8.38011293107284394032774343941128e-01
            -1.03448227934789457882480689931981e-01 -8.51972807472843318699062820087420e-01
            -2.07380576572270408641784911196737e-02 -8.57979681286574535903355354093947e-01
            6.21657382771169317314807756247319e-02 -8.55975829986143743610682577127591e-01
            1.44489109462811626816147736462881e-01 -8.45979962991234346603164340194780e-01
            2.25463424763917480442287910591403e-01 -8.28085409018738838327067242062185e-01
            3.04332648815808237685587300802581e-01 -8.02459244697673379498326085013105e-01
            3.80360400923662800298785668928758e-01 -7.69340734619711308361900137242628e-01
            4.52836830450611516063474937254796e-01 -7.29039097390154156030916965391953e-01
            5.21085244501868771749286679551005e-01 -6.81930618537131105760806804028107e-01
            5.84468426023969422899995151965413e-01 -6.28455137235006122686797880305676e-01
            6.42394583328709245506615843623877e-01 -5.69111939644513564751093781524105e-01
            6.94322875492683677656202689831844e-01 -5.04455097212406000650730675261002e-01
            7.39768462043273067330062531254953e-01 -4.35088293455635266582248732447624e-01
            7.78307029783500747832647448376520e-01 -3.61659187531011672156466829619603e-01
            8.09578754490025143120135453500552e-01 -2.84853367216163000374962166461046e-01
            8.33291660494968611239130495960126e-01 -2.05387947761168782045970715444128e-01
            8.49224346784057115833377338276478e-01 -1.24004876376689776584782975987764e-01
            8.57228054158236885129440452146810e-01 -4.14640048727738588785207696219004e-02
            8.20162726595980329236112993385177e-01 4.22770113912560377422700241822895e-02
            8.11468797661507368346178736828733e-01 1.26382887335733939959681038089911e-01
            7.94173097602062671995781784062274e-01 2.09149073234078303196170622868522e-01
            7.68458965140941807625551973615075e-01 2.89698226925954593902190481458092e-01
            7.34598976479158727315166288462933e-01 3.67176507343949687367512524360791e-01
            6.92952055919905274272707629279466e-01 4.40762625441297406503338152106153e-01
            6.43959671181648429794108778878581e-01 5.09676550060086941407178073859541e-01
            5.88141153730489474327214338700287e-01 5.73187776455585162871386728511425e-01
            5.26088193737428988505655524932081e-01 6.30623069828259885660770578397205e-01
            4.58458568015359613223580481644603e-01 6.81373601780135618177780543192057e-01
            3.85969167421212455693080300989095e-01 7.24901404047271213926251220982522e-01
            3.09388397634533685032209859855357e-01 7.60745071097187364195235659281025e-01
            2.29528033866122638251283660792978e-01 7.88524651142296972849976555153262e-01
            1.47234615838853194480506658692320e-01 8.07945673723372559393851588538382e-01
            6.33804742560153400177114235702902e-02 8.18802271169671191941574761585798e-01
            -2.11455161211487815964282788172568e-02 8.20979360847457151351136417360976e-01
            -1.05447358767041282634480126034759e-01 8.14453865064549864527521094714757e-01
            -1.88631433177777058096680207199825e-01 7.99294955699600850884678493457614e-01
            -2.69815967470831918895157741644653e-01 7.75663320962972968608539758861298e-01
            -3.48140385386355777352918039468932e-01 7.43809462061735815474605715280632e-01
            -4.22774428609614283391948674761807e-01 7.04071037824553047634879021643428e-01
            -4.92926957715669078474718389770715e-01 6.56869285434099170473132289771456e-01
            -5.57854338444093489357555881724693e-01 6.02704555208131709242991291830549e-01
            -6.16868324407128132413902221742319e-01 5.42151006761650511300842936179833e-01
            -6.69343352672606917153075301030185e-01 4.75850522772144568506291761877947e-01
            -7.14723174886660261861948129080702e-01 4.04505904863527943060574898481718e-01
            -7.52526753644643386920165539777372e-01 3.28873423734091507864008008255041e-01
            -7.82353361607294184310035234375391e-01 2.49754802498962064083443124218320e-01
            -8.03886829310218820054956267995294e-01 1.67988718225636213254858830623562e-01
            -8.16898896638868055042337346094428e-01 8.44419117484267039985823544157029e-02
            -8.21251632442535295375307669019094e-01 1.00574318296528940844775581832597e-16
            -8.16898896638868055042337346094428e-01 -8.44419117484265097095530450133083e-02
            -8.03886829310218931077258730510948e-01 -1.67988718225635658143346518045291e-01
            -7.82353361607294184310035234375391e-01 -2.49754802498961897549989430444839e-01
            -7.52526753644643386920165539777372e-01 -3.28873423734091674397461702028522e-01
            -7.14723174886660261861948129080702e-01 -4.04505904863528109594028592255199e-01
            -6.69343352672607250219982688577147e-01 -4.75850522772144124417081911815330e-01
            -6.16868324407128243436204684257973e-01 -5.42151006761650400278540473664179e-01
            -5.57854338444093600379858344240347e-01 -6.02704555208131598220688829314895e-01
            -4.92926957715668967452415927255061e-01 -6.56869285434099281495434752287110e-01
            -4.22774428609614727481158524824423e-01 -7.04071037824552825590274096612120e-01
            -3.48140385386355943886371733242413e-01 -7.43809462061735704452303252764978e-01
            -2.69815967470831918895157741644653e-01 -7.75663320962972968608539758861298e-01
            -1.88631433177777807497221829180489e-01 -7.99294955699600739862376030941959e-01
            -1.05447358767041129978814240075735e-01 -8.14453865064549864527521094714757e-01
            -2.11455161211491632355929937148176e-02 -8.20979360847457151351136417360976e-01
            6.33804742560151457286821141678956e-02 -8.18802271169671191941574761585798e-01
            1.47234615838853000191477349289926e-01 -8.07945673723372559393851588538382e-01
            2.29528033866122638251283660792978e-01 -7.88524651142296972849976555153262e-01
            3.09388397634533685032209859855357e-01 -7.60745071097187364195235659281025e-01
            3.85969167421212122626172913442133e-01 -7.24901404047271435970856146013830e-01
            4.58458568015359335667824325355468e-01 -6.81373601780135951244687930739019e-01
            5.26088193737428988505655524932081e-01 -6.30623069828260107705375503428513e-01
            5.88141153730489363304911876184633e-01 -5.73187776455585162871386728511425e-01
            6.43959671181647985704898928815965e-01 -5.09676550060087496518690386437811e-01
            6.92952055919905385295010091795120e-01 -4.40762625441297350992186920848326e-01
            7.34598976479158505270561363431625e-01 -3.67176507343950131456722374423407e-01
            7.68458965140942029670156898646383e-01 -2.89698226925954205324131862653303e-01
            7.94173097602062560973479321546620e-01 -2.09149073234078469729624316642003e-01
            8.11468797661507257323876274313079e-01 -1.26382887335734689360222660070576e-01
            8.20162726595980329236112993385177e-01 -4.22770113912559405977553694810922e-02
            7.80320804777397847296072086464847e-01 4.30514984872473471799736444154405e-02
            7.70848767257975020505966767814243e-01 1.28631908589212223814612912065058e-01
            7.52019669923453371040977799566463e-01 2.12650901570305167487262565373385e-01
            7.24062072508902421219545431085862e-01 2.94088600670879829479531508695800e-01
            6.87315342374569926420235788100399e-01 3.71956462542286037109562357727555e-01
            6.42225535045846895876309190498432e-01 4.45309276824005728645516910546576e-01
            5.89339979703432104152227566373767e-01 5.13256639717014739865419414854841e-01
            5.29300635348511239186564125702716e-01 5.74973762279728406454637479328085e-01
            4.62836298290101033625631998802419e-01 6.29711482248465848066132366511738e-01
            3.90753755545114267455630852055037e-01 6.76805357852486633163380247424357e-01
            3.13927991536874451128369400976226e-01 7.15683733237012620342909485771088e-01
            2.33291566969504288175940587279911e-01 7.45874677590918522263052636844805e-01
            1.49823298804255738980728551723587e-01 7.67011713747485113223945063509746e-01
            6.45363787475426026185587602412852e-02 7.78838266720759619943237339612097e-01
            -2.15339255238702620420809807910700e-02 7.81210778178319631415149615349947e-01
            -1.07342837110051908533492337483040e-01 7.74100449044959670885646119131707e-01
            -1.91848752064178174059350112656830e-01 7.57593589084451513038231951213675e-01
            -2.74025883053451824178381457386422e-01 7.31890569215930875124342946946854e-01
            -3.52876711027755252114701534082997e-01 6.97303389282367902524129021912813e-01
            -4.27444093749642317625614396092715e-01 6.54251890795120472077428530610632e-01
            -4.96822884204522918771829154138686e-01 6.03258660626718623554154419252882e-01
            -5.60170917859274974937022761878325e-01 5.44942687514146428817696232727030e-01
            -6.16719235398850429419326246716082e-01 4.80011848374079896917265841693734e-01
            -6.65781416850699692133730422938243e-01 4.09254315636033427772133563848911e-01
            -7.06761913793389373594777680409607e-01 3.33528989896753891297720429065521e-01
            -7.39163278507687926399682964984095e-01 2.53755074030470539891979342428385e-01
            -7.62592202318015277562324172322406e-01 1.70900915311190060297263926258893e-01
            -7.76764289826975540265152631036472e-01 8.59722509885468139101405427027203e-02
            -7.81507511090228312866656779078767e-01 9.57070671966262742941227094779036e-17
            -7.76764289826975540265152631036472e-01 -8.59722509885466196211112333003257e-02
            -7.62592202318015277562324172322406e-01 -1.70900915311189893763810232485412e-01
            -7.39163278507687926399682964984095e-01 -2.53755074030470373358525648654904e-01
            -7.06761913793389595639382605440915e-01 -3.33528989896753447208510579002905e-01
            -6.65781416850699581111427960422589e-01 -4.09254315636033649816738488880219e-01
            -6.16719235398850540441628709231736e-01 -4.80011848374079785894963379178080e-01
            -5.60170917859275196981627686909633e-01 -5.44942687514146317795393770211376e-01
            -4.96822884204523085305282847912167e-01 -6.03258660626718512531851956737228e-01
            -4.27444093749642484159068089866196e-01 -6.54251890795120361055126068094978e-01
            -3.52876711027755418648155227856478e-01 -6.97303389282367791501826559397159e-01
            -2.74025883053451990711835151159903e-01 -7.31890569215930764102040484431200e-01
            -1.91848752064178174059350112656830e-01 -7.57593589084451513038231951213675e-01
            -1.07342837110051936289067953111953e-01 -7.74100449044959670885646119131707e-01
            -2.15339255238702828587626925127552e-02 -7.81210778178319631415149615349947e-01
            6.45363787475418948513805617039907e-02 -7.78838266720759730965539802127751e-01
            1.49823298804255711225152936094673e-01 -7.67011713747485113223945063509746e-01
            2.33291566969504288175940587279911e-01 -7.45874677590918522263052636844805e-01
            3.13927991536873896016857088397956e-01 -7.15683733237012842387514410802396e-01
            3.90753755545114267455630852055037e-01 -6.76805357852486633163380247424357e-01
            4.62836298290100534025270917481976e-01 -6.29711482248466181133039754058700e-01
            5.29300635348511239186564125702716e-01 -5.74973762279728517476939941843739e-01
            5.89339979703432326196832491405075e-01 -5.13256639717014517820814489823533e-01
            6.42225535045846562809401802951470e-01 -4.45309276824006228245877991867019e-01
            6.87315342374570037442538250616053e-01 -3.71956462542285870576108663954074e-01
            7.24062072508902199174940506054554e-01 -2.94088600670880384591043821274070e-01
            7.52019669923453148996372874535155e-01 -2.12650901570305750354350493580569e-01
            7.70848767257975131528269230329897e-01 -1.28631908589212085036734833920491e-01
            7.80320804777397847296072086464847e-01 -4.30514984872478953525920530864823e-02
            7.37877870538540370226598952285713e-01 4.37892540355065695845127038410283e-02
            7.27519682684419244367290957598016e-01 1.30753056967089859030650700333354e-01
            7.06948713228220948501245857187314e-01 2.15881373593090813978179198784346e-01
            6.76453733488989406019697980809724e-01 2.97979188951651874361914451583289e-01
            6.36462826136443671209974581870483e-01 3.75894029675769403286977876632591e-01
            5.87537375848663057098519857390784e-01 4.48532142193114047312718639659579e-01
            5.30364188701778593859614829852944e-01 5.14873846628648768053437834169017e-01
            4.65745850918160564368974974058801e-01 5.73987850874908001053142925229622e-01
            3.94589462315147632143208511479315e-01 6.25044323891769781909033554256894e-01
            3.17893902611998901974743603204843e-01 6.67326544715246550154574833868537e-01
            2.36735809348205955560118241010059e-01 7.00240963648747771763680702861166e-01
            1.52254464252458560080683014348324e-01 7.23325534399743008684424694365589e-01
            6.56358002245079896752599779574666e-02 7.36256200196891752440819800540339e-01
            -2.19042465631460424313470269908066e-02 7.38851442836770733180173920118250e-01
            -1.09136805743754283781754566007294e-01 7.31074830801558328552403054345632e-01
            -1.94837323402548612261142579882289e-01 7.13035530677684881162292640510714e-01
            -2.77802752129451491214240377303213e-01 6.84986774696256128791560513491277e-01
            -3.56868439167599416084186714215321e-01 6.47322305907619965914534532203106e-01
            -4.30924475585100552610384738727589e-01 6.00570850892035101864507851132657e-01
            -4.98931276963486880493547914738883e-01 5.45388697597466998168158625048818e-01
            -5.59934176884153034237101564940531e-01 4.82550482495399668536606441193726e-01
            -6.13076828352218883289026507554809e-01 4.12938316382799430748207214492140e-01
            -6.57613225031200898662575582420686e-01 3.37529401480137936086833860827028e-01
            -6.92918173536712145299532039643964e-01 2.57382313654267669278397079324350e-01
            -7.18496069781136448284541984321550e-01 1.73622142333681700465675135092170e-01
            -7.33987856168642482934671988914488e-01 8.74246967191599222424258641694905e-02
            -7.39176061976764109395787727407878e-01 9.05229598306189780773564299706729e-17
            -7.33987856168642482934671988914488e-01 -8.74246967191600610203039423140581e-02
            -7.18496069781136670329146909352858e-01 -1.73622142333681228620889669400640e-01
            -6.92918173536712256321834502159618e-01 -2.57382313654267502744943385550869e-01
            -6.57613225031201009684878044936340e-01 -3.37529401480137769553380167053547e-01
            -6.13076828352218994311328970070463e-01 -4.12938316382799375237055983234313e-01
            -5.59934176884153367304008952487493e-01 -4.82550482495399279958547822388937e-01
            -4.98931276963487213560455302285845e-01 -5.45388697597466665101251237501856e-01
            -4.30924475585100719143838432501070e-01 -6.00570850892035101864507851132657e-01
            -3.56868439167599305061884251699666e-01 -6.47322305907620076936836994718760e-01
            -2.77802752129451657747694071076694e-01 -6.84986774696256017769258050975623e-01
            -1.94837323402548667772293811140116e-01 -7.13035530677684881162292640510714e-01
            -1.09136805743754630726449761368713e-01 -7.31074830801558217530100591829978e-01
            -2.19042465631462228425885285787444e-02 -7.38851442836770733180173920118250e-01
            6.56358002245074761971110888225667e-02 -7.36256200196891752440819800540339e-01
            1.52254464252458865392014786266373e-01 -7.23325534399742897662122231849935e-01
            2.36735809348206122093571934783540e-01 -7.00240963648747771763680702861166e-01
            3.17893902611998568907836215657881e-01 -6.67326544715246661176877296384191e-01
            3.94589462315147632143208511479315e-01 -6.25044323891769781909033554256894e-01
            4.65745850918160120279765123996185e-01 -5.73987850874908334120050312776584e-01
            5.30364188701778371815009904821636e-01 -5.14873846628648879075740296684671e-01
            5.87537375848663057098519857390784e-01 -4.48532142193114047312718639659579e-01
            6.36462826136443338143067194323521e-01 -3.75894029675769625331582801663899e-01
            6.76453733488989406019697980809724e-01 -2.97979188951651929873065682841116e-01
            7.06948713228221059523548319702968e-01 -2.15881373593090647444725505010865e-01
            7.27519682684419133344988495082362e-01 -1.30753056967090081075255625364662e-01
            7.37877870538540370226598952285713e-01 -4.37892540355065487678309921193431e-02
            6.92978003545075660341012735443655e-01 4.44906639696626693414316378039075e-02
            6.81599323885276553447454261913663e-01 1.32741456436616972469622055541549e-01
            6.59028802171111482977039486286230e-01 2.18812637858717629057991871377453e-01
            6.25637045745131570306796220393153e-01 3.01290921816580070657920487064985e-01
            5.81972346324686196084030598285608e-01 3.78822017167851410324175276400638e-01
            5.28751677067083480920928195700981e-01 4.50132865470326493095853948034346e-01
            4.66848919890168301272126427647891e-01 5.14052544566373614820520288049011e-01
            3.97280516355391688509968162179575e-01 5.69531495092390649404023861279711e-01
            3.21188777725472107693605039457907e-01 6.15658754214538639359943772433326e-01
            2.39823128245043593054219854820985e-01 6.51676913613288721904837075271644e-01
            1.54519589629099424188396483259567e-01 6.76994556107089473506732701935107e-01
            6.66788436233702458411087832246267e-02 6.91195966706136477597510747727938e-01
            -2.22567671512187217897071889183280e-02 6.94047958641012652236668145633303e-01
            -1.10826922424506049691395048739651e-01 6.85503702282994953343120414501755e-01
            -1.97577302695558648659712730477622e-01 6.65703494085263192125978548574494e-01
            -2.81083469118669548869604568608338e-01 6.34972452919017826822312144940952e-01
            -3.59974252749823975250365037936717e-01 5.93815181630603206031082663685083e-01
            -4.32954269102851507788898288708879e-01 5.42907481476720965574145338905510e-01
            -4.98825188326877055899899460200686e-01 4.83085255486478293285301788273500e-01
            -5.56505411749341982741157153213862e-01 4.15330782956760513613403418275993e-01
            -6.05047831696305271620417443045881e-01 3.40756590453332008916476070226054e-01
            -6.43655382974265388718038138904376e-01 2.60587184155384177230985187634360e-01
            -6.71694130658601729066958796465769e-01 1.76138943497926220294047539027815e-01
            -6.88703679287510195372590260376455e-01 8.87985062578565548241371629956120e-02
            -6.94404732542758806879135136114201e-01 8.50400533021263411673594964326447e-17
            -6.88703679287510306394892722892109e-01 -8.87985062578563882906834692221310e-02
            -6.71694130658601729066958796465769e-01 -1.76138943497926053760593845254334e-01
            -6.43655382974265499740340601420030e-01 -2.60587184155384066208682725118706e-01
            -6.05047831696305493665022368077189e-01 -3.40756590453331564827266220163438e-01
            -5.56505411749342093763459615729516e-01 -4.15330782956760402591100955760339e-01
            -4.98825188326877166922201922716340e-01 -4.83085255486478237774150557015673e-01
            -4.32954269102851674322351982482360e-01 -5.42907481476720743529540413874201e-01
            -3.59974252749824363828423656741506e-01 -5.93815181630602983986477738653775e-01
            -2.81083469118669826425360724897473e-01 -6.34972452919017715800009682425298e-01
            -1.97577302695558648659712730477622e-01 -6.65703494085263192125978548574494e-01
            -1.10826922424505758257851084636059e-01 -6.85503702282994953343120414501755e-01
            -2.22567671512187356674949967327848e-02 -6.94047958641012652236668145633303e-01
            6.66788436233697601185355097186402e-02 -6.91195966706136477597510747727938e-01
            1.54519589629099285410518405114999e-01 -6.76994556107089473506732701935107e-01
            2.39823128245043593054219854820985e-01 -6.51676913613288721904837075271644e-01
            3.21188777725471941160151345684426e-01 -6.15658754214538639359943772433326e-01
            3.97280516355391688509968162179575e-01 -5.69531495092390649404023861279711e-01
            4.66848919890168079227521502616582e-01 -5.14052544566373836865125213080319e-01
            5.28751677067083036831718345638365e-01 -4.50132865470327103718517491870443e-01
            5.81972346324686307106333060801262e-01 -3.78822017167851188279570351369330e-01
            6.25637045745131459284493757877499e-01 -3.01290921816580237191374180838466e-01
            6.59028802171111371954737023770576e-01 -2.18812637858718128658352952697896e-01
            6.81599323885276553447454261913663e-01 -1.32741456436617222269802596201771e-01
            6.92978003545075660341012735443655e-01 -4.44906639696632869029890855472331e-02
            6.45741364402466766492239003127906e-01 4.51546349527171264615077461712644e-02
            6.33172743264287962716707625077106e-01 1.34585021251432707112272169069911e-01
            6.08280134901790447976566156285116e-01 2.21395863199681797173212771667750e-01
            5.71548045621827704998452190920943e-01 3.03897486504810909746510105833295e-01
            5.23691423760102026108143036253750e-01 3.80484090913391248545138978442992e-01
            4.65641744025051484978661164859659e-01 4.49665005286581098697951119902427e-01
            3.98528877402186620937385441720835e-01 5.10093701818230105260454365634359e-01
            3.23659099500567370988335369474953e-01 5.60594004666973177997135735495249e-01
            2.42489665383938429732424424400961e-01 6.00182982881102722316768449672963e-01
            1.56600445758517531347209228442807e-01 6.28090082031475982482504605286522e-01
            6.76631765867736906239215954883548e-02 6.43772122176985539532267921458697e-01
            -2.25910793515088116623079628197956e-02 6.46923870244255572181657498731511e-01
            -1.12405625627186367410104139707983e-01 6.37483981042216707457725988206221e-01
            -2.00032324259534655119807666778797e-01 6.15636191276472066746805467118975e-01
            -2.83765621233567688630472503064084e-01 5.81805743323319135562599058175692e-01
            -3.61975743168899077861766500063823e-01 5.36651108370602147878969390148995e-01
            -4.33140419004753252085748727040482e-01 4.81051170025039331878957682420150e-01
            -4.95874509274603914033008322803653e-01 4.16088117842535021306815679054125e-01
            -5.48956966270318647005410639394540e-01 3.43026383739444551412844930382562e-01
            -5.91354600346875591831974361411994e-01 2.63288031263594457520582636789186e-01
            -6.22242189783568711014538621384418e-01 1.78425076744895133584734026044316e-01
            -6.41018542786125022914234250492882e-01 9.00892810628728391009190090699121e-02
            -6.47318199001134630954368276434252e-01 7.92736160436568952287615670767555e-17
            -6.41018542786125022914234250492882e-01 -9.00892810628727003230409309253446e-02
            -6.22242189783568933059143546415726e-01 -1.78425076744894717251099791610613e-01
            -5.91354600346875813876579286443302e-01 -2.63288031263594068942524017984397e-01
            -5.48956966270318758027713101910194e-01 -3.43026383739444495901693699124735e-01
            -4.95874509274604025055310785319307e-01 -4.16088117842534854773361985280644e-01
            -4.33140419004753418619202420813963e-01 -4.81051170025039220856655219904496e-01
            -3.61975743168899410928673887610785e-01 -5.36651108370601925834364465117687e-01
            -2.83765621233567799652774965579738e-01 -5.81805743323319024540296595660038e-01
            -2.00032324259534793897685744923365e-01 -6.15636191276472066746805467118975e-01
            -1.12405625627186395165679755336896e-01 -6.37483981042216707457725988206221e-01
            -2.25910793515094049377367468878219e-02 -6.46923870244255461159355036215857e-01
            6.76631765867733853125898235703062e-02 -6.43772122176985539532267921458697e-01
            1.56600445758517253791453072153672e-01 -6.28090082031475982482504605286522e-01
            2.42489665383938429732424424400961e-01 -6.00182982881102722316768449672963e-01
            3.23659099500567370988335369474953e-01 -5.60594004666973177997135735495249e-01
            3.98528877402186731959687904236489e-01 -5.10093701818229994238151903118705e-01
            4.65641744025051262934056239828351e-01 -4.49665005286581320742556044933735e-01
            5.23691423760102026108143036253750e-01 -3.80484090913391415078592672216473e-01
            5.71548045621827704998452190920943e-01 -3.03897486504810909746510105833295e-01
            6.08280134901790447976566156285116e-01 -2.21395863199681741662061540409923e-01
            6.33172743264287962716707625077106e-01 -1.34585021251433067934755172245787e-01
            6.45741364402466766492239003127906e-01 -4.51546349527167725779186469026172e-02
            5.96268973587884110187928854429629e-01 4.57782669544448336806929944486910e-02
            5.82292934221131042171748504188145e-01 1.36261797085782149219213010837848e-01
            5.54668442004839779002622890402563e-01 2.23551466183572439261340036864567e-01
            5.14042991623126499511897691263584e-01 3.05601278387456321006254711392103e-01
            4.61368809200403406922674776069471e-01 3.80488055641570788178995599082555e-01
            3.97880532928092389699514797030133e-01 4.46456515358168437579422516137129e-01
            3.25066274191848636476720457721967e-01 5.01960412753766016535905691853259e-01
            2.44632737501946029290422757185297e-01 5.45698783516332608378718305175425e-01
            1.58465216786091184220097716206510e-01 5.76646437306117753962553251767531e-01
            6.85834056976600825450418597029056e-02 5.94077987348303859782561175961746e-01
            -2.29059422917251530316118390828706e-02 5.97584852884198713951491299667396e-01
            -1.13858394407968632755512317089597e-01 5.87084835957922490656812897213968e-01
            -2.02142102261189587908418729966797e-01 5.62824048066825288749726041714894e-01
            -2.85687770565109133702463850568165e-01 5.25371141516584261310640613373835e-01
            -3.62537159664708785733466811507242e-01 4.75603980693125316658864676355734e-01
            -4.30888985014015180041724306647666e-01 4.14689065665460987464285835812916e-01
            -4.89141137759161681586306258395780e-01 3.44054190412751925709500255834428e-01
            -5.35928236812037050995627396332566e-01 2.65354976543577258940587171309744e-01
            -5.70153632225748219219951806735480e-01 1.80436066928669897047043946258782e-01
            -5.91015109739897903651240085309837e-01 9.12878888354733963872433832875686e-02
            -5.98023694002922656665077738580294e-01 3.38812650008869107283161329845951e-16
            -5.91015109739897903651240085309837e-01 -9.12878888354732437315774973285443e-02
            -5.70153632225748219219951806735480e-01 -1.80436066928670008069346408774436e-01
            -5.35928236812037050995627396332566e-01 -2.65354976543577147918284708794090e-01
            -4.89141137759161848119759952169261e-01 -3.44054190412751592642592868287466e-01
            -4.30888985014015346575178000421147e-01 -4.14689065665460931953134604555089e-01
            -3.62537159664708730222315580249415e-01 -4.75603980693125372170015907613561e-01
            -2.85687770565109022680161388052511e-01 -5.25371141516584372332943075889489e-01
            -2.02142102261189587908418729966797e-01 -5.62824048066825288749726041714894e-01
            -1.13858394407969049089146551523299e-01 -5.87084835957922379634510434698313e-01
            -2.29059422917252952789368691810523e-02 -5.97584852884198713951491299667396e-01
            6.85834056976600825450418597029056e-02 -5.94077987348303859782561175961746e-01
            1.58465216786090906664341559917375e-01 -5.76646437306117864984855714283185e-01
            2.44632737501945890512544679040730e-01 -5.45698783516332719401020767691080e-01
            3.25066274191848747499022920237621e-01 -5.01960412753766016535905691853259e-01
            3.97880532928092167654909871998825e-01 -4.46456515358168604112876209910610e-01
            4.61368809200403018344616157264682e-01 -3.80488055641571176757054217887344e-01
            5.14042991623126277467292766232276e-01 -3.05601278387456654073162098939065e-01
            5.54668442004839779002622890402563e-01 -2.23551466183572578039218115009135e-01
            5.82292934221131042171748504188145e-01 -1.36261797085782065952486163951107e-01
            5.96268973587884110187928854429629e-01 -4.57782669544450834808735351089126e-02
            5.44645549812486695628876987029798e-01 4.63561679896271200407298351819918e-02
            5.28977088978037857103231544897426e-01 1.37734921416282379835749338781170e-01
            4.98090920399852365996196112973848e-01 2.25151291927131375070203489485721e-01
            4.52875582913619179059594443970127e-01 3.06090469701162160021112867980264e-01
            3.94631839455459432208783709938871e-01 3.78223981959405763930703869846184e-01
            3.25035256480547540824943553161575e-01 4.39476678887347815827268959765206e-01
            2.46088000966892067600255700199341e-01 4.88086431916876062331311914022081e-01
            1.60061241716714736105231509100122e-01 5.22654826956885365518701291875914e-01
            6.94298119651166056875979393225862e-02 5.42187394220593255056428461102769e-01
            -2.31989870661772380755483169423314e-02 5.46122217310678337298668338917196e-01
            -1.15160393477866829226030631616595e-01 5.34346098530953383942687651142478e-01
            -2.03808845041198699599149790628871e-01 5.07197815377985472551358725468162e-01
            -2.86594087206525405253643157266197e-01 4.65458374529330975999386055264040e-01
            -3.61134539283461397651819879683899e-01 4.10328543703396830810703477254719e-01
            -4.25285808181213031975431704267976e-01 3.43394307758414785158862514435896e-01
            -4.77202378693512618834660088396049e-01 2.66581242795665862566067971783923e-01
            -5.15390705610983990148099564976292e-01 1.82099120840932188203353803146456e-01
            -5.38752180297522920149333458539331e-01 9.23783387266398775539144594404206e-02
            -5.46614735660527539806707864045165e-01 6.69409986393441652573278926663564e-17
            -5.38752180297522920149333458539331e-01 -9.23783387266397387760363812958531e-02
            -5.15390705610983990148099564976292e-01 -1.82099120840932077181051340630802e-01
            -4.77202378693512785368113782169530e-01 -2.66581242795665529499160584236961e-01
            -4.25285808181212976464280473010149e-01 -3.43394307758414896181164976951550e-01
            -3.61134539283461564185273573457380e-01 -4.10328543703396719788401014739065e-01
            -2.86594087206525682809399313555332e-01 -4.65458374529330753954781130232732e-01
            -2.03808845041198810621452253144525e-01 -5.07197815377985472551358725468162e-01
            -1.15160393477866732081515976915398e-01 -5.34346098530953383942687651142478e-01
            -2.31989870661774913451758095561672e-02 -5.46122217310678226276365876401542e-01
            6.94298119651162309873271283322538e-02 -5.42187394220593255056428461102769e-01
            1.60061241716714486305050968439900e-01 -5.22654826956885476541003754391568e-01
            2.46088000966892067600255700199341e-01 -4.88086431916876062331311914022081e-01
            3.25035256480547651847246015677229e-01 -4.39476678887347760316117728507379e-01
            3.94631839455459265675330016165390e-01 -3.78223981959405874953006332361838e-01
            4.52875582913618957014989518938819e-01 -3.06090469701162493088020255527226e-01
            4.98090920399852310485044881716021e-01 -2.25151291927131541603657183259202e-01
            5.28977088978037857103231544897426e-01 -1.37734921416282352080173723152257e-01
            5.44645549812486584606574524514144e-01 -4.63561679896273559631225680277566e-02
            4.90940697527530722776845095722820e-01 4.68791526368102645649926785154094e-02
            4.73196821585374849394867169394274e-01 1.38943123191695633300568601953273e-01
            4.38350379608830442723643727731542e-01 2.25985327261656682162893616805377e-01
            3.87660812802448739855520898345276e-01 3.04859832805354280527154742230778e-01
            3.22960174180990600145690905264928e-01 3.72715909686919588672537884121994e-01
            2.46586913400105189886346579442034e-01 4.27101062490568894602915861469228e-01
            1.61301359093003582323433420242509e-01 4.66049670094844825651847486369661e-01
            7.01859534016891634111701137044292e-02 4.88154028341321488682069684728049e-01
            -2.34661555132804587608941204734947e-02 4.92615228130627635927396568149561e-01
            -1.16270136427528064659853157536418e-01 4.79272030078835120647795520198997e-01
            -2.04871811672399484205442377060535e-01 4.48606692128898920657320559257641e-01
            -2.86068885855131238571402718662284e-01 4.01727539492088669970115688556689e-01
            -3.56926685157846645957135933713289e-01 3.40328906887139404080500071358983e-01
            -4.14884224095549924982151424046606e-01 2.66629900868971092542381029488752e-01
            -4.57846766204137778366600741719594e-01 1.83294195535967208154914942497271e-01
            -4.84261533273994182469124325507437e-01 9.33337604079253480016120647633215e-02
            -4.93173826800210268750390696368413e-01 6.03963748414128686306572158147626e-17
            -4.84261533273994293491426788023091e-01 -9.33337604079250288124924850308162e-02
            -4.57846766204137833877751972977421e-01 -1.83294195535967097132612479981617e-01
            -4.14884224095550091515605117820087e-01 -2.66629900868970814986624873199617e-01
            -3.56926685157846701468287164971116e-01 -3.40328906887139348569348840101156e-01
            -2.86068885855131349593705181177938e-01 -4.01727539492088614458964457298862e-01
            -2.04871811672399400938715530173795e-01 -4.48606692128898976168471790515468e-01
            -1.16270136427528078537640965350874e-01 -4.79272030078835120647795520198997e-01
            -2.34661555132806912138399013656453e-02 -4.92615228130627635927396568149561e-01
            7.01859534016889274887773808586644e-02 -4.88154028341321544193220915985876e-01
            1.61301359093003582323433420242509e-01 -4.66049670094844881162998717627488e-01
            2.46586913400105189886346579442034e-01 -4.27101062490568894602915861469228e-01
            3.22960174180990322589934748975793e-01 -3.72715909686919810717142809153302e-01
            3.87660812802448573322067204571795e-01 -3.04859832805354502571759667262086e-01
            4.38350379608830387212492496473715e-01 -2.25985327261656793185196079321031e-01
            4.73196821585374849394867169394274e-01 -1.38943123191695688811719833211100e-01
            4.90940697527530667265693864464993e-01 -4.68791526368106462041573934129701e-02
            4.35208211092425301114161584337126e-01 4.73317453123325015962308270900394e-02
            4.14858358840928920230339826957788e-01 1.39782056131649429220331626311236e-01
            3.75110190811979826719380071153864e-01 2.25696313362847456041038185503567e-01
            3.17822287165695827049205490766326e-01 3.01057261824634492253238704506657e-01
            2.45673366605645399074475676570728e-01 3.62341107324615718798810348744155e-01
            1.62037032469450781313469178712694e-01 4.06682285359314221739879258166184e-01
            7.08240267862111638752509179539629e-02 4.32007451725507363171630004217150e-01
            -2.37006316742992759194486040996708e-02 4.37132429790812682135481281875400e-01
            -1.17117074939079940376629451748158e-01 4.21817581276900388509432104910957e-01
            -2.05057253945988754439966328391165e-01 3.86779011479049639188332321282360e-01
            -2.83409183663151986731776332817390e-01 3.33655084978434490761145525539177e-01
            -3.48509214938910127923321624621167e-01 2.64929817535220268887030670157401e-01
            -3.97313342664297131090478387704934e-01 1.83816726272402558572949260451423e-01
            -4.27539540068765600011602145968936e-01 9.41085691867054180415053110664303e-02
            -4.37774463755688403310273315582890e-01 5.36119095786852773853941215668982e-17
            -4.27539540068765600011602145968936e-01 -9.41085691867053208969906563652330e-02
            -3.97313342664297075579327156447107e-01 -1.83816726272402614084100491709250e-01
            -3.48509214938910294456775318394648e-01 -2.64929817535219991331274513868266e-01
            -2.83409183663151875709473870301736e-01 -3.33655084978434546272296756797004e-01
            -2.05057253945989031995722484680300e-01 -3.86779011479049472654878627508879e-01
            -1.17117074939080134665658761150553e-01 -4.21817581276900332998280873653130e-01
            -2.37006316742995777613334240641052e-02 -4.37132429790812626624330050617573e-01
            7.08240267862110667307362632527656e-02 -4.32007451725507418682781235474977e-01
            1.62037032469450587024439869310299e-01 -4.06682285359314277251030489424011e-01
            2.45673366605645371318900060941814e-01 -3.62341107324615774309961580001982e-01
            3.17822287165695827049205490766326e-01 -3.01057261824634492253238704506657e-01
            3.75110190811979826719380071153864e-01 -2.25696313362847456041038185503567e-01
            4.14858358840928920230339826957788e-01 -1.39782056131649373709180395053409e-01
            4.35208211092425245603010353079299e-01 -4.73317453123328207853504068225448e-02
            3.77482447083496652773249024903635e-01 4.76871229143740540945550776541495e-02
            3.53763836649912177811927449511131e-01 1.40065011429442026757996586638910e-01
            3.07816943307232582238697204957134e-01 2.23642100153319589583844617663999e-01
            2.42528779345031753056360912523814e-01 2.93166933226454373695446520287078e-01
            1.62001640218125630976686579742818e-01 3.44271009692411422697944090032252e-01
            7.12953422359589306100957628586912e-02 3.73743272479188481938194854592439e-01
            -2.38907043048203066026857754877710e-02 3.79731870924492065366706583517953e-01
            -1.17575610030263247307580343203881e-01 3.61860519363479182786136334470939e-01
            -2.03872807764659158547004835781991e-01 3.21252140540961683701226547782426e-01
            -2.77359927195462985238805231347214e-01 2.60458308245528846747163242980605e-01
            -3.33419502342118090343348058013362e-01 1.83298922544377601573373226528929e-01
            -3.68529103925464451840809942950727e-01 9.46221914134821734387870151294919e-02
            -3.80482666553938364550901951588457e-01 4.65956879726330336680934247657923e-17
            -3.68529103925464562863112405466381e-01 -9.46221914134819236386064744692703e-02
            -3.33419502342118090343348058013362e-01 -1.83298922544377657084524457786756e-01
            -2.77359927195463151772258925120695e-01 -2.60458308245528680213709549207124e-01
            -2.03872807764658964257975526379596e-01 -3.21252140540961794723529010298080e-01
            -1.17575610030263413841034036977362e-01 -3.61860519363479127274985103213112e-01
            -2.38907043048202302748528325082589e-02 -3.79731870924492065366706583517953e-01
            7.12953422359587501988542612707533e-02 -3.73743272479188537449346085850266e-01
            1.62001640218125325665354807824770e-01 -3.44271009692411533720246552547906e-01
            2.42528779345031586522907218750333e-01 -2.93166933226454484717748982802732e-01
            3.07816943307232526727545973699307e-01 -2.23642100153319672850571464550740e-01
            3.53763836649912177811927449511131e-01 -1.40065011429441999002420971009997e-01
            3.77482447083496597262097793645808e-01 -4.76871229143741998113270597059454e-02
            3.17768862677946906103443325264379e-01 4.78959495979184232683500965777057e-02
            2.89533704723326290597640308988048e-01 1.39432083484067409484552513276867e-01
            2.35572206506302839201794085965957e-01 2.18579064865036976073042751522735e-01
            1.60679083949593654034870837676863e-01 2.78304337114321065360655893528019e-01
            7.15089196554172523700998453932698e-02 3.13301047692530532096100159833441e-01
            -2.40151259618680348872921115344070e-02 3.20459585284256776027689284092048e-01
            -1.17405322248797058803937432003295e-01 2.99143882409750039297335888477392e-01
            -2.00363540429149861177293701075541e-01 2.51247932811831609090091887992457e-01
            -2.65518578761458234893666485731956e-01 1.81027501800189311031985539557354e-01
            -3.07081126161720008305167084472487e-01 9.47219828274936948009354864552733e-02
            -3.21358167899187252558590444095898e-01 3.93550251697597381897804051759663e-17
            -3.07081126161720063816318315730314e-01 -9.47219828274934866341183692384220e-02
            -2.65518578761458179382515254474129e-01 -1.81027501800189366543136770815181e-01
            -2.00363540429149944444020547962282e-01 -2.51247932811831553578940656734630e-01
            -1.17405322248796989414998392931011e-01 -2.99143882409750039297335888477392e-01
            -2.40151259618682534624500846121009e-02 -3.20459585284256776027689284092048e-01
            7.15089196554171829811608063209860e-02 -3.13301047692530532096100159833441e-01
            1.60679083949593404234690297016641e-01 -2.78304337114321176382958356043673e-01
            2.35572206506302894712945317223785e-01 -2.18579064865036892806315904635994e-01
            2.89533704723326235086489077730221e-01 -1.39432083484067464995703744534694e-01
            3.17768862677946850592292094006552e-01 -4.78959495979186938852123489596124e-02
            2.56020605667101441849098364400561e-01 4.78585455263874359754794340915396e-02
            2.21443604212609640446984826667176e-01 1.37112074812468121010056165687274e-01
            1.56959416947834357047852904543106e-01 2.07847858630890502951160669908859e-01
            7.12769906821002496855044228141196e-02 2.50512637416467565110167470265878e-01
            -2.40317881346913640727702698995927e-02 2.59344296380506655896880374712055e-01
            -1.16094940799157733679614068478259e-01 2.33150071042002499099865531206888e-01
            -1.92478828404423540909817802457837e-01 1.75467636680133265425496347234002e-01
            -2.42867383671664521793687185891031e-01 9.40873256848724637269043569176574e-02
            -2.60455352999416689385725476313382e-01 3.18965814371529639131695481865052e-17
            -2.42867383671664577304838417148858e-01 -9.40873256848723110712384709586331e-02
            -1.92478828404423457643090955571097e-01 -1.75467636680133293181071962862916e-01
            -1.16094940799158011235370224767394e-01 -2.33150071042002360321987453062320e-01
            -2.40317881346913710116641738068211e-02 -2.59344296380506655896880374712055e-01
            7.12769906821001802965653837418358e-02 -2.50512637416467565110167470265878e-01
            1.56959416947834301536701673285279e-01 -2.07847858630890586217887516795599e-01
            2.21443604212609557180257979780436e-01 -1.37112074812468232032358628202928e-01
            2.56020605667101441849098364400561e-01 -4.78585455263873596476464911120274e-02
            1.92075607320556895896146443192265e-01 4.73423852329401192995383951256372e-02
            1.48073400445416919479768580458767e-01 1.31181585779544862546686090354342e-01
            7.01493620061532791032377076589910e-02 1.84968665933542747437101638752210e-01
            -2.38450498772633384669816791756602e-02 1.96381653836237207721993058839871e-01
            -1.12376848197801637585513390149572e-01 1.62805971500535356932815034269879e-01
            -1.75164464884055626203718247779761e-01 9.19334031187104411264598979869334e-02
            -1.97824013626012762401273903378751e-01 -6.36250553923861451354191140519481e-17
            -1.75164464884055737226020710295415e-01 -9.19334031187102468374305885845388e-02
            -1.12376848197801679218876813592942e-01 -1.62805971500535329177239418640966e-01
            -2.38450498772634737754128053666136e-02 -1.96381653836237207721993058839871e-01
            7.01493620061532791032377076589910e-02 -1.84968665933542747437101638752210e-01
            1.48073400445416836213041733572027e-01 -1.31181585779544945813412937241083e-01
            1.92075607320556895896146443192265e-01 -4.73423852329401262384322990328656e-02
            1.25458325272629483970732167108508e-01 4.56630960401243624069422821776243e-02
            6.67549805635926502000998539188004e-02 1.15623017994415322462486983567942e-01
            -2.31837614501184258175570107596286e-02 1.31481644822410564943382382807613e-01
            -1.02274563822511030397599540719966e-01 8.58185487822862302920157162589021e-02
            -1.33509961127185272644624092208687e-01 1.63502546548694993889092534847629e-17
            -1.02274563822511085908750771977793e-01 -8.58185487822861470252888693721616e-02
            -2.31837614501184292870039627132428e-02 -1.31481644822410564943382382807613e-01
            6.67549805635925530555851992176031e-02 -1.15623017994415391851426022640226e-01
            1.25458325272629483970732167108508e-01 -4.56630960401243485291544743631675e-02
            5.46535723337500667362576223240467e-02 3.97081446078866237558990803790948e-02
            -2.08758070248916093036850583075648e-02 6.42491276057564342227834686127608e-02
            -6.75555306177169079262512241257355e-02 8.27316643356880309093765860411820e-18
            -2.08758070248916231814728661220215e-02 -6.42491276057564203449956607983040e-02
            5.46535723337500597973637184168183e-02 -3.97081446078866445725807921007799e-02
            -0.00000000000000000000000000000000e+00 0.00000000000000000000000000000000e+00
            ];
        
    case   45
        
        % DEGREE.             :          45
        % CARDIN.             :        1081
        % LEBESGUE CONST.     : 1.40102e+03
        % ABS.DET.VAND.MATRIX : Inf
        % CONDITIONING VAND.  : 7.52671e+04
        % POINTS OUT DISK     : 0.00000e+00
        
        pts=[
            9.99404140551070407916256499447627e-01 3.45161389697081280591994811857148e-02
            9.94641524695192735805449046893045e-01 1.03383931788370159177148366325127e-01
            9.85138989016873800608209421625361e-01 1.71759053091276037150691990973428e-01
            9.70941817426052011796855367720127e-01 2.39315664287557738898470915955841e-01
            9.52117665910714117138979872834170e-01 3.05731827359752850181706662624492e-01
            9.28756240125302334753598643146688e-01 3.70691039045067505242059269221500e-01
            9.00968867902419145998749172576936e-01 4.33883739117558175912847673316719e-01
            8.68887968725006398784671546309255e-01 4.95008785583581245592910136110731e-01
            8.32666422687206364550149828573922e-01 5.53774889760533128857389328913996e-01
            7.92476841951090471560803507600212e-01 6.09902004400072805800903097406263e-01
            7.48510748171101081283040912239812e-01 6.63122658240795193052008471568115e-01
            7.00977659806149455690160721132997e-01 7.13183230630596298738055338617414e-01
            6.50104093668744220657629284687573e-01 7.59845160144578812833060510456562e-01
            5.96132485469225481544697231583996e-01 8.02886081438882404093249078869121e-01
            5.39320034499199185695772484905319e-01 8.42100884922811765420647134305909e-01
            4.79937477959786418235665905740461e-01 8.77302694199441956968144040729385e-01
            4.18267800775565190551930072615505e-01 9.08323756616753907877637175261043e-01
            3.54604887042535787955443993269000e-01 9.35016242685414722402015286206733e-01
            2.89252119536567764424006554691005e-01 9.57252950553615700179932446189923e-01
            2.22520933956314448387558968533995e-01 9.74927912181823619341969333618181e-01
            1.54729334790281447542525938843028e-01 9.87956898328746446757975263608387e-01
            8.62003798806195431492227498893044e-02 9.96277819942026465760420705919387e-01
            1.72606409053885738458244958337673e-02 9.99851024040849356566695860237814e-01
            -5.17613528842093689741332696030440e-02 9.98659482680456123127044065768132e-01
            -1.20536680255322881105684018621105e-01 9.92708874098053972723221249907510e-01
            -1.88737595452916573357526885956759e-01 9.82027555653430361815026117255911e-01
            -2.56039090057547102929902393952943e-01 9.66666428693219503820444060693262e-01
            -3.22120441798490642071328693418764e-01 9.46698695982805871196319458249491e-01
            -3.86666742941418728474189947519335e-01 9.22219512861810364334758105542278e-01
            -4.49370400967161021110740648509818e-01 8.93345533785563250539496493729530e-01
            -5.09932604390135657546068159717834e-01 8.60214356413500746967315535584930e-01
            -5.68064746731155700842919031856582e-01 8.22983865893656463263994282897329e-01
            -6.23489801858733483364005678595277e-01 7.81831482468029914656426626606844e-01
            -6.75943644144754385294504572812002e-01 7.36953315984336776445218220032984e-01
            -7.25176307143376552843960780592170e-01 6.88563231343277015739090529677924e-01
            -7.70953174794979601003319658047985e-01 6.36891829334889192359980825131061e-01
            -8.13056099478532301461086717608850e-01 5.82185347720770907109510972077260e-01
            -8.51284441584351125875684829225065e-01 5.24704487799008134629730193410069e-01
            -8.85456025653209799486376141430810e-01 4.64723172043768673056263196485816e-01
            -9.15408008525366301277870206831722e-01 4.02527238739967596625746182326111e-01
            -9.40997655362376450582928555377293e-01 3.38413079833670471519013744909898e-01
            -9.62103019843600582028386725141900e-01 2.72686228489493698301515678394935e-01
            -9.78623525295955309921680509432917e-01 2.05659903085936457411975197828724e-01
            -9.90480443987562964025528344791383e-01 1.37653514587168457339316773868632e-01
            -9.97617272301247637322774153290084e-01 6.89911444043246613322395432987832e-02
            -1.00000000000000000000000000000000e+00 1.22464679914735320717376402945840e-16
            -9.97617272301247637322774153290084e-01 -6.89911444043244254098468104530184e-02
            -9.90480443987563186070133269822691e-01 -1.37653514587168235294711848837323e-01
            -9.78623525295955309921680509432917e-01 -2.05659903085936235367370272797416e-01
            -9.62103019843600471006084262626246e-01 -2.72686228489493920346120603426243e-01
            -9.40997655362376561605231017892947e-01 -3.38413079833670249474408819878590e-01
            -9.15408008525366412300172669347376e-01 -4.02527238739967374581141257294803e-01
            -8.85456025653209910508678603946464e-01 -4.64723172043768451011658271454507e-01
            -8.51284441584351236897987291740719e-01 -5.24704487799008023607427730894415e-01
            -8.13056099478532745550296567671467e-01 -5.82185347720770351997998659498990e-01
            -7.70953174794979489981017195532331e-01 -6.36891829334889303382283287646715e-01
            -7.25176307143376663866263243107824e-01 -6.88563231343276904716788067162270e-01
            -6.75943644144754163249899647780694e-01 -7.36953315984336887467520682548638e-01
            -6.23489801858733705408610603626585e-01 -7.81831482468029692611821701575536e-01
            -5.68064746731155922887523956887890e-01 -8.22983865893656352241691820381675e-01
            -5.09932604390135879590673084749142e-01 -8.60214356413500635945013073069276e-01
            -4.49370400967161243155345573541126e-01 -8.93345533785563139517194031213876e-01
            -3.86666742941419561141458416386740e-01 -9.22219512861810031267850717995316e-01
            -3.22120441798490475537874999645283e-01 -9.46698695982805982218621920765145e-01
            -2.56039090057547769063717169046868e-01 -9.66666428693219392798141598177608e-01
            -1.88737595452916379068497576554364e-01 -9.82027555653430361815026117255911e-01
            -1.20536680255323547239498793715029e-01 -9.92708874098053750678616324876202e-01
            -5.17613528842098338800248313873453e-02 -9.98659482680456123127044065768132e-01
            1.72606409053881054704859820958518e-02 -9.99851024040849245544393397722160e-01
            8.62003798806190713044372841977747e-02 -9.96277819942026465760420705919387e-01
            1.54729334790280975697740473151498e-01 -9.87956898328746446757975263608387e-01
            2.22520933956314226342954043502687e-01 -9.74927912181823619341969333618181e-01
            2.89252119536567486868250398401869e-01 -9.57252950553615811202234908705577e-01
            3.54604887042535565910839068237692e-01 -9.35016242685414833424317748722387e-01
            4.18267800775565190551930072615505e-01 -9.08323756616754018899939637776697e-01
            4.79937477959785641079548668130883e-01 -8.77302694199442401057353890792001e-01
            5.39320034499199296718074947420973e-01 -8.42100884922811654398344671790255e-01
            5.96132485469224815410882456490071e-01 -8.02886081438882848182458928931737e-01
            6.50104093668743776568419434624957e-01 -7.59845160144579256922270360519178e-01
            7.00977659806149677734765646164306e-01 -7.13183230630596076693450413586106e-01
            7.48510748171100748216133524692850e-01 -6.63122658240795526118915859115077e-01
            7.92476841951090138493896120053250e-01 -6.09902004400073138867810484953225e-01
            8.32666422687205698416335053479997e-01 -5.53774889760534128058111491554882e-01
            8.68887968725006842873881396371871e-01 -4.95008785583580857014851517305942e-01
            9.00968867902419034976446710061282e-01 -4.33883739117558342446301367090200e-01
            9.28756240125302223731296180631034e-01 -3.70691039045067671775512962994981e-01
            9.52117665910714117138979872834170e-01 -3.05731827359753016715160356397973e-01
            9.70941817426051789752250442688819e-01 -2.39315664287558654832466231709986e-01
            9.85138989016873800608209421625361e-01 -1.71759053091276009395116375344514e-01
            9.94641524695192735805449046893045e-01 -1.03383931788370062032633711623930e-01
            9.99404140551070518938558961963281e-01 -3.45161389697079615257457874122338e-02
            9.90115745435576899424745533906389e-01 3.57688856886682893243545322548016e-02
            9.84953740398010757495228517655050e-01 1.07120174658302327874714876543294e-01
            9.74656642626950620034165240213042e-01 1.77912988637754426735071433540725e-01
            9.59278136422249017023489159328165e-01 2.47778246674550006733994678143063e-01
            9.38898398194456640375449296698207e-01 3.16351703663407868294399349906598e-01
            9.13623678462142985168270570284221e-01 3.83275849351560338185151977086207e-01
            8.83585747910889396372624560171971e-01 4.48201772231671624613369431244791e-01
            8.48941210401950363539924637734657e-01 5.10790978604877765612002349371323e-01
            8.09870686512232484943751842365600e-01 5.70717157330198454623371162597323e-01
            7.66577871862241910783097864623414e-01 6.27667881059731702642068285058485e-01
            7.19288475141435901250019924191292e-01 6.81346235090181551186105934903026e-01
            6.68249041367628970888858930265997e-01 7.31472365338638130793924574390985e-01
            6.13725666515427037417396149976412e-01 7.77784937372183793335977952665417e-01
            5.56002610215029835494249255134491e-01 8.20042498884619219801095368893584e-01
            4.95380813754140225668720631801989e-01 8.58024738516986462677493818773655e-01
            4.32176331109437650290772126027150e-01 8.91533634458982593429254848160781e-01
            3.66718681187486350570026161221904e-01 9.20394486842988301944501472462434e-01
            2.99349129865738139422148833546089e-01 9.44456828548283944257946131983772e-01
            2.30418910790263636867436503052886e-01 9.63595209666946006521470735606272e-01
            1.60287394206156341702751433331287e-01 9.77709851541579411104976315982640e-01
            8.93202133674759479742277790137450e-02 9.86727166965035817902673898061039e-01
            1.78873582947626612316138761116235e-02 9.90600143830038026848683330172207e-01
            -5.36387531816102589021788560330606e-02 9.89308590228539008748498417844530e-01
            -1.24885217035562823273409094326780e-01 9.82859239722981614661989624437410e-01
            -1.95480587194230337466649416455766e-01 9.71285716240620877748312977928435e-01
            -2.65056812085796900113621177297318e-01 9.54648358773937055765657078154618e-01
            -3.33251153489967810727989672159310e-01 9.33033906801067458580689617519965e-01
            -3.99708077687089491369931693043327e-01 9.06555048066331581324561739165802e-01
            -4.64081109046339979062878455806640e-01 8.75349831078510054460650735563831e-01
            -5.26034636389236864850715846841922e-01 8.39580945389841737380720587680116e-01
            -5.85245662710921044080691899580415e-01 7.99434873408029433861088364210445e-01
            -6.41405489136982920328478030569386e-01 7.55120918163313059601193799608154e-01
            -6.94221324336451783842960594483884e-01 7.06870112099387215565116093785036e-01
            -7.43417811000226191886497417726787e-01 6.54934012577213175987367321795318e-01
            -7.88738461426580217406012707215268e-01 5.99583390371421165454535184835549e-01
            -8.29946994729279019509249337716028e-01 5.41106817996867550668582680373220e-01
            -8.66828568696712875585319579840871e-01 4.79809165225160261236680980800884e-01
            -8.99190899879708127606647849461297e-01 4.16010009634837751857361354268505e-01
            -9.26865266068398030441244372923393e-01 3.50041970481847930507512955955463e-01
            -9.49707385931699565873032042873092e-01 2.82248974576764399824213569445419e-01
            -9.67598171233366999288705301296432e-01 2.12984463209645952241899635737354e-01
            -9.80444347702913443498573542456143e-01 1.42609549470804508608523519797018e-01
            -9.88178941324467263740416456130333e-01 7.14911355743637483284302902575291e-02
            -9.90761627508280673382046188635286e-01 1.21333305584603826192177301949853e-16
            -9.88178941324467263740416456130333e-01 -7.14911355743635262838253652262210e-02
            -9.80444347702913443498573542456143e-01 -1.42609549470804258808342979136796e-01
            -9.67598171233367110311007763812086e-01 -2.12984463209645286108084860643430e-01
            -9.49707385931699454850729580357438e-01 -2.82248974576764566357667263218900e-01
            -9.26865266068398141463546835439047e-01 -3.50041970481847708462908030924154e-01
            -8.99190899879708238628950311976951e-01 -4.16010009634837529812756429237197e-01
            -8.66828568696712986607622042356525e-01 -4.79809165225160039192076055769576e-01
            -8.29946994729279352576156725262990e-01 -5.41106817996866995557070367794950e-01
            -7.88738461426580106383710244699614e-01 -5.99583390371421276476837647351203e-01
            -7.43417811000226302908799880242441e-01 -6.54934012577212953942762396764010e-01
            -6.94221324336452227932170444546500e-01 -7.06870112099386771475906243722420e-01
            -6.41405489136982698283873105538078e-01 -7.55120918163313170623496262123808e-01
            -5.85245662710921266125296824611723e-01 -7.99434873408029211816483439179137e-01
            -5.26034636389236309739203534263652e-01 -8.39580945389842070447627975227078e-01
            -4.64081109046339812529424762033159e-01 -8.75349831078510165482953198079485e-01
            -3.99708077687089491369931693043327e-01 -9.06555048066331581324561739165802e-01
            -3.33251153489968032772594597190619e-01 -9.33033906801067347558387155004311e-01
            -2.65056812085797566247435952391243e-01 -9.54648358773936833721052153123310e-01
            -1.95480587194231225645069116580999e-01 -9.71285716240620766726010515412781e-01
            -1.24885217035562823273409094326780e-01 -9.82859239722981614661989624437410e-01
            -5.36387531816107168691765139101335e-02 -9.89308590228539008748498417844530e-01
            1.78873582947628624595370894212465e-02 -9.90600143830038026848683330172207e-01
            8.93202133674757120518350461679802e-02 -9.86727166965035817902673898061039e-01
            1.60287394206155897613541583268670e-01 -9.77709851541579522127278778498294e-01
            2.30418910790263831156465812455281e-01 -9.63595209666945895499168273090618e-01
            2.99349129865738139422148833546089e-01 -9.44456828548283944257946131983772e-01
            3.66718681187486128525421236190596e-01 -9.20394486842988412966803934978088e-01
            4.32176331109437816824225819800631e-01 -8.91533634458982482406952385645127e-01
            4.95380813754140447713325556833297e-01 -8.58024738516986351655191356258001e-01
            5.56002610215029724471946792618837e-01 -8.20042498884619330823397831409238e-01
            6.13725666515426704350488762429450e-01 -7.77784937372184126402885340212379e-01
            6.68249041367628415777346617687726e-01 -7.31472365338638685905436886969255e-01
            7.19288475141435901250019924191292e-01 -6.81346235090181551186105934903026e-01
            7.66577871862241577716190477076452e-01 -6.27667881059732035708975672605447e-01
            8.09870686512232151876844454818638e-01 -5.70717157330198898712581012659939e-01
            8.48941210401950363539924637734657e-01 -5.10790978604877765612002349371323e-01
            8.83585747910889285350322097656317e-01 -4.48201772231671846657974356276100e-01
            9.13623678462142763123665645252913e-01 -3.83275849351560893296664289664477e-01
            9.38898398194456418330844371666899e-01 -3.16351703663408589939365356258349e-01
            9.59278136422249017023489159328165e-01 -2.47778246674550173267448371916544e-01
            9.74656642626950509011862777697388e-01 -1.77912988637754870824281283603341e-01
            9.84953740398010757495228517655050e-01 -1.07120174658302161341261182769813e-01
            9.90115745435576899424745533906389e-01 -3.57688856886684003466569947704556e-02
            9.73090217583751027063954097684473e-01 3.68495641357207276422869313137198e-02
            9.67516444939804154401485902781133e-01 1.10337621440863647981345252446772e-01
            9.56400825716858138392240107350517e-01 1.83193674842491494025864540162729e-01
            9.39807029175198982429151328688022e-01 2.55000411464513243586793578288052e-01
            9.17830103078694947704718742897967e-01 3.25346528822326119811947364723892e-01
            8.90595929269811459327854663570179e-01 3.93829090726199870786672363465186e-01
            8.58260502629818122777294320258079e-01 4.60055835263282419944630419195164e-01
            8.21009037554235043820938244607532e-01 5.23647421638313015357368840341223e-01
            7.79054907061548229663117126619909e-01 5.84239603003345653320366182015277e-01
            7.32638420611883223187987823621370e-01 6.41485312830706866371599517151481e-01
            6.82025447636178783206162279384444e-01 6.95056652878637271086859072966035e-01
            6.27505894660164376119837470469065e-01 7.44646771362725501397505922795972e-01
            5.69392044746033332280887861998053e-01 7.89971620575141697528920303739142e-01
            5.08016768763344561676831290242262e-01 8.30771583884183484336460878694197e-01
            4.43731618734824362348945214762352e-01 8.66812962794833219426493542414391e-01
            3.76904814178217584252905680841650e-01 8.97889315552572897516370176163036e-01
            3.07919132978235698949731613538461e-01 9.23822639623058883273643004940823e-01
            2.37169718869497059277051675962866e-01 9.44464391274519199370729438669514e-01
            1.65061818088998224496322109189350e-01 9.59696336422797280363283789483830e-01
            9.20084581623694108820643577928422e-02 9.69431227865477862515319884550991e-01
            1.84280821196084777791046604988878e-02 9.73613305025962327832189657783601e-01
            -5.52578483086997099271719946500525e-02 9.72218613345001370085185499192448e-01
            -1.28627266786007721233175971065066e-01 9.65255141490241164170527099486208e-01
            -2.01259919927561259367365664729732e-01 9.52762775597858935228146037843544e-01
            -2.72739774473727825121471823877073e-01 9.34813070808385937482398730935529e-01
            -3.42657400290833191736084017975372e-01 9.11508841405343717134712733241031e-01
            -4.10612315549888473587003545617335e-01 8.82983571904338071512086116854334e-01
            -4.76215280650239436432968886947492e-01 8.49400652465842065375056790799135e-01
            -5.39090527748750325542914652032778e-01 8.10952443011153656371448050776962e-01
            -5.98877913123979310761058059142670e-01 7.67859171402186291288671782240272e-01
            -6.55234980046801140929346729535609e-01 7.20367671996219205432510079845088e-01
            -7.07838920341538835323547118605347e-01 6.68749971801053111342127976968186e-01
            -7.56388423401959775205227742844727e-01 6.13301732328942694749684960697778e-01
            -8.00605402071143834596966826211428e-01 5.54340556074229939831354840862332e-01
            -8.40236585499532728782412505097454e-01 4.92204167315018592532283037144225e-01
            -8.75054969857420483769772090454353e-01 4.27248477659094128000560885993764e-01
            -9.04861118592333868448918110516388e-01 3.59845547414463451385557846151642e-01
            -9.29484304783543602290762919437839e-01 2.90381454461604682215636330511188e-01
            -9.48783489050405104414664947398705e-01 2.19254082834332342244465507974382e-01
            -9.62648127413158305465401554101845e-01 1.46870843676082107887026495518512e-01
            -9.70998804478833466014009445643751e-01 7.36463416257766012584795589646092e-02
            -9.73787688325429834357294112123782e-01 -3.13194007514475385893098079558657e-16
            -9.70998804478833466014009445643751e-01 -7.36463416257763653360868261188443e-02
            -9.62648127413158416487704016617499e-01 -1.46870843676081413997636104795674e-01
            -9.48783489050405215436967409914359e-01 -2.19254082834332120199860582943074e-01
            -9.29484304783543713313065381953493e-01 -2.90381454461604460171031405479880e-01
            -9.04861118592334090493523035547696e-01 -3.59845547414462840762894302315544e-01
            -8.75054969857420372747469627938699e-01 -4.27248477659094294534014579767245e-01
            -8.40236585499532839804714967613108e-01 -4.92204167315018370487678112112917e-01
            -8.00605402071143945619269288727082e-01 -5.54340556074229717786749915831024e-01
            -7.56388423401960108272135130391689e-01 -6.13301732328942139638172648119507e-01
            -7.07838920341538946345849581121001e-01 -6.68749971801052889297523051936878e-01
            -6.55234980046801029907044267019955e-01 -7.20367671996219427477115004876396e-01
            -5.98877913123979199738755596627016e-01 -7.67859171402186402310974244755926e-01
            -5.39090527748750880654426964611048e-01 -8.10952443011153212282238200714346e-01
            -4.76215280650239269899515193174011e-01 -8.49400652465842176397359253314789e-01
            -4.10612315549889084209667089453433e-01 -8.82983571904337738445178729307372e-01
            -3.42657400290833025202630324201891e-01 -9.11508841405343828157015195756685e-01
            -2.72739774473728491255286598970997e-01 -9.34813070808385826460096268419875e-01
            -2.01259919927561731212151130421262e-01 -9.52762775597858824205843575327890e-01
            -1.28627266786007332655117352260277e-01 -9.65255141490241275192829562001862e-01
            -5.52578483087001609552757486198971e-02 -9.72218613345001370085185499192448e-01
            1.84280821196078081758429334513494e-02 -9.73613305025962327832189657783601e-01
            9.20084581623689529150666999157693e-02 -9.69431227865477862515319884550991e-01
            1.65061818088997974696141568529129e-01 -9.59696336422797280363283789483830e-01
            2.37169718869496642943417441529164e-01 -9.44464391274519310393031901185168e-01
            3.07919132978235476905126688507153e-01 -9.23822639623058994295945467456477e-01
            3.76904814178217362208300755810342e-01 -8.97889315552573008538672638678690e-01
            4.43731618734824140304340289731044e-01 -8.66812962794833330448796004930045e-01
            5.08016768763344339632226365210954e-01 -8.30771583884183595358763341209851e-01
            5.69392044746033221258585399482399e-01 -7.89971620575141808551222766254796e-01
            6.27505894660164154075232545437757e-01 -7.44646771362725723442110847827280e-01
            6.82025447636178783206162279384444e-01 -6.95056652878637271086859072966035e-01
            7.32638420611883112165685361105716e-01 -6.41485312830706977393901979667135e-01
            7.79054907061548229663117126619909e-01 -5.84239603003345653320366182015277e-01
            8.21009037554234932798635782091878e-01 -5.23647421638313126379671302856877e-01
            8.58260502629818122777294320258079e-01 -4.60055835263282419944630419195164e-01
            8.90595929269811459327854663570179e-01 -3.93829090726199870786672363465186e-01
            9.17830103078694614637811355351005e-01 -3.25346528822326896968064602333470e-01
            9.39807029175199093451453791203676e-01 -2.55000411464513188075642347030225e-01
            9.56400825716857916347635182319209e-01 -1.83193674842492243426406162143394e-01
            9.67516444939804043379183440265479e-01 -1.10337621440864355748523450984067e-01
            9.73090217583751027063954097684473e-01 -3.68495641357214076538895142221008e-02
            9.51003839275275653086794136470417e-01 3.78385137272492719229255442314752e-02
            9.44991286808092745275189372478053e-01 1.13276313915074866578436285635689e-01
            9.33004195166289629348455036961241e-01 1.87997944774685649127476949615811e-01
            9.15118350602716845720863148017088e-01 2.61530992097618208980236431671074e-01
            8.91446833185421838585682507982710e-01 3.33410556283217029971410738653503e-01
            8.62139301869049412552215017058188e-01 4.03182191583593696471154999017017e-01
            8.27381048302745281119996434426866e-01 4.70404779255963634287951435908326e-01
            7.87391825356691943404996436584042e-01 5.34653316457364025104936899879249e-01
            7.42424457773708468266704585403204e-01 5.95521603249467901264324609655887e-01
            6.92763243729825339833894304319983e-01 6.52624810725375481545995626220247e-01
            6.38722157409679303086136314959731e-01 7.05601914021869891513460970600136e-01
            5.80642863960627808594949783582706e-01 7.54117974834840776310329601983540e-01
            5.18892559375680906263994529581396e-01 7.97866259007082634369112383865286e-01
            4.53861648962208263924367201980203e-01 8.36570175800396831355953963793581e-01
            3.85961279073884888646261970279738e-01 8.69985026591292731623639156168792e-01
            3.15620737711069021536047785048140e-01 8.97899551934470019354250780452276e-01
            2.43284740423842682499611100865877e-01 9.20137267213052889580637838662369e-01
            1.69410618677120927699775165820029e-01 9.36557578431159054588306389632635e-01
            9.44654284538824495776054845919134e-02 9.47056671094410162936583219561726e-01
            1.89229973768672912748378678315930e-02 9.51568166558590111669957423146116e-01
            -5.67390709822134034490126452965342e-02 9.50063541696805180514218136522686e-01
            -1.32042416666231759991845251533960e-01 9.42552309231876384032489113451447e-01
            -2.06510947678308770525390514194441e-01 9.29081957593843488218965376290726e-01
            -2.79673849988708034253193090989953e-01 9.09737650682819198877382405044045e-01
            -3.51068564172718977633991244147182e-01 8.84641689435393452356493071420118e-01
            -4.20243709860270708844609544030391e-01 8.53952738598734217845276361913420e-01
            -4.86761939507963370399323821402504e-01 8.17864823600970902717222088540439e-01
            -5.50202703451048824589975083654281e-01 7.76606103859967533686869956000010e-01
            -6.10164908753817125663942988467170e-01 7.30437430286022260084166646265658e-01
            -6.66269455048277503550480105332099e-01 6.79650696098424433877482897514710e-01
            -7.18161631328740890367612337286118e-01 6.24566991382544234312490516458638e-01
            -7.65513358549006484032872776879231e-01 5.65534573054929934343704189814162e-01
            -8.08025263843723529078033607220277e-01 5.02926663070951684986198415572289e-01
            -8.45428573260034954550690144969849e-01 4.37139088795435060141869598737685e-01
            -8.77486811033044267205127653141972e-01 3.68587780454615598912937457498629e-01
            -9.03997294661740613541667244135169e-01 2.97706141491329845383262409086456e-01
            -9.24792416333026334740452512050979e-01 2.24942308448908806495225576327357e-01
            -9.39740702592277821203481380507583e-01 1.50756317707661902094429251519614e-01
            -9.48747645560855445978631905745715e-01 7.56171969867634186091009951269371e-02
            -9.51756300445340652771619716077112e-01 1.16556530690871313641069803870210e-16
            -9.48747645560855445978631905745715e-01 -7.56171969867631826867082622811722e-02
            -9.39740702592277932225783843023237e-01 -1.50756317707661680049824326488306e-01
            -9.24792416333026334740452512050979e-01 -2.24942308448908584450620651296049e-01
            -9.03997294661740724563969706650823e-01 -2.97706141491329623338657484055148e-01
            -8.77486811033044378227430115657626e-01 -3.68587780454615376868332532467321e-01
            -8.45428573260035065572992607485503e-01 -4.37139088795434838097264673706377e-01
            -8.08025263843723862144940994767239e-01 -5.02926663070951240896988565509673e-01
            -7.65513358549006595055175239394885e-01 -5.65534573054929712299099264782853e-01
            -7.18161631328741001389914799801772e-01 -6.24566991382544123290188053942984e-01
            -6.66269455048277392528177642816445e-01 -6.79650696098424544899785360030364e-01
            -6.10164908753817347708547913498478e-01 -7.30437430286022149061864183750004e-01
            -5.50202703451049046634580008685589e-01 -7.76606103859967422664567493484356e-01
            -4.86761939507963592443928746433812e-01 -8.17864823600970902717222088540439e-01
            -4.20243709860270930889214469061699e-01 -8.53952738598734217845276361913420e-01
            -3.51068564172719532745503556725453e-01 -8.84641689435393119289585683873156e-01
            -2.79673849988708311808949247279088e-01 -9.09737650682819087855079942528391e-01
            -2.06510947678308798280966129823355e-01 -9.29081957593843488218965376290726e-01
            -1.32042416666231565702815942131565e-01 -9.42552309231876384032489113451447e-01
            -5.67390709822140557050396125760017e-02 -9.50063541696805069491915674007032e-01
            1.89229973768670588218920869394424e-02 -9.51568166558590111669957423146116e-01
            9.44654284538826299888469861798512e-02 -9.47056671094410162936583219561726e-01
            1.69410618677120483610565315757412e-01 -9.36557578431159165610608852148289e-01
            2.43284740423842460455006175834569e-01 -9.20137267213052889580637838662369e-01
            3.15620737711069021536047785048140e-01 -8.97899551934470019354250780452276e-01
            3.85961279073884444557052120217122e-01 -8.69985026591292842645941618684446e-01
            4.53861648962207819835157351917587e-01 -8.36570175800397053400558888824889e-01
            5.18892559375680906263994529581396e-01 -7.97866259007082634369112383865286e-01
            5.80642863960627253483437471004436e-01 -7.54117974834841220399539452046156e-01
            6.38722157409678970019228927412769e-01 -7.05601914021870113558065895631444e-01
            6.92763243729825228811591841804329e-01 -6.52624810725375592568298088735901e-01
            7.42424457773708024177494735340588e-01 -5.95521603249468345353534459718503e-01
            7.87391825356691610338089049037080e-01 -5.34653316457364580216449212457519e-01
            8.27381048302745281119996434426866e-01 -4.70404779255963745310253898423980e-01
            8.62139301869049412552215017058188e-01 -4.03182191583593696471154999017017e-01
            8.91446833185421616541077582951402e-01 -3.33410556283217585082923051231774e-01
            9.15118350602716845720863148017088e-01 -2.61530992097618542047143819218036e-01
            9.33004195166289629348455036961241e-01 -1.87997944774685676883052565244725e-01
            9.44991286808092634252886909962399e-01 -1.13276313915075463323312021657330e-01
            9.51003839275275653086794136470417e-01 -3.78385137272496327454085474073509e-02
            9.24815088837064203097781955875689e-01 3.87612366137685127043255306489300e-02
            9.18328175467596707903794595040381e-01 1.16011827616370064020223651368724e-01
            9.05399849765107789245632829988608e-01 1.92448679002625883116550653539889e-01
            8.86120794645411047341099219920579e-01 2.67535641179863392657978238275973e-01
            8.60626238828189449314720604888862e-01 3.40746033058317077113485993322683e-01
            8.29095008304687408617894561757566e-01 4.11566336340553673434072834425024e-01
            7.91748272001869590752676231204532e-01 4.79499797483365963746138049828005e-01
            7.48847990441307231890277762431651e-01 5.44069912066961647312268723908346e-01
            7.00695078274337745938282751012594e-01 6.04823767131099976346320090669906e-01
            6.47627293581993224158566135884030e-01 6.61335218034090677186043194524245e-01
            5.90016868744739131358301165164448e-01 7.13207877551271018923273459222401e-01
            5.28267899499776150129548568656901e-01 7.60077896246581952155452199804131e-01
            4.62813510499784086515973058340023e-01 8.01616514614938324712056783027947e-01
            3.94112817254684888457205715894816e-01 8.37532369093941908566591791895917e-01
            3.22647705766212489209010527702048e-01 8.67573535769928239069770370406331e-01
            2.48919452443846722644593683071434e-01 8.91529297443214185925342007976724e-01
            1.73445208010967355516385168812121e-01 9.09231621657852207007977085595485e-01
            9.67543700641010917529172274953453e-02 9.20556339328579276148900589760160e-01
            1.93848697291539168174878682293638e-02 9.25424015697733692853432785341283e-01
            -5.81206015389333779941338775643089e-02 9.23800507513006241566699827671982e-01
            -1.35218398546819634775673080184788e-01 9.15697202517824049294858923531137e-01
            -2.11367735643185478133787569277047e-01 9.01170939574511553615820957929827e-01
            -2.86034479941522867818548547802493e-01 8.80323609980510513040030673437286e-01
            -3.58694897878560792214841512759449e-01 8.53301442774137219871022352890577e-01
            -4.28839328828908794566387996383128e-01 8.20293979042944321200536705873674e-01
            -4.95975760008154964442184109429945e-01 7.81532742429175808496211175224744e-01
            -5.59633277589035915688953082280932e-01 7.37289615157767252995313356223051e-01
            -6.19365369823584810404781819670461e-01 6.87874930977884546656753173010657e-01
            -6.74753059002225263895979878725484e-01 6.33635298394648271980145182169508e-01
            -7.25407840281369398205413290270371e-01 5.74951169459507083203675392724108e-01
            -7.70974406765753794701367951347493e-01 5.12234171172452512621475761989132e-01
            -8.11133141731023354914498213474872e-01 4.45924218214367562573841041739797e-01
            -8.45602360505407935065136371122207e-01 3.76486427261617906392388022140949e-01
            -8.74140286285305045943516688566888e-01 3.04407854526752397195110688699060e-01
            -8.96546746025839724758554893924156e-01 2.30194079409123369961420735307911e-01
            -9.12664574510951509545009230350843e-01 1.54365658218657220146496911183931e-01
            -9.22380716754460983075603053293889e-01 7.74544728473600119222908233496128e-02
            -9.25627020999568395076551041711355e-01 1.13356616847142141084685043055105e-16
            -9.22380716754460983075603053293889e-01 -7.74544728473597759998980905038479e-02
            -9.12664574510951398522706767835189e-01 -1.54365658218657386679950604957412e-01
            -8.96546746025839835780857356439810e-01 -2.30194079409123147916815810276603e-01
            -8.74140286285304934921214226051234e-01 -3.04407854526752508217413151214714e-01
            -8.45602360505408046087438833637862e-01 -3.76486427261617684347783097109641e-01
            -8.11133141731023465936800675990526e-01 -4.45924218214367396040387347966316e-01
            -7.70974406765753683679065488831839e-01 -5.12234171172452734666080687020440e-01
            -7.25407840281369509227715752786025e-01 -5.74951169459506861159070467692800e-01
            -6.74753059002225707985189728788100e-01 -6.33635298394647827890935332106892e-01
            -6.19365369823584699382479357154807e-01 -6.87874930977884657679055635526311e-01
            -5.59633277589036359778162932343548e-01 -7.37289615157766919928405968676088e-01
            -4.95975760008154853419881646914291e-01 -7.81532742429175919518513637740398e-01
            -4.28839328828909405189051540219225e-01 -8.20293979042944099155931780842366e-01
            -3.58694897878561014259446437790757e-01 -8.53301442774137219871022352890577e-01
            -2.86034479941523089863153472833801e-01 -8.80323609980510402017728210921632e-01
            -2.11367735643185700178392494308355e-01 -9.01170939574511553615820957929827e-01
            -1.35218398546820689487546474083501e-01 -9.15697202517823938272556461015483e-01
            -5.81206015389334057497094931932224e-02 -9.23800507513006241566699827671982e-01
            1.93848697291532749698017568107389e-02 -9.25424015697733692853432785341283e-01
            9.67543700641012721641587290832831e-02 -9.20556339328579276148900589760160e-01
            1.73445208010966939182750934378419e-01 -9.09231621657852207007977085595485e-01
            2.48919452443846500599988758040126e-01 -8.91529297443214185925342007976724e-01
            3.22647705766212267164405602670740e-01 -8.67573535769928350092072832921986e-01
            3.94112817254684832946054484636988e-01 -8.37532369093941908566591791895917e-01
            4.62813510499783586915611977019580e-01 -8.01616514614938657778964170574909e-01
            5.28267899499776150129548568656901e-01 -7.60077896246581952155452199804131e-01
            5.90016868744738687269091315101832e-01 -7.13207877551271351990180846769363e-01
            6.47627293581993335180868598399684e-01 -6.61335218034090455141438269492937e-01
            7.00695078274337523893677825981285e-01 -6.04823767131100198390925015701214e-01
            7.48847990441307120867975299915997e-01 -5.44069912066961869356873648939654e-01
            7.91748272001869479730373768688878e-01 -4.79499797483366074768440512343659e-01
            8.29095008304687408617894561757566e-01 -4.11566336340553673434072834425024e-01
            8.60626238828189116247813217341900e-01 -3.40746033058317798758451999674435e-01
            8.86120794645411158363401682436233e-01 -2.67535641179863170613373313244665e-01
            9.05399849765107678223330367472954e-01 -1.92448679002626382716911734860332e-01
            9.18328175467596707903794595040381e-01 -1.16011827616369633808801609120565e-01
            9.24815088837064203097781955875689e-01 -3.87612366137687971989755908452935e-02
            8.95078453263471462975076065049507e-01 3.96311054446122565386723124447599e-02
            8.88073250774465083878794757765718e-01 1.18583149199894002934208003807726e-01
            8.74117671003933560669452162983362e-01 1.96607119031710630974174591756309e-01
            8.53320935285255544044957787264138e-01 2.73092371587320081882666045203223e-01
            8.25845806272686222548884416028159e-01 3.47440306062936632436333184159594e-01
            7.91907314102905601771453802939504e-01 4.19069049066633336764198247692548e-01
            7.51771073492650376834944836446084e-01 4.87418008566567362294108534115367e-01
            7.05751204943422472126712818862870e-01 5.51952261283707112937690908438526e-01
            6.54207876322662862378365389304236e-01 6.12166739191767672600974492524983e-01
            5.97544484061857450463151053554611e-01 6.67590182359311667958934322086861e-01
            5.36204496032513078240810955321649e-01 7.17788827197671674973378230788512e-01
            4.70667980808789354618681954889325e-01 7.62369801249149325883536221226677e-01
            4.01447850480003198825329491228331e-01 8.00984197946673193158062531438190e-01
            3.29085846418098570964616556011606e-01 8.33329807280751233555804446950788e-01
            2.54148299416890932622692389486474e-01 8.59153481002546293154864542884752e-01
            1.77221697385746751463031500861689e-01 8.78253113852154432272811845905380e-01
            9.89080952865007273500097539908893e-02 8.90479225306287980323816100280965e-01
            1.98204032370863265921645535172502e-02 8.95736129466044084246334477938944e-01
            -5.94224103411545787056802225833962e-02 8.93982683928798316230768250534311e-01
            -1.38200162990594149770018361778057e-01 8.85232611783289269347108074725838e-01
            -2.15896311985925876131275913394347e-01 8.69554394207841530040070665563690e-01
            -2.91902779616929675121639320423128e-01 8.47070734512295975271456427435623e-01
            -3.65624712221015057966866379501880e-01 8.17957597818242843068503589165630e-01
            -4.36485135719664574249776478609419e-01 7.82442833893362665875770289858337e-01
            -5.03929471222887670478485233616084e-01 7.40804393918064740809370505303377e-01
            -5.67429875360963120733970299625071e-01 6.93368155140638320332868715922814e-01
            -6.26489371374479908638477354543284e-01 6.40505370445946686785987367329653e-01
            -6.80645738631308061528102371084969e-01 5.82629762798238304277731458569178e-01
            -7.29475130129746185403405434044544e-01 5.20194287298005875186390767339617e-01
            -7.72595389675983623689603518869262e-01 4.53687586194184366839010635885643e-01
            -8.09669042774461833467114502127515e-01 3.83630164596029943346877644216875e-01
            -8.40405937823369142414264842955163e-01 3.10570316814910207803279718064005e-01
            -8.64565516944324929937693013926037e-01 2.35079835217915866785176604025764e-01
            -8.81958698673939944789879064046545e-01 1.57749535177320404644163431839843e-01
            -8.92449357782632457514182533486746e-01 7.91846311392377655291596738607041e-02
            -8.95955390639115667461567227292107e-01 1.09722890132500943934843550503494e-16
            -8.92449357782632457514182533486746e-01 -7.91846311392375434845547488293960e-02
            -8.81958698673940055812181526562199e-01 -1.57749535177320210355134122437448e-01
            -8.64565516944325040959995476441691e-01 -2.35079835217915672496147294623370e-01
            -8.40405937823369031391962380439509e-01 -3.10570316814910374336733411837486e-01
            -8.09669042774462166534021889674477e-01 -3.83630164596029388235365331638604e-01
            -7.72595389675983512667301056353608e-01 -4.53687586194184588883615560916951e-01
            -7.29475130129746185403405434044544e-01 -5.20194287298005653141785842308309e-01
            -6.80645738631308283572707296116278e-01 -5.82629762798238193255428996053524e-01
            -6.26489371374479797616174892027630e-01 -6.40505370445946797808289829845307e-01
            -5.67429875360963231756272762140725e-01 -6.93368155140638098288263790891506e-01
            -5.03929471222888114567695083678700e-01 -7.40804393918064407742463117756415e-01
            -4.36485135719664074649415397288976e-01 -7.82442833893362887920375214889646e-01
            -3.65624712221015668589529923337977e-01 -8.17957597818242510001596201618668e-01
            -2.91902779616929897166244245454436e-01 -8.47070734512295864249153964919969e-01
            -2.15896311985926458998363841601531e-01 -8.69554394207841307995465740532381e-01
            -1.38200162990594760392681905614154e-01 -8.85232611783289158324805612210184e-01
            -5.94224103411545995223619343050814e-02 -8.93982683928798316230768250534311e-01
            1.98204032370859067890833671299333e-02 -8.95736129466044084246334477938944e-01
            9.89080952865003110163755195571866e-02 -8.90479225306287980323816100280965e-01
            1.77221697385746723707455885232775e-01 -8.78253113852154432272811845905380e-01
            2.54148299416890932622692389486474e-01 -8.59153481002546293154864542884752e-01
            3.29085846418098904031523943558568e-01 -8.33329807280751122533501984435134e-01
            4.01447850480003365358783185001812e-01 -8.00984197946673082135760068922536e-01
            4.70667980808788688484867179795401e-01 -7.62369801249149658950443608773639e-01
            5.36204496032512967218508492805995e-01 -7.17788827197671785995680693304166e-01
            5.97544484061857006373941203491995e-01 -6.67590182359312001025841709633823e-01
            6.54207876322662529311458001757273e-01 -6.12166739191768116690184342587600e-01
            7.05751204943422361104410356347216e-01 -5.51952261283707223959993370954180e-01
            7.51771073492650265812642373930430e-01 -4.87418008566567584338713459146675e-01
            7.91907314102905712793756265455158e-01 -4.19069049066633225741895785176894e-01
            8.25845806272686222548884416028159e-01 -3.47440306062936632436333184159594e-01
            8.53320935285255544044957787264138e-01 -2.73092371587320359438422201492358e-01
            8.74117671003933671691754625499016e-01 -1.96607119031710297907267204209347e-01
            8.88073250774465194901097220281372e-01 -1.18583149199893878034117733477615e-01
            8.95078453263471462975076065049507e-01 -3.96311054446131585948798203844490e-02
            8.62168043706588393959577842906583e-01 4.04562326275469397174333607836161e-02
            8.54591279938204939625734368746635e-01 1.21013167055657372417343253800937e-01
            8.39504337273866307889136351150228e-01 2.00506633420508617593469580242527e-01
            8.17039800308175911958130654966226e-01 2.78238040281403031794837943380116e-01
            7.87395088199727810618355761107523e-01 3.53524281239920801223064472651458e-01
            7.50830719744442154350849705224391e-01 4.25703738103511031276582343707560e-01
            7.07668023927019995689136067085201e-01 4.94142095209957277202050818232237e-01
            6.58286316070271326772456177423010e-01 5.58237913816224562424395116977394e-01
            6.03119564398420404671696815057658e-01 6.17427917563758588137545757490443e-01
            5.42652576308746081856781984242843e-01 6.71191942571378263870940372726182e-01
            4.77416737866743767781940732675139e-01 7.19057508654166399608698156953324e-01
            4.07985343966275115779041016139672e-01 7.60603971496323416623397406510776e-01
            3.34968560193426634352675819172873e-01 7.95466219288539333476251158572268e-01
            2.59008060669400630438019561552210e-01 8.23337881343702004954820949933492e-01
            1.80771388995264958854392034481862e-01 8.43974020493511556395560546661727e-01
            1.00946091854786368369190086013987e-01 8.57193285605122312631465320009738e-01
            2.02336768294492895525760189912035e-02 8.62879505301418769924737262044800e-01
            -6.06565524753908194566243139433936e-02 8.60982708879254987621720829338301e-01
            -1.41013729816098026814685795216064e-01 8.51519565453790594489191789762117e-01
            -2.20131673428862972841102418897208e-01 8.34573237469707129854157301451778e-01
            -2.97315091980435541874072669088491e-01 8.10292649866654612900163101585349e-01
            -3.71885694813362310817694833531277e-01 7.78891181321526238079400172864553e-01
            -4.43188152788671185788871298427694e-01 7.40644789068974129797595651325537e-01
            -5.10595857341909931115253584721358e-01 6.95889583779308873445756944420282e-01
            -5.73516427141739004724740880192257e-01 6.45018875805843605597544865304371e-01
            -6.31396913958372829611676024796907e-01 5.88479718759366332569982205313863e-01
            -6.83728661992504704869588749716058e-01 5.26768980784934837124922069051536e-01
            -7.30051777960759262775525257893605e-01 4.60428978066752425668539672187762e-01
            -7.69959172654403833924163791380124e-01 3.90042708934041915114221410476603e-01
            -8.03100138453952894224130432121456e-01 3.16228730450763217962872886346304e-01
            -8.29183431360336342663686082232744e-01 2.39635722513898530294795818917919e-01
            -8.47979830457636585272496176912682e-01 1.60936787231191202884872382128378e-01
            -8.59324152314739575508895086386474e-01 8.08235336756202571439899884353508e-02
            -8.63116702623266229821297201851849e-01 1.05701310715820096636179810332571e-16
            -8.59324152314739575508895086386474e-01 -8.08235336756200350993850634040427e-02
            -8.47979830457636696294798639428336e-01 -1.60936787231191008595843072725984e-01
            -8.29183431360336453685988544748398e-01 -2.39635722513898336005766509515524e-01
            -8.03100138453953005246432894637110e-01 -3.16228730450763051429419192572823e-01
            -7.69959172654404055968768716411432e-01 -3.90042708934041360002709097898332e-01
            -7.30051777960759151753222795377951e-01 -4.60428978066752592201993365961243e-01
            -6.83728661992504815891891212231712e-01 -5.26768980784934615080317144020228e-01
            -6.31396913958372940633978487312561e-01 -5.88479718759366110525377280282555e-01
            -5.73516427141739115747043342707912e-01 -6.45018875805843494575242402788717e-01
            -5.10595857341910153159858509752667e-01 -6.95889583779308762423454481904628e-01
            -4.43188152788671352322324992201175e-01 -7.40644789068974018775293188809883e-01
            -3.71885694813362199795392371015623e-01 -7.78891181321526238079400172864553e-01
            -2.97315091980436096985584981666761e-01 -8.10292649866654501877860639069695e-01
            -2.20131673428863167130131728299602e-01 -8.34573237469707129854157301451778e-01
            -1.41013729816098054570261410844978e-01 -8.51519565453790594489191789762117e-01
            -6.06565524753906529231706201699126e-02 -8.60982708879254987621720829338301e-01
            2.02336768294490779163119498207379e-02 -8.62879505301418769924737262044800e-01
            1.00946091854786160202372968797135e-01 -8.57193285605122423653767782525392e-01
            1.80771388995265125387845728255343e-01 -8.43974020493511556395560546661727e-01
            2.59008060669400019815356017716113e-01 -8.23337881343702115977123412449146e-01
            3.34968560193426412308070894141565e-01 -7.95466219288539444498553621087922e-01
            4.07985343966275115779041016139672e-01 -7.60603971496323416623397406510776e-01
            4.77416737866743323692730882612523e-01 -7.19057508654166732675605544500286e-01
            5.42652576308746303901386909274152e-01 -6.71191942571378041826335447694873e-01
            6.03119564398420293649394352542004e-01 -6.17427917563758588137545757490443e-01
            6.58286316070270993705548789876048e-01 -5.58237913816225006513604967040010e-01
            7.07668023927020106711438529600855e-01 -4.94142095209956999646294661943102e-01
            7.50830719744442043328547242708737e-01 -4.25703738103511308832338499996695e-01
            7.87395088199727477551448373560561e-01 -3.53524281239921522868030479003210e-01
            8.17039800308176022980433117481880e-01 -2.78238040281402865261384249606635e-01
            8.39504337273866307889136351150228e-01 -2.00506633420508978415952583418402e-01
            8.54591279938204939625734368746635e-01 -1.21013167055657538950796947574418e-01
            8.62168043706588393959577842906583e-01 -4.04562326275468772673882256185607e-02
            8.26358224087778370225976232177345e-01 4.12418243894476163613482810887945e-02
            8.18145504799498102244115216308273e-01 1.23315593388879179981287848022475e-01
            8.01801687916946281831087617320009e-01 2.04163796619314413804957553111308e-01
            7.77489205635075286693336238386109e-01 2.82982928314441939399159764434444e-01
            7.45449686325651672547110138111748e-01 3.58989648532467509056687049451284e-01
            7.06001553125941594402092960081063e-01 4.31428568340386120461005248216679e-01
            6.59536859306514955392231058795005e-01 4.99579757208571617610459725256078e-01
            6.06517391869704769469251459668158e-01 5.62765898003821707362703818944283e-01
            5.47470082102911814736501128209056e-01 6.20359018471326795207687609945424e-01
            4.82981768698735935974042376983562e-01 6.71786732305065581449809997138800e-01
            4.13693365488400299767590695410036e-01 7.16537927780070638128506743669277e-01
            3.40293491752155119467460053783725e-01 7.54167847410377789607593967957655e-01
            2.63511628411492893064860254526138e-01 7.84302508148737476112444255704759e-01
            1.84110868120019616211990864940162e-01 8.06642418198156629927098038024269e-01
            1.02880331305827674159836249145883e-01 8.20965553495930810967706747760531e-01
            2.06273235381545863575958321689541e-02 8.27129564288527463489231195126195e-01
            -6.18306878380619623358782632749353e-02 8.25073189867389311658030237595085e-01
            -1.43674198059920182890536466402409e-01 8.14816867405379507971474595251493e-01
            -2.24089809553067259573211345013988e-01 7.96462528842975192588937716209330e-01
            -3.02278315842227196519331755553139e-01 7.70192587842848386259220205829479e-01
            -3.77462644424210569393807190863299e-01 7.36268126880933793110273199999938e-01
            -4.48895579663567412254110422509257e-01 6.95026302491486114298879783746088e-01
            -5.15867188957270794702480998239480e-01 6.46876994453969289544659204693744e-01
            -5.77711878363878827968846962903626e-01 5.92298732223660806539555778726935e-01
            -6.33815007575154965024921693839133e-01 5.31833939090937679594617293332703e-01
            -6.83618998487589557555565988877788e-01 4.66083541334921969134796881917282e-01
            -7.26628876664096146065219272713875e-01 3.95700995948141176494772253136034e-01
            -7.62417190612342587918703884497518e-01 3.21385796287359193357247022504453e-01
            -7.90628259989724191392213015205925e-01 2.43876520194335116853423528482381e-01
            -8.10981710514404707801361382735195e-01 1.63943489677410625393605414501508e-01
            -8.23275260450890944419199968251633e-01 8.23811151053123885690254724067927e-02
            -8.27386730976800821579786315851379e-01 1.01325651174773132794728930721167e-16
            -8.23275260450890944419199968251633e-01 -8.23811151053121804022083551899414e-02
            -8.10981710514404818823663845250849e-01 -1.63943489677410431104576105099113e-01
            -7.90628259989724413436817940237233e-01 -2.43876520194334589497486831533024e-01
            -7.62417190612342476896401421981864e-01 -3.21385796287359359890700716277934e-01
            -7.26628876664096257087521735229529e-01 -3.95700995948140954450167328104726e-01
            -6.83618998487589779600170913909096e-01 -4.66083541334921913623645650659455e-01
            -6.33815007575155187069526618870441e-01 -5.31833939090937457550012368301395e-01
            -5.77711878363879050013451887934934e-01 -5.92298732223660695517253316211281e-01
            -5.15867188957270905724783460755134e-01 -6.46876994453969067500054279662436e-01
            -4.48895579663567301231807959993603e-01 -6.95026302491486114298879783746088e-01
            -3.77462644424211068994168272183742e-01 -7.36268126880933571065668274968630e-01
            -3.02278315842227862653146530647064e-01 -7.70192587842848164214615280798171e-01
            -2.24089809553066954261879573095939e-01 -7.96462528842975303611240178724984e-01
            -1.43674198059920210646112082031323e-01 -8.14816867405379507971474595251493e-01
            -6.18306878380623439750429781724961e-02 -8.25073189867389311658030237595085e-01
            2.06273235381543816602256669057169e-02 -8.27129564288527463489231195126195e-01
            1.02880331305827119048323936567613e-01 -8.20965553495930921990009210276185e-01
            1.84110868120019421922961555537768e-01 -8.06642418198156629927098038024269e-01
            2.63511628411493004087162717041792e-01 -7.84302508148737365090141793189105e-01
            3.40293491752154841911703897494590e-01 -7.54167847410377900629896430473309e-01
            4.13693365488400521812195620441344e-01 -7.16537927780070638128506743669277e-01
            4.82981768698735602907134989436599e-01 -6.71786732305065692472112459654454e-01
            5.47470082102911259624988815630786e-01 -6.20359018471327239296897460008040e-01
            6.06517391869704991513856384699466e-01 -5.62765898003821596340401356428629e-01
            6.59536859306514844369928596279351e-01 -4.99579757208571728632762187771732e-01
            7.06001553125941705424395422596717e-01 -4.31428568340386064949854016958852e-01
            7.45449686325651561524807675596094e-01 -3.58989648532467675590140743224765e-01
            7.77489205635075064648731313354801e-01 -2.82982928314442494510672077012714e-01
            8.01801687916946281831087617320009e-01 -2.04163796619314691360713709400443e-01
            8.18145504799498102244115216308273e-01 -1.23315593388879138347924424579105e-01
            8.26358224087778370225976232177345e-01 -4.12418243894479771838312842646701e-02
            7.87861089666929803598804937792011e-01 4.19911949677684789850040658620856e-02
            7.78934308707685318928781725844601e-01 1.25497807885490475499068452336360e-01
            7.61181890784425441154326108517125e-01 2.07582480493490206807649656184367e-01
            7.34804977885726740005623014440062e-01 2.87315160651748058295851251386921e-01
            7.00102430974411271691337788070086e-01 3.63792445234508488027813655207865e-01
            6.57467443773418369623584567307262e-01 4.36147816048676417732821164463530e-01
            6.07383087723811776470483891898766e-01 5.03561457831188219458340427081566e-01
            5.50416838592326818080380235187477e-01 5.65269547083523393737891638011206e-01
            4.87214146744181286763364369107876e-01 6.20572906497151688398616897757165e-01
            4.18491123932529129891833008514368e-01 6.68844926911815407244432662992040e-01
            3.45026429466152917413523937284481e-01 7.09538667047695859046996247343486e-01
            2.67652447688359107491606891926494e-01 7.42193050568659917765046429849463e-01
            1.87245856729764403869609168395982e-01 7.66438090261385540635785673657665e-01
            1.04717695394773727124437812108226e-01 7.81999080138327640199236157059204e-01
            2.10030407278919174773879063877757e-02 7.88699707966324603525265501957620e-01
            -6.29495867828259864085183039605909e-02 7.86464052954650050253349036211148e-01
            -1.46188970321916023031860731862253e-01 7.75317445967908747128660706948722e-01
            -2.27771974413109756785189574657124e-01 7.55386182517218784937540476676077e-01
            -3.06774231021140209030306778004160e-01 7.26896091781604858361731658078497e-01
            -3.82300613010937873070815840037540e-01 6.90169977873164364190472497284645e-01
            -4.53495376295747598671681544146850e-01 6.45623962337490642227066928171553e-01
            -5.19551855759568304016227102692937e-01 5.93762769330287265567847043712391e-01
            -5.79721605095245062777564726275159e-01 5.35174006891007136843541047710460e-01
            -6.33322877000193074081835220567882e-01 4.70521509108968893908553354776814e-01
            -6.79748347645746986422921054327162e-01 4.00537814617870913114217046313570e-01
            -7.18471997898816328032012279436458e-01 3.26015866640362139694531151690171e-01
            -7.49055073328848464164764209272107e-01 2.47800028624487106432283667345473e-01
            -7.71151055470843838079986198863480e-01 1.66776517268429486096081859614060e-01
            -7.84509588018027170797097369359108e-01 8.38633613312058656674707890488207e-02
            -7.88979313458840425532514473161427e-01 9.66220990820845166484681935303914e-17
            -7.84509588018027281819399831874762e-01 -8.38633613312053383115340920994640e-02
            -7.71151055470843727057683736347826e-01 -1.66776517268429624873959937758627e-01
            -7.49055073328848575187066671787761e-01 -2.47800028624486884387678742314165e-01
            -7.18471997898816661098919666983420e-01 -3.26015866640361584583018839111901e-01
            -6.79748347645746986422921054327162e-01 -4.00537814617870746580763352540089e-01
            -6.33322877000192963059532758052228e-01 -4.70521509108969004930855817292468e-01
            -5.79721605095245506866774576337775e-01 -5.35174006891006803776633660163498e-01
            -5.19551855759568526060832027724246e-01 -5.93762769330287154545544581196737e-01
            -4.53495376295747376627076619115542e-01 -6.45623962337490753249369390687207e-01
            -3.82300613010937762048513377521886e-01 -6.90169977873164475212774959800299e-01
            -3.06774231021140708630667859324603e-01 -7.26896091781604636317126733047189e-01
            -2.27771974413109756785189574657124e-01 -7.55386182517218784937540476676077e-01
            -1.46188970321915856498407038088772e-01 -7.75317445967908747128660706948722e-01
            -6.29495867828267080534843103123421e-02 -7.86464052954650050253349036211148e-01
            2.10030407278919001301531466197048e-02 -7.88699707966324603525265501957620e-01
            1.04717695394773532835408502705832e-01 -7.81999080138327640199236157059204e-01
            1.87245856729763709980218777673144e-01 -7.66438090261385651658088136173319e-01
            2.67652447688358940958153198153013e-01 -7.42193050568660028787348892365117e-01
            3.45026429466152695368919012253173e-01 -7.09538667047695859046996247343486e-01
            4.18491123932528963358379314740887e-01 -6.68844926911815518266735125507694e-01
            4.87214146744181120229910675334395e-01 -6.20572906497151799420919360272819e-01
            5.50416838592326596035775310156168e-01 -5.65269547083523504760194100526860e-01
            6.07383087723811998515088816930074e-01 -5.03561457831187886391433039534604e-01
            6.57467443773418147578979642275954e-01 -4.36147816048676750799728552010492e-01
            7.00102430974411049646732863038778e-01 -3.63792445234508821094721042754827e-01
            7.34804977885726851027925476955716e-01 -2.87315160651747725228943863839959e-01
            7.61181890784425330132023646001471e-01 -2.07582480493490623141283890618070e-01
            7.78934308707685429951084188360255e-01 -1.25497807885490253454463527305052e-01
            7.87861089666929803598804937792011e-01 -4.19911949677683055126564681813761e-02
            7.46846586045342597515173110878095e-01 4.27062329218483097137415427368978e-02
            7.37110298641591943358264416019665e-01 1.27561957708642814690591649195994e-01
            7.17764651230131112136234605713980e-01 2.10754717295833338130961465139990e-01
            6.89061843910323212902824252523715e-01 2.91199966835272439080739559358335e-01
            6.51376061670868367059483716730028e-01 3.67848979474060089334130907445797e-01
            6.05198596316233961012187592132250e-01 4.39702518112892404289482328749727e-01
            5.51131441726649184964514915918699e-01 5.05823861989787459947365277912468e-01
            4.89879445947245750758725080231670e-01 5.65351018267746696643882842181483e-01
            4.22241122415862757399906968203140e-01 6.17507959429634323278435203974368e-01
            3.49098240119216307597582726884866e-01 6.61614739983643729281936884945026e-01
            2.71404328385664750378225562599255e-01 6.97096360592626251850845164881321e-01
            1.90172246172179981726912956219167e-01 7.23490264069798105772690632875310e-01
            1.06460977898873071501029130558891e-01 7.40452365519061683762913617101731e-01
            2.13618279675724873079012411380972e-02 7.47761538007834625219061308598612e-01
            -6.40158060599912009935863466125738e-02 7.45322495294787223940602416405454e-01
            -1.48558896156004899280489439661324e-01 7.33167034031719011544225850229850e-01
            -2.31165293849074415799549342409591e-01 7.11453619245576374119366391823860e-01
            -3.10758098415067074427042825846002e-01 6.80465318504484772965668071265100e-01
            -3.86299695924958386150649403134594e-01 6.40606111699102642731418200128246e-01
            -4.56805286129222665181259799282998e-01 5.92395624546938615040403419698123e-01
            -5.21355720835144142988326620979933e-01 5.36462354476458846974651351047214e-01
            -5.79109486409163931597277041873895e-01 4.73535477201944110525744235928869e-01
            -6.29313674194023287000732125306968e-01 4.04435340802923926073475513476296e-01
            -6.71313795824536985179520343081094e-01 3.30062771232398022291931738436688e-01
            -7.04562315484343337779193916503573e-01 2.51387328672904974968815849933890e-01
            -7.28625787872619334883950159564847e-01 1.69434667836789648598383450917026e-01
            -7.43190508826445550560890751512488e-01 8.52731669884929793790107055428962e-02
            -7.48066604934318979402974036929663e-01 9.16117373281841413119004159582399e-17
            -7.43190508826445550560890751512488e-01 -8.52731669884927989677692039549584e-02
            -7.28625787872619334883950159564847e-01 -1.69434667836789482064929757143545e-01
            -7.04562315484343448801496379019227e-01 -2.51387328672904808435362156160409e-01
            -6.71313795824536985179520343081094e-01 -3.30062771232398133314234200952342e-01
            -6.29313674194023509045337050338276e-01 -4.04435340802923537495416894671507e-01
            -5.79109486409164042619579504389549e-01 -4.73535477201943943992290542155388e-01
            -5.21355720835144254010629083495587e-01 -5.36462354476458624930046426015906e-01
            -4.56805286129223109270469649345614e-01 -5.92395624546938281973496032151161e-01
            -3.86299695924958830239859253197210e-01 -6.40606111699102420686813275096938e-01
            -3.10758098415067129938194057103829e-01 -6.80465318504484772965668071265100e-01
            -2.31165293849074554577427420554159e-01 -7.11453619245576263097063929308206e-01
            -1.48558896156005232347396827208286e-01 -7.33167034031718900521923387714196e-01
            -6.40158060599917005939474279330170e-02 -7.45322495294787112918299953889800e-01
            2.13618279675723034272127875965452e-02 -7.47761538007834625219061308598612e-01
            1.06460977898872891089787628970953e-01 -7.40452365519061683762913617101731e-01
            1.90172246172179482126551874898723e-01 -7.23490264069798216794993095390964e-01
            2.71404328385664861400528025114909e-01 -6.97096360592626140828542702365667e-01
            3.49098240119216141064129033111385e-01 -6.61614739983643840304239347460680e-01
            4.22241122415862535355302043171832e-01 -6.17507959429634434300737666490022e-01
            4.89879445947245917292178774005151e-01 -5.65351018267746585621580379665829e-01
            5.51131441726649295986817378434353e-01 -5.05823861989787348925062815396814e-01
            6.05198596316234183056792517163558e-01 -4.39702518112892071222574941202765e-01
            6.51376061670868256037181254214374e-01 -3.67848979474060422401038294992759e-01
            6.89061843910322990858219327492407e-01 -2.91199966835272938681100640678778e-01
            7.17764651230131112136234605713980e-01 -2.10754717295833421397688312026730e-01
            7.37110298641591943358264416019665e-01 -1.27561957708643064490772189856216e-01
            7.46846586045342597515173110878095e-01 -4.27062329218487399251635849850572e-02
            7.03454348640268012360365901258774e-01 4.33875791006067892952025033537211e-02
            6.92790697776760722170763528993120e-01 1.29505025829518033431142498557165e-01
            6.71625046126909874821819812495960e-01 2.13659308377008194668178475694731e-01
            6.40278243394649559938613947451813e-01 2.94574733601809468641619105255813e-01
            5.99225475156230036333226962597109e-01 3.71024706138156690204965570956119e-01
            5.49089059531257750457200472737895e-01 4.41850322331209910409199892455945e-01
            4.90629013474359276791858519572997e-01 5.05977938035140240025100411003223e-01
            4.24731531692867814165026629780186e-01 5.62435443963967940383952281990787e-01
            3.52395552838396020067790459506796e-01 6.10367001877424986133746642735787e-01
            2.74717616615141491109852722729556e-01 6.49046018216282827317797909927322e-01
            1.92875241355720206115620385389775e-01 6.77886158520062842569586791796610e-01
            1.08109074043541628085129957526078e-01 6.96450235659780036989729978813557e-01
            2.17040833691848414344072182302625e-02 7.04456837149174619483460446645040e-01
            -6.50299190851242464583847890935431e-02 7.01784591071147323404488815867808e-01
            -1.50778134253952506016460688442749e-01 6.88474005952303347299903180100955e-01
            -2.34240706602257764412655660635210e-01 6.64726856694981327322580000327434e-01
            -3.14152428610301737155197088213754e-01 6.30903125875410863976355813065311e-01
            -3.89301920029966275205168813045020e-01 5.87515546774803998353320366732078e-01
            -4.58549991174503013269259099615738e-01 5.35221830865463266135861886141356e-01
            -5.20846911872957174516329814650817e-01 4.74814697575295374676329629437532e-01
            -5.75248324309525216335714503657073e-01 4.07209857469337854762869710611994e-01
            -6.20929558525414870828740276920144e-01 3.33432131011017873767343644431094e-01
            -6.57198133574799281397815775562776e-01 2.54599913328570182091681317615439e-01
            -6.83504254830079593929781367478427e-01 1.71908220484922630300061996422301e-01
            -6.99449148308009194252576889994089e-01 8.66105742523150257117237060811021e-02
            -7.04791105676792151157883381529246e-01 8.63120171634607438207422295727374e-17
            -6.99449148308009194252576889994089e-01 -8.66105742523148591782700123076211e-02
            -6.83504254830079593929781367478427e-01 -1.71908220484922769077940074566868e-01
            -6.57198133574799392420118238078430e-01 -2.54599913328570015558227623841958e-01
            -6.20929558525414981851042739435798e-01 -3.33432131011017707233889950657613e-01
            -5.75248324309525327358016966172727e-01 -4.07209857469337743740567248096340e-01
            -5.20846911872957285538632277166471e-01 -4.74814697575295208142875935664051e-01
            -4.58549991174502846735805405842257e-01 -5.35221830865463266135861886141356e-01
            -3.89301920029966441738622506818501e-01 -5.87515546774803887331017904216424e-01
            -3.14152428610301570621743394440273e-01 -6.30903125875410863976355813065311e-01
            -2.34240706602257930946109354408691e-01 -6.64726856694981216300277537811780e-01
            -1.50778134253952811327792460360797e-01 -6.88474005952303236277600717585301e-01
            -6.50299190851242742139604047224566e-02 -7.01784591071147323404488815867808e-01
            2.17040833691846714315065725031673e-02 -7.04456837149174619483460446645040e-01
            1.08109074043541766863008035670646e-01 -6.96450235659780036989729978813557e-01
            1.92875241355720206115620385389775e-01 -6.77886158520062842569586791796610e-01
            2.74717616615141768665608879018691e-01 -6.49046018216282716295495447411668e-01
            3.52395552838396131090092922022450e-01 -6.10367001877424875111444180220133e-01
            4.24731531692867536609270473491051e-01 -5.62435443963968051406254744506441e-01
            4.90629013474359443325312213346479e-01 -5.05977938035140017980495485971915e-01
            5.49089059531257639434898010222241e-01 -4.41850322331209965920351123713772e-01
            5.99225475156229814288622037565801e-01 -3.71024706138156967760721727245254e-01
            6.40278243394649670960916409967467e-01 -2.94574733601809413130467873997986e-01
            6.71625046126909763799517349980306e-01 -2.13659308377008361201632169468212e-01
            6.92790697776760722170763528993120e-01 -1.29505025829517839142113189154770e-01
            7.03454348640268012360365901258774e-01 -4.33875791006068378674598307043198e-02
            6.57801084611144948333105730853276e-01 4.40346015315770111797633035166655e-02
            6.46062608672662075370851653133286e-01 1.31318006087200983555973721195187e-01
            6.22795130176908240393629512254847e-01 2.16258037713217526887277131208975e-01
            5.88413857828856912135506718186662e-01 2.97338939532993618009015790448757e-01
            5.43532326248066466334307733632158e-01 3.73113820932713335931651954524568e-01
            4.88951447428859542476686783629702e-01 4.42230477358658169428906603570795e-01
            4.25645218446809747714354443814955e-01 5.03455520439503256824309573858045e-01
            3.54743340457854217095956528282841e-01 5.55696387831022708958528255607234e-01
            2.77511059154402495163793673782493e-01 5.98020840017005728128651753650047e-01
            1.95326586425981524319794857547095e-01 6.29673596145508551735758828726830e-01
            1.09656506135415929281684555007814e-01 6.50089812033550429326567154930672e-01
            2.20296028950532421508690106293216e-02 6.58905159824940023227668461913709e-01
            -6.59904191308627874335002161387820e-02 6.55962329429500390354235150880413e-01
            -1.52832840564046362752392838046944e-01 6.41313835725355496641952868230874e-01
            -2.36947956336687609590896386180248e-01 6.15221081429684568675497757794801e-01
            -3.16834730215099114047916373237967e-01 5.78149692361043188171265683195088e-01
            -3.91067580826868210763791466888506e-01 5.30761208335598255736442752095172e-01
            -4.58321821194218825823440965905320e-01 4.73901277973438284085716531990329e-01
            -5.17397297804513045527130543632666e-01 4.08584568078912468980234962145914e-01
            -5.67239807378116078773189201456262e-01 3.35976656887470637169457177151344e-01
            -6.06959909150896370633176957198884e-01 2.57373234294436870062128264180501e-01
            -6.35848796965731710706393187138019e-01 1.74176980238133799483435382171592e-01
            -6.53390947935175714356148546357872e-01 8.78725338431519537030212063655199e-02
            -6.59273321959597757846438526030397e-01 -2.12038472274157326063344092489837e-16
            -6.53390947935175825378451008873526e-01 -8.78725338431514957360235484884470e-02
            -6.35848796965731710706393187138019e-01 -1.74176980238133632949981688398111e-01
            -6.06959909150896370633176957198884e-01 -2.57373234294436759039825801664847e-01
            -5.67239807378116189795491663971916e-01 -3.35976656887470526147154714635690e-01
            -5.17397297804513156549433006148320e-01 -4.08584568078912302446781268372433e-01
            -4.58321821194218881334592197163147e-01 -4.73901277973438117552262838216848e-01
            -3.91067580826868044230337773115025e-01 -5.30761208335598366758745214610826e-01
            -3.16834730215099003025613910722313e-01 -5.78149692361043188171265683195088e-01
            -2.36947956336687914902228158098296e-01 -6.15221081429684568675497757794801e-01
            -1.52832840564046806841602688109560e-01 -6.41313835725355385619650405715220e-01
            -6.59904191308630927448319880568306e-02 -6.55962329429500390354235150880413e-01
            2.20296028950529368395372387112729e-02 -6.58905159824940023227668461913709e-01
            1.09656506135415762748230861234333e-01 -6.50089812033550429326567154930672e-01
            1.95326586425981246764038701257959e-01 -6.29673596145508662758061291242484e-01
            2.77511059154402328630339980009012e-01 -5.98020840017005839150954216165701e-01
            3.54743340457854050562502834509360e-01 -5.55696387831022708958528255607234e-01
            4.25645218446809692203203212557128e-01 -5.03455520439503256824309573858045e-01
            4.88951447428859486965535552371875e-01 -4.42230477358658169428906603570795e-01
            5.43532326248066466334307733632158e-01 -3.73113820932713335931651954524568e-01
            5.88413857828856579068599330639699e-01 -2.97338939532994173120528103027027e-01
            6.22795130176908240393629512254847e-01 -2.16258037713217471376125899951148e-01
            6.46062608672662075370851653133286e-01 -1.31318006087200900289246874308446e-01
            6.57801084611144948333105730853276e-01 -4.40346015315774899634426731154235e-02
            6.09985289687997700447397164680297e-01 4.46451688054660678073304325153003e-02
            5.96984512264393196723233359080041e-01 1.32983972154029350676296417077538e-01
            5.71260046416665723256755882175639e-01 2.18488453016282030416661541494250e-01
            5.33360164472822417813802076125285e-01 2.99336231831268562153525181201985e-01
            4.84092636616608007482653874831158e-01 3.73804178557436417307258125219960e-01
            4.24507514668448437955561303169816e-01 4.40305138197859546878021319571417e-01
            3.55874752053945864194162140847766e-01 4.97421758253458023979476365639130e-01
            2.79657136951442841787951465448714e-01 5.43936697130779189812699314643396e-01
            1.97479115501619700845381544240809e-01 5.78858569664574496016484772553667e-01
            1.11092169558289391440020210666262e-01 6.01443076771402629354668079031399e-01
            2.23374868935188077012643503849176e-02 6.11208868892378687220912070188206e-01
            -6.68932805231541999235744810903270e-02 6.07947805123326134868477765849093e-01
            -1.54698333802260140634743379450811e-01 5.91729389376785652743251375795808e-01
            -2.39206260675916992930467586120358e-01 5.62899289026788873790962952625705e-01
            -3.18615921401268986645760605824762e-01 5.22071967608910725289206311572343e-01
            -3.91234836927055018573895495137549e-01 4.70117588596810298540162875724491e-01
            -4.55515261146189398555605976071092e-01 4.08143469378523804369507388400962e-01
            -5.10087168416913594448658386681927e-01 3.37470480708808584502378380420851e-01
            -5.53787453280781272191291009221459e-01 2.59604894642234296231464441007120e-01
            -5.85684720036178108060198610473890e-01 1.76206280959456146328889758478908e-01
            -6.05099133820659607074787800229387e-01 8.90521363186006914558490166200500e-02
            -6.11616910110748257523027859861031e-01 7.49014691271522304962315750059229e-17
            -6.05099133820659607074787800229387e-01 -8.90521363186005388001831306610256e-02
            -5.85684720036178108060198610473890e-01 -1.76206280959456007551011680334341e-01
            -5.53787453280781383213593471737113e-01 -2.59604894642234185209161978491466e-01
            -5.10087168416913816493263311713235e-01 -3.37470480708808251435470992873888e-01
            -4.55515261146189454066757207328919e-01 -4.08143469378523693347204925885308e-01
            -3.91234836927054852040441801364068e-01 -4.70117588596810409562465338240145e-01
            -3.18615921401269375223819224629551e-01 -5.22071967608910503244601386541035e-01
            -2.39206260675916992930467586120358e-01 -5.62899289026788873790962952625705e-01
            -1.54698333802260168390318995079724e-01 -5.91729389376785652743251375795808e-01
            -6.68932805231544774793306373794621e-02 -6.07947805123326134868477765849093e-01
            2.23374868935185197371673382349400e-02 -6.11208868892378687220912070188206e-01
            1.11092169558288961228598168418102e-01 -6.01443076771402740376970541547053e-01
            1.97479115501619645334230312982982e-01 -5.78858569664574496016484772553667e-01
            2.79657136951442675254497771675233e-01 -5.43936697130779300835001777159050e-01
            3.55874752053945697660708447074285e-01 -4.97421758253458135001778828154784e-01
            4.24507514668448160399805146880681e-01 -4.40305138197859824433777475860552e-01
            4.84092636616608062993805106088985e-01 -3.73804178557436361796106893962133e-01
            5.33360164472822417813802076125285e-01 -2.99336231831268562153525181201985e-01
            5.71260046416665612234453419659985e-01 -2.18488453016282169194539619638817e-01
            5.96984512264393307745535821595695e-01 -1.32983972154029045364964645159489e-01
            6.09985289687997700447397164680297e-01 -4.46451688054664216909195317839476e-02
            5.60090169012179339702584002225194e-01 4.52151528808382857649306174607773e-02
            5.45584127836589938276290467911167e-01 1.34474409933327904154154452953662e-01
            5.16947744332186043259014240902616e-01 2.20250850404701076223901168305019e-01
            4.74922685789731846561778638715623e-01 3.00322909543039751056880959367845e-01
            4.20597379150729477892411978245946e-01 3.72616763076578039193265112771769e-01
            3.55378821321358950857671743506216e-01 4.35260038173010788131733761474607e-01
            2.80956138691668855233984913866152e-01 4.86630306912338661540218254231149e-01
            1.99256839649332551100968657920021e-01 5.25397106317773032735374272306217e-01
            1.12396893124879285186246136163390e-01 5.50556396647976176161876082915114e-01
            2.26259261078626053298457065920957e-02 5.61456565498962389959558549890062e-01
            -6.77310405104958185296126771390846e-02 5.57815304223086672053000256710220e-01
            -1.56333808757110392928524333910900e-01 5.39726919574727515005463374109240e-01
            -2.40887613475286616049331200883898e-01 5.07659891214886194177324796328321e-01
            -3.19202555536892695897677185712382e-01 4.62444738334047977801333217939828e-01
            -3.89250319079479378814312440226786e-01 4.05252509641399638606884536784492e-01
            -4.49216703821690155340462524691247e-01 3.37564453818385790118128397807595e-01
            -4.97548611897594306174852363255923e-01 2.61133655955922749924980053037871e-01
            -5.32994272275608693689719075337052e-01 1.77939633571398109213035354514432e-01
            -5.54635660970691279914035476394929e-01 9.01370681447621890924892795737833e-02
            -5.61912277383337821490272290247958e-01 6.88144071899104367029024489558640e-17
            -5.54635660970691390936337938910583e-01 -9.01370681447620503146112014292157e-02
            -5.32994272275608804712021537852706e-01 -1.77939633571397970435157276369864e-01
            -4.97548611897594361686003594513750e-01 -2.61133655955922638902677590522217e-01
            -4.49216703821690266362764987206901e-01 -3.37564453818385623584674704034114e-01
            -3.89250319079479489836614902742440e-01 -4.05252509641399472073430843011010e-01
            -3.19202555536892806919979648228036e-01 -4.62444738334047922290181986682001e-01
            -2.40887613475286532782604353997158e-01 -5.07659891214886305199627258843975e-01
            -1.56333808757110392928524333910900e-01 -5.39726919574727515005463374109240e-01
            -6.77310405104960822075810256137629e-02 -5.57815304223086672053000256710220e-01
            2.26259261078623451213243100710315e-02 -5.61456565498962500981861012405716e-01
            1.12396893124879146408368058018823e-01 -5.50556396647976176161876082915114e-01
            1.99256839649332412323090579775453e-01 -5.25397106317773143757676734821871e-01
            2.80956138691668522167077526319190e-01 -4.86630306912338828073671948004630e-01
            3.55378821321358617790764355959254e-01 -4.35260038173011065687489917763742e-01
            4.20597379150729311358958284472465e-01 -3.72616763076578205726718806545250e-01
            4.74922685789731735539476176199969e-01 -3.00322909543039917590334653141326e-01
            5.16947744332185932236711778386962e-01 -2.20250850404701159490628015191760e-01
            5.45584127836589938276290467911167e-01 -1.34474409933327931909730068582576e-01
            5.60090169012179339702584002225194e-01 -4.52151528808382233148854822957219e-02
            5.08185115716239810268461951636709e-01 4.57374882489014061848209280469746e-02
            4.91851627961013893042263589450158e-01 1.35742424241453857325367948760686e-01
            4.59709624186253495992104944889434e-01 2.21384487029647275546651030708745e-01
            4.12792174839808179154232448127004e-01 2.99911070248945144101071491604671e-01
            3.52607245347478670538521328126080e-01 3.68798264902791383956781601227704e-01
            2.81089228863473317154841879528249e-01 4.25831979874438715238937902540783e-01
            2.00536773282808000740118359317421e-01 4.69179104637201527250311983152642e-01
            1.13538900806626624762074584396032e-01 4.97446426935071572827951058570761e-01
            2.28917946384014948935092803594671e-02 5.09725411770964864643929104204290e-01
            -6.84910726449332180054696550541848e-02 5.05621402469073721874792681774125e-01
            -1.57672580498817493932506295095664e-01 4.85266305265150688086350783123635e-01
            -2.41786361882038419723883748702065e-01 4.49314349731559758982513130831649e-01
            -3.18128930651889407776877760625212e-01 3.98921061300518242642709765277687e-01
            -3.84246573833232629713307915153564e-01 3.35706121725935446864497180285980e-01
            -4.38014215972441722790620133309858e-01 2.61701311179164064490976215893170e-01
            -4.77703720810999210577563189872308e-01 1.79285205162538235912350614853494e-01
            -5.02039435006760403901182598929154e-01 9.11067251356302981735169055355072e-02
            -5.10239188681981259421149843547028e-01 6.24862789218930724758859288594632e-17
            -5.02039435006760403901182598929154e-01 -9.11067251356301732734266352053965e-02
            -4.77703720810999210577563189872308e-01 -1.79285205162538124890048152337840e-01
            -4.38014215972441889324073827083339e-01 -2.61701311179163731424068828346208e-01
            -3.84246573833232740735610377669218e-01 -3.35706121725935335842194717770326e-01
            -3.18128930651889518799180223140866e-01 -3.98921061300518131620407302762032e-01
            -2.41786361882038530746186211217719e-01 -4.49314349731559703471361899573822e-01
            -1.57672580498817604954808757611318e-01 -4.85266305265150632575199551865808e-01
            -6.84910726449333429055599253842956e-02 -5.05621402469073610852490219258470e-01
            2.28917946384013699934190100293563e-02 -5.09725411770964975666231566719944e-01
            1.13538900806626499861984314065921e-01 -4.97446426935071572827951058570761e-01
            2.00536773282807889717815896801767e-01 -4.69179104637201582761463214410469e-01
            2.81089228863473150621388185754768e-01 -4.25831979874438826261240365056437e-01
            3.52607245347478559516218865610426e-01 -3.68798264902791439467932832485531e-01
            4.12792174839808123643081216869177e-01 -2.99911070248945255123373954120325e-01
            4.59709624186253440480953713631607e-01 -2.21384487029647386568953493224399e-01
            4.91851627961013893042263589450158e-01 -1.35742424241453968347670411276340e-01
            5.08185115716239810268461951636709e-01 -4.57374882489015310849111983770854e-02
            4.54325687208453621312997938730405e-01 4.62004067568987791814194565631624e-02
            4.35725540193137916844534629490227e-01 1.36709770189751611546569165511755e-01
            3.99286738366737947725226831607870e-01 2.21622219568320066862554540421115e-01
            3.46501090557404134440133702810272e-01 2.97461429238256358509318033611635e-01
            2.79529647388500668281352545818663e-01 3.61122533044944515889795866314671e-01
            2.01114227612173013248764164018212e-01 4.09999237918676651126759225007845e-01
            1.14465167727484495863166102935793e-01 4.42090525819153201680933307216037e-01
            2.31298904269468391659003714266873e-02 4.56082575649162436093320138752460e-01
            -6.91523273053170628443808709562290e-02 4.51402551244667715746317071534577e-01
            -1.58603440632647529895393745391630e-01 4.28242053354668583686759575357428e-01
            -2.41561310465364609267879814069602e-01 3.87549275484024458027221271549934e-01
            -3.14629631865380565702849935405538e-01 3.30990184739958170911933166280505e-01
            -3.74816979169416086836719159691711e-01 2.60880316942942336311261897208169e-01
            -4.19659275307130485987983092854847e-01 1.80089978318146881619554733333644e-01
            -4.47320671405899761285951399258920e-01 9.19267348213325119488104064657819e-02
            -4.56668706659364320721294916438637e-01 5.59257869881152068696771449143560e-17
            -4.47320671405899761285951399258920e-01 -9.19267348213323870487201361356711e-02
            -4.19659275307130541499134324112674e-01 -1.80089978318146770597252270817989e-01
            -3.74816979169416197859021622207365e-01 -2.60880316942942225288959434692515e-01
            -3.14629631865380787747454860436847e-01 -3.30990184739957948867328241249197e-01
            -2.41561310465364692534606660956342e-01 -3.87549275484024402516070040292107e-01
            -1.58603440632647751939998670422938e-01 -4.28242053354668472664457112841774e-01
            -6.91523273053171738666833334718831e-02 -4.51402551244667715746317071534577e-01
            2.31298904269469259020741702670421e-02 -4.56082575649162436093320138752460e-01
            1.14465167727484301574136793533398e-01 -4.42090525819153257192084538473864e-01
            2.01114227612172735693008007729077e-01 -4.09999237918676762149061687523499e-01
            2.79529647388500446236747620787355e-01 -3.61122533044944626912098328830325e-01
            3.46501090557404189951284934068099e-01 -2.97461429238256191975864339838154e-01
            3.99286738366737892214075600350043e-01 -2.21622219568320288907159465452423e-01
            4.35725540193137861333383398232399e-01 -1.36709770189751889102325321800890e-01
            4.54325687208453621312997938730405e-01 -4.62004067568986820369048018619651e-02
            3.98551461538215467950152515186346e-01 4.65839848392790023545728672615951e-02
            3.77065449085489556857453408156289e-01 1.37240599837336413324706541061460e-01
            3.35251740672811215926429895262117e-01 2.20498538574757818597760206102976e-01
            2.75364524143782929410662063673954e-01 2.91869344023694632372922797003412e-01
            2.00632334842712922728935609484324e-01 3.47505397588750208903718430519802e-01
            1.15084004438527939817582534942630e-01 3.84407345221376761656983944703825e-01
            2.33314655666776137044049477253793e-02 4.00585793372986165294946658832487e-01
            -6.96788786529968229288556358369533e-02 3.95168557716090051989965559187112e-01
            -1.58932816488782963082471155757958e-01 3.68447682827150735374033274638350e-01
            -2.39618645049432421600954512541648e-01 3.21863697987871788530611638634582e-01
            -3.07386570432492678417446541061508e-01 2.57927957878753499887380939981085e-01
            -3.58583206239488860855857410570025e-01 1.80087254798228374452762068358425e-01
            -3.90448528582310827594881175173214e-01 9.25380011976821570396367633293266e-02
            -4.01264669685425734435568756452994e-01 4.91407493341176621857590801337443e-17
            -3.90448528582310827594881175173214e-01 -9.25380011976820598951221086281294e-02
            -3.58583206239488860855857410570025e-01 -1.80087254798228291186035221471684e-01
            -3.07386570432492678417446541061508e-01 -2.57927957878753555398532171238912e-01
            -2.39618645049432504867681359428389e-01 -3.21863697987871677508309176118928e-01
            -1.58932816488782963082471155757958e-01 -3.68447682827150735374033274638350e-01
            -6.96788786529969200733702905381506e-02 -3.95168557716089996478814327929285e-01
            2.33314655666773361486487914362442e-02 -4.00585793372986165294946658832487e-01
            1.15084004438527939817582534942630e-01 -3.84407345221376761656983944703825e-01
            2.00632334842712922728935609484324e-01 -3.47505397588750208903718430519802e-01
            2.75364524143782984921813294931781e-01 -2.91869344023694632372922797003412e-01
            3.35251740672811049392976201488636e-01 -2.20498538574758096153516362392111e-01
            3.77065449085489445835150945640635e-01 -1.37240599837336718636038312979508e-01
            3.98551461538215467950152515186346e-01 -4.65839848392789260267399242820829e-02
            3.40880015568269523207334259495838e-01 4.68528797138154165513590498903795e-02
            3.15598504235877874712912216637051e-01 1.37083775390735157495569751517905e-01
            2.66910495611399345428083051956492e-01 2.17147794563467971817871671191824e-01
            1.98426956561692846570110759785166e-01 2.81106955198488439595649879265693e-01
            1.15226997886730478382055764541292e-01 3.24217698945187704495651814795565e-01
            2.34811799069493641611838796734446e-02 3.43282699158402704320280918182107e-01
            -7.00061297672799620617212212891900e-02 3.36887991988891910555281583583564e-01
            -1.58301405053403704270564844591718e-01 3.05507843613579133101865181743051e-01
            -2.34856189307457524639843882141577e-01 2.51469576082834711527880244830158e-01
            -2.93992764396152572725640084172483e-01 1.78780960490789508909870164643507e-01
            -3.31325241076990517630207477850490e-01 9.28329789276152589350132871004462e-02
            -3.44084840339270003894966976076830e-01 4.21382398356615089202674905727931e-17
            -3.31325241076990462119056246592663e-01 -9.28329789276153144461645183582732e-02
            -2.93992764396152739259093777945964e-01 -1.78780960490789286865265239612199e-01
            -2.34856189307457496884268266512663e-01 -2.51469576082834767039031476087985e-01
            -1.58301405053403898559594153994112e-01 -3.05507843613579077590713950485224e-01
            -7.00061297672798926727821822169062e-02 -3.36887991988891910555281583583564e-01
            2.34811799069492843639039847403183e-02 -3.43282699158402704320280918182107e-01
            1.15226997886730395115328917654551e-01 -3.24217698945187704495651814795565e-01
            1.98426956561692791058959528527339e-01 -2.81106955198488495106801110523520e-01
            2.66910495611399289916931820698665e-01 -2.17147794563468082840174133707478e-01
            3.15598504235877763690609754121397e-01 -1.37083775390735296273447829662473e-01
            3.40880015568269523207334259495838e-01 -4.68528797138153263457382990964106e-02
            2.81292305062206260402035695733503e-01 4.69393837137723896058005834674987e-02
            2.50809919108892553918366274956497e-01 1.35731540576348175264342899026815e-01
            1.93148386703257873842076719483885e-01 2.09815078925626397055026473026373e-01
            1.14556229592313235654543746022682e-01 2.61161897856925728778065831647837e-01
            2.35501274819947814531673202509410e-02 2.84207772811054359962668058869895e-01
            -7.00079963588759457415733322704909e-02 2.76455325643138405400378587728483e-01
            -1.55979667508275188225752572179772e-01 2.38744654295433372803714178189693e-01
            -2.25048521409241752966323701912188e-01 1.75162295149818486583725984928606e-01
            -2.69729876027915482783470224603661e-01 9.25983834016740336991801996191498e-02
            -2.85181813288712504572686157189310e-01 3.49246994819059865469178779804361e-17
            -2.69729876027915482783470224603661e-01 -9.25983834016740753325436230625201e-02
            -2.25048521409241891744201780056756e-01 -1.75162295149818375561423522412952e-01
            -1.55979667508275160470176956550858e-01 -2.38744654295433400559289793818607e-01
            -7.00079963588760151305123713427747e-02 -2.76455325643138349889227356470656e-01
            2.35501274819947745142734163437126e-02 -2.84207772811054359962668058869895e-01
            1.14556229592312999732151013176917e-01 -2.61161897856925784289217062905664e-01
            1.93148386703257901597652335112798e-01 -2.09815078925626397055026473026373e-01
            2.50809919108892442896063812440843e-01 -1.35731540576348341797796592800296e-01
            2.81292305062206315913186926991330e-01 -4.69393837137723410335432561169000e-02
            2.19695613077152462899732654477702e-01 4.66977441296670681136760094886995e-02
            1.81708245704125581632126795739168e-01 1.32018768193294638857437917067728e-01
            1.12301871881266696062695586988411e-01 1.94512547883444519847273568302626e-01
            2.34774841796594156695388022626503e-02 2.23373340953524651686379343118460e-01
            -6.94063738228588716916434009363002e-02 2.13610854089644308650974835472880e-01
            -1.50289239254293494063574598840205e-01 1.66913109959977268292874441613094e-01
            -2.05185729883785000771112549955433e-01 9.13545727602299711955780026073626e-02
            -2.24603743762533336614239942718996e-01 1.27250124684399233474033542116515e-16
            -2.05185729883784973015536934326519e-01 -9.13545727602300128289414260507328e-02
            -1.50289239254293605085877061355859e-01 -1.66913109959977157270571979097440e-01
            -6.94063738228589272027946321941272e-02 -2.13610854089644280895399219843966e-01
            2.34774841796593081166832917006104e-02 -2.23373340953524679441954958747374e-01
            1.12301871881266696062695586988411e-01 -1.94512547883444519847273568302626e-01
            1.81708245704125553876551180110255e-01 -1.32018768193294694368589148325555e-01
            2.19695613077152462899732654477702e-01 -4.66977441296669917858430665091873e-02
            1.55816803685680821400794116016186e-01 4.57519416070924292427868351751385e-02
            1.06346069464402392945601150131552e-01 1.22729906628797277856612879531895e-01
            2.31112095935965822235402811202221e-02 1.60741993463940968656089580690605e-01
            -6.74612960271723516303410406180774e-02 1.47719633122936705449390615285665e-01
            -1.36615316818054333136700506656780e-01 8.77973330024519743597366527865233e-02
            -1.62394939796906223605787999986205e-01 9.20054848200574152807597646406419e-17
            -1.36615316818054333136700506656780e-01 -8.77973330024519327263732293431531e-02
            -6.74612960271724765304313109481882e-02 -1.47719633122936622182663768398925e-01
            2.31112095935965405901768576768518e-02 -1.60741993463940996411665196319518e-01
            1.06346069464402309678874303244811e-01 -1.22729906628797347245551918604178e-01
            1.55816803685680821400794116016186e-01 -4.57519416070924500594685468968237e-02
            8.88322412724433935204970680388215e-02 4.27793527285953364969195433786808e-02
            2.19397517468024952358440771149617e-02 9.61243330413888985574999423988629e-02
            -6.14738183335560087194870959592663e-02 7.70857299949616187051404381236352e-02
            -9.85963493713797323181324827601202e-02 1.20745703665274344307040247409037e-17
            -6.14738183335560295361688076809514e-02 -7.70857299949616048273526303091785e-02
            2.19397517468023842135416145993076e-02 -9.61243330413889263130755580277764e-02
            8.88322412724434212760726836677350e-02 -4.27793527285952809857683121208538e-02
            1.66229826389162095578999611689142e-02 2.87918505039382391363922408800136e-02
            -3.32459652778324121769060184305999e-02 4.07145649620615058012713123660987e-18
            1.66229826389162095578999611689142e-02 -2.87918505039382391363922408800136e-02
            ];
        
    case   46
        
        % DEGREE.             :          46
        % CARDIN.             :        1128
        % LEBESGUE CONST.     : 1.68226e+03
        % ABS.DET.VAND.MATRIX : Inf
        % CONDITIONING VAND.  : 4.56739e+04
        % POINTS OUT DISK     : 0.00000e+00
        
        pts=[
            9.99429490929718000735704208636889e-01 3.37741418834681603189373788609373e-02
            9.94869323391895155062059075135039e-01 1.01168321987432169306586615675769e-01
            9.85769795314803798369496234954568e-01 1.68100894242148191093377818106092e-01
            9.72172425757990454897594645444769e-01 2.34266460672082094118806594451598e-01
            9.54139256400048818562709129764698e-01 2.99363122973357931311255697437446e-01
            9.31752568456668428531486370047787e-01 3.63093860006474533630438372711069e-01
            9.05114507250321165265916079079034e-01 4.25167883035640681299582865904085e-01
            8.74346616144582200469415056431899e-01 4.85301962531080932627958191005746e-01
            8.39589281969638667746380633616354e-01 5.43221720480418723830950966657838e-01
            8.01001094469384611329587642103434e-01 5.98662882312614996749289275612682e-01
            7.58758122692790748509139575617155e-01 6.51372482722222145845591967372457e-01
            7.13053111631220426502864029316697e-01 7.01110019892052571677254491078202e-01
            6.64094602767238972873542479646858e-01 7.47648552847808955945652087393682e-01
            6.12105982547662907933272435911931e-01 7.90775736937698536799246085138293e-01
            5.57324463122436442041873760899762e-01 8.30294792712376383825301218166715e-01
            5.00000000000000111022302462515654e-01 8.66025403784438596588302061718423e-01
            4.40394151557634283555842102941824e-01 8.97804539570741688692123716464266e-01
            3.78778885610576099285395912374952e-01 9.25487199163559592918204543821048e-01
            3.15435338485255400975404427299509e-01 9.48947072936469071535725561261643e-01
            2.50652532258720528446360731322784e-01 9.68077118866204289204802080348600e-01
            1.84726056017189416147417091451644e-01 9.82790050940857917716186875622952e-01
            1.17956717150846199237967937278881e-01 9.93018737425933606388639418582898e-01
            5.06491688387127672599241634543432e-02 9.98716507171052758629059553641127e-01
            -1.68894800139311844489053981988036e-02 9.99857362559709805793772829929367e-01
            -8.43510660430446396196302316639049e-02 9.96436098130432990060967313183937e-01
            -1.51427777504576588363249811663991e-01 9.88468324328111380694394938473124e-01
            -2.17813558748851582302918927780411e-01 9.75990396277115257461787223292049e-01
            -2.83205506682304042342934735643212e-01 9.59059247901202116537433539633639e-01
            -3.47305252844820167013040190795437e-01 9.37752132147080530444327450823039e-01
            -4.09820324796587309723605585531914e-01 9.12166268496933385634406477038283e-01
            -4.70465480602755503625189703598153e-01 8.82418399378219198148087798472261e-01
            -5.28964010326962497110514505038736e-01 8.48644257494750919867954053188441e-01
            -5.85048998595307456760394870798336e-01 8.10997946509501299594546708249254e-01
            -6.38464542469983409311851119127823e-01 7.69651237904932283839798401459120e-01
            -6.88966919075686634599264834832866e-01 7.24792787229119883640748867037473e-01
            -7.36325697651197375037668280128855e-01 6.76627273303757270639380294596776e-01
            -7.80324790952091729145934095868142e-01 6.25374464321637013597410259535536e-01
            -8.20763441207276289723893114569364e-01 5.71268215094792308761384447279852e-01
            -8.57457136130651109695577360980678e-01 5.14555400028628651121209713892313e-01
            -8.90238450808351511334137740050210e-01 4.55494786690634201331562280756771e-01
            -9.18957811620230602400738462165464e-01 3.94355855113318609639350142970216e-01
            -9.43484178709980247923283513955539e-01 3.31417568218635716359443676992669e-01
            -9.63705643889940843926922298123827e-01 2.66967098974151884061001283043879e-01
            -9.79529941252494484871249369462021e-01 2.01298520088660171101224705125787e-01
            -9.90884868158238840685214654513402e-01 1.34711462225860917341080380538187e-01
            -9.97718614680070725597715863841586e-01 6.75097468583655685447908467722300e-02
            -1.00000000000000000000000000000000e+00 5.66553889764797961538732358338787e-16
            -9.97718614680070725597715863841586e-01 -6.75097468583653187446103061120084e-02
            -9.90884868158238951707517117029056e-01 -1.34711462225860695296475455506879e-01
            -9.79529941252494484871249369462021e-01 -2.01298520088660365390254014528182e-01
            -9.63705643889940843926922298123827e-01 -2.66967098974151662016396358012571e-01
            -9.43484178709980358945585976471193e-01 -3.31417568218635438803687520703534e-01
            -9.18957811620230491378435999649810e-01 -3.94355855113318831683955068001524e-01
            -8.90238450808351622356440202565864e-01 -4.55494786690633979286957355725463e-01
            -8.57457136130651220717879823496332e-01 -5.14555400028628540098907251376659e-01
            -8.20763441207276511768498039600672e-01 -5.71268215094792086716779522248544e-01
            -7.80324790952091840168236558383796e-01 -6.25374464321636791552805334504228e-01
            -7.36325697651197264015365817613201e-01 -6.76627273303757381661682757112430e-01
            -6.88966919075686745621567297348520e-01 -7.24792787229119772618446404521819e-01
            -6.38464542469983853401060969190439e-01 -7.69651237904931728728286088880850e-01
            -5.85048998595307567782697333313990e-01 -8.10997946509501188572244245733600e-01
            -5.28964010326962719155119430070044e-01 -8.48644257494750808845651590672787e-01
            -4.70465480602756114247853247434250e-01 -8.82418399378218865081180410925299e-01
            -4.09820324796587531768210510563222e-01 -9.12166268496933385634406477038283e-01
            -3.47305252844820611102250040858053e-01 -9.37752132147080308399722525791731e-01
            -2.83205506682303820298329810611904e-01 -9.59059247901202116537433539633639e-01
            -2.17813558748851610058494543409324e-01 -9.75990396277115257461787223292049e-01
            -1.51427777504577032452459661726607e-01 -9.88468324328111380694394938473124e-01
            -8.43510660430446673752058472928184e-02 -9.96436098130432990060967313183937e-01
            -1.68894800139312052655871099204887e-02 -9.99857362559709805793772829929367e-01
            5.06491688387122815373508899483568e-02 -9.98716507171052647606757091125473e-01
            1.17956717150846171482392321649968e-01 -9.93018737425933606388639418582898e-01
            1.84726056017189194102812166420335e-01 -9.82790050940858028738489338138606e-01
            2.50652532258720972535570581385400e-01 -9.68077118866204178182499617832946e-01
            3.15435338485255567508858121072990e-01 -9.48947072936468960513423098745989e-01
            3.78778885610575877240790987343644e-01 -9.25487199163559592918204543821048e-01
            4.40394151557634672133900721746613e-01 -8.97804539570741466647518791432958e-01
            5.00000000000000111022302462515654e-01 -8.66025403784438596588302061718423e-01
            5.57324463122436219997268835868454e-01 -8.30294792712376494847603680682369e-01
            6.12105982547662463844062585849315e-01 -7.90775736937698869866153472685255e-01
            6.64094602767239083895844942162512e-01 -7.47648552847808955945652087393682e-01
            7.13053111631220093435956641769735e-01 -7.01110019892052793721859416109510e-01
            7.58758122692790526464534650585847e-01 -6.51372482722222700957104279950727e-01
            8.01001094469384611329587642103434e-01 -5.98662882312614996749289275612682e-01
            8.39589281969638667746380633616354e-01 -5.43221720480419056897858354204800e-01
            8.74346616144581867402507668884937e-01 -4.85301962531081543250621734841843e-01
            9.05114507250320832199008691532072e-01 -4.25167883035641513966851334771491e-01
            9.31752568456668317509183907532133e-01 -3.63093860006474866697345760258031e-01
            9.54139256400048929585011592280352e-01 -2.99363122973357709266650772406138e-01
            9.72172425757990565919897107960423e-01 -2.34266460672082205141109056967252e-01
            9.85769795314803687347193772438914e-01 -1.68100894242148551915860821281967e-01
            9.94869323391895044039756612619385e-01 -1.01168321987432849318189198584150e-01
            9.99429490929718000735704208636889e-01 -3.37741418834691387029778297801386e-02
            9.90464738433798674854813270940213e-01 3.49767388970679340975955540216091e-02
            9.85530292928811002539646324294154e-01 1.04755964337402016073319543920661e-01
            9.75685985078131201575502018386032e-01 1.74013300832792205952159747539554e-01
            9.60980858728287645753596279973863e-01 2.42403711816568251391501576108567e-01
            9.41488174079065043287073422106914e-01 3.09586479701351169335765689538675e-01
            9.17305042704874007419846293487353e-01 3.75226903316934756738021405908512e-01
            8.88551943749772088487759447161807e-01 4.38997965374680054750911040173378e-01
            8.55372123706429121625660627614707e-01 5.00581961651196727380863649159437e-01
            8.17930882769305256374536838848144e-01 5.59672083774804818290249386336654e-01
            7.76414751317397677787823795370059e-01 6.15973947729407278472990583395585e-01
            7.31030560629274739348204548150534e-01 6.69207060460852543037901796196820e-01
            6.82004412460050835065317187400069e-01 7.19106217279219306348636564507615e-01
            6.29580552613814625750876530219102e-01 7.65422823095242454982667368312832e-01
            5.74020154123320192063317790598376e-01 8.07926130908542150521611802105326e-01
            5.15600016099073910069705561909359e-01 8.46404391377574061294808416278102e-01
            4.54611184730090600591978500233381e-01 8.80665907744197062889668359275674e-01
            3.91357503306418830213431192532880e-01 9.10539990857278769276206276117591e-01
            3.26154098487154875396498709960724e-01 9.35877809537462135303087507054443e-01
            2.59325810355277408536522898430121e-01 9.56553132046613407979407384118531e-01
            1.91205574080694301608573937301117e-01 9.72462954967992176946722793218214e-01
            1.22132761253973695647623287641181e-01 9.83528016364092594336909769481281e-01
            5.24514891541502381588912840015837e-02 9.89693190655628884933037170412717e-01
            -1.74910936262493744985935251179399e-02 9.90927763254398241699050231545698e-01
            -8.73465366580317426059565377727267e-02 9.87225583581814447597935213707387e-01
            -1.56766823637847579897552918737347e-01 9.78605095710781136553180203918600e-01
            -2.25406106187910598714907450812461e-01 9.65109246478247806422245957946870e-01
            -2.92922426855217132857234219045495e-01 9.46805271526229397238694218685851e-01
            -3.58979422726376340424536692808033e-01 9.23784360337218779513079880416626e-01
            -4.23248001170725862696286867503659e-01 8.96161201932772932821080758003518e-01
            -4.85407979363264296956970156315947e-01 8.64073413498575249036548484582454e-01
            -5.45149679419377863887063995207427e-01 8.27680854782540276204372275969945e-01
            -6.02175471194485667503215609031031e-01 7.87164831681590126954972674866440e-01
            -6.56201255062448418620135726087028e-01 7.42727192984796169561434453498805e-01
            -7.06957877285615543527796944545116e-01 6.94589324772864391555060592509108e-01
            -7.54192470925207358867226048459997e-01 6.42991047483817856900145670806523e-01
            -7.97669715611683094458328469045227e-01 5.88189421139639012636735060368665e-01
            -8.37173009898986464349945890717208e-01 5.30457464686169277712224356946535e-01
            -8.72505550362054682622670043201651e-01 4.70082795826453514465015359746758e-01
            -9.03491312061581064440929367265198e-01 4.07366198123813083586952643599943e-01
            -9.29975925491409727285940789442975e-01 3.42620122513262292951452536726720e-01
            -9.51827445639650049358237993146759e-01 2.76167130686665984740102430805564e-01
            -9.68937009332088372559610434109345e-01 2.08338288106616448258634477497253e-01
            -9.81219377583045782031945236667525e-01 1.39471514654954775735973271366674e-01
            -9.88613360251718087390315758966608e-01 6.99099011329123304347987755136273e-02
            -9.91082120888378770295901176723419e-01 1.21372554703812333605035205851560e-16
            -9.88613360251718087390315758966608e-01 -6.99099011329120806346182348534057e-02
            -9.81219377583045893054247699183179e-01 -1.39471514654954525935792730706453e-01
            -9.68937009332088372559610434109345e-01 -2.08338288106616642547663786899648e-01
            -9.51827445639650271402842918178067e-01 -2.76167130686665318606287655711640e-01
            -9.29975925491409616263638326927321e-01 -3.42620122513262459484906230500201e-01
            -9.03491312061581064440929367265198e-01 -4.07366198123813250120406337373424e-01
            -8.72505550362054793644972505717305e-01 -4.70082795826453292420410434715450e-01
            -8.37173009898986575372248353232862e-01 -5.30457464686169166689921894430881e-01
            -7.97669715611683205480630931560881e-01 -5.88189421139638790592130135337356e-01
            -7.54192470925207802956435898522614e-01 -6.42991047483817412810935820743907e-01
            -7.06957877285615765572401869576424e-01 -6.94589324772864169510455667477800e-01
            -6.56201255062448529642438188602682e-01 -7.42727192984795947516829528467497e-01
            -6.02175471194485223414005758968415e-01 -7.87164831681590571044182524929056e-01
            -5.45149679419378085931668920238735e-01 -8.27680854782540165182069813454291e-01
            -4.85407979363264519001575081347255e-01 -8.64073413498575138014246022066800e-01
            -4.23248001170726084740891792534967e-01 -8.96161201932772821798778295487864e-01
            -3.58979422726376173891082999034552e-01 -9.23784360337218890535382342932280e-01
            -2.92922426855217576946444069108111e-01 -9.46805271526229286216391756170196e-01
            -2.25406106187911042804117300875077e-01 -9.65109246478247695399943495431216e-01
            -1.56766823637847829697733459397568e-01 -9.78605095710781025530877741402946e-01
            -8.73465366580315483169272283703322e-02 -9.87225583581814558620237676223041e-01
            -1.74910936262491767401172637619311e-02 -9.90927763254398241699050231545698e-01
            5.24514891541495512083947971859743e-02 -9.89693190655628884933037170412717e-01
            1.22132761253973223802837821949652e-01 -9.83528016364092705359212231996935e-01
            1.91205574080694079563969012269808e-01 -9.72462954967992176946722793218214e-01
            2.59325810355276520358103198304889e-01 -9.56553132046613630024012309149839e-01
            3.26154098487155041929952403734205e-01 -9.35877809537462135303087507054443e-01
            3.91357503306418386124221342470264e-01 -9.10539990857278991320811201148899e-01
            4.54611184730090156502768650170765e-01 -8.80665907744197173911970821791328e-01
            5.15600016099073799047403099393705e-01 -8.46404391377574172317110878793756e-01
            5.74020154123320192063317790598376e-01 -8.07926130908542150521611802105326e-01
            6.29580552613814847795481455250410e-01 -7.65422823095242343960364905797178e-01
            6.82004412460050390976107337337453e-01 -7.19106217279219750437846414570231e-01
            7.31030560629274517303599623119226e-01 -6.69207060460852876104809183743782e-01
            7.76414751317397566765521332854405e-01 -6.15973947729407500517595508426894e-01
            8.17930882769305367396839301363798e-01 -5.59672083774804707267946923821000e-01
            8.55372123706428788558753240067745e-01 -5.00581961651197282492375961737707e-01
            8.88551943749771866443154522130499e-01 -4.38997965374680498840120890235994e-01
            9.17305042704874229464451218518661e-01 -3.75226903316934312648811555845896e-01
            9.41488174079065043287073422106914e-01 -3.09586479701351280358068152054329e-01
            9.60980858728287645753596279973863e-01 -2.42403711816568223635925960479653e-01
            9.75685985078131090553199555870378e-01 -1.74013300832792844330398907004565e-01
            9.85530292928811002539646324294154e-01 -1.04755964337402501795892817426648e-01
            9.90464738433798674854813270940213e-01 -3.49767388970673859249771453505673e-02
            9.74018852572383075916206962574506e-01 3.60160538344986291825478019745788e-02
            9.68699099361685300735302917018998e-01 1.07851454306795616067127241421986e-01
            9.58088647587587605158887527068146e-01 1.79097807535487707486510089438525e-01
            9.42245447858276685693112995068077e-01 2.49365990645449897566976460439037e-01
            9.21256030236703105096296440024162e-01 3.18272223187544278655281004830613e-01
            8.95235031643382139776576877920888e-01 3.85440163214348707754197675967589e-01
            8.64324569749287840991769371612463e-01 4.50502962729369349492714036387042e-01
            8.28693466778416376605775894859107e-01 5.13105271283584518648979155841516e-01
            7.88536327459340768974982438521693e-01 5.72905176776372426772354629065376e-01
            7.44072476161667273331090655119624e-01 6.29576072860838942268912887811894e-01
            6.95544759022383995983318527578376e-01 6.82808442754426536680512072052807e-01
            6.43218217604472952686478492978495e-01 7.32311549712249210131176369031891e-01
            5.87378641331801176761473470833153e-01 7.77815024930374021572276888036868e-01
            5.28331006606392428182061848929152e-01 8.19070344206471290249282901640981e-01
            4.66397811133075324008245843288023e-01 8.55852185292826916906960832420737e-01
            4.01917312548853711273721955876681e-01 8.87959658528324258242037103627808e-01
            3.35241680976989753215633527361206e-01 9.15217404028110248503935508779250e-01
            2.66735075595915971380378550747992e-01 9.37476549438476469688907855015714e-01
            1.96771655728079503111516146418580e-01 9.54615523026030254882812187133823e-01
            1.25733537311473825281993299540773e-01 9.66540717660345327644222379603889e-01
            5.40087059148895987092942050367128e-02 9.73187002063647610405894283758244e-01
            -1.80111023047177000455665307754316e-02 9.74518076535268895632668773032492e-01
            -8.99325401292749571080520354371401e-02 9.70526671208023827830402296967804e-01
            -1.61362797605695024172334228751424e-01 9.61234585753703907329281719285063e-01
            -2.31911747437623771972425856802147e-01 9.46692570320829651642213775630808e-01
            -3.01194075725451038127999936477863e-01 9.26980048354937635757266889413586e-01
            -3.68831386417210083106255069651525e-01 9.02204682815263336870259536226513e-01
            -4.34454267976599417533378755251761e-01 8.72501788156991864298106520436704e-01
            -4.97704310980691733146130673048901e-01 8.38033591290627266623403102130396e-01
            -5.58236065627916167031230543216225e-01 7.98988345554862311459487500542309e-01
            -6.15718928465080805878528735775035e-01 7.55579302542124908725895693351049e-01
            -6.69838948028792846578483022312867e-01 7.08043547392327554668156608386198e-01
            -7.20300539539479034445434990630019e-01 6.56640703916050672006576860439964e-01
            -7.66828099282954256388222802343080e-01 6.01651516619315707146142813144252e-01
            -8.09167509862334211057088850793662e-01 5.43376317374451134334378821222344e-01
            -8.47087528099139230874925488024019e-01 4.82133385111548906643008649552939e-01
            -8.80381048003343713581614338181680e-01 4.18257207489321658488989896795829e-01
            -9.08866231914477573639032925711945e-01 3.52096654039498357935400463247788e-01
            -9.32387503635870196205814863787964e-01 2.84013070762423380788419535747380e-01
            -9.50816398137887985875238427979639e-01 2.14378306580503830147677035711240e-01
            -9.64052263189377423024950530816568e-01 1.43572682428345227423349683704146e-01
            -9.72022809085249295257824542204617e-01 7.19829140716879561923136066070583e-02
            -9.74684503467779128627057616540696e-01 1.19364425735034310561991957180892e-16
            -9.72022809085249295257824542204617e-01 -7.19829140716877202699208737612935e-02
            -9.64052263189377423024950530816568e-01 -1.43572682428345005378744758672838e-01
            -9.50816398137887985875238427979639e-01 -2.14378306580503580347496495051018e-01
            -9.32387503635870418250419788819272e-01 -2.84013070762422714654604760653456e-01
            -9.08866231914477462616730463196291e-01 -3.52096654039498524468854157021269e-01
            -8.80381048003343713581614338181680e-01 -4.18257207489321436444384971764521e-01
            -8.47087528099139119852623025508365e-01 -4.82133385111549073176462343326421e-01
            -8.09167509862334433101693775824970e-01 -5.43376317374450912289773896191036e-01
            -7.66828099282954478432827727374388e-01 -6.01651516619315485101537888112944e-01
            -7.20300539539479145467737453145673e-01 -6.56640703916050449961971935408656e-01
            -6.69838948028793068623087947344175e-01 -7.08043547392327443645854145870544e-01
            -6.15718928465081694056948435900267e-01 -7.55579302542124131569778455741471e-01
            -5.58236065627916389075835468247533e-01 -7.98988345554862200437185038026655e-01
            -4.97704310980692288257642985627172e-01 -8.38033591290626933556495714583434e-01
            -4.34454267976599250999925061478280e-01 -8.72501788156991975320408982952358e-01
            -3.68831386417210083106255069651525e-01 -9.02204682815263336870259536226513e-01
            -3.01194075725451260172604861509171e-01 -9.26980048354937524734964426897932e-01
            -2.31911747437624438106240631896071e-01 -9.46692570320829429597608850599499e-01
            -1.61362797605695468261544078814040e-01 -9.61234585753703796306979256769409e-01
            -8.99325401292758452864717355623725e-02 -9.70526671208023716808099834452150e-01
            -1.80111023047179394374062155748106e-02 -9.74518076535268895632668773032492e-01
            5.40087059148891407422965471596399e-02 -9.73187002063647610405894283758244e-01
            1.25733537311474019571022608943167e-01 -9.66540717660345327644222379603889e-01
            1.96771655728079697400545455820975e-01 -9.54615523026030254882812187133823e-01
            2.66735075595915749335773625716683e-01 -9.37476549438476469688907855015714e-01
            3.35241680976989531171028602329898e-01 -9.15217404028110359526237971294904e-01
            4.01917312548853100651058412040584e-01 -8.87959658528324480286642028659116e-01
            4.66397811133074713385582299451926e-01 -8.55852185292827249973868219967699e-01
            5.28331006606392317159759386413498e-01 -8.19070344206471290249282901640981e-01
            5.87378641331800954716868545801844e-01 -7.77815024930374243616881813068176e-01
            6.43218217604473174731083418009803e-01 -7.32311549712249099108873906516237e-01
            6.95544759022384107005620990094030e-01 -6.82808442754426425658209609537153e-01
            7.44072476161667273331090655119624e-01 -6.29576072860838942268912887811894e-01
            7.88536327459340657952679976006038e-01 -5.72905176776372648816959554096684e-01
            8.28693466778416043538868507312145e-01 -5.13105271283584962738189005904133e-01
            8.64324569749287507924861984065501e-01 -4.50502962729369960115377580223139e-01
            8.95235031643382139776576877920888e-01 -3.85440163214348763265348907225416e-01
            9.21256030236702994073993977508508e-01 -3.18272223187544445188734698604094e-01
            9.42245447858276574670810532552423e-01 -2.49365990645450258389459463614912e-01
            9.58088647587587494136585064552492e-01 -1.79097807535488262598022402016795e-01
            9.68699099361685411757605379534652e-01 -1.07851454306795546678188202349702e-01
            9.74018852572383075916206962574506e-01 -3.60160538344987748993197840263747e-02
            9.52676393802450172110241055634106e-01 3.69681826865078805299802411354904e-02
            9.46946885874010879646789362595882e-01 1.10682217059007367843115332561865e-01
            9.35522327951973098336679868225474e-01 1.83730595554755543608038692582340e-01
            9.18471428671943868060623117344221e-01 2.55673996630284172670855014075642e-01
            8.95896734148477369430452199594583e-01 3.26079744206346888724112886848161e-01
            8.67934011250676040738483152381377e-01 3.94524409832769984429745591114624e-01
            8.34751431084264750026591173082124e-01 4.60596359236974617346049853949808e-01
            7.96548557590773254055704910570057e-01 5.23898227940926441981162042793585e-01
            7.53555147346509746064668888720917e-01 5.84049311057862619023239858506713e-01
            7.06029767779478567568673952337122e-01 6.40687852896275722436314481456066e-01
            6.54258242114441057601936790888431e-01 6.93473222601208805215833308466244e-01
            5.98551930398413589706763104913989e-01 7.42087962748296248172152900224319e-01
            5.39245856944706725144556003215257e-01 7.86239698570069145411309818882728e-01
            4.76696695457285657404611356469104e-01 8.25662896332206575067402809509076e-01
            4.11280623953146184934581697234535e-01 8.60120460284659715810562374826986e-01
            3.43391062383458178786099779244978e-01 8.89405158583389421345088976522675e-01
            2.73436306559687258843638346661464e-01 9.13340869607060179546920153370593e-01
            2.01837072614543089343897008802742e-01 9.31783641173194121520850785600487e-01
            1.29023966765653808064229224328301e-01 9.44622556283534642318500118562952e-01
            5.54348955991062000703273326962517e-02 9.51780400191924669250909119000426e-01
            -1.84875675522888291424372653182218e-02 9.53214124782875704688933637953596e-01
            -9.22988442970959777067463392086211e-02 9.48915107467999230372868169069989e-01
            -1.65555024932010574900687061017379e-01 9.38909203043268414390354337228928e-01
            -2.37815538167048784456980570212181e-01 9.23256588195232485993813043023692e-01
            -3.08645800773123757387850218947278e-01 9.02051399591343283645983319729567e-01
            -3.77619831216721657529689082366531e-01 8.75421167730960680941620921657886e-01
            -4.44322811562964992138091702145175e-01 8.43526049961923929387808129831683e-01
            -5.08353582239485124460998122231103e-01 8.06557867275415785179859540221514e-01
            -5.69327054657288944561344123940216e-01 7.64738950671953521265322706312872e-01
            -6.26876527178848896859619799215579e-01 7.18320804036587823304671474033967e-01
            -6.80655890504894833803462006471818e-01 6.67582591564948479856411722721532e-01
            -7.30341709216466905552067601092858e-01 6.12829458836921303621636525349459e-01
            -7.75635166953579924253858735028189e-01 5.54390697635229412476576271728845e-01
            -8.16263863531975553122777000680799e-01 4.92617765545901198365186246519443e-01
            -8.51983453189879225142533414327772e-01 4.27882172250998393803200769980322e-01
            -8.82579114112163609640049344307045e-01 3.60573245225672245339865185087547e-01
            -9.07866840394021434867966036108555e-01 2.91095788276918565617989997917903e-01
            -9.27694548674128149912121443776414e-01 2.19867647005851624131267385564570e-01
            -9.41942992781871546448257959127659e-01 1.47317195835093200928511691927270e-01
            -9.50526480897852743545684006676311e-01 7.38807617145907646882818653466529e-02
            -9.53393390914571092764617787906900e-01 1.16757016451177075934651966317110e-16
            -9.50526480897852743545684006676311e-01 -7.38807617145909728550989825635043e-02
            -9.41942992781871657470560421643313e-01 -1.47317195835093006639482382524875e-01
            -9.27694548674128260934423906292068e-01 -2.19867647005850957997452610470646e-01
            -9.07866840394021434867966036108555e-01 -2.91095788276918343573385072886595e-01
            -8.82579114112163720662351806822699e-01 -3.60573245225671967784109028798412e-01
            -8.51983453189879558209440801874734e-01 -4.27882172250997838691688457402051e-01
            -8.16263863531975664145079463196453e-01 -4.92617765545901031831732552745962e-01
            -7.75635166953580035276161197543843e-01 -5.54390697635229190431971346697537e-01
            -7.30341709216466794529765138577204e-01 -6.12829458836921414643938987865113e-01
            -6.80655890504895055848066931503126e-01 -6.67582591564948257811806797690224e-01
            -6.26876527178849451971132111793850e-01 -7.18320804036587379215461623971350e-01
            -5.69327054657289166605949048971524e-01 -7.64738950671953299220717781281564e-01
            -5.08353582239485013438695659715449e-01 -8.06557867275415896202162002737168e-01
            -4.44322811562965991338813864786061e-01 -8.43526049961923374276295817253413e-01
            -3.77619831216721713040840313624358e-01 -8.75421167730960680941620921657886e-01
            -3.08645800773123979432455143978586e-01 -9.02051399591343172623680857213913e-01
            -2.37815538167048784456980570212181e-01 -9.23256588195232485993813043023692e-01
            -1.65555024932010602656262676646293e-01 -9.38909203043268414390354337228928e-01
            -9.22988442970959915845341470230778e-02 -9.48915107467999230372868169069989e-01
            -1.84875675522890615953830462103724e-02 -9.53214124782875704688933637953596e-01
            5.54348955991061792536456209745666e-02 -9.51780400191924669250909119000426e-01
            1.29023966765652947641385139831982e-01 -9.44622556283534753340802581078606e-01
            2.01837072614543061588321393173828e-01 -9.31783641173194121520850785600487e-01
            2.73436306559687258843638346661464e-01 -9.13340869607060179546920153370593e-01
            3.43391062383458178786099779244978e-01 -8.89405158583389421345088976522675e-01
            4.11280623953146184934581697234535e-01 -8.60120460284659715810562374826986e-01
            4.76696695457284935759645350117353e-01 -8.25662896332207019156612659571692e-01
            5.39245856944706725144556003215257e-01 -7.86239698570069034389007356367074e-01
            5.98551930398413589706763104913989e-01 -7.42087962748296248172152900224319e-01
            6.54258242114440502490424478310160e-01 -6.93473222601209249305043158528861e-01
            7.06029767779478567568673952337122e-01 -6.40687852896275611414012018940412e-01
            7.53555147346509412997761501173954e-01 -5.84049311057863174134752171084983e-01
            7.96548557590773254055704910570057e-01 -5.23898227940926330958859580277931e-01
            8.34751431084264750026591173082124e-01 -4.60596359236974450812596160176327e-01
            8.67934011250675707671575764834415e-01 -3.94524409832770650563560366208549e-01
            8.95896734148477369430452199594583e-01 -3.26079744206346777701810424332507e-01
            9.18471428671943646016018192312913e-01 -2.55673996630284894315821020427393e-01
            9.35522327951972987314377405709820e-01 -1.83730595554756209741853467676265e-01
            9.46946885874010879646789362595882e-01 -1.10682217059007173554086023159471e-01
            9.52676393802450172110241055634106e-01 -3.69681826865085397249011123221862e-02
            9.27363615794693951777105667133583e-01 3.78573555693422145185245142329222e-02
            9.21192163935806940244788165728096e-01 1.13320132252736682776372845182777e-01
            9.08890330211935881798979153245455e-01 1.88028782152494994273084216729330e-01
            8.90539981296853522252376933465712e-01 2.61486131529593768263453057443257e-01
            8.66263235734995307169015177350957e-01 3.33203333843538063163691731460858e-01
            8.36221651262694209982839765871176e-01 4.02703122945434033308487187241553e-01
            8.00615149668100878344034754263703e-01 4.69522989205466756423845708923182e-01
            7.59680686344668121279255501576699e-01 5.33218257438177301033022104093106e-01
            7.13690673392102237215794957592152e-01 5.93365046142456886713034691638313e-01
            6.62951166758784515842251039430266e-01 6.49563088363000029623606224049581e-01
            6.07799829489930498738203823450021e-01 7.01438395400853176298028301971499e-01
            5.48603684635734389907213426340604e-01 7.48645745646502769332641946675722e-01
            4.85756672773523856534438891685568e-01 7.90870981972728648301540488319006e-01
            4.19677030398215522577487490707426e-01 8.27833102398452980175136417528847e-01
            3.50804506627442946875561347042094e-01 8.59286130110563761697051177179674e-01
            2.79597436743734439890118892435567e-01 8.85020750399020728060861529229442e-01
            2.06529692048826180039711175595585e-01 9.04865703611717919763179907022277e-01
            1.32087526328333870750952883099671e-01 9.18688924859211497597755169408629e-01
            5.67663399130340987075449277199368e-02 9.26398422884770589291747455717996e-01
            -1.89326171286000773108515460307899e-02 9.27942892251012452220493287313730e-01
            -9.45055807269051667551806872324960e-02 9.23312054769124479491892998339608e-01
            -1.69449625277796195321755590157409e-01 9.12536727898514143930697173345834e-01
            -2.43266010529683718299764905168558e-01 8.95688619661701546093013348581735e-01
            -3.15463500617562786487724224571139e-01 8.72879851439260390222329988318961e-01
            -3.85561633156645600095657755446155e-01 8.44262211820529517858346935099689e-01
            -4.53093916640263050243930820215610e-01 8.10026146475592900841888877039310e-01
            -5.17610934863873772826536878710613e-01 7.70399490770768191616468811844243e-01
            -5.78683337715758416841538291919278e-01 7.25645953561833034761718863592250e-01
            -6.35904698431174808526122887997190e-01 6.76063362255098776465445098438067e-01
            -6.88894218295421967290792508720187e-01 6.21981680815160253850137905828888e-01
            -7.37299260796458577615908325242344e-01 5.63760813909150781952916986483615e-01
            -7.80797698362710179686985156877199e-01 5.01788211800562988784690787724685e-01
            -8.19100056068910231665824994706782e-01 4.36476291931670090651351756605436e-01
            -8.51951438043968445334996886231238e-01 3.68259694353490818485852287267335e-01
            -8.79133223760937276836102682864293e-01 2.97592389267961887622249150808784e-01
            -9.00464522920549126361322578304680e-01 2.24944655931142767357755474222358e-01
            -9.15803379246313387085365320672281e-01 1.50799953022358157461724204040365e-01
            -9.25047715180115415201100859121652e-01 7.56517013064502974462044448955567e-02
            -9.28136011191523779828571605321486e-01 1.13663879527909148075622666888886e-16
            -9.25047715180115415201100859121652e-01 -7.56517013064500615238117120497918e-02
            -9.15803379246313498107667783187935e-01 -1.50799953022357546839060660204268e-01
            -9.00464522920549126361322578304680e-01 -2.24944655931142961646784783624753e-01
            -8.79133223760937276836102682864293e-01 -2.97592389267961665577644225777476e-01
            -8.51951438043968556357299348746892e-01 -3.68259694353490651952398593493854e-01
            -8.19100056068910231665824994706782e-01 -4.36476291931669868606746831574128e-01
            -7.80797698362710068664682694361545e-01 -5.01788211800563099806993250240339e-01
            -7.37299260796458799660513250273652e-01 -5.63760813909150559908312061452307e-01
            -6.88894218295421856268490046204533e-01 -6.21981680815160364872440368344542e-01
            -6.35904698431175030570727813028498e-01 -6.76063362255098665443142635922413e-01
            -5.78683337715758638886143216950586e-01 -7.25645953561832812717113938560942e-01
            -5.17610934863873994871141803741921e-01 -7.70399490770768080594166349328589e-01
            -4.53093916640263216777384513989091e-01 -8.10026146475592789819586414523656e-01
            -3.85561633156645822140262680477463e-01 -8.44262211820529406836044472584035e-01
            -3.15463500617562619954270530797658e-01 -8.72879851439260390222329988318961e-01
            -2.43266010529684328922428449004656e-01 -8.95688619661701324048408423550427e-01
            -1.69449625277796001032726280755014e-01 -9.12536727898514143930697173345834e-01
            -9.45055807269057912556320388830500e-02 -9.23312054769124368469590535823954e-01
            -1.89326171285996887327929272260008e-02 -9.27942892251012452220493287313730e-01
            5.67663399130336615572289815645490e-02 -9.26398422884770589291747455717996e-01
            1.32087526328333426661743033037055e-01 -9.18688924859211608620057631924283e-01
            2.06529692048825985750681866193190e-01 -9.04865703611717919763179907022277e-01
            2.79597436743734217845513967404258e-01 -8.85020750399020839083163991745096e-01
            3.50804506627442169719444109432516e-01 -8.59286130110564094763958564726636e-01
            4.19677030398215467066336259449599e-01 -8.27833102398452980175136417528847e-01
            4.85756672773523245911775347849471e-01 -7.90870981972728981368447875865968e-01
            5.48603684635734389907213426340604e-01 -7.48645745646502658310339484160068e-01
            6.07799829489930831805111210996984e-01 -7.01438395400853065275725839455845e-01
            6.62951166758784182775343651883304e-01 -6.49563088363000362690513611596543e-01
            7.13690673392102459260399882623460e-01 -5.93365046142456553646127304091351e-01
            7.59680686344667788212348114029737e-01 -5.33218257438177745122231954155723e-01
            8.00615149668100767321732291748049e-01 -4.69522989205466978468450633954490e-01
            8.36221651262694098960537303355522e-01 -4.02703122945434310864243343530688e-01
            8.66263235734995307169015177350957e-01 -3.33203333843538229697145425234339e-01
            8.90539981296853522252376933465712e-01 -2.61486131529593879285755519958911e-01
            9.08890330211935881798979153245455e-01 -1.88028782152494994273084216729330e-01
            9.21192163935806940244788165728096e-01 -1.13320132252737432176914467163442e-01
            9.27363615794693951777105667133583e-01 -3.78573555693420688017525321811263e-02
            8.98616548975230355900123413448455e-01 3.86963188889980422291436923387664e-02
            8.91963506444884757229374372400343e-01 1.15802462660590729792708941658930e-01
            8.78706678183393652403765372582711e-01 1.92051245514361146327075857698219e-01
            8.58944213109048781973342556739226e-01 2.66878148139161885943337892967975e-01
            8.32822425598982674088688327174168e-01 3.39729178327588587915641937797773e-01
            8.00534712228710421122457319142995e-01 4.10064972540458871907986804217217e-01
            7.62320119931548467739901298045879e-01 4.77364789165750091903817065031035e-01
            7.18461576178755945143450389878126e-01 5.41130363907302180948022396478336e-01
            6.69283794283523802981505923526129e-01 6.00889598759340670675044293602696e-01
            6.15150869337212524712299455131870e-01 6.56200057254937463291355470573762e-01
            5.56463582576680604319108169875108e-01 7.06652240110818175011786479444709e-01
            4.93656434140228195239785691228462e-01 7.51872617016782984755707275326131e-01
            4.27194426180590725028451970501919e-01 7.91526392123438560233239513763692e-01
            3.57569620151691081044731390647939e-01 8.25319982753529912677947777410736e-01
            2.85297493757790732171741865386139e-01 8.53003192985369085299396374466596e-01
            2.10913124536918156204379215523659e-01 8.74371066015902642654111787123838e-01
            1.34967228333983613186575212239404e-01 8.89265401589173332119742099166615e-01
            5.80220819933425710490659810147918e-02 8.97575927255666372595044322224567e-01
            -1.93526395422368782672783993348276e-02 8.99241114790944040535691783588845e-01
            -9.65840809055384108550157407080405e-02 8.94248635729092966606401660101255e-01
            -1.73100447525611766952380321527016e-01 8.82635452638372397515809097967576e-01
            -2.48335238994723678240816866491514e-01 8.64487545463290540936895922641270e-01
            -3.21731443239173686698961773799965e-01 8.39939274959178083790334312652703e-01
            -3.92745660441808752683101602087845e-01 8.09172387932163061918799940031022e-01
            -4.60852126184148225274128662931616e-01 7.72414671649407136300169440801255e-01
            -5.25546604022192886951359014346963e-01 7.29938267381873839845241036528023e-01
            -5.86350118676634890491072837903630e-01 6.82057655565574405542861313733738e-01
            -6.42812502198251145557605923386291e-01 6.29127327498444355313722553546540e-01
            -6.94515726853897286119376985880081e-01 5.71539160810800583867319346609293e-01
            -7.41077000057590140613683615811169e-01 5.09719518140471006262259834329598e-01
            -7.82151598432885175604667438165052e-01 4.44126090492997671610453380708350e-01
            -8.17435420024149150819425813097041e-01 3.75244508657560982278766914532753e-01
            -8.46667235761043635022815578849986e-01 3.03584747766525664403047812811565e-01
            -8.69630623507164801644364615640370e-01 2.29677351617984470966149501691689e-01
            -8.86155570373823087138021037389990e-01 1.54069504715098642977366694140073e-01
            -8.96119731435987887380179017782211e-01 7.73209811034789584738291523535736e-02
            -8.99449335531308014068940792640205e-01 1.10150774975363007304989930253897e-16
            -8.96119731435987887380179017782211e-01 -7.73209811034787364292242273222655e-02
            -8.86155570373823087138021037389990e-01 -1.54069504715098420932761769108765e-01
            -8.69630623507164912666667078156024e-01 -2.29677351617984276677120192289294e-01
            -8.46667235761043635022815578849986e-01 -3.03584747766525442358442887780257e-01
            -8.17435420024149039797123350581387e-01 -3.75244508657561093301069377048407e-01
            -7.82151598432885286626969900680706e-01 -4.44126090492997449565848455677042e-01
            -7.41077000057590362658288540842477e-01 -5.09719518140470784217654909298290e-01
            -6.94515726853897508163981910911389e-01 -5.71539160810800472845016884093639e-01
            -6.42812502198251367602210848417599e-01 -6.29127327498444133269117628515232e-01
            -5.86350118676635001513375300419284e-01 -6.82057655565574183498256388702430e-01
            -5.25546604022192997973661476862617e-01 -7.29938267381873728822938574012369e-01
            -4.60852126184148780385640975509887e-01 -7.72414671649406803233262053254293e-01
            -3.92745660441808253082740520767402e-01 -8.09172387932163283963404865062330e-01
            -3.21731443239174130788171623862581e-01 -8.39939274959177972768031850137049e-01
            -2.48335238994724066818875485296303e-01 -8.64487545463290540936895922641270e-01
            -1.73100447525612377575043865363114e-01 -8.82635452638372175471204172936268e-01
            -9.65840809055388271886499751417432e-02 -8.94248635729092855584099197585601e-01
            -1.93526395422372980703595857221444e-02 -8.99241114790944040535691783588845e-01
            5.80220819933421477765378426738607e-02 -8.97575927255666372595044322224567e-01
            1.34967228333983196852940977805702e-01 -8.89265401589173443142044561682269e-01
            2.10913124536918517026862218699534e-01 -8.74371066015902531631809324608184e-01
            2.85297493757790343593683246581350e-01 -8.53003192985369307344001299497904e-01
            3.57569620151690692466672771843150e-01 -8.25319982753530023700250239926390e-01
            4.27194426180591058095359358048881e-01 -7.91526392123438338188634588732384e-01
            4.93656434140227751150575841165846e-01 -7.51872617016783317822614662873093e-01
            5.56463582576680271252200782328146e-01 -7.06652240110818286034088941960363e-01
            6.15150869337212746756904380163178e-01 -6.56200057254937241246750545542454e-01
            6.69283794283523358892296073463513e-01 -6.00889598759341114764254143665312e-01
            7.18461576178756056165752852393780e-01 -5.41130363907301958903417471447028e-01
            7.62320119931548245695296373014571e-01 -4.77364789165750480481875683835824e-01
            8.00534712228710088055549931596033e-01 -4.10064972540459427019499116795487e-01
            8.32822425598982674088688327174168e-01 -3.39729178327588365871037012766465e-01
            8.58944213109048670951040094223572e-01 -2.66878148139162441054850205546245e-01
            8.78706678183393541381462910067057e-01 -1.92051245514361729194163785905403e-01
            8.91963506444884868251676834915997e-01 -1.15802462660590535503679632256535e-01
            8.98616548975230355900123413448455e-01 -3.86963188889986528518072361748636e-02
            8.66796966055944695384027909312863e-01 3.94928439146197685083450323872967e-02
            8.59614413408823274664882774231955e-01 1.18151281601427460277164982471731e-01
            8.45308825007865527467743049783166e-01 1.95830680558682912462131753272843e-01
            8.23998741463919937011439742491348e-01 2.71887364822514354667504221652052e-01
            7.95860744840564349189548920548987e-01 3.45691104754052402903141683054855e-01
            7.61127995439514148934279091918143e-01 4.16630339320700482375059436890297e-01
            7.20088299760932137871805025497451e-01 4.84117243683454212543892936082557e-01
            6.73081725648127293659683800797211e-01 5.47592600098644632922173514089081e-01
            6.20497784378304606534015874785837e-01 6.06530431772281386493261834402801e-01
            5.62772203049451524847768268955406e-01 6.60442361269416022828693257906707e-01
            5.00383314008376323123172824125504e-01 7.08881657363377937208781531808199e-01
            4.33848091238239585987201962780091e-01 7.51446936791408615086140798666747e-01
            3.63717866549313317836578107744572e-01 7.87785490242788655201877645595232e-01
            2.90573761069968627968052032883861e-01 8.17596205019267441294061882217648e-01
            2.15021869893987555011349854794389e-01 8.40632060149711479724032869853545e-01
            1.37688239785735883069506257925241e-01 8.56702173283668488856790190766333e-01
            5.92136815595068755069263488621800e-02 8.65673382402638247334891730133677e-01
            -1.97515398806995430558419712951945e-02 8.67471349242495803899544171144953e-01
            -9.85530938409652085274714750084968e-02 8.62081175283760048344561255362350e-01
            -1.76538005827654886914501730643678e-01 8.49547525205417763949355958175147e-01
            -2.53060068299717721984620766306762e-01 8.29974256779327679289792740746634e-01
            -3.27485195347886337557952174392994e-01 8.03523560272013215310948908154387e-01
            -3.99196676930217930756583655238501e-01 7.70414614485035786906053090206115e-01
            -4.67600289125726820138595485332189e-01 7.30921770570415962886556826560991e-01
            -5.32129218060936493017720749776345e-01 6.85372278670585921567237619456137e-01
            -5.92248756708147361393912433413789e-01 6.34143576220644766827660987473791e-01
            -6.47460735636264939074635549332015e-01 5.77660160382903464793002967780922e-01
            -6.97307650999599126784289637726033e-01 5.16390070529707534419117109791841e-01
            -7.41376455558814262403188877215143e-01 4.50841009921795543569089659285964e-01
            -7.79301981320438930112004527472891e-01 3.81556138719184201324452487824601e-01
            -8.10769965433862926929009518062230e-01 3.09109573185023911445767907935078e-01
            -8.35519654272292244812092576466966e-01 2.34101628377430176497497882337484e-01
            -8.53345964119419875260064145550132e-01 1.57153843749851529487671086826595e-01
            -8.64101180557689696470902163127903e-01 7.89038328794109400377010388183407e-02
            -8.67696182476478949929799000528874e-01 1.06262135250219762030705160715806e-16
            -8.64101180557689696470902163127903e-01 -7.89038328794107457486717294159462e-02
            -8.53345964119419986282366608065786e-01 -1.57153843749850918865007542990497e-01
            -8.35519654272292244812092576466966e-01 -2.34101628377429982208468572935089e-01
            -8.10769965433863037951311980577884e-01 -3.09109573185023689401162982903770e-01
            -7.79301981320439041134306989988545e-01 -3.81556138719184034790998794051120e-01
            -7.41376455558814595470096264762105e-01 -4.50841009921794988457577346707694e-01
            -6.97307650999599015761987175210379e-01 -5.16390070529707756463722034823149e-01
            -6.47460735636265050096938011847669e-01 -5.77660160382903242748398042749614e-01
            -5.92248756708147916505424745992059e-01 -6.34143576220644322738451137411175e-01
            -5.32129218060936715062325674807653e-01 -6.85372278670585699522632694424829e-01
            -4.67600289125726986672049179105670e-01 -7.30921770570415851864254364045337e-01
            -3.99196676930218430356944736558944e-01 -7.70414614485035564861448165174806e-01
            -3.27485195347886504091405868166476e-01 -8.03523560272013215310948908154387e-01
            -2.53060068299718277096133078885032e-01 -8.29974256779327457245187815715326e-01
            -1.76538005827654914670077346272592e-01 -8.49547525205417763949355958175147e-01
            -9.85530938409654166942885922253481e-02 -8.62081175283759937322258792846696e-01
            -1.97515398807001432701646592704492e-02 -8.67471349242495803899544171144953e-01
            5.92136815595068616291385410477233e-02 -8.65673382402638247334891730133677e-01
            1.37688239785735494491447639120452e-01 -8.56702173283668599879092653281987e-01
            2.15021869893986972144261926587205e-01 -8.40632060149711590746335332369199e-01
            2.90573761069968405923447107852553e-01 -8.17596205019267441294061882217648e-01
            3.63717866549312929258519488939783e-01 -7.87785490242788877246482570626540e-01
            4.33848091238239585987201962780091e-01 -7.51446936791408615086140798666747e-01
            5.00383314008376323123172824125504e-01 -7.08881657363378159253386456839507e-01
            5.62772203049451080758558418892790e-01 -6.60442361269416466917903107969323e-01
            6.20497784378304606534015874785837e-01 -6.06530431772281386493261834402801e-01
            6.73081725648127071615078875765903e-01 -5.47592600098644965989080901636044e-01
            7.20088299760931804804897637950489e-01 -4.84117243683454767655405248660827e-01
            7.61127995439514037911976629402488e-01 -4.16630339320700704419664361921605e-01
            7.95860744840564127144943995517679e-01 -3.45691104754052791481200301859644e-01
            8.23998741463919937011439742491348e-01 -2.71887364822514299156352990394225e-01
            8.45308825007865416445440587267512e-01 -1.95830680558683190017887909561978e-01
            8.59614413408823163642580311716301e-01 -1.18151281601427987633101679421088e-01
            8.66796966055944695384027909312863e-01 -3.94928439146198378972840714595804e-02
            8.32170276949179665848532749805599e-01 4.02519635831105615508818118541967e-02
            8.24400527289351092719016378396191e-01 1.20380069010655954553357105396572e-01
            8.08933572028822989175012025953038e-01 1.99384218168488502875845824746648e-01
            7.85913821961519265535400791122811e-01 2.76526770602428029199870707088849e-01
            7.55556206291484899750798831519205e-01 3.51087467085325288795871756519773e-01
            7.18144165896818176264559951960109e-01 4.22370154483402870937425177544355e-01
            6.74027006918559656867273588431999e-01 4.89709285550497142036618924976210e-01
            6.23616639383369419924463272764115e-01 5.52476132963373278705887514661299e-01
            5.67383731310591166163703746860847e-01 6.10084659579341659352280657913070e-01
            5.05853314211770599406747805915074e-01 6.61996990107159066774045186321018e-01
            4.39599881012892490517174337583128e-01 7.07728433103701926043527237197850e-01
            3.69242022168721706343319510779111e-01 7.46852006407376256547081538883504e-01
            2.95436650050395543942727272224147e-01 7.79002423755517203751708166237222e-01
            2.18872865531610644174165258846187e-01 8.03879505363802593365107895806432e-01
            1.40265524039432515346348395723908e-01 8.21250980624019466524998733802931e-01
            6.03485611417813663792664158336265e-02 8.30954656752152187593196686066221e-01
            -2.01318600112180869088351897744360e-02 8.32899933138704806623309195856564e-01
            -1.00424315411526299257616301474627e-01 8.27068647262182543578035165410256e-01
            -1.79779136036692571698480946906784e-01 8.13515244267660087018612102838233e-01
            -2.57455407307529138272172986035002e-01 7.92366268627132219748432362393942e-01
            -3.32727886807909378763525864997064e-01 7.63819182627873849433797204255825e-01
            -4.04893775677801659451660043487209e-01 7.28140522720267524547921311750542e-01
            -4.73279280456864737125499686953845e-01 6.85663410938780359948907516809413e-01
            -5.37245904112445882283566334081115e-01 6.36784444631282475768330186838284e-01
            -5.96196407514338888589122689154465e-01 5.81959993536468656039062352647306e-01
            -6.49580385695626705278016288502840e-01 5.21701938782568874763967414764920e-01
            -6.96899406835558954398379682970699e-01 4.56572893591172812577383410825860e-01
            -7.37711665983166287041683517600177e-01 3.87180950309169547018939283589134e-01
            -7.71636110071050818071114463236881e-01 3.14174002814344044409722300770227e-01
            -7.98355995705206766821504515974084e-01 2.38233697304806479877470337669365e-01
            -8.17621846512748162716377464676043e-01 1.60069067952101379281870663362497e-01
            -8.29253782435585229393382178386673e-01 8.04099168401840314057693603899679e-02
            -8.33143199222060704123293817247031e-01 1.02030615215868228007734919229838e-16
            -8.29253782435585229393382178386673e-01 -8.04099168401838232389522431731166e-02
            -8.17621846512748162716377464676043e-01 -1.60069067952101184992841353960102e-01
            -7.98355995705206766821504515974084e-01 -2.38233697304806674166499647071760e-01
            -7.71636110071051040115719388268190e-01 -3.14174002814343489298209988191957e-01
            -7.37711665983166398063985980115831e-01 -3.87180950309169380485485589815653e-01
            -6.96899406835559176442984608002007e-01 -4.56572893591172646043929717052379e-01
            -6.49580385695626816300318751018494e-01 -5.21701938782568763741664952249266e-01
            -5.96196407514338999611425151670119e-01 -5.81959993536468656039062352647306e-01
            -5.37245904112445549216658946534153e-01 -6.36784444631282808835237574385246e-01
            -4.73279280456864903658953380727326e-01 -6.85663410938780248926605054293759e-01
            -4.04893775677802103540869893549825e-01 -7.28140522720267191481013924203580e-01
            -3.32727886807909267741223402481410e-01 -7.63819182627873960456099666771479e-01
            -2.57455407307529360316777911066310e-01 -7.92366268627132108726129899878288e-01
            -1.79779136036693293343446953258535e-01 -8.13515244267659975996309640322579e-01
            -1.00424315411526146601950415515603e-01 -8.27068647262182654600337627925910e-01
            -2.01318600112182950756523069912873e-02 -8.32899933138704806623309195856564e-01
            6.03485611417813455625847041119414e-02 -8.30954656752152187593196686066221e-01
            1.40265524039432681879802089497389e-01 -8.21250980624019466524998733802931e-01
            2.18872865531610255596106640041398e-01 -8.03879505363802593365107895806432e-01
            2.95436650050395543942727272224147e-01 -7.79002423755517203751708166237222e-01
            3.69242022168721206742958429458668e-01 -7.46852006407376478591686463914812e-01
            4.39599881012892212961418181293993e-01 -7.07728433103702037065829699713504e-01
            5.05853314211770377362142880883766e-01 -6.61996990107159177796347648836672e-01
            5.67383731310590833096796359313885e-01 -6.10084659579341992419188045460032e-01
            6.23616639383369530946765735279769e-01 -5.52476132963373056661282589629991e-01
            6.74027006918559545844971125916345e-01 -4.89709285550497364081223850007518e-01
            7.18144165896817843197652564413147e-01 -4.22370154483403481560088721380453e-01
            7.55556206291485121795403756550513e-01 -3.51087467085325066751266831488465e-01
            7.85913821961519154513098328607157e-01 -2.76526770602428251244475632120157e-01
            8.08933572028822767130407100921730e-01 -1.99384218168489280031963062356226e-01
            8.24400527289351092719016378396191e-01 -1.20380069010655746386539988179720e-01
            8.32170276949179554826230287289945e-01 -4.02519635831108807400013915867021e-02
            7.94941751192767220857149368384853e-01 4.09769432098529562402688952715835e-02
            7.86515170871811108987969873851398e-01 1.22496463837666588747588036767411e-01
            7.69751334077588222903898440563353e-01 2.02717491475254973920527845621109e-01
            7.44827941650470948253826009022305e-01 2.80789663273008693877841324137989e-01
            7.12009187750399341609863768098876e-01 3.55885394787793185589208633246017e-01
            6.71642959333062727900198751740390e-01 4.27208652583924874956977646434098e-01
            6.24157148461624733393193764641182e-01 4.94003392385619466420365597514319e-01
            5.70055116544406548229062536847778e-01 5.55561573334396374690413722419180e-01
            5.09910358578737787915713397524087e-01 6.11230663398319551404824778728653e-01
            4.44360423961315531560245517539443e-01 6.60420556373865985655413624044741e-01
            3.74100158305995300622726063011214e-01 7.02609827158484967490892358910060e-01
            2.99874337907427956917416622673045e-01 7.37351258986399638040154513873858e-01
            2.22469774927055996549540850537596e-01 7.64276584037579920227756247186335e-01
            1.42706976988468681177835151174804e-01 7.83100387168247813463040074566379e-01
            6.14314495924714806807109823694191e-02 7.93623131382405366807120117300656e-01
            -2.04952664515579661974609138042069e-02 7.95733272973630612057149846805260e-01
            -1.02204727572576606342558136475418e-01 7.89408443916115087901630431588273e-01
            -1.82830793155771886837612782983342e-01 7.74715688971301497112165179714793e-01
            -2.61518806848549445476237451657653e-01 7.51810754996733221489080278843176e-01
            -3.37434656130483678904141697785235e-01 7.20936439990620181461622451024596e-01
            -4.09773614113537909542372972282465e-01 6.82420019372656061484860856580781e-01
            -4.77768869847270127859673038983601e-01 6.36669776783152396859577493160032e-01
            -5.40699656705666997780213023361284e-01 5.84170676174883718445585145673249e-01
            -5.97898892692685590688483898702543e-01 5.25479221074541924529910374985775e-01
            -6.48760251677362620448263896832941e-01 4.61217555506912624263549105307902e-01
            -6.92744590601638732252354202501010e-01 3.92066869113439409044730155073921e-01
            -7.29385664530896260515646645217203e-01 3.18760176372566483848913776455447e-01
            -7.58295068966254981468466667138273e-01 2.42074546463913520266686418835889e-01
            -7.79166357028883926894025080400752e-01 1.62822866141659250427409233452636e-01
            -7.91778287873151742637389816081850e-01 8.18452229327247954282498199063411e-02
            -7.95997171894628596788834329345264e-01 9.74815388691102460346134481562075e-17
            -7.91778287873151742637389816081850e-01 -8.18452229327246150170083183184033e-02
            -7.79166357028884037916327542916406e-01 -1.62822866141658723071472536503279e-01
            -7.58295068966255092490769129653927e-01 -2.42074546463913325977657109433494e-01
            -7.29385664530896260515646645217203e-01 -3.18760176372566594871216238971101e-01
            -6.92744590601638732252354202501010e-01 -3.92066869113439575578183848847402e-01
            -6.48760251677362953515171284379903e-01 -4.61217555506912180174339255245286e-01
            -5.97898892692685812733088823733851e-01 -5.25479221074541924529910374985775e-01
            -5.40699656705666997780213023361284e-01 -5.84170676174883496400980220641941e-01
            -4.77768869847270016837370576467947e-01 -6.36669776783152507881879955675686e-01
            -4.09773614113538353631582822345081e-01 -6.82420019372655728417953469033819e-01
            -3.37434656130483845437595391558716e-01 -7.20936439990620181461622451024596e-01
            -2.61518806848549445476237451657653e-01 -7.51810754996733221489080278843176e-01
            -1.82830793155772580727003173706180e-01 -7.74715688971301275067560254683485e-01
            -1.02204727572576453686892250516394e-01 -7.89408443916115087901630431588273e-01
            -2.04952664515583339588378208873110e-02 -7.95733272973630612057149846805260e-01
            6.14314495924712933305755768742529e-02 -7.93623131382405366807120117300656e-01
            1.42706976988468514644381457401323e-01 -7.83100387168247813463040074566379e-01
            2.22469774927055996549540850537596e-01 -7.64276584037579920227756247186335e-01
            2.99874337907427956917416622673045e-01 -7.37351258986399638040154513873858e-01
            3.74100158305994967555818675464252e-01 -7.02609827158485189535497283941368e-01
            4.44360423961315309515640592508134e-01 -6.60420556373866318722321011591703e-01
            5.09910358578737787915713397524087e-01 -6.11230663398319773449429703759961e-01
            5.70055116544406437206760074332124e-01 -5.55561573334396485712716184934834e-01
            6.24157148461624289303983914578566e-01 -4.94003392385619966020726678834762e-01
            6.71642959333062838922501214256044e-01 -4.27208652583924763934675183918444e-01
            7.12009187750399230587561305583222e-01 -3.55885394787793574167267252050806e-01
            7.44827941650471059276128471537959e-01 -2.80789663273008305299782705333200e-01
            7.69751334077588111881595978047699e-01 -2.02717491475255140453981539394590e-01
            7.86515170871810997965667411335744e-01 -1.22496463837667324270341850933619e-01
            7.94941751192767220857149368384853e-01 -4.09769432098528660346481444776146e-02
            7.55275977345009508212569926399738e-01 4.16697368531635109478727940768295e-02
            7.46107950103993666779444993153447e-01 1.24503396401414570537902193336777e-01
            7.27883183053328997047515258600470e-01 2.05825753374122732974882410417194e-01
            7.00822900177086927087088952248450e-01 2.84649664519823542008225558674894e-01
            6.65255576652554414529561199742602e-01 3.60018314334907885143621797396918e-01
            6.21612951606546060290270361292642e-01 4.31016829507699206214255127633805e-01
            5.70424787387253551251831140689319e-01 4.96783384241137604409033201591228e-01
            5.12312438966974759146921769570326e-01 5.56519661650494601445871012401767e-01
            4.47981311534457971035294576722663e-01 6.09500544248926967583201985689811e-01
            3.78212297831479693499545646773186e-01 6.55082915891494921289961439470062e-01
            3.03852299172783058001101608169847e-01 6.92713468333974846657952184614260e-01
            2.25803945211361545286621321793064e-01 7.21935417645412136344873488269513e-01
            1.45014637237204285780123313998047e-01 7.42394048946267703925627756689209e-01
            6.24650480090208487515823776448087e-02 7.53841022166545360327916114329128e-01
            -2.08427822845956393915667348437637e-02 7.56137386557832025246739249269012e-01
            -1.03897609435658261345380992679566e-01 7.49255267367154753621605323132826e-01
            -1.85691260351603548706123092415510e-01 7.33278204198723027040784927521599e-01
            -2.65230870910927563066650236578425e-01 7.08400136956298220880512417352293e-01
            -3.41550937988652381083198861233541e-01 6.74923051675480278888130669656675e-01
            -4.13725039356356849573614908877062e-01 6.33253314822316726306894452136476e-01
            -4.80877079193065770645887369028060e-01 5.83896740554883719731549263087800e-01
            -5.42191922701725337319089703669306e-01 5.27452450824600460599356210877886e-01
            -5.96925290741428526963829881424317e-01 4.64605602847331378146833458231413e-01
            -6.44412794367958841057486552017508e-01 3.96119072222923918058512526840786e-01
            -6.84077999615566811897338084236253e-01 3.22824192658846209624812217953149e-01
            -7.15439424624457864787530070316279e-01 2.45610664705130266050048248871462e-01
            -7.38116384178336137900089397589909e-01 1.65415755994917618165729322754487e-01
            -7.51833610707241084547547416150337e-01 8.32129240850479900970526614401024e-02
            -7.56424595662959164954486368515063e-01 9.26352959874973844049010981576928e-17
            -7.51833610707241084547547416150337e-01 -8.32129240850477958080233520377078e-02
            -7.38116384178336137900089397589909e-01 -1.65415755994917451632275628981006e-01
            -7.15439424624457975809832532831933e-01 -2.45610664705130099516594555097981e-01
            -6.84077999615566922919640546751907e-01 -3.22824192658845765535602367890533e-01
            -6.44412794367958730035184089501854e-01 -3.96119072222924084591966220614268e-01
            -5.96925290741428749008434806455625e-01 -4.64605602847331267124530995715759e-01
            -5.42191922701725448341392166184960e-01 -5.27452450824600349577053748362232e-01
            -4.80877079193065937179341062801541e-01 -5.83896740554883608709246800572146e-01
            -4.13725039356357016107068602650543e-01 -6.33253314822316615284591989620822e-01
            -3.41550937988652547616652555007022e-01 -6.74923051675480167865828207141021e-01
            -2.65230870910927729600103930351906e-01 -7.08400136956298220880512417352293e-01
            -1.85691260351603548706123092415510e-01 -7.33278204198723027040784927521599e-01
            -1.03897609435658275223168800494022e-01 -7.49255267367154753621605323132826e-01
            -2.08427822845956567388014946118346e-02 -7.56137386557832025246739249269012e-01
            6.24650480090201687399797947364277e-02 -7.53841022166545471350218576844782e-01
            1.45014637237204258024547698369133e-01 -7.42394048946267703925627756689209e-01
            2.25803945211361545286621321793064e-01 -7.21935417645412136344873488269513e-01
            3.03852299172782502889589295591577e-01 -6.92713468333975068702557109645568e-01
            3.78212297831479693499545646773186e-01 -6.55082915891494921289961439470062e-01
            4.47981311534457471434933495402220e-01 -6.09500544248927300650109373236774e-01
            5.12312438966974759146921769570326e-01 -5.56519661650494601445871012401767e-01
            5.70424787387253773296436065720627e-01 -4.96783384241137437875579507817747e-01
            6.21612951606545727223362973745679e-01 -4.31016829507699705814616208954249e-01
            6.65255576652554525551863662258256e-01 -3.60018314334907774121319334881264e-01
            7.00822900177086816064786489732796e-01 -2.84649664519824041608586639995337e-01
            7.27883183053328886025212796084816e-01 -2.05825753374123288086394722995465e-01
            7.46107950103993666779444993153447e-01 -1.24503396401414431760024115192209e-01
            7.55275977345009508212569926399738e-01 -4.16697368531640313649155871189578e-02
            7.13308333713091435868136613862589e-01 4.23311784751173106333688167524087e-02
            7.03295048298910652206927807128523e-01 1.26399298470648874248567494760209e-01
            6.83409042048371828670383365533780e-01 2.08693049386331846983821947105753e-01
            6.53929470898569231707142535015009e-01 2.88057207349436794618924295718898e-01
            6.15270163408429326956650129432091e-01 3.63377673550541457903051423272700e-01
            5.67973811512866411099764718528604e-01 4.33597113748680373923605202435283e-01
            5.12704352317612244149813705007546e-01 4.97729800926383136872033219333389e-01
            4.50237647877619440173191378562478e-01 5.54875452736258600872076840460068e-01
            3.81450593794520620427590529288864e-01 6.04231869491709927544320635206532e-01
            3.07308809524560633263945419457741e-01 6.45106195292090234261195291765034e-01
            2.28853083198093831818198395922082e-01 6.76924644200789571435450397984823e-01
            1.47184761235671313084338862609002e-01 6.99240554942029635121514274942456e-01
            6.34502878584752849633332516532391e-02 7.11740661046083356033875588764204e-01
            -2.11748884755073099595001906436664e-02 7.14249488423820300120326010073768e-01
            -1.05502815791221907226749010533240e-01 7.06731818638274389421383148146560e-01
            -1.88349714838251941495528285486216e-01 6.89293183294299227625856474332977e-01
            -2.68552596756619854634351440836326e-01 6.62178382606164128709735905431444e-01
            -3.44985588891076833117921296434361e-01 6.25768048939154497567471935326466e-01
            -4.16575739575240244771947573099169e-01 5.80573303565519505120562371303095e-01
            -4.82318080021050088479483974879258e-01 5.27228581642201099555222754133865e-01
            -5.41289731877634738843596551305382e-01 4.66482726131930258706148606506758e-01
            -5.92662862420383129702372571045998e-01 3.99188475689513377897554846640560e-01
            -6.35716305507765477855741664825473e-01 3.26290494080346438199313752193120e-01
            -6.69845685173146465629656631790567e-01 2.48812109171874962232351435886812e-01
            -6.94571899738546827407503769791219e-01 1.67840947653500660585734749474796e-01
            -7.09547847351999383391785158892162e-01 8.45136671419652596437543934371206e-02
            -7.14563298536693092266602889139904e-01 8.75087656341135783342910013704382e-17
            -7.09547847351999383391785158892162e-01 -8.45136671419653984216324715816882e-02
            -6.94571899738547049452108694822527e-01 -1.67840947653500188740949283783266e-01
            -6.69845685173146576651959094306221e-01 -2.48812109171874795698897742113331e-01
            -6.35716305507765588878044127341127e-01 -3.26290494080346271665860058419639e-01
            -5.92662862420383129702372571045998e-01 -3.99188475689513322386403615382733e-01
            -5.41289731877635071910503938852344e-01 -4.66482726131929870128089987701969e-01
            -4.82318080021050421546391362426220e-01 -5.27228581642200766488315366586903e-01
            -4.16575739575240355794250035614823e-01 -5.80573303565519394098259908787441e-01
            -3.44985588891076666584467602660879e-01 -6.25768048939154608589774397842120e-01
            -2.68552596756620021167805134609807e-01 -6.62178382606164128709735905431444e-01
            -1.88349714838251997006679516744043e-01 -6.89293183294299227625856474332977e-01
            -1.05502815791222254171444205894659e-01 -7.06731818638274278399080685630906e-01
            -2.11748884755074834318477883243759e-02 -7.14249488423820300120326010073768e-01
            6.34502878584747853629721703327959e-02 -7.11740661046083467056178051279858e-01
            1.47184761235671618395670634527050e-01 -6.99240554942029524099211812426802e-01
            2.28853083198093998351652089695563e-01 -6.76924644200789571435450397984823e-01
            3.07308809524560300197038031910779e-01 -6.45106195292090345283497754280688e-01
            3.81450593794520620427590529288864e-01 -6.04231869491709927544320635206532e-01
            4.50237647877618996083981528499862e-01 -5.54875452736258933938984228007030e-01
            5.12704352317612022105208779976238e-01 -4.97729800926383303405486913106870e-01
            5.67973811512866411099764718528604e-01 -4.33597113748680373923605202435283e-01
            6.15270163408429104912045204400783e-01 -3.63377673550541679947656348304008e-01
            6.53929470898569231707142535015009e-01 -2.88057207349436850130075526976725e-01
            6.83409042048371939692685828049434e-01 -2.08693049386331708205943868961185e-01
            7.03295048298910541184625344612869e-01 -1.26399298470649096293172419791517e-01
            7.13308333713091435868136613862589e-01 -4.23311784751172898166871050307236e-02
            6.69152169555365383679657043103362e-01 4.29609946750957802374948357737594e-02
            6.58164709430976491155718122172402e-01 1.28177565680443084072948067841935e-01
            6.36370202973676524216273264755728e-01 2.11289464600977555663874341007613e-01
            6.04126515376952721858572203927906e-01 2.90931996354176547470160585362464e-01
            5.61963087099718205941201176756294e-01 3.65797432770489205910990904158098e-01
            5.10572240468614602093566645635292e-01 4.34656485453726093570736566107371e-01
            4.50797811764547695645433122990653e-01 4.96378490662540139410907613637391e-01
            3.83621295454285138326611104275798e-01 5.49949974777799277525502930075163e-01
            3.10145728078446369924137115958729e-01 5.94491295511394790551662481448147e-01
            2.31577576422001135680872607736092e-01 6.29271085608291924629043023742270e-01
            1.49206927363014080212266776470642e-01 6.53718261876639283869394603243563e-01
            6.43863046817746143002381131736911e-02 6.67431402357988923235154743451858e-01
            -2.14915393422842604387312803737586e-02 6.70185337664757518894020904554054e-01
            -1.07016492884508346294936131926079e-01 6.61934848255344543410672031313879e-01
            -1.90784238572199449368582691022311e-01 6.42815406937755406957535342371557e-01
            -2.71419312337050022687634509566124e-01 6.13140954409839511463076178188203e-01
            -3.47597688497118306738542514722212e-01 5.73398744361710677175381078995997e-01
            -4.18068520221920481017008341950714e-01 5.24241342783626440571254079259234e-01
            -4.81674678402806866195362545113312e-01 4.66475912850469298653877103788545e-01
            -5.37371751680934428563318761007395e-01 4.01050961324730115276082642594702e-01
            -5.84245195652905002781096754915779e-01 3.29040764101691252108139451593161e-01
            -6.21525349664585169406905151845422e-01 2.51627726628925463270292084416724e-01
            -6.48600074617768584950283639045665e-01 1.70082968841536452675455848293495e-01
            -6.65024804277245085160075177554972e-01 8.57454534079671731872096529514238e-02
            -6.70529845036092364551905120606534e-01 8.21162228456221305040787694826318e-17
            -6.65024804277245196182377640070627e-01 -8.57454534079670205315437669923995e-02
            -6.48600074617768584950283639045665e-01 -1.70082968841536313897577770148928e-01
            -6.21525349664585169406905151845422e-01 -2.51627726628925352247989621901070e-01
            -5.84245195652905224825701679947088e-01 -3.29040764101690808018929601530544e-01
            -5.37371751680934539585621223523049e-01 -4.01050961324730059764931411336875e-01
            -4.81674678402806977217665007628966e-01 -4.66475912850469187631574641272891e-01
            -4.18068520221920647550462035724195e-01 -5.24241342783626329548951616743580e-01
            -3.47597688497118639805449902269174e-01 -5.73398744361710455130776153964689e-01
            -2.71419312337050355754541897113086e-01 -6.13140954409839400440773715672549e-01
            -1.90784238572199449368582691022311e-01 -6.42815406937755406957535342371557e-01
            -1.07016492884508068739179975636944e-01 -6.61934848255344543410672031313879e-01
            -2.14915393422842743165190881882154e-02 -6.70185337664757518894020904554054e-01
            6.43863046817741563332404552966182e-02 -6.67431402357988923235154743451858e-01
            1.49206927363013913678813082697161e-01 -6.53718261876639283869394603243563e-01
            2.31577576422001135680872607736092e-01 -6.29271085608291924629043023742270e-01
            3.10145728078446203390683422185248e-01 -5.94491295511394790551662481448147e-01
            3.83621295454285138326611104275798e-01 -5.49949974777799277525502930075163e-01
            4.50797811764547473600828197959345e-01 -4.96378490662540361455512538668700e-01
            5.10572240468614046982054333057022e-01 -4.34656485453726704193400109943468e-01
            5.61963087099718316963503639271948e-01 -3.65797432770488983866385979126790e-01
            6.04126515376952610836269741412252e-01 -2.90931996354176714003614279135945e-01
            6.36370202973676413193970802240074e-01 -2.11289464600978055264235422328056e-01
            6.58164709430976491155718122172402e-01 -1.28177565680443333873128608502157e-01
            6.69152169555365383679657043103362e-01 -4.29609946750963700434766678881715e-02
            6.22903441419272785317673424287932e-01 4.35576518070909454727335230472818e-02
            6.10779334474209623095930510316975e-01 1.29825155274942372063406992310775e-01
            5.86767102534801354707383325148840e-01 2.13565759769292429215425954680541e-01
            5.51334116382239947107279931515222e-01 2.93149549677184373397409444805817e-01
            5.05170038787560393700459826504812e-01 3.67027517053280349923483072416275e-01
            4.49173401010283301904024710893282e-01 4.33761711297546981302986068840255e-01
            3.84434113909511820939002291197539e-01 4.92053227228040568341782545758178e-01
            3.12212254068815087126864682431915e-01 5.40767486792790519345430766406935e-01
            2.33913537838843998972748750020401e-01 5.78956322341018125854361642268486e-01
            1.51061960667545708281167549102975e-01 6.05876431627933587087397881987272e-01
            6.52701342622868385667800339433597e-02 6.21003845347437688495517704723170e-01
            -2.17921010627098628298359273003371e-02 6.24044125598658183662337251007557e-01
            -1.08430177928668755593655248503637e-01 6.14938096784772625369441811926663e-01
            -1.92957784718745278818019528443983e-01 5.93862997398689307360086786502507e-01
            -2.73729687715498548605808082356816e-01 5.61229030277387574976444284402533e-01
            -3.49173753703774236711865341931116e-01 5.17671378470296761342694935592590e-01
            -4.17821549755464205500032903728425e-01 4.64037842123746824274377331676078e-01
            -4.78336924606132529724789037572918e-01 4.01372337015480362687469551019603e-01
            -5.29542015319529935091225070209475e-01 3.30894575921473810264927806201740e-01
            -5.70440173049847176756088629190344e-01 2.53976328294157505105488326080376e-01
            -6.00235361677828760385011719336035e-01 1.72114720330386938851319200693979e-01
            -6.18347651748355819911751041217940e-01 8.69030951129777795571840215416159e-02
            -6.24424508137630063231426902348176e-01 7.64699475199909040551301536826750e-17
            -6.18347651748355819911751041217940e-01 -8.69030951129776407793059433970484e-02
            -6.00235361677828871407314181851689e-01 -1.72114720330386522517684966260276e-01
            -5.70440173049847398800693554221652e-01 -2.53976328294157116527429707275587e-01
            -5.29542015319529935091225070209475e-01 -3.30894575921473699242625343686086e-01
            -4.78336924606132640747091500088573e-01 -4.01372337015480196154015857246122e-01
            -4.17821549755464372033486597501906e-01 -4.64037842123746713252074869160424e-01
            -3.49173753703774569778772729478078e-01 -5.17671378470296539298090010561282e-01
            -2.73729687715498715139261776130297e-01 -5.61229030277387574976444284402533e-01
            -1.92957784718745417595897606588551e-01 -5.93862997398689196337784323986853e-01
            -1.08430177928668769471443056318094e-01 -6.14938096784772625369441811926663e-01
            -2.17921010627104352885829996466782e-02 -6.24044125598658183662337251007557e-01
            6.52701342622865471332360698397679e-02 -6.21003845347437688495517704723170e-01
            1.51061960667545430725411392813839e-01 -6.05876431627933698109700344502926e-01
            2.33913537838843998972748750020401e-01 -5.78956322341018125854361642268486e-01
            3.12212254068815087126864682431915e-01 -5.40767486792790519345430766406935e-01
            3.84434113909511987472455984971020e-01 -4.92053227228040457319480083242524e-01
            4.49173401010283079859419785861974e-01 -4.33761711297547203347590993871563e-01
            5.05170038787560282678157363989158e-01 -3.67027517053280460945785534931929e-01
            5.51334116382239947107279931515222e-01 -2.93149549677184373397409444805817e-01
            5.86767102534801354707383325148840e-01 -2.13565759769292345948699107793800e-01
            6.10779334474209512073628047801321e-01 -1.29825155274942732885889995486650e-01
            6.22903441419272896339975886803586e-01 -4.35576518070906124058261355003197e-02
            5.74643669183371286202088867867133e-01 4.41179944904189838550401248085109e-02
            5.61174508623101919724263098032679e-01 1.31319895073079673242233411656343e-01
            5.34551893210164719150156997784507e-01 2.15443768616809194771377633514930e-01
            4.95399834485556411767248619071324e-01 2.94517822825831443456223723842413e-01
            4.44636023522035739308222446197760e-01 3.66688628889547341138666070037289e-01
            3.83450321023176610157889854235691e-01 4.30264564282962225227890940004727e-01
            3.13276867996955532547076472837944e-01 4.83755462964918503399047722268733e-01
            2.35760470706046526556676212749153e-01 5.25907543607094352111630541912746e-01
            1.52718047803096529380084689364594e-01 5.55732797165684355711334774241550e-01
            6.60960432974571493458526560971222e-02 5.72532144975987478119350271299481e-01
            -2.20751964426662249108002100683734e-02 5.75911824563797414278099040529924e-01
            -1.09729012288242264161475247874478e-01 5.65792619104059424373076581105124e-01
            -1.94810873087780167534077691016137e-01 5.42411714196108896146597544429824e-01
            -2.75326532136179691345745368380449e-01 5.06317138434252189682638345402665e-01
            -3.49388770627254929834748509165365e-01 4.58354918082003293111625907840789e-01
            -4.15261632463017116290160402058973e-01 3.99649246933526158809257822213112e-01
            -4.71401113593284903924285345055978e-01 3.31576136163921619814942687298753e-01
            -5.16491352161982386625993513007415e-01 2.55731161793535721749037747940747e-01
            -5.49475471193773712386132501706015e-01 1.73892065738390916296296495602292e-01
            -5.69580350894596243449541361769661e-01 8.79770870464189197468485303943453e-02
            -5.76334749924368616724734692979837e-01 3.26524694376273144136569847693213e-16
            -5.69580350894596243449541361769661e-01 -8.79770870464187809689704522497777e-02
            -5.49475471193773712386132501706015e-01 -1.73892065738391027318598958117946e-01
            -5.16491352161982497648295975523070e-01 -2.55731161793535610726735285425093e-01
            -4.71401113593285070457739038829459e-01 -3.31576136163921286748035299751791e-01
            -4.15261632463017227312462864574627e-01 -3.99649246933526103298106590955285e-01
            -3.49388770627254874323597277907538e-01 -4.58354918082003348622777139098616e-01
            -2.75326532136179580323442905864795e-01 -5.06317138434252300704940807918319e-01
            -1.94810873087780167534077691016137e-01 -5.42411714196108896146597544429824e-01
            -1.09729012288242666617321674493724e-01 -5.65792619104059313350774118589470e-01
            -2.20751964426663671581252401665552e-02 -5.75911824563797414278099040529924e-01
            6.60960432974571493458526560971222e-02 -5.72532144975987478119350271299481e-01
            1.52718047803096279579904148704372e-01 -5.55732797165684355711334774241550e-01
            2.35760470706046387778798134604585e-01 -5.25907543607094463133933004428400e-01
            3.13276867996955643569378935353598e-01 -4.83755462964918447887896491010906e-01
            3.83450321023176443624436160462210e-01 -4.30264564282962391761344633778208e-01
            4.44636023522035350730163827392971e-01 -3.66688628889547729716724688842078e-01
            4.95399834485556245233794925297843e-01 -2.94517822825831721011979880131548e-01
            5.34551893210164608127854535268852e-01 -2.15443768616809305793680096030585e-01
            5.61174508623101919724263098032679e-01 -1.31319895073079617731082180398516e-01
            5.74643669183371286202088867867133e-01 -4.41179944904192267163267615615041e-02
            5.24441603707597736594436810264597e-01 4.46365587501610996956635801780067e-02
            5.09354373617354472258966779918410e-01 1.32625563724819095501317178786849e-01
            4.79613945577313516288597838865826e-01 2.16799172701870102031307396828197e-01
            4.36075897553925950766995356389089e-01 2.94735864205548425687197777733672e-01
            3.79992739919299937767505070951302e-01 3.64193541520270225309019451742643e-01
            3.12977883008235757689163847317104e-01 4.23174033730965848398852813261328e-01
            2.36959222240421790717235239753791e-01 4.69980579462245362520889102597721e-01
            1.54123676079320870435651613661321e-01 5.03266639613883182136078175972216e-01
            6.68542723696884666484407944153645e-02 5.22074634839093776328411422582576e-01
            -2.23384070347523409905132751873680e-02 5.25863493358878497652142414153786e-01
            -1.10888451140238861181153140478273e-01 5.14524216611980667046566395583795e-01
            -1.96248436400515369193442438700004e-01 4.88383014945039217735711645218544e-01
            -2.75962711454177833658718554943334e-01 4.48191923134846070819747865243698e-01
            -3.47738041743347547907205807860009e-01 3.95107165717043684605158659906010e-01
            -4.09509581696620217350357506802538e-01 3.30655894511367620669517464193632e-01
            -4.59500276576699395736369524456677e-01 2.56692255244271638758846165728755e-01
            -4.96271985109714874884190294324071e-01 1.75344047152210219531198731601762e-01
            -5.18766852191252514359121050802059e-01 8.89515100716829348881375949531503e-02
            -5.26337741451678109427803065045737e-01 6.44577830339244761185480184301920e-17
            -5.18766852191252514359121050802059e-01 -8.89515100716827961102595168085827e-02
            -4.96271985109714874884190294324071e-01 -1.75344047152210108508896269086108e-01
            -4.59500276576699562269823218230158e-01 -2.56692255244271305691938778181793e-01
            -4.09509581696620161839206275544711e-01 -3.30655894511367731691819926709286e-01
            -3.47738041743347658929508270375663e-01 -3.95107165717043629094007428648183e-01
            -2.75962711454178111214474711232469e-01 -4.48191923134845904286294171470217e-01
            -1.96248436400515507971320516844571e-01 -4.88383014945039162224560413960717e-01
            -1.10888451140238764036638485777075e-01 -5.14524216611980667046566395583795e-01
            -2.23384070347525873212468638939754e-02 -5.25863493358878497652142414153786e-01
            6.68542723696881058259577912394889e-02 -5.22074634839093776328411422582576e-01
            1.54123676079320648391046688630013e-01 -5.03266639613883182136078175972216e-01
            2.36959222240421790717235239753791e-01 -4.69980579462245362520889102597721e-01
            3.12977883008235868711466309832758e-01 -4.23174033730965792887701582003501e-01
            3.79992739919299826745202608435648e-01 -3.64193541520270336331321914258297e-01
            4.36075897553925673211239200099953e-01 -2.94735864205548758754105165280635e-01
            4.79613945577313460777446607607999e-01 -2.16799172701870240809185474972764e-01
            5.09354373617354472258966779918410e-01 -1.32625563724819067745741563157935e-01
            5.24441603707597625572134347748943e-01 -4.46365587501613217402685052093148e-02
            4.72353655436412500634446587355342e-01 4.51043053127961751647134747145174e-02
            4.55281563623495422188369730065460e-01 1.33682728826262808841107698754058e-01
            4.21754409876681446434076860896312e-01 2.17429510212995724671714015130419e-01
            3.72983952886527525549809070071205e-01 2.93317822593567700817374088728684e-01
            3.10732884038844026086678695719456e-01 3.58604864633475628465930640231818e-01
            2.37251119155364120771878333471250e-01 4.10930992529668248636198768508621e-01
            1.55194480673847640117557489247702e-01 4.48405003685580783034936303010909e-01
            6.75287093055031706345658903956064e-02 4.69672489700454831584863768512150e-01
            -2.25777255614783636805675826053630e-02 4.73964788217818566717909334329306e-01
            -1.11868142600977688028152101651358e-01 4.61126764385779652766217395765125e-01
            -1.97115353497275408445332800511096e-01 4.31622417834772786893182683343184e-01
            -2.75238301939137064433538171215332e-01 3.86518112521976653361832632072037e-01
            -3.43413421022517595382339550269535e-01 3.27444035559516788413958465753240e-01
            -3.99176684315203034181251950940350e-01 2.56535278004822897557346550456714e-01
            -4.40512662192030557406496882322244e-01 1.76354667106887186278640911041293e-01
            -4.65927364712691638448660569338244e-01 8.98001390521053488580349721814855e-02
            -4.74502238310728130521454204426846e-01 5.81097647335487836109949619440760e-17
            -4.65927364712691749470963031853898e-01 -8.98001390521050296689153924489801e-02
            -4.40512662192030612917648113580071e-01 -1.76354667106887075256338448525639e-01
            -3.99176684315203200714705644713831e-01 -2.56535278004822675512741625425406e-01
            -3.43413421022517650893490781527362e-01 -3.27444035559516732902807234495413e-01
            -2.75238301939137175455840633730986e-01 -3.86518112521976597850681400814210e-01
            -1.97115353497275325178605953624356e-01 -4.31622417834772842404333914601011e-01
            -1.11868142600977701905939909465815e-01 -4.61126764385779652766217395765125e-01
            -2.25777255614785891946194595902853e-02 -4.73964788217818566717909334329306e-01
            6.75287093055029485899609653642983e-02 -4.69672489700454887096014999769977e-01
            1.55194480673847640117557489247702e-01 -4.48405003685580838546087534268736e-01
            2.37251119155364120771878333471250e-01 -4.10930992529668248636198768508621e-01
            3.10732884038843748530922539430321e-01 -3.58604864633475794999384334005299e-01
            3.72983952886527359016355376297724e-01 -2.93317822593567922861979013759992e-01
            4.21754409876681390922925629638485e-01 -2.17429510212995835694016477646073e-01
            4.55281563623495422188369730065460e-01 -1.33682728826262864352258930011885e-01
            4.72353655436412445123295356097515e-01 -4.51043053127965429260903817976214e-02
            4.18422734247319239031526194594335e-01 4.55062146933573746787615732500853e-02
            3.98857752237382456872438751815935e-01 1.34390824057535746005598298324912e-01
            3.60642625031377783706432182952994e-01 2.16991467853456715397797438527050e-01
            3.05564249504394702672271932897274e-01 2.89445831781244888869508713469259e-01
            2.36198029280857313416674969630549e-01 3.48366030310878593834189587141736e-01
            1.55787451723401748626685048293439e-01 3.90997020444209308909222500005853e-01
            6.80924260686763399563758980548300e-02 4.15345424463545220827853654554929e-01
            -2.27865257497241284478928236012507e-02 4.20272738058249328840787484296015e-01
            -1.12600004949472171089652761111211e-01 4.05548565520949089169278067856794e-01
            -1.97148433063699723977180155998212e-01 3.71861392794746281609263860445935e-01
            -2.72478419562614482263285253793583e-01 3.20786394635714788847735690069385e-01
            -3.35067618000793487897936984154512e-01 2.54711781191987729489056846432504e-01
            -3.81989427022165706215872660322930e-01 1.76727127951535029071195026517671e-01
            -4.11049834986736528641415588936070e-01 9.04789106261640885264796452247538e-02
            -4.20890009516406427003687440446811e-01 5.15441602947366132633725173682100e-17
            -4.11049834986736528641415588936070e-01 -9.04789106261639775041771827090997e-02
            -3.81989427022165650704721429065103e-01 -1.76727127951535112337921873404412e-01
            -3.35067618000793654431390677927993e-01 -2.54711781191987507444451921401196e-01
            -2.72478419562614371240982791277929e-01 -3.20786394635714844358886921327212e-01
            -1.97148433063699973777360696658434e-01 -3.71861392794746170586961397930281e-01
            -1.12600004949472351500894262699148e-01 -4.05548565520949033658126836598967e-01
            -2.27865257497244198814367877048426e-02 -4.20272738058249328840787484296015e-01
            6.80924260686762428118612433536327e-02 -4.15345424463545220827853654554929e-01
            1.55787451723401582093231354519958e-01 -3.90997020444209419931524962521507e-01
            2.36198029280857257905523738372722e-01 -3.48366030310878593834189587141736e-01
            3.05564249504394702672271932897274e-01 -2.89445831781244888869508713469259e-01
            3.60642625031377783706432182952994e-01 -2.16991467853456715397797438527050e-01
            3.98857752237382456872438751815935e-01 -1.34390824057535718250022682695999e-01
            4.18422734247319183520374963336508e-01 -4.55062146933576730511994412609056e-02
            3.62674422196211321267611538132769e-01 4.58164343343488017490372499196383e-02
            3.39886254426400968853272388514597e-01 1.34570487932760607385773710120702e-01
            2.95741783276775971334160431069904e-01 2.14868982858722357143221870501293e-01
            2.33014768221675411252746812351688e-01 2.81666469358829330005278279713821e-01
            1.55646578310835365099862315219070e-01 3.30765815692308895457074413570808e-01
            6.84985414566525591117951421438192e-02 3.59081929354264028919629936353886e-01
            -2.29535106772652194861983332430100e-02 3.64835604783932954120473368675448e-01
            -1.12963309318223056876284715599468e-01 3.47665317393531347889279459195677e-01
            -1.95875207784726779181028177845292e-01 3.08649939487697866358217879678705e-01
            -2.66479546567492786568465135133010e-01 2.50240950748779056311832391656935e-01
            -3.20339995396206334010713590032537e-01 1.76108402752474968444573732995195e-01
            -3.54072304186084430011050017128582e-01 9.09103161298338430240661978132266e-02
            -3.65556947917105579115570890280651e-01 4.47678146172759076622404930226326e-17
            -3.54072304186084485522201248386409e-01 -9.09103161298336071016734649674618e-02
            -3.20339995396206334010713590032537e-01 -1.76108402752475023955724964253022e-01
            -2.66479546567492953101918828906491e-01 -2.50240950748778889778378697883454e-01
            -1.95875207784726557136423252813984e-01 -3.08649939487698032891671573452186e-01
            -1.12963309318223209531950601558492e-01 -3.47665317393531292378128227937850e-01
            -2.29535106772651500972592941707262e-02 -3.64835604783932954120473368675448e-01
            6.84985414566523787005536405558814e-02 -3.59081929354264084430781167611713e-01
            1.55646578310835059788530543301022e-01 -3.30765815692309006479376876086462e-01
            2.33014768221675244719293118578207e-01 -2.81666469358829441027580742229475e-01
            2.95741783276775915823009199812077e-01 -2.14868982858722440409948717388033e-01
            3.39886254426400968853272388514597e-01 -1.34570487932760579630198094491789e-01
            3.62674422196211321267611538132769e-01 -4.58164343343489405269153280642058e-02
            3.05107655348625661506645201370702e-01 4.59875796494488009447110243854695e-02
            2.77997501228008425666615721638664e-01 1.33876540683323635994028677487222e-01
            2.26186049151342549734522435755935e-01 2.09869983569963169944827541257837e-01
            1.54276974006452266552358310036652e-01 2.67215557417158300346216037723934e-01
            6.86597126877395991240149442091933e-02 3.00817856331679900350195566716138e-01
            -2.30582654114649711341034077349832e-02 3.07691168593712816026197742758086e-01
            -1.12727415439329944901736269002868e-01 2.87224770245741334306899261719082e-01
            -1.92380239909295758238272355811205e-01 2.41237190596292533362188237333612e-01
            -2.54939235816543430246383650228381e-01 1.73814627910389096765442218384123e-01
            -2.94845761839082065591810533078387e-01 9.09478727617168553054582957884122e-02
            -3.08553948012904477593565388815477e-01 3.77869604798282312573426982210242e-17
            -2.94845761839082176614112995594041e-01 -9.09478727617166471386411785715609e-02
            -2.54939235816543430246383650228381e-01 -1.73814627910389180032169065270864e-01
            -1.92380239909295841504999202697945e-01 -2.41237190596292477851037006075785e-01
            -1.12727415439329875512797229930584e-01 -2.87224770245741334306899261719082e-01
            -2.30582654114651827703674769054487e-02 -3.07691168593712816026197742758086e-01
            6.86597126877395297350759051369096e-02 -3.00817856331679900350195566716138e-01
            1.54276974006452044507753385005344e-01 -2.67215557417158411368518500239588e-01
            2.26186049151342633001249282642675e-01 -2.09869983569963086678100694371096e-01
            2.77997501228008425666615721638664e-01 -1.33876540683323719260755524373963e-01
            3.05107655348625661506645201370702e-01 -4.59875796494490576837854689529195e-02
            2.45672117831318287395347965684778e-01 4.59240778888017411873967432711652e-02
            2.12492737001999637547200450171658e-01 1.31569932473422218643932524173579e-01
            1.50615034577657791459159852820449e-01 1.99446538623343383456187893898459e-01
            6.83959371468857990628009702049894e-02 2.40386784560759736439905509541859e-01
            -2.30604105905442245683101276654270e-02 2.48861463214089029261089081046521e-01
            -1.11402322095574879412538393808063e-01 2.23726022271383634398844719726185e-01
            -1.84698732700021683861280052951770e-01 1.68375142312242181974468735461414e-01
            -2.33050556002321718196412803081330e-01 9.02842663849608567661064739695576e-02
            -2.49927610338797623334983200038550e-01 3.06073048019955471808346765734812e-17
            -2.33050556002321773707564034339157e-01 -9.02842663849607041104405880105332e-02
            -1.84698732700021628350128821693943e-01 -1.68375142312242209730044351090328e-01
            -1.11402322095575143090506742282741e-01 -2.23726022271383495620966641581617e-01
            -2.30604105905442315072040315726554e-02 -2.48861463214089029261089081046521e-01
            6.83959371468857435516497389471624e-02 -2.40386784560759736439905509541859e-01
            1.50615034577657735948008621562622e-01 -1.99446538623343438967339125156286e-01
            2.12492737001999554280473603284918e-01 -1.31569932473422329666234986689233e-01
            2.45672117831318287395347965684778e-01 -4.59240778888016717984577041988814e-02
            1.84207872095464214590165852314385e-01 4.54031626677578528661349821504700e-02
            1.42008068543904908409558629500680e-01 1.25808170603515984131703930870572e-01
            6.72759278716851122359443593268225e-02 1.77392042806822664013921553305408e-01
            -2.28683171131162550626658713781580e-02 1.88337535808950573557041252570343e-01
            -1.07773706240399572142685258313577e-01 1.56137169070602294107530383371341e-01
            -1.67989438081965175575405169183796e-01 8.81676585550470875984885310572281e-02
            -1.89720814151146277559689679037547e-01 -6.10188676703100136398772760746629e-17
            -1.67989438081965286597707631699450e-01 -8.81676585550468933094592216548335e-02
            -1.07773706240399613776048681756947e-01 -1.56137169070602266351954767742427e-01
            -2.28683171131163869016500456154972e-02 -1.88337535808950573557041252570343e-01
            6.72759278716851122359443593268225e-02 -1.77392042806822664013921553305408e-01
            1.42008068543904852898407398242853e-01 -1.25808170603516067398430777757312e-01
            1.84207872095464214590165852314385e-01 -4.54031626677578667439227899649268e-02
            1.20255460886286358324070988601306e-01 4.37694082705717760206631794517307e-02
            6.39865942470162069044548047713761e-02 1.10828032239126475499979562755470e-01
            -2.22223109722152964429220389774855e-02 1.26028988206615788492115370900137e-01
            -9.80331499140710271866794300876791e-02 8.22595799360440332881339031700918e-02
            -1.27973188494032386053333993913839e-01 1.56721955665897646584933834497112e-17
            -9.80331499140710826978306613455061e-02 -8.22595799360439638991948640978080e-02
            -2.22223109722152999123689909310997e-02 -1.26028988206615788492115370900137e-01
            6.39865942470161097599401500701788e-02 -1.10828032239126531011130794013297e-01
            1.20255460886286358324070988601306e-01 -4.37694082705717621428753716372739e-02
            5.23607964168604500532211432073382e-02 3.80423453970798325363134040344448e-02
            -2.00000445532269761905741489727006e-02 6.15538078642382871508154096318322e-02
            -6.47215037272669269086122767475899e-02 7.92609823756009284708466663233885e-18
            -2.00000445532269900683619567871574e-02 -6.15538078642382802119215057246038e-02
            5.23607964168604431143272393001098e-02 -3.80423453970798464141012118489016e-02
            -0.00000000000000000000000000000000e+00 0.00000000000000000000000000000000e+00
            ];
        
    case   47
        
        % DEGREE.             :          47
        % CARDIN.             :        1176
        % LEBESGUE CONST.     : 2.04302e+03
        % ABS.DET.VAND.MATRIX : Inf
        % CONDITIONING VAND.  : 1.13121e+05
        % POINTS OUT DISK     : 0.00000e+00
        
        pts=[
            9.99453257340926048968299255648162e-01 3.30633693173082165994713932377636e-02
            9.95082902545011416250986258091871e-01 9.90455302504626988735481063486077e-02
            9.86361303402722322530848941823933e-01 1.64594590280733893417064450659382e-01
            9.73326597248005853657559782732278e-01 2.29423920046751550483321580031770e-01
            9.56035781534357642641452912357636e-01 2.93250037384464756762270098988665e-01
            9.34564464599460853477808086609002e-01 3.55793846922516421305004996611387e-01
            9.09006535049162511796794206020422e-01 4.16781860495290423784808808704838e-01
            8.79473751206489073872774042683886e-01 4.75947393037073507304768327230704e-01
            8.46095252420935417525527100224281e-01 5.33031728727993758809589053271338e-01
            8.09016994374947451262869435595348e-01 5.87785252292473137103456792829093e-01
            7.68401110856858915454381531162653e-01 6.39968540503316529743926821538480e-01
            7.24425204791089072386967018246651e-01 6.89353409118565796376287835300900e-01
            6.77281571625741096731587731483160e-01 7.35723910673131586968054307362763e-01
            6.27176358473537032267586255329661e-01 7.78877278762112434939979266346199e-01
            5.74328662682943691386583395797061e-01 8.18624814686692459098082963464549e-01
            5.18969573781215220975582269602455e-01 8.54792712585539016245661514403764e-01
            4.61341162978687824303136721937335e-01 8.87222819443611809830940728716087e-01
            4.01695424652969534928814709928702e-01 9.15773326655057395839776290813461e-01
            3.40293174441642976013611132657388e-01 9.40319390116161279991047194926068e-01
            2.77402908761844757545844686319469e-01 9.60753676136848144828661588690011e-01
            2.13299630743747054006931307412742e-01 9.76986830783599269345529592101229e-01
            1.48263647711841972665069988579489e-01 9.88947870601468492779417829297017e-01
            8.25793454723323938626577955801622e-02 9.96584493006669847048328847449739e-01
            1.65339447663583431757938768669192e-02 9.99863304992468782117498449224513e-01
            -4.95837546732221592926670439283043e-02 9.98769969148304848083341767051024e-01
            -1.15484636969585899302082054873608e-01 9.93309266353638142810211775213247e-01
            -1.80880534332109849104952559173398e-01 9.83505074872382367701106886670459e-01
            -2.45485487140799124583523393994255e-01 9.69400265939330374465043860254809e-01
            -3.09016994374947118195962048048386e-01 9.51056516295153642204240895807743e-01
            -3.71197248918220645830245985052898e-01 9.28554038489707189718558311142260e-01
            -4.31754352338492797258595601306297e-01 9.01991230132959009857529508735752e-01
            -4.90423503830508145107103246118641e-01 8.71484243627277277433051949628862e-01
            -5.46948158122426697502760362112895e-01 8.37166478262528657161567480216036e-01
            -6.01081147283025085670260523329489e-01 7.99187996894924812529836799512850e-01
            -6.52585761524168694869274531811243e-01 7.57714869760334641668464428221341e-01
            -7.01236784272488589131455682945671e-01 7.12928448291397121039381090668030e-01
            -7.46821476984153576061942203523358e-01 6.65024572113848577714634302537888e-01
            -7.89140509396393463603658346983138e-01 6.14212712689667927890013743308373e-01
            -8.28008831148020041368340571352746e-01 5.60715057351672707675049878162099e-01
            -8.63256480957573901768853374960599e-01 5.04765537734843561246123044838896e-01
            -8.94729329820763474856448738137260e-01 4.46608806852806627940566386314458e-01
            -9.22289754977384745870949700474739e-01 3.86499169292452149360173052627943e-01
            -9.45817241700634636636380037089111e-01 3.24699469204683621725848752248567e-01
            -9.65208910277348564044075374113163e-01 2.61479940953820155780107370446785e-01
            -9.80379965874809355952379519294482e-01 1.97117027451480103517056363671145e-01
            -9.91264069326975194584861128532793e-01 1.31892171342068958983517745764402e-01
            -9.97813627218774534810563636710867e-01 6.60905843256997527213059129280737e-02
            -1.00000000000000000000000000000000e+00 1.22464679914735320717376402945840e-16
            -9.97813627218774534810563636710867e-01 -6.60905843256990588319155222052359e-02
            -9.91264069326975194584861128532793e-01 -1.31892171342069153272547055166797e-01
            -9.80379965874809355952379519294482e-01 -1.97117027451480297806085673073540e-01
            -9.65208910277348786088680299144471e-01 -2.61479940953819489646292595352861e-01
            -9.45817241700634747658682499604765e-01 -3.24699469204683399681243827217259e-01
            -9.22289754977384856893252162990393e-01 -3.86499169292451927315568127596634e-01
            -8.94729329820763696901053663168568e-01 -4.46608806852806017317902842478361e-01
            -8.63256480957573790746550912444945e-01 -5.04765537734843672268425507354550e-01
            -8.28008831148020152390643033868400e-01 -5.60715057351672485630444953130791e-01
            -7.89140509396393463603658346983138e-01 -6.14212712689667705845408818277065e-01
            -7.46821476984154020151152053585974e-01 -6.65024572113848022603121989959618e-01
            -7.01236784272488700153758145461325e-01 -7.12928448291397010017078628152376e-01
            -6.52585761524168916913879456842551e-01 -7.57714869760334419623859503190033e-01
            -6.01081147283025196692562985845143e-01 -7.99187996894924479462929411965888e-01
            -5.46948158122426919547365287144203e-01 -8.37166478262528546139265017700382e-01
            -4.90423503830507978573649552345159e-01 -8.71484243627277388455354412144516e-01
            -4.31754352338493407881259145142394e-01 -9.01991230132958676790622121188790e-01
            -3.71197248918220257252187366248108e-01 -9.28554038489707300740860773657914e-01
            -3.09016994374947562285171898111003e-01 -9.51056516295153531181938433292089e-01
            -2.45485487140799124583523393994255e-01 -9.69400265939330374465043860254809e-01
            -1.80880534332109654815923249771004e-01 -9.83505074872382367701106886670459e-01
            -1.15484636969586579313684637781989e-01 -9.93309266353638142810211775213247e-01
            -4.95837546732226241985586057126056e-02 -9.98769969148304737061039304535370e-01
            1.65339447663583223591121651452340e-02 -9.99863304992468782117498449224513e-01
            8.25793454723323661070821799512487e-02 -9.96584493006669847048328847449739e-01
            1.48263647711842166954099297981884e-01 -9.88947870601468381757115366781363e-01
            2.13299630743746387873116532318818e-01 -9.76986830783599380367832054616883e-01
            2.77402908761844313456634836256853e-01 -9.60753676136848255850964051205665e-01
            3.40293174441642920502459901399561e-01 -9.40319390116161279991047194926068e-01
            4.01695424652969534928814709928702e-01 -9.15773326655057395839776290813461e-01
            4.61341162978687213680473178101238e-01 -8.87222819443612142897848116263049e-01
            5.18969573781214776886372419539839e-01 -8.54792712585539238290266439435072e-01
            5.74328662682943469341978470765753e-01 -8.18624814686692570120385425980203e-01
            6.27176358473536255111469017720083e-01 -7.78877278762112990051491578924470e-01
            6.77281571625740541620075418904889e-01 -7.35723910673132142079566619941033e-01
            7.24425204791089183409269480762305e-01 -6.89353409118565685353985372785246e-01
            7.68401110856858804432079068646999e-01 -6.39968540503316862810834209085442e-01
            8.09016994374947118195962048048386e-01 -5.87785252292473248125759255344747e-01
            8.46095252420934973436317250161665e-01 -5.33031728727994535965706290880917e-01
            8.79473751206488740805866655136924e-01 -4.75947393037074173438583102324628e-01
            9.09006535049162622819096668536076e-01 -4.16781860495290090717901421157876e-01
            9.34564464599460742455505624093348e-01 -3.55793846922516809883063615416177e-01
            9.56035781534357642641452912357636e-01 -2.93250037384464923295723792762146e-01
            9.73326597248005853657559782732278e-01 -2.29423920046751578238897195660684e-01
            9.86361303402722211508546479308279e-01 -1.64594590280734587306454841382219e-01
            9.95082902545011416250986258091871e-01 -9.90455302504623380510651031727321e-02
            9.99453257340925826923694330616854e-01 -3.30633693173085427274848768774973e-02
            9.90790177702065344433890459185932e-01 3.42186409639341909683096787375689e-02
            9.86068611301940345370553586690221e-01 1.02492855484525705045406596127577e-01
            9.76647978915776371344747985858703e-01 1.70278644873742807108740748844866e-01
            9.62573174147026033864449345855974e-01 2.37252978975666495298213476417004e-01
            9.43911269850043366247405174362939e-01 3.03096694588356474486801062084851e-01
            9.20751198497388290142851019481895e-01 3.67496016421854643230204828796559e-01
            8.93203328376094729534884208987933e-01 4.30144052380333707930049058631994e-01
            8.61398937632522176954807946458459e-01 4.90742256042692226447599068706040e-01
            8.25489588672203566943608166184276e-01 5.49001849372208527988448167889146e-01
            7.85646405895963129140113778703380e-01 6.04645198875393807824707437248435e-01
            7.42059260214215421491701363265747e-01 6.57407138652022937641561384225497e-01
            6.94935864225611599209742053062655e-01 7.07036234031404808852983023825800e-01
            6.44500782371913993884504634479526e-01 7.53295979773090040865213268261869e-01
            5.90994360786166295085308775014710e-01 7.95965927122046834618629418400815e-01
            5.34671581933915063267193090723595e-01 8.34842734347370218905837191414321e-01
            4.75800849505644496417744448990561e-01 8.69741135758230088370623889204580e-01
            4.14662709350959834964100991783198e-01 9.00494824579258890118182989681372e-01
            3.51548512549854808018068297315040e-01 9.26957245478071345523574109392939e-01
            2.86759026992134125055855520258774e-01 9.49002292968164185005264243955025e-01
            2.20603004081450532192221203331428e-01 9.66524912358987520200059861963382e-01
            1.53395707394261421319114901962166e-01 9.79441600389386768377164571575122e-01
            8.54574103053160477605487699293008e-02 9.87690803158669639039146659342805e-01
            1.71118697391744213620601300362978e-02 9.91233209458974084959947958850535e-01
            -5.13152166789771491117733148712432e-02 9.90051938111076279547262402047636e-01
            -1.19497762720831540717014718211431e-01 9.84152618410897073175647165044211e-01
            -1.87110847504338428937131766360835e-01 9.73563363303343143329016129428055e-01
            -2.53832263889674059065271194413071e-01 9.58334635411322133258238409325713e-01
            -3.19344053942995753647693391030771e-01 9.38539006558364530263816050137393e-01
            -3.83334024150793539753578897943953e-01 9.14270811930834703673554031411186e-01
            -4.45497233164154682327762202476151e-01 8.85645700527807999691276563680731e-01
            -5.05537444983160444422765067429282e-01 8.52800084040923889183716255502077e-01
            -5.63168540656330485205671720905229e-01 8.15890486790554536611352887121029e-01
            -6.18115881767724806294950212759431e-01 7.75092799816136324153603709419258e-01
            -6.70117619214065762811571858037496e-01 7.30601442675267054305265901348321e-01
            -7.18925941034959881115184998634504e-01 6.82628436945976080352238568593748e-01
            -7.64308253349742616755690960417269e-01 6.31402395847350805802022932766704e-01
            -8.06048288773242194160673079750268e-01 5.77167434793437461593157422612421e-01
            -8.43947137028358107535552790068323e-01 5.20182008072123447384171868179692e-01
            -8.77824192844113393441318748955382e-01 4.60717677192757246729115649941377e-01
            -9.07518016622019474404226002661744e-01 3.99057816771886897377896730176872e-01
            -9.32887103769281300635896059247898e-01 3.35496264124164556008622639637906e-01
            -9.53810559032623128672412349260412e-01 2.70335918993728940851184461280354e-01
            -9.70188672619225811466492359613767e-01 2.03887300098985257967854067828739e-01
            -9.81943395359297199753711993253091e-01 1.36467065369502621452468815732573e-01
            -9.89018710645909404632902806042694e-01 6.83965029267723373385123863954504e-02
            -9.91380901379640744330856705346378e-01 1.21409144761039478114049218615848e-16
            -9.89018710645909404632902806042694e-01 -6.83965029267721014161196535496856e-02
            -9.81943395359297199753711993253091e-01 -1.36467065369502371652288275072351e-01
            -9.70188672619225811466492359613767e-01 -2.03887300098985035923249142797431e-01
            -9.53810559032623017650109886744758e-01 -2.70335918993729162895789386311662e-01
            -9.32887103769281411658198521763552e-01 -3.35496264124164333964017714606598e-01
            -9.07518016622019585426528465177398e-01 -3.99057816771886675333291805145564e-01
            -8.77824192844113504463621211471036e-01 -4.60717677192757024684510724910069e-01
            -8.43947137028358218557855252583977e-01 -5.20182008072123336361869405664038e-01
            -8.06048288773242638249882929812884e-01 -5.77167434793436906481645110034151e-01
            -7.64308253349742505733388497901615e-01 -6.31402395847350916824325395282358e-01
            -7.18925941034959992137487461150158e-01 -6.82628436945975969329936106078094e-01
            -6.70117619214065540766966933006188e-01 -7.30601442675267165327568363863975e-01
            -6.18115881767725028339555137790740e-01 -7.75092799816136102108998784387950e-01
            -5.63168540656330707250276645936538e-01 -8.15890486790554425589050424605375e-01
            -5.05537444983160666467369992460590e-01 -8.52800084040923778161413792986423e-01
            -4.45497233164154904372367127507459e-01 -8.85645700527807888668974101165077e-01
            -3.83334024150794372420847366811358e-01 -9.14270811930834370606646643864224e-01
            -3.19344053942995587114239697257290e-01 -9.38539006558364641286118512653047e-01
            -2.53832263889674725199085969506996e-01 -9.58334635411322022235935946810059e-01
            -1.87110847504338234648102456958441e-01 -9.73563363303343143329016129428055e-01
            -1.19497762720832234606405108934268e-01 -9.84152618410897073175647165044211e-01
            -5.13152166789776140176648766555445e-02 -9.90051938111076279547262402047636e-01
            1.71118697391739633950624721592249e-02 -9.91233209458974195982250421366189e-01
            8.54574103053155897935511120522278e-02 -9.87690803158669639039146659342805e-01
            1.53395707394260949474329436270637e-01 -9.79441600389386768377164571575122e-01
            2.20603004081450310147616278300120e-01 -9.66524912358987520200059861963382e-01
            2.86759026992133847500099363969639e-01 -9.49002292968164296027566706470679e-01
            3.51548512549854585973463372283732e-01 -9.26957245478071456545876571908593e-01
            4.14662709350959834964100991783198e-01 -9.00494824579259001140485452197026e-01
            4.75800849505643774772778442638810e-01 -8.69741135758230532459833739267197e-01
            5.34671581933915174289495553239249e-01 -8.34842734347370107883534728898667e-01
            5.90994360786165739973796462436439e-01 -7.95965927122047278707839268463431e-01
            6.44500782371913549795294784416910e-01 -7.53295979773090484954423118324485e-01
            6.94935864225611821254346978093963e-01 -7.07036234031404586808378098794492e-01
            7.42059260214215088424793975718785e-01 -6.57407138652023270708468771772459e-01
            7.85646405895962796073206391156418e-01 -6.04645198875394140891614824795397e-01
            8.25489588672202900809793391090352e-01 -5.49001849372209527189170330530033e-01
            8.61398937632522398999412871489767e-01 -4.90742256042691726847237987385597e-01
            8.93203328376094618512581746472279e-01 -4.30144052380333874463502752405475e-01
            9.20751198497388179120548556966241e-01 -3.67496016421854809763658522570040e-01
            9.43911269850043366247405174362939e-01 -3.03096694588356641020254755858332e-01
            9.62573174147025811819844420824666e-01 -2.37252978975667411232208792171150e-01
            9.76647978915776371344747985858703e-01 -1.70278644873742779353165133215953e-01
            9.86068611301940345370553586690221e-01 -1.02492855484525607900891941426380e-01
            9.90790177702065455456192921701586e-01 -3.42186409639340244348559849640878e-02
            9.74887550380285072826325176720275e-01 3.52187524636503879182924947599531e-02
            9.69804938100536251255334718734957e-01 1.05472643123152437505396505912358e-01
            9.59666211928033141553839868720388e-01 1.75176648259030565135674351040507e-01
            9.44524230486445182108923290797975e-01 2.43967363463963027303549324642518e-01
            9.24457937055727652087000478786649e-01 3.11486145801442015912385841147625e-01
            8.99571947998414112035447942616884e-01 3.77380983603979980323117615625961e-01
            8.69996007338342924875007611262845e-01 4.41308331698950118138213838392403e-01
            8.35884310335393787561031331279082e-01 5.02934902494042268550344942923402e-01
            7.97414699582799424426582390879048e-01 5.61939403584445718031759042787598e-01
            7.54787737818213289031632484693546e-01 6.18014212822676878289485102868639e-01
            7.08225662282462087304679698718246e-01 6.70866982118017762815043170121498e-01
            6.57971226077476933902232758555328e-01 7.20222161604091803965843610058073e-01
            6.04286432564022368829625975195086e-01 7.65822436228278724534845878224587e-01
            5.47451169397490833290476075490005e-01 8.07430067273252172199704546073917e-01
            4.87761749323265492161993961417465e-01 8.44828131816570571110958098870469e-01
            4.25529365339269438628377884015208e-01 8.77821653666351120470778823801083e-01
            3.61078468279766473525427272761590e-01 9.06238619876854722967607358441455e-01
            2.94745075278946444541361415758729e-01 9.29930877544335010576048716757214e-01
            2.26875017933173078743536166257400e-01 9.48774906207679569192237067909446e-01
            1.57822139295174218576178759576578e-01 9.62672461826899583670069660001900e-01
            8.79464491002065473779225612815935e-02 9.71551088982063548726841872849036e-01
            1.76122468419933654593112493103035e-02 9.75364498622307563024946830410045e-01
            -5.28137775161511904831179720076761e-02 9.74092809395513015147116675507277e-01
            -1.22964455293001748148462581866625e-01 9.67742651300470546615883904451039e-01
            -1.92474053336911310463364088718663e-01 9.56347131121136673215232804068364e-01
            -2.60980180789118942907833798017236e-01 9.39965659823191357347127450339030e-01
            -3.28125678421885058622109454518068e-01 9.18683642812772927044306925381534e-01
            -3.93560480701327985997295400011353e-01 8.92612034672235710175414169498254e-01
            -4.56943440867025429952263948507607e-01 8.61886760694333897703245384036563e-01
            -5.17944109513259642874061228212668e-01 8.26668008230683426518226042389870e-01
            -5.76244457399208043213434393692296e-01 7.87139391549083300425593279214809e-01
            -6.31540533506148138442881645460147e-01 7.43506994553742361908632574341027e-01
            -6.83544049697325850623030873975949e-01 6.95998296359228496577031819469994e-01
            -7.31983883718816064067880233778851e-01 6.44860985319694823836300656694220e-01
            -7.76607492705412405520348784193629e-01 5.90361667696490566292766288825078e-01
            -8.17182229822191685819632311904570e-01 5.32784477696563008031205299630528e-01
            -8.53496557177387149550895628635772e-01 4.72429596128265294474601887486642e-01
            -8.85361148683005749759900027129333e-01 4.09611685397618219273141448866227e-01
            -9.12609877113387257807630703609902e-01 3.44658249004222871914038250906742e-01
            -9.35100680215635193803791480604559e-01 2.77907924089661806377193897787947e-01
            -9.52716301356423267421291711798403e-01 2.09708715940243345388083184843708e-01
            -9.65364900843788786843902016698848e-01 1.40416183648575998432761480216868e-01
            -9.72980534736760049874249034473905e-01 7.03915863930993090935572809030418e-02
            -9.75523498646531206368592847866239e-01 1.19467173011050188912611188944130e-16
            -9.72980534736760049874249034473905e-01 -7.03915863930990870489523558717337e-02
            -9.65364900843788786843902016698848e-01 -1.40416183648575748632580939556647e-01
            -9.52716301356423378443594174314057e-01 -2.09708715940242707009844025378698e-01
            -9.35100680215635082781489018088905e-01 -2.77907924089661972910647591561428e-01
            -9.12609877113387368829933166125556e-01 -3.44658249004222649869433325875434e-01
            -8.85361148683005860782202489644988e-01 -4.09611685397617997228536523834919e-01
            -8.53496557177387260573198091151426e-01 -4.72429596128265072429996962455334e-01
            -8.17182229822192018886539699451532e-01 -5.32784477696562563941995449567912e-01
            -7.76607492705412294498046321677975e-01 -5.90361667696490677315068751340732e-01
            -7.31983883718816175090182696294505e-01 -6.44860985319694601791695731662912e-01
            -6.83544049697326294712240724038566e-01 -6.95998296359228052487821969407378e-01
            -6.31540533506147916398276720428839e-01 -7.43506994553742472930935036856681e-01
            -5.76244457399208265258039318723604e-01 -7.87139391549083078380988354183501e-01
            -5.17944109513259087762548915634397e-01 -8.26668008230683759585133429936832e-01
            -4.56943440867025263418810254734126e-01 -8.61886760694334008725547846552217e-01
            -3.93560480701327985997295400011353e-01 -8.92612034672235710175414169498254e-01
            -3.28125678421885280666714379549376e-01 -9.18683642812772816022004462865880e-01
            -2.60980180789119553530497341853334e-01 -9.39965659823191246324824987823376e-01
            -1.92474053336912198641783788843895e-01 -9.56347131121136562192930341552710e-01
            -1.22964455293001748148462581866625e-01 -9.67742651300470546615883904451039e-01
            -5.28137775161516415112217259775207e-02 -9.74092809395513015147116675507277e-01
            1.76122468419935632177875106663123e-02 -9.75364498622307563024946830410045e-01
            8.79464491002063114555298284358287e-02 -9.71551088982063548726841872849036e-01
            1.57822139295173774486968909513962e-01 -9.62672461826899694692372122517554e-01
            2.26875017933173273032565475659794e-01 -9.48774906207679458169934605393792e-01
            2.94745075278946444541361415758729e-01 -9.29930877544335010576048716757214e-01
            3.61078468279766251480822347730282e-01 -9.06238619876854833989909820957109e-01
            4.25529365339269605161831577788689e-01 -8.77821653666351009448476361285429e-01
            4.87761749323265714206598886448774e-01 -8.44828131816570460088655636354815e-01
            5.47451169397490722268173612974351e-01 -8.07430067273252283222007008589571e-01
            6.04286432564022035762718587648124e-01 -7.65822436228279057601753265771549e-01
            6.57971226077476378790720445977058e-01 -7.20222161604092359077355922636343e-01
            7.08225662282462087304679698718246e-01 -6.70866982118017762815043170121498e-01
            7.54787737818213066987027559662238e-01 -6.18014212822677211356392490415601e-01
            7.97414699582799091359675003332086e-01 -5.61939403584446162120968892850215e-01
            8.35884310335393787561031331279082e-01 -5.02934902494042268550344942923402e-01
            8.69996007338342813852705148747191e-01 -4.41308331698950340182818763423711e-01
            8.99571947998413889990843017585576e-01 -3.77380983603980535434629928204231e-01
            9.24457937055727430042395553755341e-01 -3.11486145801442737557351847499376e-01
            9.44524230486445182108923290797975e-01 -2.43967363463963166081427402787085e-01
            9.59666211928033030531537406204734e-01 -1.75176648259031009224884201103123e-01
            9.69804938100536251255334718734957e-01 -1.05472643123152270971942812138877e-01
            9.74887550380285072826325176720275e-01 -3.52187524636504989405949572756072e-02
            9.54244172805838841711079112428706e-01 3.61358908059520311795154157152865e-02
            9.48778348599695120491048783151200e-01 1.08200689307760722357443228247575e-01
            9.37878007933479418412048289610539e-01 1.79645724059793648885730021902418e-01
            9.21605586971400381202101925737225e-01 2.50061764373003869721401315473486e-01
            9.00054292667109900882849160552723e-01 3.19045473545304880680362202838296e-01
            8.73347568882712366189480235334486e-01 3.86201719137674370774249155147118e-01
            8.41638389313502877087103115627542e-01 4.51145836256982291079253855059505e-01
            8.05108381268492379057022390043130e-01 5.13505830881663016818095002236078e-01
            7.63966785325630670655527865164913e-01 5.72924510609784443104786078038160e-01
            7.18449256820724135863542869628873e-01 6.29061530624777875964070972258924e-01
            6.68816516035013353125293633638648e-01 6.81595343159727140580628201860236e-01
            6.15352854813012162260577042616205e-01 7.30225039293857181021962787781376e-01
            5.58364508164568174031217040464981e-01 7.74672072531583655319309400510974e-01
            4.98177900178458976654383150162175e-01 8.14681854291612772556163690751418e-01
            4.35137774294771462191278033060371e-01 8.50025212167281440933663816394983e-01
            3.69605218645697508605962866568007e-01 8.80499702605347489559051155083580e-01
            3.01955597775412309946574396235519e-01 9.05930770484330460945443519449327e-01
            2.32576402585958630364615373764536e-01 9.26172748950439217452412776765414e-01
            1.61865030824449307456092128632008e-01 9.41109693784119571979829288466135e-01
            9.02265108247625180482032192230690e-02 9.50656047518043334498827334755333e-01
            1.80711815419215028610810946929632e-02 9.54757129502533885556658788118511e-01
            -5.41876578322784338559436889681820e-02 9.53389449111375020251557543815579e-01
            -1.26136115209611432419478660449386e-01 9.46560840293991234695170078339288e-01
            -1.97362076341822623160027205813094e-01 9.34310416703294510654131954652257e-01
            -2.67457565373719896584248090221081e-01 9.16708347656222333199593776953407e-01
            -3.36021081691927736567748752349871e-01 8.93855456210245424841787098557688e-01
            -4.02659899684039535028290401896811e-01 8.65882641658024310160612913023215e-01
            -4.66992318235361358880197713006055e-01 8.32950129748115331018709639465669e-01
            -5.28649847078330514804633821768221e-01 7.95246554926393289797204033675371e-01
            -5.87279317471397055427928535209503e-01 7.52987879855027464337524634174770e-01
            -6.42544905117593878607351598475361e-01 7.06416158397910276534048534813337e-01
            -6.94130053735696472827498837432358e-01 6.55798149158045684536944008868886e-01
            -7.41739288265935381438964668632252e-01 6.01423787508428064896293108176906e-01
            -7.85099907324380952289288870815653e-01 5.43604524868481542299036846088711e-01
            -8.23963545211774062160259290976683e-01 4.82671544738535407415014333309955e-01
            -8.58107594529759043489036685059546e-01 4.18973865710726534050678537823842e-01
            -8.87336481255904030440717633609893e-01 3.52876342322108627058696583844721e-01
            -9.11482784973989379473380267882021e-01 2.84757575200905332923895230123890e-01
            -9.30408197842990669634843925450696e-01 2.15007742476399116293706015312637e-01
            -9.44004316811866139858011592878029e-01 1.44026364873939632937904775644711e-01
            -9.52193264542417150408937231986783e-01 7.22200172964095332694967055431334e-02
            -9.54928135483628537372169375885278e-01 -3.07128312696940585608120201446500e-16
            -9.52193264542417150408937231986783e-01 -7.22200172964092834693161648829118e-02
            -9.44004316811866250880314055393683e-01 -1.44026364873938966804090000550786e-01
            -9.30408197842990780657146387966350e-01 -2.15007742476398922004676705910242e-01
            -9.11482784973989490495682730397675e-01 -2.84757575200905110879290305092582e-01
            -8.87336481255904252485322558641201e-01 -3.52876342322108071947184271266451e-01
            -8.58107594529758932466734222543892e-01 -4.18973865710726700584132231597323e-01
            -8.23963545211774173182561753492337e-01 -4.82671544738535185370409408278647e-01
            -7.85099907324381063311591333331307e-01 -5.43604524868481320254431921057403e-01
            -7.41739288265935714505872056179214e-01 -6.01423787508427509784780795598635e-01
            -6.94130053735696583849801299948012e-01 -6.55798149158045462492339083837578e-01
            -6.42544905117593767585049135959707e-01 -7.06416158397910498578653459844645e-01
            -5.87279317471396944405626072693849e-01 -7.52987879855027575359827096690424e-01
            -5.28649847078331069916146134346491e-01 -7.95246554926392845707994183612755e-01
            -4.66992318235361192346744019232574e-01 -8.32950129748115442041012101981323e-01
            -4.02659899684040090139802714475081e-01 -8.65882641658023977093705525476253e-01
            -3.36021081691927570034295058576390e-01 -8.93855456210245535864089561073342e-01
            -2.67457565373720562718062865315005e-01 -9.16708347656222222177291314437753e-01
            -1.97362076341823067249237055875710e-01 -9.34310416703294399631829492136603e-01
            -1.26136115209611043841420041644596e-01 -9.46560840293991345717472540854942e-01
            -5.41876578322788779451535390307981e-02 -9.53389449111375020251557543815579e-01
            1.80711815419208436661602235062674e-02 -9.54757129502533885556658788118511e-01
            9.02265108247620739589933691604529e-02 -9.50656047518043334498827334755333e-01
            1.61865030824449085411487203600700e-01 -9.41109693784119571979829288466135e-01
            2.32576402585958214030981139330834e-01 -9.26172748950439328474715239281068e-01
            3.01955597775412087901969471204211e-01 -9.05930770484330571967745981964981e-01
            3.69605218645697286561357941536698e-01 -8.80499702605347600581353617599234e-01
            4.35137774294771240146673108029063e-01 -8.50025212167281551955966278910637e-01
            4.98177900178458754609778225130867e-01 -8.14681854291612883578466153267073e-01
            5.58364508164568063008914577949326e-01 -7.74672072531583766341611863026628e-01
            6.15352854813011940215972117584897e-01 -7.30225039293857403066567712812684e-01
            6.68816516035013242102991171122994e-01 -6.81595343159727140580628201860236e-01
            7.18449256820724024841240407113219e-01 -6.29061530624777986986373434774578e-01
            7.63966785325630670655527865164913e-01 -5.72924510609784443104786078038160e-01
            8.05108381268492268034719927527476e-01 -5.13505830881663127840397464751732e-01
            8.41638389313502877087103115627542e-01 -4.51145836256982291079253855059505e-01
            8.73347568882712366189480235334486e-01 -3.86201719137674370774249155147118e-01
            9.00054292667109567815941773005761e-01 -3.19045473545305602325328209190047e-01
            9.21605586971400492224404388252879e-01 -2.50061764373003814210250084215659e-01
            9.37878007933479196367443364579231e-01 -1.79645724059794398286271643883083e-01
            9.48778348599695009468746320635546e-01 -1.08200689307761402369045811155956e-01
            9.54244172805838841711079112428706e-01 -3.61358908059526973133301908092108e-02
            9.29756024496639632559435995062813e-01 3.69931062767513280098441441623436e-02
            9.23877807555659069649323100748006e-01 1.10745436501679422880428660391772e-01
            9.12158537653812051537727256800281e-01 1.83797598420268354368900531881081e-01
            8.94672307788678233819723573105875e-01 2.55687732744219742286873042758089e-01
            8.71529671535517302949358509067679e-01 3.25961326897827363691106938858866e-01
            8.42876944091970337069597007939592e-01 3.94174088592820159870910856625414e-01
            8.08895277226271414150460259406827e-01 4.59894754787258275285921627073549e-01
            7.69799513977443727874572232394712e-01 5.22707818269336987881956702040043e-01
            7.25836830348432715531714620738057e-01 5.82216154627763216033997650811216e-01
            6.77285172579833227857193378440570e-01 6.38043533000142937261500719614560e-01
            6.24451499884264960016366785566788e-01 6.89836994725631424962841720116558e-01
            5.67669843751399172404603632458020e-01 7.37269084863227619486281128047267e-01
            5.07299196093331961066041912999935e-01 7.80039922467342772272047568549169e-01
            4.43721239582132220835575253659044e-01 8.17879096531690996663144233025378e-01
            3.77337934529096419300486786596593e-01 8.50547375614735701176982729521114e-01
            3.08568977562243718093526467782794e-01 8.77838220337888053279584710253403e-01
            2.37849148169100910177320429284009e-01 8.99579089193958569836695460253395e-01
            1.65625559880798162160076003601716e-01 9.15632529410118300994270157389110e-01
            9.23548334763667072566661886412476e-02 9.25897045968584686548297213448677e-01
            1.85002100791559626058457865838136e-02 9.30307743290802680036222227499820e-01
            -5.54713776026990942891181646245968e-02 9.28836735528186241417358814942418e-01
            -1.29092257375197111413100969912193e-01 9.21493322865431729873364474769915e-01
            -2.01896974332656298223298563243588e-01 9.08323932721756266417401093349326e-01
            -2.73425233613492746354012297160807e-01 8.89411826221804813208393625245662e-01
            -3.43224810532535784535212997070630e-01 8.64876571792012382999814690265339e-01
            -4.10854409691091049250388778091292e-01 8.34873289210514957225939269847004e-01
            -4.75886454988535378962666300139972e-01 7.99591668889967577271704612940084e-01
            -5.37909792896090754865667804551776e-01 7.59254772593681903636309016292216e-01
            -5.96532291901813338519389162684092e-01 7.14117623167338400058667957637226e-01
            -6.51383321692268202340869720501360e-01 6.64465592202445054503812116308836e-01
            -7.02116096396700251069944442861015e-01 6.10612595825256732062769060576102e-01
            -7.48409867078965507225518649647711e-01 5.52899110017952777340610737155657e-01
            -7.89971949615577373471353439526865e-01 4.91690018019852348452047863247572e-01
            -8.26539575138970583623176935361698e-01 4.27372303418095900173767631713417e-01
            -8.57881551346885151687615689297672e-01 3.60352603512810121255682815899490e-01
            -8.83799724174540002330502375116339e-01 2.91054638425169043269846724797389e-01
            -9.04130230588428562832348234223900e-01 2.19916532202365455628267909560236e-01
            -9.18744534581176663934343196160626e-01 1.47388042856318818296657013888762e-01
            -9.27550239817565902455953619210050e-01 7.39277188487163783303657282885979e-02
            -9.30491673793913620649220774794230e-01 1.13952364994497942641428056991628e-16
            -9.27550239817565902455953619210050e-01 -7.39277188487161424079729954428331e-02
            -9.18744534581176774956645658676280e-01 -1.47388042856318624007627704486367e-01
            -9.04130230588428562832348234223900e-01 -2.19916532202365205828087368900015e-01
            -8.83799724174540113352804837631993e-01 -2.91054638425168821225241799766081e-01
            -8.57881551346885262709918151813326e-01 -3.60352603512809899211077890868182e-01
            -8.26539575138970583623176935361698e-01 -4.27372303418095678129162706682109e-01
            -7.89971949615577706538260827073827e-01 -4.91690018019851793340535550669301e-01
            -7.48409867078965618247821112163365e-01 -5.52899110017952555296005812124349e-01
            -7.02116096396700362092246905376669e-01 -6.10612595825256621040466598060448e-01
            -6.51383321692268091318567257985706e-01 -6.64465592202445165526114578824490e-01
            -5.96532291901813449541691625199746e-01 -7.14117623167338400058667957637226e-01
            -5.37909792896090976910272729583085e-01 -7.59254772593681792614006553776562e-01
            -4.75886454988535601007271225171280e-01 -7.99591668889967577271704612940084e-01
            -4.10854409691091215783842471864773e-01 -8.34873289210514846203636807331350e-01
            -3.43224810532536339646725309648900e-01 -8.64876571792012049932907302718377e-01
            -2.73425233613493023909768453449942e-01 -8.89411826221804702186091162730008e-01
            -2.01896974332656298223298563243588e-01 -9.08323932721756266417401093349326e-01
            -1.29092257375196917124071660509799e-01 -9.21493322865431729873364474769915e-01
            -5.54713776026997326673573240896076e-02 -9.28836735528186130395056352426764e-01
            1.85002100791557370917939095988913e-02 -9.30307743290802680036222227499820e-01
            9.23548334763668876679076902291854e-02 -9.25897045968584686548297213448677e-01
            1.65625559880797718070866153539100e-01 -9.15632529410118412016572619904764e-01
            2.37849148169100715888291119881615e-01 -8.99579089193958569836695460253395e-01
            3.08568977562243718093526467782794e-01 -8.77838220337888053279584710253403e-01
            3.77337934529095975211276936533977e-01 -8.50547375614735812199285192036768e-01
            4.43721239582131832257516634854255e-01 -8.17879096531691107685446695541032e-01
            5.07299196093331850043739450484281e-01 -7.80039922467342772272047568549169e-01
            5.67669843751398617293091319879750e-01 -7.37269084863228063575490978109883e-01
            6.24451499884264626949459398019826e-01 -6.89836994725631535985144182632212e-01
            6.77285172579833116834890915924916e-01 -6.38043533000143048283803182130214e-01
            7.25836830348432382464807233191095e-01 -5.82216154627763660123207500873832e-01
            7.69799513977443505829967307363404e-01 -5.22707818269337542993469014618313e-01
            8.08895277226271414150460259406827e-01 -4.59894754787258386308224089589203e-01
            8.42876944091970337069597007939592e-01 -3.94174088592820159870910856625414e-01
            8.71529671535517080904753584036371e-01 -3.25961326897827863291468020179309e-01
            8.94672307788678233819723573105875e-01 -2.55687732744220019842629199047224e-01
            9.12158537653812051537727256800281e-01 -1.83797598420268382124476147509995e-01
            9.23877807555658958627020638232352e-01 -1.10745436501680019625304396413412e-01
            9.29756024496639632559435995062813e-01 -3.69931062767516749545393395237625e-02
            9.01941756722466903006818483845564e-01 3.78025599561957054151051238477521e-02
            8.95615283343316859188121270562988e-01 1.13142522071596293709028202556510e-01
            8.83006712250206771130933702806942e-01 1.87688870687454517627301697757503e-01
            8.64204483510108811827876706956886e-01 2.60918716729707844681485084947781e-01
            8.39340481248252223700490048940992e-01 3.32318405443941533583540604013251e-01
            8.08589108575742732121227618335979e-01 4.01387119314430829142281709209783e-01
            7.72166064277047481390070515772095e-01 4.67640390939176808782207217518589e-01
            7.30326829838000346484250258072279e-01 5.30613501220641770039776474732207e-01
            6.83364877426742789445768266887171e-01 5.89864739036318419529436596349115e-01
            6.31609611397323966741623735288158e-01 6.44978499524885617866232223605039e-01
            5.75424057754832296573965777497506e-01 6.95568199255698349503518329584040e-01
            5.15202317788805652654104960674886e-01 7.41278987833793867601173133152770e-01
            4.51366803735844923650688542693388e-01 7.81790236920453351920912155037513e-01
            3.84365275861278554714317579055205e-01 8.16817789210625977425195287651150e-01
            3.14667701742614991378133026955766e-01 8.46115951592257831137544599187095e-01
            2.42762959784658588491268460529682e-01 8.69479218506942652666680260153953e-01
            1.69155410088758922926288619237312e-01 8.86743713423757573544037313695299e-01
            9.43613567290810528742639462507213e-02 8.97788338315384071286473499640124e-01
            1.89054262504897603591746957363284e-02 9.02535623073759230017287791270064e-01
            -5.66831122097184933461555544909061e-02 9.00952268907222353355734867363935e-01
            -1.31874059364535500815662771856296e-01 8.93049381907613404329993045394076e-01
            -2.06140004744291421845403533552599e-01 8.78882395149018114111072463856544e-01
            -2.78960026102155145277805559089757e-01 8.58550679864582222400315458799014e-01
            -3.49823343309414502844134631232009e-01 8.32196848428708557676714008266572e-01
            -4.18232901111083410494728695994127e-01 8.00005754033718319284673725633183e-01
            -4.83708855611383103934031169046648e-01 7.62203194077522572236205178342061e-01
            -5.45791940033902300832835408073151e-01 7.19054326357112305601049229153432e-01
            -6.04046686148051459319674449943705e-01 6.70861809177127677017438145412598e-01
            -6.58064478765816973648838938970584e-01 6.17963678419310435963041072682245e-01
            -7.07466421883716334306768658279907e-01 5.60730976463671981768754903896479e-01
            -7.51905996366023954280422003648710e-01 4.99565149592791468702301926896325e-01
            -7.91071490527537002357405526709044e-01 4.34895232134582310212778111235821e-01
            -8.24688186567080983024879969889298e-01 3.67174837094742523291301949939225e-01
            -8.52520287515501573594178807979915e-01 2.96878974387439320548054411119665e-01
            -8.74372571181982416455014117673272e-01 2.24500718982056951533721189662174e-01
            -8.90091759497447232440947573195444e-01 1.50547752336559481634026269603055e-01
            -8.99567593650084207368422539730091e-01 7.55388013768322902352636560863175e-02
            -9.02733607471690069345982010418084e-01 1.10552982287294846086843698651061e-16
            -8.99567593650084207368422539730091e-01 -7.55388013768320681906587310550094e-02
            -8.90091759497447121418645110679790e-01 -1.50547752336559648167479963376536e-01
            -8.74372571181982527477316580188926e-01 -2.24500718982056729489116264630866e-01
            -8.52520287515501573594178807979915e-01 -2.96878974387439487081508104893146e-01
            -8.24688186567081094047182432404952e-01 -3.67174837094742356757848256165744e-01
            -7.91071490527537113379707989224698e-01 -4.34895232134582088168173186204513e-01
            -7.51905996366023843258119541133055e-01 -4.99565149592791635235755620669806e-01
            -7.07466421883716445329071120795561e-01 -5.60730976463671759724149978865171e-01
            -6.58064478765817417738048789033201e-01 -6.17963678419309991873831222619629e-01
            -6.04046686148051348297371987428050e-01 -6.70861809177127788039740607928252e-01
            -5.45791940033902855944347720651422e-01 -7.19054326357111972534141841606470e-01
            -4.83708855611382992911728706530994e-01 -7.62203194077522683258507640857715e-01
            -4.18232901111083965606241008572397e-01 -8.00005754033717986217766338086221e-01
            -3.49823343309414724888739556263317e-01 -8.32196848428708446654411545750918e-01
            -2.78960026102155367322410484121065e-01 -8.58550679864582111378012996283360e-01
            -2.06140004744291643890008458583907e-01 -8.78882395149018114111072463856544e-01
            -1.31874059364536500016384934497182e-01 -8.93049381907613293307690582878422e-01
            -5.66831122097185211017311701198196e-02 -9.00952268907222353355734867363935e-01
            1.89054262504891393281702960393886e-02 -9.02535623073759230017287791270064e-01
            9.43613567290812194077176400242024e-02 -8.97788338315384071286473499640124e-01
            1.69155410088758478837078769174695e-01 -8.86743713423757684566339776210953e-01
            2.42762959784658366446663535498374e-01 -8.69479218506942652666680260153953e-01
            3.14667701742614769333528101924458e-01 -8.46115951592257942159847061702749e-01
            3.84365275861278554714317579055205e-01 -8.16817789210625977425195287651150e-01
            4.51366803735844424050327461372945e-01 -7.81790236920453684987819542584475e-01
            5.15202317788805652654104960674886e-01 -7.41278987833793867601173133152770e-01
            5.75424057754831852484755927434890e-01 -6.95568199255698682570425717131002e-01
            6.31609611397324188786228660319466e-01 -6.44978499524885395821627298573731e-01
            6.83364877426742678423465804371517e-01 -5.89864739036318752596343983896077e-01
            7.30326829838000235461947795556625e-01 -5.30613501220641992084381399763515e-01
            7.72166064277047370367768053256441e-01 -4.67640390939176919804509680034244e-01
            8.08589108575742732121227618335979e-01 -4.01387119314430884653432940467610e-01
            8.39340481248251890633582661394030e-01 -3.32318405443942255228506610365002e-01
            8.64204483510108811827876706956886e-01 -2.60918716729707622636880159916473e-01
            8.83006712250206660108631240291288e-01 -1.87688870687455017227662779077946e-01
            8.95615283343316859188121270562988e-01 -1.13142522071595863497606160308351e-01
            9.01941756722466903006818483845564e-01 -3.78025599561959829708612801368872e-02
            8.71151501742494782654091522999806e-01 3.85716993833462237772913283606613e-02
            8.64333560090499997130564224789850e-01 1.15413222304921125882515298144426e-01
            8.50751036424044260186860810790677e-01 1.91351480278929814149435628678475e-01
            8.30510232406683757133691869967151e-01 2.65792153475830239539590138519998e-01
            8.03769559773350739106945184175856e-01 3.38152642697461647269818740824121e-01
            7.70738300543744925263922596059274e-01 4.07866629005687486575482125772396e-01
            7.31674969106774431004680536716478e-01 4.74388505935930016033097444960731e-01
            6.86885288994955933716823892609682e-01 5.37197649607515592684592320438242e-01
            6.36719800183256801062725571682677e-01 5.95802493311430092504110689333174e-01
            5.81571115638512603496224073751364e-01 6.49744374686306191968299117434071e-01
            5.21870848590635594277387099282350e-01 6.98601125373279785435443045571446e-01
            4.58086234573889305998761756200111e-01 7.41990375055794681991017114341957e-01
            3.90716474675330716070931202921201e-01 7.79572544025766034359037348622223e-01
            3.20288828609462283836251117463689e-01 8.11053500855215880882553847186500e-01
            2.47354488196080968265277988393791e-01 8.36186864373495208901942987722578e-01
            1.72484263536955645390591485011100e-01 8.54775931933999477685404144722270e-01
            9.62641156528454972063357786282722e-02 8.66675218879078612665978198492667e-01
            1.92905705440403960060358201644704e-02 8.71791597154737751829145508963848e-01
            -5.78339494343944049425942921516253e-02 8.70085024163927966966980420693289e-01
            -1.34505840344338184477734898791823e-01 8.61568856154159457005903277604375e-01
            -2.10125040683828812060340851530782e-01 8.46309743686755933111953709158115e-01
            -2.84099727681909275389671165612526e-01 8.24427110005844121509710475947941e-01
            -3.55850949114231651648765364370774e-01 7.96092216389548523736152674246114e-01
            -4.24817154389186601992633995905635e-01 7.61526821798285236120307217788650e-01
            -4.90458589442659798063317566629848e-01 7.21001447310225418441120837087510e-01
            -5.52261521045412262509444190072827e-01 6.74833258927070800403669181832811e-01
            -6.09742257462140058166255585092586e-01 6.23383585320063104973087320104241e-01
            -6.62450933995119561892295223515248e-01 5.67055089943223178394759997900110e-01
            -7.09975033785415043929845069214934e-01 5.06288619645871462715547295374563e-01
            -7.51942616316612078009029573877342e-01 4.41559754448309693675156495373813e-01
            -7.88025228353651963075776620826218e-01 3.73375085483348412296322749170940e-01
            -8.17940474534732064881836777203716e-01 3.02268250233828805750846413502586e-01
            -8.41454227497895002052530344371917e-01 2.28795756095789393214090523542836e-01
            -8.58382460245079803584644650982227e-01 1.53532624953548885171628057833004e-01
            -8.68592686402893443542438944859896e-01 7.70678928538203883435997454398603e-02
            -8.72004997108114743298301618779078e-01 1.06789812854894965182978953216165e-16
            -8.68592686402893443542438944859896e-01 -7.70678928538201801767826282230089e-02
            -8.58382460245079914606947113497881e-01 -1.53532624953548690882598748430610e-01
            -8.41454227497895113074832806887571e-01 -2.28795756095789198925061214140442e-01
            -8.17940474534731953859534314688062e-01 -3.02268250233828972284300107276067e-01
            -7.88025228353652296142684008373180e-01 -3.73375085483347912695961667850497e-01
            -7.51942616316611966986727111361688e-01 -4.41559754448309860208610189147294e-01
            -7.09975033785415154952147531730589e-01 -5.06288619645871240670942370343255e-01
            -6.62450933995119783936900148546556e-01 -5.67055089943223067372457535384456e-01
            -6.09742257462140058166255585092586e-01 -6.23383585320063327017692245135549e-01
            -5.52261521045412373531746652588481e-01 -6.74833258927070578359064256801503e-01
            -4.90458589442660297663678647950292e-01 -7.21001447310224974351910987024894e-01
            -4.24817154389186102392272914585192e-01 -7.61526821798285458164912142819958e-01
            -3.55850949114232262271428908206872e-01 -7.96092216389548190669245286699152e-01
            -2.84099727681909497434276090643834e-01 -8.24427110005844010487408013432287e-01
            -2.10125040683829394927428779737966e-01 -8.46309743686755711067348784126807e-01
            -1.34505840344338767344822826999007e-01 -8.61568856154159345983600815088721e-01
            -5.78339494343944326981699077805388e-02 -8.70085024163927966966980420693289e-01
            1.92905705440399866112954896379961e-02 -8.71791597154737751829145508963848e-01
            9.62641156528451086282771598234831e-02 -8.66675218879078612665978198492667e-01
            1.72484263536955617635015869382187e-01 -8.54775931933999477685404144722270e-01
            2.47354488196080968265277988393791e-01 -8.36186864373495208901942987722578e-01
            3.20288828609462616903158505010651e-01 -8.11053500855215769860251384670846e-01
            3.90716474675330827093233665436856e-01 -7.79572544025765923336734886106569e-01
            4.58086234573888639864946981106186e-01 -7.41990375055795015057924501888920e-01
            5.21870848590635483255084636766696e-01 -6.98601125373279896457745508087100e-01
            5.81571115638512270429316686204402e-01 -6.49744374686306414012904042465379e-01
            6.36719800183256467995818184135715e-01 -5.95802493311430425571018076880137e-01
            6.86885288994955822694521430094028e-01 -5.37197649607515703706894782953896e-01
            7.31674969106774208960075611685170e-01 -4.74388505935930238077702369992039e-01
            7.70738300543745036286225058574928e-01 -4.07866629005687375553179663256742e-01
            8.03769559773350739106945184175856e-01 -3.38152642697461647269818740824121e-01
            8.30510232406683757133691869967151e-01 -2.65792153475830461584195063551306e-01
            8.50751036424044371209163273306331e-01 -1.91351480278929481082528241131513e-01
            8.64333560090500108152866687305504e-01 -1.15413222304921014860212835628772e-01
            8.71151501742494782654091522999806e-01 -3.85716993833471050168171245786652e-02
            8.37642205083134472332062614441384e-01 3.93053861771607560005037385053583e-02
            8.30280975266429965842007732135244e-01 1.17570741384484880875938017652516e-01
            8.15623206385332144563449219276663e-01 1.94802880689124657820343600178603e-01
            7.93797711439805819821913246414624e-01 2.70323085273896257518799757235684e-01
            7.64996293664194193517857911501778e-01 3.43467680865488955710418395028682e-01
            7.29472060953499035207414635806344e-01 4.13593870127841767292409258516273e-01
            6.87537201542098408424408262362704e-01 4.80085381588245707629170055952272e-01
            6.39560240482317965415859362110496e-01 5.42357885453204291437145911913831e-01
            5.85962801033020674879026046255603e-01 5.99864128719669431610839183122152e-01
            5.27215899419247402413191139203263e-01 6.52098744454109202628444563742960e-01
            4.63835805524695221624398300264147e-01 6.98602692975290984200853472430026e-01
            3.96379505893417360962160955750733e-01 7.38967295911505006600350498047192e-01
            3.25439808912045824840220120677259e-01 7.72837827680790012685463352681836e-01
            2.51640135188375357877532678685384e-01 7.99916632832101903716193191939965e-01
            1.75629038908645063177260681186453e-01 8.19965741852119789356834189675283e-01
            9.80745083200324357930455221321608e-02 8.32808962449885781254010908014607e-01
            1.96580954259159973451787095655163e-02 8.38333427940993525240287453925703e-01
            -5.89310735176335129259506118160061e-02 8.36490589124068262272260199097218e-01
            -1.37002354068172543799519758067618e-01 8.27296640932894566944355574378278e-01
            -2.13869653005075932572509600504418e-01 8.10832380114755890687661121773999e-01
            -2.88857457741429679565214883041335e-01 7.87242495185714541428012580581708e-01
            -3.61306772752934490799958666684688e-01 7.56734294902729365261961902433541e-01
            -4.30580910854266196707840208546259e-01 7.19575886426846555998793064645724e-01
            -4.96071088428955975224710073234746e-01 6.76093819187827294037163028406212e-01
            -5.57201775441698576862847858137684e-01 6.26670215156018395319392766396049e-01
            -6.13435753216998946868443454150110e-01 5.71739410740736531124639441259205e-01
            -6.64278835536207701295552396913990e-01 5.11784139826286010865885600651382e-01
            -7.09284211563778965725646230566781e-01 4.47331291489227178548304664218449e-01
            -7.48056372436959660099375923891785e-01 3.78947279678226611743241392105119e-01
            -7.80254587011897426940265631856164e-01 3.07233065547907524539539281249745e-01
            -8.05595896221181662077981400216231e-01 2.32818876190618667676446307268634e-01
            -8.23857599728303746644542115973309e-01 1.56358666178084054765307087109250e-01
            -8.34879213026221811411176076944685e-01 7.85243705851123852124118229767191e-02
            -8.38563877780978295106706354999915e-01 1.02694456880506739155200141457946e-16
            -8.34879213026221811411176076944685e-01 -7.85243705851121770455947057598678e-02
            -8.23857599728303857666844578488963e-01 -1.56358666178083860476277777706855e-01
            -8.05595896221181662077981400216231e-01 -2.32818876190618473387416997866239e-01
            -7.80254587011897537962568094371818e-01 -3.07233065547907358006085587476264e-01
            -7.48056372436959993166283311438747e-01 -3.78947279678226056631729079526849e-01
            -7.09284211563778854703343768051127e-01 -4.47331291489227345081758357991930e-01
            -6.64278835536207812317854859429644e-01 -5.11784139826285788821280675620073e-01
            -6.13435753216999057890745916665765e-01 -5.71739410740736309080034516227897e-01
            -5.57201775441698798907452783168992e-01 -6.26670215156018284297090303880395e-01
            -4.96071088428956141758163767008227e-01 -6.76093819187827071992558103374904e-01
            -4.30580910854266363241293902319740e-01 -7.19575886426846444976490602130070e-01
            -3.61306772752934324266504972911207e-01 -7.56734294902729365261961902433541e-01
            -2.88857457741430234676727195619605e-01 -7.87242495185714319383407655550400e-01
            -2.13869653005076126861538909906812e-01 -8.10832380114755890687661121773999e-01
            -1.37002354068172571555095373696531e-01 -8.27296640932894566944355574378278e-01
            -5.89310735176333463924969180425251e-02 -8.36490589124068262272260199097218e-01
            1.96580954259157891783615923486650e-02 -8.38333427940993525240287453925703e-01
            9.80745083200322415040162127297663e-02 -8.32808962449885892276313370530261e-01
            1.75629038908645229710714374959935e-01 -8.19965741852119789356834189675283e-01
            2.51640135188374747254869134849287e-01 -7.99916632832102014738495654455619e-01
            3.25439808912045658306766426903778e-01 -7.72837827680790123707765815197490e-01
            3.96379505893417360962160955750733e-01 -7.38967295911505006600350498047192e-01
            4.63835805524694722024037218943704e-01 -6.98602692975291206245458397461334e-01
            5.27215899419247624457796064234572e-01 -6.52098744454108980583839638711652e-01
            5.85962801033020674879026046255603e-01 -5.99864128719669431610839183122152e-01
            6.39560240482317632348951974563533e-01 -5.42357885453204735526355761976447e-01
            6.87537201542098519446710724878358e-01 -4.80085381588245430073413899663137e-01
            7.29472060953498924185112173290690e-01 -4.13593870127842044848165414805408e-01
            7.64996293664193971473252986470470e-01 -3.43467680865489677355384401380434e-01
            7.93797711439805930844215708930278e-01 -2.70323085273896146496497294720029e-01
            8.15623206385332144563449219276663e-01 -1.94802880689124990887250987725565e-01
            8.30280975266429965842007732135244e-01 -1.17570741384485047409391711425997e-01
            8.37642205083134472332062614441384e-01 -3.93053861771606935504586033403029e-02
            8.01612667542679901977464851370314e-01 4.00068250057618243764601118073188e-02
            7.93645880712761209174743726180168e-01 1.19622869216544053250217416461965e-01
            7.77791484559671397747138144040946e-01 1.98050047610181828572351037109911e-01
            7.54207047195271651496284448512597e-01 2.74508915652883767055669750334346e-01
            7.23126961353850794544939617480850e-01 3.48239590763427142583452678081812e-01
            6.84860114891825966232374867104227e-01 4.18509304367642220867651303706225e-01
            6.39786820921452115129568483098410e-01 4.84619684481712553747456695418805e-01
            5.88355038088249404637508632731624e-01 5.45913696446706953047112165222643e-01
            5.31075918556730197650495028938167e-01 6.01782172834205986156064227543538e-01
            4.68518727950542612781248408282408e-01 6.51669867625884857709195330244256e-01
            4.01305187734949553313157366574160e-01 6.95080974497899517494658994110068e-01
            3.30103296269587453970473234221572e-01 7.31584054366882452491438471042784e-01
            2.55620689940654954863674674925278e-01 7.60816323225386947903814416349633e-01
            1.78597610352590197013711303952732e-01 7.82487257652338508151501628162805e-01
            9.97995474744364230446080910041928e-02 7.96381482165319121158120196923846e-01
            2.00096318566191158638822855664330e-02 8.02360909718871639917381344275782e-01
            -5.99791484723006945722900695727731e-02 8.00366114075596324362038558319909e-01
            -1.39371829076918724021894036013691e-01 7.90416920410796142171250266983407e-01
            -2.17379369828700541589228123484645e-01 7.72612208280978318697407303261571e-01
            -2.93226496741269826440401402578573e-01 7.47128928914397527627500039670849e-01
            -3.66159406991591385160944582821685e-01 7.14220346590251464746756937529426e-01
            -4.35453260551088183749612881001667e-01 6.74213521584489550164676074928138e-01
            -5.00419383971491216200888629828114e-01 6.27506059697853557644009470095625e-01
            -5.60412114730970634113305095524993e-01 5.74562160670796573391783113038400e-01
            -6.14835218118352844207663565612165e-01 5.15908004757912541649034210422542e-01
            -6.63147812881549891805832430691225e-01 4.52126523312169292800888342753751e-01
            -7.04869746748444936379485170618864e-01 3.83851605351229308027427578053903e-01
            -7.39586368395888427151874111586949e-01 3.11761797683606511899512270247214e-01
            -7.66952648440839435117766242910875e-01 2.36573561205631804904570003600384e-01
            -7.86696608497385097003018472605618e-01 1.59034150391180961747750188806094e-01
            -7.98622024220129844707116717472672e-01 7.99141867409978029490602580153791e-02
            -8.02610375469899328670919658179628e-01 9.82914227281667568086119712603851e-17
            -7.98622024220129844707116717472672e-01 -7.99141867409976086600309486129845e-02
            -7.86696608497385208025320935121272e-01 -1.59034150391180739703145263774786e-01
            -7.66952648440839657162371167942183e-01 -2.36573561205631277548633306651027e-01
            -7.39586368395888316129571649071295e-01 -3.11761797683606622921814732762869e-01
            -7.04869746748445047401787633134518e-01 -3.83851605351229141493973884280422e-01
            -6.63147812881550113850437355722534e-01 -4.52126523312169181778585880238097e-01
            -6.14835218118352955229966028127819e-01 -5.15908004757912319604429285391234e-01
            -5.60412114730970856157910020556301e-01 -5.74562160670796462369480650522746e-01
            -5.00419383971491438245493554859422e-01 -6.27506059697853335599404545064317e-01
            -4.35453260551088072727310418486013e-01 -6.74213521584489550164676074928138e-01
            -3.66159406991591884761305664142128e-01 -7.14220346590251131679849549982464e-01
            -2.93226496741270492574216177672497e-01 -7.47128928914397305582895114639541e-01
            -2.17379369828700236277896351566596e-01 -7.72612208280978429719709765777225e-01
            -1.39371829076918751777469651642605e-01 -7.90416920410796142171250266983407e-01
            -5.99791484723010623336669766558771e-02 -8.00366114075596324362038558319909e-01
            2.00096318566189181054060242104242e-02 -8.02360909718871639917381344275782e-01
            9.97995474744358818108835862403794e-02 -7.96381482165319232180422659439500e-01
            1.78597610352590030480257610179251e-01 -7.82487257652338508151501628162805e-01
            2.55620689940655065885977137440932e-01 -7.60816323225386836881511953833979e-01
            3.30103296269587120903565846674610e-01 -7.31584054366882674536043396074092e-01
            4.01305187734949775357762291605468e-01 -6.95080974497899406472356531594414e-01
            4.68518727950542279714341020735446e-01 -6.51669867625885079753800255275564e-01
            5.31075918556729642538982716359897e-01 -6.01782172834206430245274077606155e-01
            5.88355038088249626682113557762932e-01 -5.45913696446706731002507240191335e-01
            6.39786820921452004107266020582756e-01 -4.84619684481712664769759157934459e-01
            6.84860114891825966232374867104227e-01 -4.18509304367642109845348841190571e-01
            7.23126961353850683522637154965196e-01 -3.48239590763427364628057603113120e-01
            7.54207047195271429451679523481289e-01 -2.74508915652884322167182062912616e-01
            7.77791484559671286724835681525292e-01 -1.98050047610182106128107193399046e-01
            7.93645880712761209174743726180168e-01 -1.19622869216543997739066185204138e-01
            8.01612667542679901977464851370314e-01 -4.00068250057621713211553071687376e-02
            7.63222381923527537495033357117791e-01 4.06780081710395660654633331887453e-02
            7.54574767368143994872298208065331e-01 1.21573126426433461566567473255418e-01
            7.37377519185700713855169396993006e-01 2.01090772581259374929274486021313e-01
            7.11825489069776495831831653049449e-01 2.78329979930943882671101619052934e-01
            6.78208191731658138756699827354169e-01 3.52415597392993662495541684620548e-01
            6.36906524582976807380418904358521e-01 4.22508205318453067267370215631672e-01
            5.88388452015835894393092075915774e-01 4.87813626451941706463344416988548e-01
            5.33203703179259358435615467897151e-01 5.47591924277294750389444288884988e-01
            4.71977543328272242106891098956112e-01 6.01165786793955048139537211682182e-01
            4.05403689318718563061594295504619e-01 6.47928200732579728793325557489879e-01
            3.34236449518088785115565997330123e-01 6.87349329257931462855424342706101e-01
            2.59282177190310214598412130726501e-01 7.18982515231934349309028675634181e-01
            1.81390134191064089641542977915378e-01 7.42469342017523237231557686754968e-01
            1.01442868491613435999454395641806e-01 7.57543694482357476971401410992257e-01
            2.03462145576388947487700420424517e-02 7.64034774189605081495813010405982e-01
            -6.09809701172083495901432570462930e-02 7.61869034612478679413527515862370e-01
            -1.41617216033868481561697194592853e-01 7.51071014445773177392595698620426e-01
            -2.20648882305496230049612904622336e-01 7.31763059572647089900954142649425e-01
            -2.97180508573783086490038840565830e-01 7.04163936836880166580954210076015e-01
            -3.70344960932622813132297778793145e-01 6.68586355327118742053471578401513e-01
            -4.39313256901757986927492538598017e-01 6.25433423257948595264110736025032e-01
            -5.03303958129525441655971462751040e-01 5.75194080592750012215219612699002e-01
            -5.61592024401627920582313890918158e-01 5.18437559158542726756024876522133e-01
            -6.13517028636473060743128371541388e-01 4.55806933021931204308430096716620e-01
            -6.58490639787900566837208771175938e-01 3.88011832202972417604769361787476e-01
            -6.96003288871022030015467407793039e-01 3.15820402283492229766892478437512e-01
            -7.25629942582431630704320468794322e-01 2.40050601010709990790203960386862e-01
            -7.47034919097368854679075411695521e-01 1.61560930509123373832736092481355e-01
            -7.59975691478924630928304395638406e-01 8.12407101083964661158987041744695e-02
            -7.64305635605145972100160633999621e-01 9.36004450214125334125491237558723e-17
            -7.59975691478924741950606858154060e-01 -8.12407101083959526377498150395695e-02
            -7.47034919097368743656772949179867e-01 -1.61560930509123540366189786254836e-01
            -7.25629942582431741726622931309976e-01 -2.40050601010709768745599035355553e-01
            -6.96003288871022252060072332824348e-01 -3.15820402283491674655380165859242e-01
            -6.58490639787900566837208771175938e-01 -3.88011832202972251071315668013995e-01
            -6.13517028636472949720825909025734e-01 -4.55806933021931315330732559232274e-01
            -5.61592024401628364671523740980774e-01 -5.18437559158542393689117488975171e-01
            -5.03303958129525663700576387782348e-01 -5.75194080592749901192917150183348e-01
            -4.39313256901757820394038844824536e-01 -6.25433423257948595264110736025032e-01
            -3.70344960932622646598844085019664e-01 -6.68586355327118742053471578401513e-01
            -2.97180508573783641601551153144101e-01 -7.04163936836879944536349285044707e-01
            -2.20648882305496230049612904622336e-01 -7.31763059572647089900954142649425e-01
            -1.41617216033868342783819116448285e-01 -7.51071014445773177392595698620426e-01
            -6.09809701172090504184275516763591e-02 -7.61869034612478679413527515862370e-01
            2.03462145576388774015352822743807e-02 -7.64034774189605081495813010405982e-01
            1.01442868491613241710425086239411e-01 -7.57543694482357587993703873507911e-01
            1.81390134191063395752152587192541e-01 -7.42469342017523459276162611786276e-01
            2.59282177190310048064958436953020e-01 -7.18982515231934460331331138149835e-01
            3.34236449518088618582112303556642e-01 -6.87349329257931462855424342706101e-01
            4.05403689318718341016989370473311e-01 -6.47928200732579839815628020005533e-01
            4.71977543328272075573437405182631e-01 -6.01165786793955159161839674197836e-01
            5.33203703179259136391010542865843e-01 -5.47591924277294861411746751400642e-01
            5.88388452015836227459999463462736e-01 -4.87813626451941428907588260699413e-01
            6.36906524582976585335813979327213e-01 -4.22508205318453400334277603178634e-01
            6.78208191731657916712094902322860e-01 -3.52415597392993995562449072167510e-01
            7.11825489069776606854134115565103e-01 -2.78329979930943549604194231505971e-01
            7.37377519185700602832866934477352e-01 -2.01090772581259791262908720455016e-01
            7.54574767368144105894600670580985e-01 -1.21573126426433253399750356038567e-01
            7.63222381923527537495033357117791e-01 -4.06780081710393925931157355080359e-02
            7.22602651779853388802621338982135e-01 4.13199146028929084617509204235830e-02
            7.13182421135572397474788886029273e-01 1.23421075531164811667217406920827e-01
            6.94464766959844603810836360935355e-01 2.03913253991679283005922229676798e-01
            6.66693702499813523054683628288331e-01 2.81747111341281664120828054365120e-01
            6.30231266051084926260728025226854e-01 3.55907964217876071622015388129512e-01
            5.85552801234877962066605050495127e-01 4.25429012489808799912793801922817e-01
            5.33240760166977523226705670822412e-01 4.89403942974114603003954471205361e-01
            4.73977110303659854295688091951888e-01 5.46998744614883625203560768568423e-01
            4.08534443952964843038699882526998e-01 5.97462581092831568341239290020894e-01
            3.37765906352433309400851157988654e-01 6.40137579124976707767302741558524e-01
            2.62594073616217560385166507330723e-01 6.74467404848971940900526078621624e-01
            1.83998925544536590104272022472287e-01 7.00004516485802752434608464682242e-01
            1.03005070088291919572220933787321e-01 7.16415998731304459745672374992864e-01
            2.06683860174943050125317967058436e-02 7.23487902816279504492058549658395e-01
            -6.19377420732643360623548289822793e-02 7.21128035655896781896956326818326e-01
            -1.43736416974529268575366813820438e-01 7.09367161727543438232146399968769e-01
            -2.23661267864011914507926803707960e-01 6.88358602008814268735648056463106e-01
            -3.00670352081061742488543586659944e-01 6.58376235204094273356645317107905e-01
            -3.73759738442693667526128820099984e-01 6.19810927316803317310700549569447e-01
            -4.41976595021873253088529054366518e-01 5.73165436113289628039524359337520e-01
            -5.04431610768854565840513259900035e-01 5.19047856906475701954661872150609e-01
            -5.60310589040738937782748507743236e-01 4.58163695103493195937005566520384e-01
            -6.08885061899868573753735745412996e-01 3.91306668863769469002278356128954e-01
            -6.49521786807442769173803753801621e-01 3.19348361768982957897833330207504e-01
            -6.81691001908430127542715126764961e-01 2.43226860398162381127207254394307e-01
            -7.04973332287515241922903896920616e-01 1.63934524934508607518779399470077e-01
            -7.19065257162471382912372064311057e-01 8.25050522327891999729843064415036e-02
            -7.23783066741731984095054031058680e-01 8.86378615962317165888963579500470e-17
            -7.19065257162471382912372064311057e-01 -8.25050522327890195617428048535658e-02
            -7.04973332287515352945206359436270e-01 -1.63934524934508440985325705696596e-01
            -6.81691001908430238565017589280615e-01 -2.43226860398162214593753560620826e-01
            -6.49521786807442769173803753801621e-01 -3.19348361768983068920135792723158e-01
            -6.08885061899868795798340670444304e-01 -3.91306668863769080424219737324165e-01
            -5.60310589040739048805050970258890e-01 -4.58163695103493029403551872746903e-01
            -5.04431610768854787885118184931343e-01 -5.19047856906475590932359409634955e-01
            -4.41976595021873641666587673171307e-01 -5.73165436113289294972616971790558e-01
            -3.73759738442694111615338670162600e-01 -6.19810927316803095266095624538139e-01
            -3.00670352081061797999694817917771e-01 -6.58376235204094273356645317107905e-01
            -2.23661267864012081041380497481441e-01 -6.88358602008814268735648056463106e-01
            -1.43736416974529573886698585738486e-01 -7.09367161727543327209843937453115e-01
            -6.19377420732648287238220063954941e-02 -7.21128035655896670874653864302672e-01
            2.06683860174941280707372470715200e-02 -7.23487902816279504492058549658395e-01
            1.03005070088291739160979432199383e-01 -7.16415998731304570767974837508518e-01
            1.83998925544536118259486556780757e-01 -7.00004516485802863456910927197896e-01
            2.62594073616217726918620201104204e-01 -6.74467404848971829878223616105970e-01
            3.37765906352433142867397464215173e-01 -6.40137579124976707767302741558524e-01
            4.08534443952964565482943726237863e-01 -5.97462581092831679363541752536548e-01
            4.73977110303660020829141785725369e-01 -5.46998744614883625203560768568423e-01
            5.33240760166977523226705670822412e-01 -4.89403942974114547492803239947534e-01
            5.85552801234878295133512438042089e-01 -4.25429012489808466845886414375855e-01
            6.30231266051084815238425562711200e-01 -3.55907964217876404688922775676474e-01
            6.66693702499813301010078703257022e-01 -2.81747111341282108210037904427736e-01
            6.94464766959844603810836360935355e-01 -2.03913253991679366272649076563539e-01
            7.13182421135572397474788886029273e-01 -1.23421075531165047589610139766592e-01
            7.22602651779853388802621338982135e-01 -4.13199146028933247953851548572857e-02
            6.79863574556664462811284010967938e-01 4.19325499596606143803967370331520e-02
            6.69557535781153623233308280759957e-01 1.25161995165281231257026206549199e-01
            6.49101687272571226117179321590811e-01 2.06494112107308891435053510576836e-01
            6.18806118842763486220803770265775e-01 2.84695988798297383581825670262333e-01
            5.79130080427524451813781070086407e-01 3.58582164502215139378904495970346e-01
            5.30675020325702462287154048681259e-01 4.27032600110811177973602070778725e-01
            4.74175467856072396788391642985516e-01 4.89009656794791192080396058372571e-01
            4.10487898641601733906725257838843e-01 5.43573825550758837898968067747774e-01
            3.40577751312047871667942899875925e-01 5.89897969200024907543422614253359e-01
            2.65504792438447156932568304910092e-01 6.27279860945098133306885301863076e-01
            1.86407051552162500440701364823326e-01 6.55152829412125825570001325104386e-01
            1.04483569777232832009872254275251e-01 6.73094348811287157552385451708687e-01
            2.09762235891666620757334271729633e-02 6.80832443997068881280654295551358e-01
            -6.28491007665261530723554983524082e-02 6.78249813334234397110833469923818e-01
            -1.45721696819444274106913894684112e-01 6.65385606871043311372204698272981e-01
            -2.26385300489098079124161699837714e-01 6.42434832864427929344230960850837e-01
            -3.03617133767805913446835575086880e-01 6.09745401653597474123102983867284e-01
            -3.76246440788858438342145973365405e-01 5.67812851693936804231555015576305e-01
            -4.43172235292055516353570965293329e-01 5.17272837699146670331629138672724e-01
            -5.03379990453126757721236117504304e-01 4.58891494763734586470604881469626e-01
            -5.55957018076237208248358001583256e-01 3.93553824535936958017856568403658e-01
            -6.00106304016691072256151073816000e-01 3.22250279494853741901749799581012e-01
            -6.35158590102935183274723840440856e-01 2.46061748700476007334358996558876e-01
            -6.60582519408234980495819854695583e-01 1.66143172617334577978454035473987e-01
            -6.75992691080048779816991100233281e-01 8.37060353943394758191587357032404e-02
            -6.81155502624095854358188262267504e-01 8.34174906010205546155795720567239e-17
            -6.75992691080048779816991100233281e-01 -8.37060353943393092857050419297593e-02
            -6.60582519408234980495819854695583e-01 -1.66143172617334716756332113618555e-01
            -6.35158590102935294297026302956510e-01 -2.46061748700475840800905302785395e-01
            -6.00106304016691183278453536331654e-01 -3.22250279494853575368296105807531e-01
            -5.55957018076237319270660464098910e-01 -3.93553824535936846995554105888004e-01
            -5.03379990453126868743538580019958e-01 -4.58891494763734419937151187696145e-01
            -4.43172235292055405331268502777675e-01 -5.17272837699146670331629138672724e-01
            -3.76246440788858604875599667138886e-01 -5.67812851693936693209252553060651e-01
            -3.03617133767805802424533112571226e-01 -6.09745401653597474123102983867284e-01
            -2.26385300489098217902039777982282e-01 -6.42434832864427818321928498335183e-01
            -1.45721696819444579418245666602161e-01 -6.65385606871043200349902235757327e-01
            -6.28491007665261669501433061668649e-02 -6.78249813334234397110833469923818e-01
            2.09762235891664955422797333994822e-02 -6.80832443997068881280654295551358e-01
            1.04483569777232956909962524605362e-01 -6.73094348811287157552385451708687e-01
            1.86407051552162500440701364823326e-01 -6.55152829412125825570001325104386e-01
            2.65504792438447434488324461199227e-01 -6.27279860945098133306885301863076e-01
            3.40577751312047982690245362391579e-01 -5.89897969200024796521120151737705e-01
            4.10487898641601511862120332807535e-01 -5.43573825550759059943572992779082e-01
            4.74175467856072563321845336758997e-01 -4.89009656794791025546942364599090e-01
            5.30675020325702351264851586165605e-01 -4.27032600110811288995904533294379e-01
            5.79130080427524229769176145055098e-01 -3.58582164502215416934660652259481e-01
            6.18806118842763597243106232781429e-01 -2.84695988798297383581825670262333e-01
            6.49101687272571115094876859075157e-01 -2.06494112107309057968507204350317e-01
            6.69557535781153623233308280759957e-01 -1.25161995165281036967996897146804e-01
            6.79863574556664462811284010967938e-01 -4.19325499596606629526540643837507e-02
            6.35098585737146392737884070811560e-01 4.25148480451889992925984529392736e-02
            6.23765236428902247745043041504687e-01 1.26785865665005159641509635548573e-01
            6.01300781699311448491584997100290e-01 2.08794386508416390801912143615482e-01
            5.68106100275216574502223920717370e-01 2.87076966578154069154038552369457e-01
            5.24773552033027002039489161688834e-01 3.60236651378325056782614410622045e-01
            4.72076407322691904422384823192260e-01 4.26967904600485059773973262053914e-01
            4.10955047939985607108326348679839e-01 4.86079905449991911403628819243750e-01
            3.42500185991084449277366275055101e-01 5.36517798871297024732029967708513e-01
            2.67933400109192365601273877473432e-01 5.77381519461401149229118345829193e-01
            1.88585336354891719423676477163099e-01 6.07941853158294520653726067394018e-01
            1.05871962805668240470424734667176e-01 6.27653450083168196194094434758881e-01
            2.12693015720245189037473920734556e-02 6.36164556321921481618630878074327e-01
            -6.37129108520512327240581385012774e-02 6.33323290982091946510479374410352e-01
            -1.47558164872585106941471622121753e-01 6.19180356510979690298768218781333e-01
            -2.28770239945250142277188842854230e-01 5.93988133909273963162434029072756e-01
            -3.05899904666424360399901161144953e-01 5.58196178986117286235923984349938e-01
            -3.77570778341923041221406265322003e-01 5.12443200025040290768174600088969e-01
            -4.42503892533092302308261878351914e-01 4.57545660019511579719164728885517e-01
            -4.99540514278896730093748601575498e-01 3.94483206871476810295717996268650e-01
            -5.47662823713059521146817587577971e-01 3.24381191551340097856126476472127e-01
            -5.86012077083689963963308855454670e-01 2.48490586183236383810424285911722e-01
            -6.13903931055878038236528482229915e-01 1.68165660417841561491414381634968e-01
            -6.30840654834719738452974979736609e-01 8.48398144583719093780871389753884e-02
            -6.36520012183143357731296418933198e-01 -2.04720449712832290331345530689481e-16
            -6.30840654834719738452974979736609e-01 -8.48398144583714652888772889127722e-02
            -6.13903931055878038236528482229915e-01 -1.68165660417841422713536303490400e-01
            -5.86012077083689963963308855454670e-01 -2.48490586183236245032546207767155e-01
            -5.47662823713059632169120050093625e-01 -3.24381191551339931322672782698646e-01
            -4.99540514278896785604899832833325e-01 -3.94483206871476643762264302495169e-01
            -4.42503892533092413330564340867568e-01 -4.57545660019511468696862266369862e-01
            -3.77570778341922874687952571548522e-01 -5.12443200025040290768174600088969e-01
            -3.05899904666424249377598698629299e-01 -5.58196178986117286235923984349938e-01
            -2.28770239945250419832944999143365e-01 -5.93988133909273963162434029072756e-01
            -1.47558164872585523275105856555456e-01 -6.19180356510979690298768218781333e-01
            -6.37129108520515241576021026048693e-02 -6.33323290982091946510479374410352e-01
            2.12693015720242240007564760162495e-02 -6.36164556321921481618630878074327e-01
            1.05871962805668087814758848708152e-01 -6.27653450083168196194094434758881e-01
            1.88585336354891441867920320873964e-01 -6.07941853158294631676028529909672e-01
            2.67933400109192199067820183699951e-01 -5.77381519461401260251420808344847e-01
            3.42500185991084282743912581281620e-01 -5.36517798871297135754332430224167e-01
            4.10955047939985496086023886164185e-01 -4.86079905449992022425931281759404e-01
            4.72076407322691793400082360676606e-01 -4.26967904600485059773973262053914e-01
            5.24773552033027002039489161688834e-01 -3.60236651378325056782614410622045e-01
            5.68106100275216241435316533170408e-01 -2.87076966578154568754399633689900e-01
            6.01300781699311448491584997100290e-01 -2.08794386508416335290760912357655e-01
            6.23765236428902247745043041504687e-01 -1.26785865665005076374782788661832e-01
            6.35098585737146392737884070811560e-01 -4.25148480451894641984900147235749e-02
            5.88387417691854874846058010007255e-01 4.30644083225372939494057789033832e-02
            5.75846961412697977422681105963420e-01 1.28275381870499000092067376499472e-01
            5.51033326907858334031686808884842e-01 2.10752388359223497005245917534921e-01
            5.14475373716609563068402621865971e-01 2.88737573587876661385109855473274e-01
            4.66952271141124808373490395752015e-01 3.60568818727306283911104856088059e-01
            4.09476891605555448627740133815678e-01 4.24715165497197455479749805817846e-01
            3.43274223038809167540819089481374e-01 4.79809445883844054581146565396921e-01
            2.69755260383608808094635378438397e-01 5.24677420952751716320960895245662e-01
            1.90486932688986504436101654391678e-01 5.58362807712871500598339480347931e-01
            1.07158706738028630667258767061867e-01 5.80147660628303141194805903069209e-01
            2.15465789965619790302664426917545e-02 5.89567673380931300819440821214812e-01
            -6.45247766681183859693859972139762e-02 5.86422074753491062715227144508390e-01
            -1.49220898742823265825663270334189e-01 5.70777907719494437266405384434620e-01
            -2.30736636430720898349733261056826e-01 5.42968600538647150344218061945867e-01
            -3.07334623306559973077156655563158e-01 5.03586860312373985060219183651498e-01
            -3.77382306265693689972806623700308e-01 4.53472040460981218323865959973773e-01
            -4.39386740559148503137976149446331e-01 3.93692251362745437859302910510451e-01
            -4.92026409318971347239823899144540e-01 3.25521595435601884815923767746426e-01
            -5.34179389395919468341844549286179e-01 2.50413011856137956989698523102561e-01
            -5.64947263203557925592690480698366e-01 1.69967309683566381028896330462885e-01
            -5.83674266929328333652904348127777e-01 8.58990493938717875055388617511198e-02
            -5.89961267001707145851696623140015e-01 7.22494177254557657757065951408304e-17
            -5.83674266929328333652904348127777e-01 -8.58990493938716348498729757920955e-02
            -5.64947263203558036614992943214020e-01 -1.69967309683566270006593867947231e-01
            -5.34179389395919468341844549286179e-01 -2.50413011856137790456244829329080e-01
            -4.92026409318971513773277592918021e-01 -3.25521595435601551749016380199464e-01
            -4.39386740559148614160278611961985e-01 -3.93692251362745271325849216736970e-01
            -3.77382306265693578950504161184654e-01 -4.53472040460981273835017191231600e-01
            -3.07334623306560361655215274367947e-01 -5.03586860312373763015614258620190e-01
            -2.30736636430720898349733261056826e-01 -5.42968600538647150344218061945867e-01
            -1.49220898742823321336814501592016e-01 -5.70777907719494437266405384434620e-01
            -6.45247766681186496473543456886546e-02 -5.86422074753491062715227144508390e-01
            2.15465789965616980050633344490052e-02 -5.89567673380931300819440821214812e-01
            1.07158706738028214333624532628164e-01 -5.80147660628303141194805903069209e-01
            1.90486932688986476680526038762764e-01 -5.58362807712871500598339480347931e-01
            2.69755260383608641561181684664916e-01 -5.24677420952751716320960895245662e-01
            3.43274223038809001007365395707893e-01 -4.79809445883844110092297796654748e-01
            4.09476891605555171071983977526543e-01 -4.24715165497197677524354730849154e-01
            4.66952271141124863884641627009842e-01 -3.60568818727306228399953624830232e-01
            5.14475373716609563068402621865971e-01 -2.88737573587876716896261086731101e-01
            5.51033326907858223009384346369188e-01 -2.10752388359223635783123995679489e-01
            5.75846961412697977422681105963420e-01 -1.28275381870498722536311220210337e-01
            5.88387417691854874846058010007255e-01 -4.30644083225376408941009742648021e-02
            5.39797886677952032385974234784953e-01 4.35769904941257432695600471106445e-02
            5.25817404955773670671703712287126e-01 1.29602350318519021765695242720540e-01
            4.98218528644412461670043512640405e-01 2.12271077346644299055355986638460e-01
            4.57716054143309958313068364077481e-01 2.89442094972356844806427034200169e-01
            4.05358974267073901565083815512480e-01 3.59116714375220802413224419069593e-01
            3.42503309882590756263454068175633e-01 4.19490399511095235496327404689509e-01
            2.70776989680857171904904134862591e-01 4.68999503647798354766251804903732e-01
            1.92037687678996510376450146395655e-01 5.06361766994124828933365733973915e-01
            1.08324710439004601170154273859225e-01 5.30609526554899013639499116834486e-01
            2.18061800989942933259868595996522e-02 5.41114778094258341845090853894362e-01
            -6.52771188513208283632494044468331e-02 5.37605441115488358327922924218001e-01
            -1.50669774711879006501291655695240e-01 5.20172405602969178950445439113537e-01
            -2.32160162550590160046581900132878e-01 4.89267178019322901416643389893579e-01
            -3.07637724127361844583816719023162e-01 4.45690187525197234474916285762447e-01
            -3.75147630243894580903685209705145e-01 3.90570055284450101673598965135170e-01
            -4.32941409793091536162279453492374e-01 3.25334363768844170294869400095195e-01
            -4.79522234242304057350025914274738e-01 2.51672683121901552549815050952020e-01
            -5.13683684706078502735238089371705e-01 1.71492812179678155715123466507066e-01
            -5.34540997561587127862026136426721e-01 8.68713674830295795592505214699486e-02
            -5.41553979361714454832110732240835e-01 6.63212347390835386059665043471781e-17
            -5.34540997561587127862026136426721e-01 -8.68713674830294407813724433253810e-02
            -5.13683684706078502735238089371705e-01 -1.71492812179678016937245388362498e-01
            -4.79522234242304168372328376790392e-01 -2.51672683121901441527512588436366e-01
            -4.32941409793091647184581916008028e-01 -3.25334363768844059272566937579541e-01
            -3.75147630243894691925987672220799e-01 -3.90570055284449990651296502619516e-01
            -3.07637724127361955606119181538816e-01 -4.45690187525197123452613823246793e-01
            -2.32160162550590076779855053246138e-01 -4.89267178019322956927794621151406e-01
            -1.50669774711879006501291655695240e-01 -5.20172405602969178950445439113537e-01
            -6.52771188513210781634299451070547e-02 -5.37605441115488358327922924218001e-01
            2.18061800989940400563593669858165e-02 -5.41114778094258452867393316410016e-01
            1.08324710439004462392276195714658e-01 -5.30609526554899013639499116834486e-01
            1.92037687678996399354147683880001e-01 -5.06361766994124939955668196489569e-01
            2.70776989680856894349147978573455e-01 -4.68999503647798521299705498677213e-01
            3.42503309882590367685395449370844e-01 -4.19490399511095457540932329720818e-01
            4.05358974267073735031630121738999e-01 -3.59116714375221024457829344100901e-01
            4.57716054143309791779614670303999e-01 -2.89442094972357011339880727973650e-01
            4.98218528644412406158892281382577e-01 -2.12271077346644382322082833525201e-01
            5.25817404955773670671703712287126e-01 -1.29602350318519049521270858349453e-01
            5.39797886677952032385974234784953e-01 -4.35769904941256808195149119455891e-02
            4.89386627101215221369301389131579e-01 4.40455936507784528988196370846708e-02
            4.73657338237524094815000808011973e-01 1.30721119331564161747394336998696e-01
            4.42704312796322940748439123126445e-01 2.13195160679338163722817967027368e-01
            3.97522406483526102860537321248557e-01 2.88816934145315729054459552571643e-01
            3.39563802943823211943907836030121e-01 3.55155893708497871763540842948714e-01
            2.70691339383478113411740650917636e-01 4.10079850624646080614610355041805e-01
            1.93118633449772036936309405064094e-01 4.51823503726893282994581113598542e-01
            1.09338935738449452572673692429817e-01 4.79045177657740961496557474674773e-01
            2.20449946681171224383000151192391e-02 4.90869945418983710805349574002321e-01
            -6.59574906695305218651270706686773e-02 4.86917749245323938644958161603427e-01
            -1.51840047987055359879349225593614e-01 4.67315615973660891668828298861627e-01
            -2.32842341227868593334093816338282e-01 4.32693574296034777493247247548425e-01
            -3.06360890038301691973288143344689e-01 3.84164405119075347272428189171478e-01
            -3.70032747768323733161821564863203e-01 3.23287875870063357020001149066957e-01
            -4.21811448521112852816372651432175e-01 2.52020608288437253374780766534968e-01
            -4.60032782250817562363920387724647e-01 1.72653190993173555334294633212266e-01
            -4.83468283842746926470823609633953e-01 8.77365580798705607667997696808015e-02
            -4.91364716992941374940073728794232e-01 6.01748227879350750001139118650942e-17
            -4.83468283842746926470823609633953e-01 -8.77365580798704358667094993506907e-02
            -4.60032782250817562363920387724647e-01 -1.72653190993173444311992170696612e-01
            -4.21811448521113019349826345205656e-01 -2.52020608288436975819024610245833e-01
            -3.70032747768323844184124027378857e-01 -3.23287875870063245997698686551303e-01
            -3.06360890038301802995590605860343e-01 -3.84164405119075236250125726655824e-01
            -2.32842341227868704356396278853936e-01 -4.32693574296034721982096016290598e-01
            -1.51840047987055470901651688109268e-01 -4.67315615973660836157677067603800e-01
            -6.59574906695306467652173409987881e-02 -4.86917749245323938644958161603427e-01
            2.20449946681170044771036486963567e-02 -4.90869945418983766316500805260148e-01
            1.09338935738449341550371229914163e-01 -4.79045177657740961496557474674773e-01
            1.93118633449771925914006942548440e-01 -4.51823503726893338505732344856369e-01
            2.70691339383477946878286957144155e-01 -4.10079850624646191636912817557459e-01
            3.39563802943823100921605373514467e-01 -3.55155893708497927274692074206541e-01
            3.97522406483526047349386089990730e-01 -2.88816934145315840076762015087297e-01
            4.42704312796322885237287891868618e-01 -2.13195160679338274745120429543022e-01
            4.73657338237524094815000808011973e-01 -1.30721119331564272769696799514350e-01
            4.89386627101215165858150157873752e-01 -4.40455936507785708600160035075533e-02
            4.37198592994969881253553012356861e-01 4.44587515049393589006143656661152e-02
            4.19299631229102298668465209630085e-01 1.31556108004524358046083420958894e-01
            3.84234493295100509868689186987467e-01 2.13267541985217801148166927305283e-01
            3.33438750059961319660573053624830e-01 2.86247777739164210863975768006640e-01
            2.68991985219977636223376293855836e-01 3.47508995839783452197480073664337e-01
            1.93532656899871896571951879195694e-01 3.94543154820148622707876029380714e-01
            1.10150078867163575546683773609402e-01 4.25424670685324635144297644728795e-01
            2.22579436635490790497016178051126e-02 4.38889250547367049115621284727240e-01
            -6.65454343688487576224943609304319e-02 4.34385652924702991839467358659022e-01
            -1.52624434499429084688415514392545e-01 4.12098255633154497701298168976791e-01
            -2.32454972348993371689118703216081e-01 3.72939507336495557066058381678886e-01
            -3.02768776318290133708899247722002e-01 3.18512571790949106098622678473475e-01
            -3.60687191011295593678909199297777e-01 2.51045694132642827067769530913210e-01
            -4.03839029725353015898292596830288e-01 1.73300976259929656597691405295336e-01
            -4.30457651113383299446013552369550e-01 8.84612960571348888594300774457224e-02
            -4.39453285688205186332311313890386e-01 5.38175059692847813881718528946981e-17
            -4.30457651113383299446013552369550e-01 -8.84612960571347778371276149300684e-02
            -4.03839029725353071409443828088115e-01 -1.73300976259929545575388942779682e-01
            -3.60687191011295704701211661813431e-01 -2.51045694132642716045467068397556e-01
            -3.02768776318290300242352941495483e-01 -3.18512571790948884054017753442167e-01
            -2.32454972348993454955845550102822e-01 -3.72939507336495501554907150421059e-01
            -1.52624434499429278977444823794940e-01 -4.12098255633154442190146937718964e-01
            -6.65454343688488547670090156316292e-02 -4.34385652924702991839467358659022e-01
            2.22579436635491657858754166454673e-02 -4.38889250547367049115621284727240e-01
            1.10150078867163381257654464207008e-01 -4.25424670685324690655448875986622e-01
            1.93532656899871619016195722906559e-01 -3.94543154820148789241329723154195e-01
            2.68991985219977469689922600082355e-01 -3.47508995839783563219782536179991e-01
            3.33438750059961375171724284882657e-01 -2.86247777739164099841673305490986e-01
            3.84234493295100398846386724471813e-01 -2.13267541985218023192771852336591e-01
            4.19299631229102243157313978372258e-01 -1.31556108004524635601839577248029e-01
            4.37198592994969881253553012356861e-01 -4.44587515049392686949936148721463e-02
            3.83264663178110198682446707607596e-01 4.47972143672806799585828230192419e-02
            3.62602765981817842799728168756701e-01 1.31976613679975179893588688173622e-01
            3.22392859815217980301582656466053e-01 2.12041119588309040500107016669062e-01
            2.64802671127698285857832161127590e-01 2.80674433854839089352850578507059e-01
            1.92936901898067725280583317726268e-01 3.34176516742385354419297982531134e-01
            1.10669854347256610416216915382392e-01 3.69663057113982340684543714814936e-01
            2.24365663027607485646708340709665e-02 3.85220966392848584991526195153710e-01
            -6.70062828386054354368184249324258e-02 3.80011513662745714636770344441175e-01
            -1.52836805928212776661823113499850e-01 3.54315541868770067512883770177723e-01
            -2.30427857249897310998321131592093e-01 3.09518327501489498576603409674135e-01
            -2.95596483143212351851758512566448e-01 2.48034899982770423720879193751898e-01
            -3.44829426117978732335700442490634e-01 1.73179846804539600002570409742475e-01
            -3.75472525474954854640685653066612e-01 8.89886232591433345984199831946171e-02
            -3.85873803796135339538864172936883e-01 4.72559118693750943314913187260913e-17
            -3.75472525474954854640685653066612e-01 -8.89886232591432374539053284934198e-02
            -3.44829426117978787846851673748461e-01 -1.73179846804539516735843562855734e-01
            -2.95596483143212296340607281308621e-01 -2.48034899982770479232030425009725e-01
            -2.30427857249897394265047978478833e-01 -3.09518327501489387554300947158481e-01
            -1.52836805928212804417398729128763e-01 -3.54315541868770067512883770177723e-01
            -6.70062828386055187035452718191664e-02 -3.80011513662745659125619113183348e-01
            2.24365663027604814172555336426740e-02 -3.85220966392848584991526195153710e-01
            1.10669854347256610416216915382392e-01 -3.69663057113982340684543714814936e-01
            1.92936901898067725280583317726268e-01 -3.34176516742385354419297982531134e-01
            2.64802671127698285857832161127590e-01 -2.80674433854839033841699347249232e-01
            3.22392859815217813768128962692572e-01 -2.12041119588309290300287557329284e-01
            3.62602765981817731777425706241047e-01 -1.31976613679975457449344844462757e-01
            3.83264663178110198682446707607596e-01 -4.47972143672806036307498800397298e-02
            3.27595621743970499828435549716232e-01 4.50269818098763055513877873181627e-02
            3.03299353129469151379993263617507e-01 1.31741500173525871719704127826844e-01
            2.56508758995570851357825858940487e-01 2.08685354146566026667386495319079e-01
            1.90694083656461815801108627965732e-01 2.70151970074526515119828218303155e-01
            1.10736500499938272934485894438694e-01 3.11582650245087799945054030104075e-01
            2.25660976871157395451383820272895e-02 3.29904670642749586750852586192195e-01
            -6.72779293581325377182622560212621e-02 3.23759170832283393881567690186785e-01
            -1.52132260158935300742300000820251e-01 2.93601934420840537942609671517857e-01
            -2.25703637182530891802656469735666e-01 2.41669585672881020999014367589552e-01
            -2.82535607961733603588072583079338e-01 1.71813709320354029985722377205093e-01
            -3.18413205212816907696549151296495e-01 8.92151961429559214877826889278367e-02
            -3.30675551676753887164750267402269e-01 4.04960755917221826777315414338080e-17
            -3.18413205212816852185397920038668e-01 -8.92151961429559769989339201856637e-02
            -2.82535607961733714610375045594992e-01 -1.71813709320353807941117452173785e-01
            -2.25703637182530864047080854106753e-01 -2.41669585672881048754589983218466e-01
            -1.52132260158935522786904925851559e-01 -2.93601934420840482431458440260030e-01
            -6.72779293581324822071110247634351e-02 -3.23759170832283393881567690186785e-01
            2.25660976871156632173054390477773e-02 -3.29904670642749586750852586192195e-01
            1.10736500499938203545546855366410e-01 -3.11582650245087799945054030104075e-01
            1.90694083656461760289957396707905e-01 -2.70151970074526570630979449560982e-01
            2.56508758995570740335523396424833e-01 -2.08685354146566137689688957834733e-01
            3.03299353129469040357690801101853e-01 -1.31741500173526038253157821600325e-01
            3.27595621743970499828435549716232e-01 -4.50269818098762222846609404314222e-02
            2.70167964524254844427275656926213e-01 4.50830595994028207607051683680766e-02
            2.40891073480156453490153012353403e-01 1.30363729754867818666497214508126e-01
            1.85509896814358116179377589105570e-01 2.01517466989709237434880151340622e-01
            1.10025844346094650583189888948255e-01 2.50833659810543174728536541806534e-01
            2.26187844160550925731723026501641e-02 2.72968133505657351012274602908292e-01
            -6.72393717720655426095532902763807e-02 2.65522274398439672715710457850946e-01
            -1.49811098702332334831055504764663e-01 2.29302956857565132242626759762061e-01
            -2.16148468529497261858551837576670e-01 1.68235105939204210301340935984626e-01
            -2.59062797902438912700517903431319e-01 8.89363708556990956166643513824965e-02
            -2.73903653349170106423571269260719e-01 3.35435232348827396370198180137598e-17
            -2.59062797902438912700517903431319e-01 -8.89363708556991372500277748258668e-02
            -2.16148468529497400636429915721237e-01 -1.68235105939204099279038473468972e-01
            -1.49811098702332307075479889135750e-01 -2.29302956857565159998202375390974e-01
            -6.72393717720655981207045215342077e-02 -2.65522274398439672715710457850946e-01
            2.26187844160550856342783987429357e-02 -2.72968133505657351012274602908292e-01
            1.10025844346094414660797156102490e-01 -2.50833659810543230239687773064361e-01
            1.85509896814358143934953204734484e-01 -2.01517466989709237434880151340622e-01
            2.40891073480156370223426165466662e-01 -1.30363729754867985199950908281608e-01
            2.70167964524254899938426888184040e-01 -4.50830595994027721884478410174779e-02
            2.10888261499185880598616904535447e-01 4.48256837608354483104555754380272e-02
            1.74423765226266624939199800792267e-01 1.26726283331705297241498442417651e-01
            1.07799815355564793106779575282417e-01 1.86714757242381790280916220581275e-01
            2.25362980793079523134103681059059e-02 2.14418553375532311422446696269617e-01
            -6.66239498707018318324202255098498e-02 2.05047433698648473576753303859732e-01
            -1.44264311628483937743894216509943e-01 1.60221749937813046082979440143390e-01
            -1.96960063305574584191504072805401e-01 8.76922700438269864253726382230525e-02
            -2.15599630711129530702407919307007e-01 1.22148809411244426567176173539111e-16
            -1.96960063305574584191504072805401e-01 -8.76922700438270280587360616664228e-02
            -1.44264311628484076521772294654511e-01 -1.60221749937812962816252593256650e-01
            -6.66239498707018873435714567676769e-02 -2.05047433698648445821177688230819e-01
            2.25362980793078516994487614510945e-02 -2.14418553375532339178022311898530e-01
            1.07799815355564793106779575282417e-01 -1.86714757242381790280916220581275e-01
            1.74423765226266597183624185163353e-01 -1.26726283331705352752649673675478e-01
            2.10888261499185880598616904535447e-01 -4.48256837608353789215165363657434e-02
            1.49490789398337015070339361955121e-01 4.38944562176216621085522717748972e-02
            1.02028520015809184839916667897342e-01 1.17747188947177339191085820857552e-01
            2.21729164273356885161980756038247e-02 1.54216021147885407049926698164199e-01
            -6.47224314604757933189205232338281e-02 1.41722356272476174288144079582707e-01
            -1.31068864666434220511703756528732e-01 8.42328446428743937701710819965228e-02
            -1.55801859429143707558296227944084e-01 8.82701494921696338181653557309178e-17
            -1.31068864666434220511703756528732e-01 -8.42328446428743521368076585531526e-02
            -6.47224314604759320967986013783957e-02 -1.41722356272476118776992848324880e-01
            2.21729164273356503522816041140686e-02 -1.54216021147885434805502313793113e-01
            1.02028520015809101573189821010601e-01 -1.17747188947177408580024859929836e-01
            1.49490789398337015070339361955121e-01 -4.38944562176216829252339834965824e-02
            8.51829556114447744574746934631548e-02 4.10219493774801532981477691919281e-02
            2.10384526203972223312721467891606e-02 9.21754835559283475232561499979056e-02
            -5.89484343000331451056794662690663e-02 7.39189985795572906956962810909317e-02
            -9.45459478636176964272408440592699e-02 1.15785392423531954603749951401388e-17
            -5.89484343000331659223611779907515e-02 -7.39189985795572629401206654620182e-02
            2.10384526203971182478635881807350e-02 -9.21754835559283752788317656268191e-02
            8.51829556114448022130503090920683e-02 -4.10219493774800977869965379341011e-02
            1.59325274889486369345181770995623e-02 2.75959471038468157066958497125597e-02
            -3.18650549778972669301424502918962e-02 3.90234375833363238377840050693205e-18
            1.59325274889486369345181770995623e-02 -2.75959471038468157066958497125597e-02
            ];
        
    case   48
        
        % DEGREE.             :          48
        % CARDIN.             :        1225
        % LEBESGUE CONST.     : 2.47839e+03
        % ABS.DET.VAND.MATRIX : Inf
        % CONDITIONING VAND.  : 6.66960e+04
        % POINTS OUT DISK     : 0.00000e+00
        
        pts=[
            9.99475569045514933286256109568058e-01 3.23818912533559016830864152325375e-02
            9.95283421166613946340362417686265e-01 9.70098528546480820544672951655230e-02
            9.86916708733890701843449733132729e-01 1.61230921419759809509741899091750e-01
            9.74410524646926012870551403466379e-01 2.24775731468729367268366559073911e-01
            9.57817324187987151340450964198681e-01 2.87377753984828177014065886396565e-01
            9.37206705006343621100484142516507e-01 3.48774414329882265217719350403058e-01
            9.12665115201540144695968592714053e-01 4.08708193573556199940099986633868e-01
            8.84295490730023669989634527155431e-01 4.66927708617240588839791826103465e-01
            8.52216823655969291095857442996930e-01 5.23188766582130093674152249150211e-01
            8.16563663057210953333253655728186e-01 5.77255389039019406460795380553463e-01
            7.77485550679649306538010478107026e-01 6.28900801783844554115887603984447e-01
            7.35146393707200362932496773282764e-01 6.77908386007503138692698030354222e-01
            6.89723777278104188681595587695483e-01 7.24072586870421530669261755974730e-01
            6.41408219631140030791982553637354e-01 7.67199775670986072739765404548962e-01
            5.90402373005922687099200629745610e-01 8.07109061991609255670709899277426e-01
            5.36920173648983700687153941544238e-01 8.43633052416004391993453737086384e-01
            4.81185944490804984319254344882211e-01 8.76618552635347714208080560638336e-01
            4.23433454257490349270653950952692e-01 9.05927209998446780758740715100430e-01
            3.63904936963487413148499172166339e-01 9.31436093810842358209356461884454e-01
            3.02850075897950876679942666669376e-01 9.53038210948860875504351497511379e-01
            2.40524956366253678252675740623090e-01 9.70642954625958953585040944744833e-01
            1.77190991579222856255881879405933e-01 9.84176484429074238668988527933834e-01
            1.13113826195284358777648492377921e-01 9.93582036030977611140713179338491e-01
            4.85622221144480781251928647179739e-02 9.98820159279590780165847263560863e-01
            -1.61930688025012231578969590373163e-02 9.99868883665632202095707725675311e-01
            -8.08804403614041128589562390516221e-02 9.96723810474569371642417081602616e-01
            -1.45228571245490267749289614584995e-01 9.89398131236356004336585101555102e-01
            -2.08967563031275088691884889158246e-01 9.77922572395570677272758075559977e-01
            -2.71830072236342645819462404688238e-01 9.62345266434030288671408470690949e-01
            -3.33552431650820380149013999471208e-01 9.42731549986434269605695135396672e-01
            -3.93875756249287223287325332421460e-01 9.19163689795812199889724070089869e-01
            -4.52547029044538862141422441709437e-01 8.91740537658214371674603171413764e-01
            -5.09320162328762648940028157085180e-01 8.60577115803925374315497265342856e-01
            -5.63957029850906566004198339214781e-01 8.25804134454256488773182809381979e-01
            -6.16228465600927366452310707245488e-01 7.87567443577454340264409893279662e-01
            -6.65915225011681211064740182337118e-01 7.46027421143245939028076918475563e-01
            -7.12808904546828991932727603852982e-01 7.01358300441899285004865305381827e-01
            -7.56712815817695005904397476115264e-01 6.53747439289252718630507388297701e-01
            -7.97442810562720594269592311320594e-01 6.03394534182924879850418165005976e-01
            -8.34828053029271321960891327762511e-01 5.50510782705803336511962697841227e-01
            -8.68711736518150923203052116150502e-01 4.95317997689987743470396708289627e-01
            -8.98951741085395439334604361647507e-01 4.38047676856682111079521746432874e-01
            -9.25421229642704123996566067944514e-01 3.78940031834306911839860276813852e-01
            -9.48009179956270431333109627303202e-01 3.18242980627444049801511027908418e-01
            -9.66620850312611246124561148462817e-01 2.56211107762572110058130192555836e-01
            -9.81178176898239051695327361812815e-01 1.93104596472088080316709124417685e-01
            -9.91620101226425076923476353840670e-01 1.29188137395406521523710807741736e-01
            -9.97902826237711648715844603430014e-01 6.47298183744358796021245439078484e-02
            -1.00000000000000000000000000000000e+00 1.22464679914735320717376402945840e-16
            -9.97902826237711648715844603430014e-01 -6.47298183744360877689416611246997e-02
            -9.91620101226425187945778816356324e-01 -1.29188137395406299479105882710428e-01
            -9.81178176898239162717629824328469e-01 -1.93104596472087414182894349323760e-01
            -9.66620850312611246124561148462817e-01 -2.56211107762572332102735117587144e-01
            -9.48009179956270431333109627303202e-01 -3.18242980627443827756906102877110e-01
            -9.25421229642704346041170992975822e-01 -3.78940031834306245706045501719927e-01
            -8.98951741085395328312301899131853e-01 -4.38047676856682277612975440206355e-01
            -8.68711736518151256269959503697464e-01 -4.95317997689987188358884395711357e-01
            -8.34828053029270988893983940215549e-01 -5.50510782705803447534265160356881e-01
            -7.97442810562720816314197236351902e-01 -6.03394534182924657805813239974668e-01
            -7.56712815817695449993607326177880e-01 -6.53747439289252163518995075719431e-01
            -7.12808904546829213977332528884290e-01 -7.01358300441899173982562842866173e-01
            -6.65915225011681322087042644852772e-01 -7.46027421143245828005774455959909e-01
            -6.16228465600927921563823019823758e-01 -7.87567443577453896175200043217046e-01
            -5.63957029850906343959593414183473e-01 -8.25804134454256377750880346866325e-01
            -5.09320162328762870984633082116488e-01 -8.60577115803925263293194802827202e-01
            -4.52547029044538695607968747935956e-01 -8.91740537658214482696905633929418e-01
            -3.93875756249287056753871638647979e-01 -9.19163689795812310912026532605523e-01
            -3.33552431650821268327433699596440e-01 -9.42731549986433936538787747849710e-01
            -2.71830072236342645819462404688238e-01 -9.62345266434030288671408470690949e-01
            -2.08967563031274894402855579755851e-01 -9.77922572395570677272758075559977e-01
            -1.45228571245490933883104389678920e-01 -9.89398131236355893314282639039448e-01
            -8.08804403614039185699269296492275e-02 -9.96723810474569371642417081602616e-01
            -1.61930688025021321529983708842337e-02 -9.99868883665632202095707725675311e-01
            4.85622221144485013977210030589049e-02 -9.98820159279590669143544801045209e-01
            1.13113826195284566944465609594772e-01 -9.93582036030977611140713179338491e-01
            1.77190991579222162366491488683096e-01 -9.84176484429074349691290990449488e-01
            2.40524956366253928052856281283312e-01 -9.70642954625959064607343407260487e-01
            3.02850075897950210546127891575452e-01 -9.53038210948861097548956422542688e-01
            3.63904936963486969059289322103723e-01 -9.31436093810842469231658924400108e-01
            4.23433454257489738647990407116595e-01 -9.05927209998447002803345640131738e-01
            4.81185944490804595741195726077422e-01 -8.76618552635347936252685485669645e-01
            5.36920173648983367620246553997276e-01 -8.43633052416004836082663587149000e-01
            5.90402373005922243009990779682994e-01 -8.07109061991609588737617286824388e-01
            6.41408219631140252836587478668662e-01 -7.67199775670985850695160479517654e-01
            6.89723777278103855614688200148521e-01 -7.24072586870421863736169143521693e-01
            7.35146393707200029865589385735802e-01 -6.77908386007503471759605417901184e-01
            7.77485550679649084493405553075718e-01 -6.28900801783844776160492529015755e-01
            8.16563663057210731288648730696877e-01 -5.77255389039019739527702768100426e-01
            8.52216823655969513140462368028238e-01 -5.23188766582129649584942399087595e-01
            8.84295490730023447945029602124123e-01 -4.66927708617240921906699213650427e-01
            9.12665115201540033673666130198399e-01 -4.08708193573556477495856142923003e-01
            9.37206705006343510078181680000853e-01 -3.48774414329882598284626737950020e-01
            9.57817324187987040318148501683027e-01 -2.87377753984828454569822042685701e-01
            9.74410524646926123892853865982033e-01 -2.24775731468728812156854246495641e-01
            9.86916708733890590821147270617075e-01 -1.61230921419760114821073671009799e-01
            9.95283421166613946340362417686265e-01 -9.70098528546483457324356436402013e-02
            9.99475569045514711241651184536749e-01 -3.23818912533561445443730519855308e-02
            9.91097855612530498348178298329003e-01 3.34925874207694096451604082176345e-02
            9.86575703415714988508966598601546e-01 1.00324943267771832244861229810340e-01
            9.77552032565356276982981853507226e-01 1.66699539409186636707005391144776e-01
            9.64068016001874417142403217440005e-01 2.32313523786507214463625814460102e-01
            9.46185178200152354754948191839503e-01 2.96867514838252632980442058396875e-01
            9.23985114447469446652405622444348e-01 3.60066967509366286925853728462243e-01
            8.97569118542919319736483885208145e-01 4.21623517192745322912372785140178e-01
            8.67057720617037785970637742138933e-01 4.81256295470803341363108529549208e-01
            8.32590137180462153132509683928220e-01 5.38693211653640258163022735971026e-01
            7.94323635910923586678222818591166e-01 5.93672194266452679656254076689947e-01
            7.52432818076905207682614218356321e-01 6.45942386821565905918873795599211e-01
            7.07108821872099335692496424599085e-01 6.95265292419049218963778002944309e-01
            6.58558450295670394503133593389066e-01 7.41415861953370503023563742317492e-01
            6.07003227557601832131695118732750e-01 7.84183520960845426017726822465193e-01
            5.52678388314533863834299154405016e-01 8.23373130422619392554395290062530e-01
            4.95831804347980187319677725099609e-01 8.58805877139252382690415288379882e-01
            4.36722853582239223246830306379707e-01 8.90320089614336618311085658206139e-01
            3.75621236602418195893449137656717e-01 9.17771975724452349076898372004507e-01
            3.12805746072520041156650449920562e-01 9.41036278809647463994281224586302e-01
            2.48562994668463349556830621622794e-01 9.60006849190848110531248948973371e-01
            1.83186107330178149510402363375761e-01 9.74597128506497711875056211283663e-01
            1.16973383799736790900070104726183e-01 9.84740544658507466202479463390773e-01
            5.02269375480488763918707206812542e-02 9.90390815565470927772651066334220e-01
            -1.67486826996132952272144933658637e-02 9.91522160337186875267434515990317e-01
            -8.36478825495969163794640621745202e-02 9.88129416906947000143190962262452e-01
            -1.50165416296997367151533353535342e-01 9.80228065584863639259083356591873e-01
            -2.15997779691795677159404931444442e-01 9.67854158424764299262221811659401e-01
            -2.80844594759141474860086873377440e-01 9.51064154726939503525784402881982e-01
            -3.44409980355157241405095192021690e-01 9.29934663427304797345129827590426e-01
            -4.06403902204734268632790872288751e-01 9.04562093548397117004356005054433e-01
            -4.66543496261407786285246857005404e-01 8.75062214307117836042948511021677e-01
            -5.24554359351122712062931441323599e-01 8.41569626886348287619910024659475e-01
            -5.80171801210980331298117107508006e-01 8.04237150280625368026221622130834e-01
            -6.33142052210198813533281736454228e-01 7.63235124018118105126973205187824e-01
            -6.83223421242732942282316344062565e-01 7.18750630940432233551007357164053e-01
            -7.30187398508356899640148185426369e-01 6.70986643586511610770628522004699e-01
            -7.73819698150472023989721037651179e-01 6.20161098075497574377834553160938e-01
            -8.13921235993322111923475858930033e-01 5.66505899714201732741969408380101e-01
            -8.50309037917424626051854374964023e-01 5.10265864866383256348569830151973e-01
            -8.82817074728510897685396230372135e-01 4.51697603911830891654233255394502e-01
            -9.11297019710660238800414845172781e-01 3.91068350392054731035074155442999e-01
            -9.35618925407083246170714119216427e-01 3.28654741684931861467333646942279e-01
            -9.55671816540562657493751430592965e-01 2.64741556771799002589773408544715e-01
            -9.71364196368190491170935274567455e-01 1.99620416856276960970717482268810e-01
            -9.82624464160019805980539331358159e-01 1.33588454763606756525717855765834e-01
            -9.89401241896773142592280692042550e-01 6.69469591917175588235977556905709e-02
            -9.91663608695960152594750525167910e-01 5.61830874844892729662085883906265e-16
            -9.89401241896773142592280692042550e-01 -6.69469591917173090234172150303493e-02
            -9.82624464160019917002841793873813e-01 -1.33588454763606534481112930734525e-01
            -9.71364196368190491170935274567455e-01 -1.99620416856277155259746791671205e-01
            -9.55671816540562657493751430592965e-01 -2.64741556771798780545168483513407e-01
            -9.35618925407083246170714119216427e-01 -3.28654741684931583911577490653144e-01
            -9.11297019710660127778112382657127e-01 -3.91068350392054953079679080474307e-01
            -8.82817074728511008707698692887789e-01 -4.51697603911830669609628330363194e-01
            -8.50309037917424737074156837479677e-01 -5.10265864866383145326267367636319e-01
            -8.13921235993322333968080783961341e-01 -5.66505899714201510697364483348792e-01
            -7.73819698150472135012023500166833e-01 -6.20161098075497352333229628129629e-01
            -7.30187398508356788617845722910715e-01 -6.70986643586511721792930984520353e-01
            -6.83223421242733053304618806578219e-01 -7.18750630940432122528704894648399e-01
            -6.33142052210199368644794049032498e-01 -7.63235124018117772060065817640861e-01
            -5.80171801210980442320419570023660e-01 -8.04237150280625257003919159615180e-01
            -5.24554359351122934107536366354907e-01 -8.41569626886348176597607562143821e-01
            -4.66543496261408396907910400841502e-01 -8.75062214307117502976041123474715e-01
            -4.06403902204734490677395797320060e-01 -9.04562093548397117004356005054433e-01
            -3.44409980355157685494305042084306e-01 -9.29934663427304575300524902559118e-01
            -2.80844594759141252815481948346132e-01 -9.51064154726939503525784402881982e-01
            -2.15997779691795704914980547073355e-01 -9.67854158424764299262221811659401e-01
            -1.50165416296997783485167587969045e-01 -9.80228065584863639259083356591873e-01
            -8.36478825495969441350396778034337e-02 -9.88129416906947000143190962262452e-01
            -1.67486826996133160438962050875489e-02 -9.91522160337186875267434515990317e-01
            5.02269375480484114859791588969529e-02 -9.90390815565471038794953528849874e-01
            1.16973383799736763144494489097269e-01 -9.84740544658507466202479463390773e-01
            1.83186107330177927465797438344453e-01 -9.74597128506497822897358673799317e-01
            2.48562994668463793646040471685410e-01 -9.60006849190847999508946486457717e-01
            3.12805746072520207690104143694043e-01 -9.41036278809647352971978762070648e-01
            3.75621236602417973848844212625409e-01 -9.17771975724452349076898372004507e-01
            4.36722853582239611824888925184496e-01 -8.90320089614336396266480733174831e-01
            4.95831804347980187319677725099609e-01 -8.58805877139252382690415288379882e-01
            5.52678388314533641789694229373708e-01 -8.23373130422619503576697752578184e-01
            6.07003227557601388042485268670134e-01 -7.84183520960845759084634210012155e-01
            6.58558450295670505525436055904720e-01 -7.41415861953370503023563742317492e-01
            7.07108821872099002625589037052123e-01 -6.95265292419049441008382927975617e-01
            7.52432818076904763593404368293704e-01 -6.45942386821566350008083645661827e-01
            7.94323635910923586678222818591166e-01 -5.93672194266452679656254076689947e-01
            8.32590137180461931087904758896912e-01 -5.38693211653640480207627661002334e-01
            8.67057720617037563926032817107625e-01 -4.81256295470803951985772073385306e-01
            8.97569118542918986669576497661183e-01 -4.21623517192746155579641254007583e-01
            9.23985114447469335630103159928694e-01 -3.60066967509366619992761116009206e-01
            9.46185178200152465777250654355157e-01 -2.96867514838252410935837133365567e-01
            9.64068016001874306120100754924351e-01 -2.32313523786507269974777045717929e-01
            9.77552032565356165960679390991572e-01 -1.66699539409186969773912778691738e-01
            9.86575703415714877486664136085892e-01 -1.00324943267772512256463812718721e-01
            9.91097855612530498348178298329003e-01 -3.34925874207703810903069552296074e-02
            9.75709633942435150544270072714426e-01 3.44556850753948359922240740615962e-02
            9.70848697625819156975524037989089e-01 1.03195398736312490828304078149813e-01
            9.61151041932803873457658028200967e-01 1.71420998111612044034757218469167e-01
            9.46664980096245001206511915370356e-01 2.38792586697057579447900366176327e-01
            9.27462680947541362463937275606440e-01 3.04974522627210309355660911023733e-01
            9.03639809375146763059660770522896e-01 3.69637090826318570613295833027223e-01
            8.75315049726907989935398290981539e-01 4.32458145632240664735235213811393e-01
            8.42629514530613965561656186764594e-01 4.93124715709928163054343031035387e-01
            8.05746041478480279351970239076763e-01 5.51334563258875420821425450412789e-01
            7.64848382177957586414152046927484e-01 6.06797689746637503027670845767716e-01
            7.20140286710466370756478227121988e-01 6.59237780666932837725369154213695e-01
            6.71844488558740127182034029829083e-01 7.08393582124612786188322388625238e-01
            6.20201594959818303109955195395742e-01 7.54020202389427574019009625772014e-01
            5.65468888211894449291605724283727e-01 7.95890331934306027861225629749242e-01
            5.07919043906847722524844357394613e-01 8.33795375879987310518970389239257e-01
            4.47838772474161095349387551323161e-01 8.67546493204215729555528469063574e-01
            3.85527390803982350497847164660925e-01 8.96975537538214684474269233760424e-01
            3.21295331065435008088826407401939e-01 9.21935894863437965796038042753935e-01
            2.55462594149165667101186727450113e-01 9.42303213935235639553411601809785e-01
            1.88357155439003942642983702171477e-01 9.57976025794499030929785021726275e-01
            1.20313330855097780358597958638711e-01 9.68876249280911761019297046004795e-01
            5.16701113088158317521170204145164e-02 9.74949580029362494748568224167684e-01
            -1.72305261329213088572487322380766e-02 9.76165761011560162430100717756432e-01
            -8.60453219601860219700739662584965e-02 9.72518733275027247309196809510468e-01
            -1.54431444321655786389158038218739e-01 9.64026666128496190211194516450632e-01
            -2.22048196995652868945825275659445e-01 9.50731866623326871135191140638199e-01
            -2.88558716721581343112035256126546e-01 9.32700568781905436921420005091932e-01
            -3.53631651435746929834635920997243e-01 9.10022603623075965195710068655899e-01
            -4.16942811050671713335447066128836e-01 8.82810951628523632450651348335668e-01
            -4.78176782553802859343505815559183e-01 8.51201179879697344965450156450970e-01
            -5.37028501379273492943866585846990e-01 8.15350766669429960487036623817403e-01
            -5.93204771224226656833877768804086e-01 7.75438316953004691534090397908585e-01
            -6.46425724738046603157215486135101e-01 7.31662672547251813348623272759141e-01
            -6.96426217807422975880626836442389e-01 6.84241921510618689161731253989274e-01
            -7.42957150490985873680926943052327e-01 6.33412311639433123211517795425607e-01
            -7.85786708022682245378121024259599e-01 5.79427073493266830972459047188750e-01
            -8.24701515701281140380274337076116e-01 5.22555158813024500652488768537296e-01
            -8.59507701912402555244341328943847e-01 4.63079900616898076926020166865783e-01
            -8.90031863987146953931528514658567e-01 4.01297601649524660061274516920093e-01
            -9.16121932085469437012648086238187e-01 3.37516058216616121612219103553798e-01
            -9.37647926800474929009965308068786e-01 2.72053026759245697441258471371839e-01
            -9.54502606709283774044649817369645e-01 2.05234640807242768589802039969072e-01
            -9.66602002644406099740592708258191e-01 1.37393786198354961314294087060262e-01
            -9.73885836023911322101298537745606e-01 6.88684426577442498906833634464419e-02
            -9.76317819156290789273100472200895e-01 1.19564449218027602451879561067798e-16
            -9.73885836023911322101298537745606e-01 -6.88684426577440139682906306006771e-02
            -9.66602002644406210762895170773845e-01 -1.37393786198354711514113546400040e-01
            -9.54502606709283774044649817369645e-01 -2.05234640807242962878831349371467e-01
            -9.37647926800475151054570233100094e-01 -2.72053026759245031307443696277915e-01
            -9.16121932085469325990345623722533e-01 -3.37516058216616232634521566069452e-01
            -8.90031863987146842909226052142913e-01 -4.01297601649524826594728210693575e-01
            -8.59507701912402666266643791459501e-01 -4.63079900616897854881415241834475e-01
            -8.24701515701281251402576799591770e-01 -5.22555158813024389630186306021642e-01
            -7.85786708022682356400423486775253e-01 -5.79427073493266608927854122157441e-01
            -7.42957150490986317770136793114943e-01 -6.33412311639432679122307945362991e-01
            -6.96426217807423197925231761473697e-01 -6.84241921510618467117126328957966e-01
            -6.46425724738046714179517948650755e-01 -7.31662672547251591304018347727833e-01
            -5.93204771224226212744667918741470e-01 -7.75438316953005135623300247971201e-01
            -5.37028501379273714988471510878298e-01 -8.15350766669429849464734161301749e-01
            -4.78176782553803025876959509332664e-01 -8.51201179879697233943147693935316e-01
            -4.16942811050671935380051991160144e-01 -8.82810951628523632450651348335668e-01
            -3.53631651435746763301182227223762e-01 -9.10022603623076076218012531171553e-01
            -2.88558716721581787201245106189162e-01 -9.32700568781905325899117542576278e-01
            -2.22048196995653313035035125722061e-01 -9.50731866623326760112888678122545e-01
            -1.54431444321656036189338578878960e-01 -9.64026666128496079188892053934978e-01
            -8.60453219601858415588324646705587e-02 -9.72518733275027358331499272026122e-01
            -1.72305261329211145682194228356821e-02 -9.76165761011560162430100717756432e-01
            5.16701113088151586794083414133638e-02 -9.74949580029362494748568224167684e-01
            1.20313330855097308513812492947181e-01 -9.68876249280911872041599508520449e-01
            1.88357155439003720598378777140169e-01 -9.57976025794499030929785021726275e-01
            2.55462594149164834433918258582707e-01 -9.42303213935235861598016526841093e-01
            3.21295331065435174622280101175420e-01 -9.21935894863437965796038042753935e-01
            3.85527390803981906408637314598309e-01 -8.96975537538214906518874158791732e-01
            4.47838772474160651260177701260545e-01 -8.67546493204215840577830931579228e-01
            5.07919043906847611502541894878959e-01 -8.33795375879987421541272851754911e-01
            5.65468888211894449291605724283727e-01 -7.95890331934306027861225629749242e-01
            6.20201594959818414132257657911396e-01 -7.54020202389427462996707163256360e-01
            6.71844488558739683092824179766467e-01 -7.08393582124613230277532238687854e-01
            7.20140286710466148711873302090680e-01 -6.59237780666933170792276541760657e-01
            7.64848382177957475391849584411830e-01 -6.06797689746637725072275770799024e-01
            8.05746041478480390374272701592417e-01 -5.51334563258875309799122987897135e-01
            8.42629514530613632494748799217632e-01 -4.93124715709928718165855343613657e-01
            8.75315049726907767890793365950231e-01 -4.32458145632241108824445063874009e-01
            9.03639809375146985104265695554204e-01 -3.69637090826318182035237214222434e-01
            9.27462680947541362463937275606440e-01 -3.04974522627210475889114604797214e-01
            9.46664980096245001206511915370356e-01 -2.38792586697057551692324750547414e-01
            9.61151041932803762435355565685313e-01 -1.71420998111612682412996377934178e-01
            9.70848697625819156975524037989089e-01 -1.03195398736312976550877351655799e-01
            9.75709633942435150544270072714426e-01 -3.44556850753942947584995692977827e-02
            9.55728502554243686262225310201757e-01 3.53397360926342093967456037262309e-02
            9.50508644892771425993771572393598e-01 1.05826194894180644623382647750987e-01
            9.40097438622276015962597739417106e-01 1.75734667716731463027457493808470e-01
            9.24551746141096031372796915093204e-01 2.44683338724001164798949048417853e-01
            9.03956472630759622077789572358597e-01 3.12295634184387438381236279383302e-01
            8.78424102333324685609738935454516e-01 3.78202279186107770403424410687876e-01
            8.48094084201455600258157119242242e-01 4.42043314488714145227277185767889e-01
            8.13132070276600504854513928876258e-01 5.03470062495639858468621241627261e-01
            7.73729010954984142145463010820094e-01 5.62147031610321756822656880103750e-01
            7.30100112082760266396519455156522e-01 6.17753748574960015460533213627059e-01
            6.82483659576306966876302340097027e-01 6.69986508784322976062242105399491e-01
            6.31139717987182158331904702208703e-01 7.18560035014983444767722176038660e-01
            5.76348710119725993195061164442450e-01 7.63209035510588051920422003604472e-01
            5.18409885458946617653452904050937e-01 8.03689652913433971725964966026368e-01
            4.57639685773603310803281374319340e-01 8.39780796128794304600262421445223e-01
            3.94370016821000035633915103971958e-01 8.71285347847809310550815098395105e-01
            3.28946435592832375771621400417644e-01 8.98031241133873003867904571961844e-01
            2.61726263002730996642952732145204e-01 9.19872399192572354209573859407101e-01
            1.93076632323336994101481423058431e-01 9.36689533192483603230016342422459e-01
            1.23372484031681439731187310826499e-01 9.48390793779403162844232610950712e-01
            5.29945180143153865559568771459453e-02 9.54912272725669919459789980464848e-01
            -1.76728856834523322116847765528291e-02 9.56218351974743030474712668365100e-01
            -8.82437662080714502188527603721013e-02 9.52301898174675143238232521980535e-01
            -1.58332689882092175759353835928778e-01 9.43184301638007149826137265336001e-01
            -2.27556855309252709096412559119926e-01 9.28915359515299354775663687178167e-01
            -2.95538184102964118782352898051613e-01 9.09573003820362102622709699062398e-01
            -3.61905385819346836484555751667358e-01 8.85262875792622194737191421154421e-01
            -4.26295985816885270036635802171077e-01 8.56117748921305765641420748579549e-01
            -4.88358304967222656145509063208010e-01 8.22296803782682328431974383420311e-01
            -5.47753380404608414266931504243985e-01 7.83984758650956292669320646382403e-01
            -6.04156816823526954252088216890115e-01 7.41390860631109482881129224551842e-01
            -6.57260558213367374058577752293786e-01 6.94747742823772385101221971126506e-01
            -7.06774570353525755095347449241672e-01 6.44310153763902104806504667067202e-01
            -7.52428424879745039177691978693474e-01 5.90353566072620350446698012092384e-01
            -7.93972776270061686432200076524168e-01 5.33172671921287033569569757673889e-01
            -8.31180723683582645122669418924488e-01 4.73079773525046987092679273700924e-01
            -8.63849050214193225905034978495678e-01 4.10403077456432230363247981586028e-01
            -8.91799332790830567851969590265071e-01 3.45484902094872037281447774148546e-01
            -9.14878916662424490624516693060286e-01 2.78679808002414042267247396011953e-01
            -9.32961749145212460021525657793973e-01 2.10352661436882720780161548645992e-01
            -9.45949068078785093582894205610501e-01 1.40876641578907502161399634132977e-01
            -9.53769941230760753825279607553966e-01 7.06312023566429136867128590893117e-02
            -9.56381653704039824681615300505655e-01 1.17122973097190483875062848486604e-16
            -9.53769941230760753825279607553966e-01 -7.06312023566426777643201262435468e-02
            -9.45949068078785093582894205610501e-01 -1.40876641578907280116794709101669e-01
            -9.32961749145212460021525657793973e-01 -2.10352661436882498735556623614684e-01
            -9.14878916662424712669121618091594e-01 -2.78679808002413376133432620918029e-01
            -8.91799332790830456829667127749417e-01 -3.45484902094872203814901467922027e-01
            -8.63849050214193225905034978495678e-01 -4.10403077456432008318643056554720e-01
            -8.31180723683582534100366956408834e-01 -4.73079773525047153626132967474405e-01
            -7.93972776270061908476805001555476e-01 -5.33172671921286811524964832642581e-01
            -7.52428424879745261222296903724782e-01 -5.90353566072620239424395549576730e-01
            -7.06774570353525866117649911757326e-01 -6.44310153763901882761899742035894e-01
            -6.57260558213367596103182677325094e-01 -6.94747742823772274078919508610852e-01
            -6.04156816823527842430507917015348e-01 -7.41390860631108705725011986942263e-01
            -5.47753380404608636311536429275293e-01 -7.83984758650956181647018183866749e-01
            -4.88358304967223155745870144528453e-01 -8.22296803782681995365066995873349e-01
            -4.26295985816885103503182108397596e-01 -8.56117748921305876663723211095203e-01
            -3.61905385819346836484555751667358e-01 -8.85262875792622194737191421154421e-01
            -2.95538184102964340826957823082921e-01 -9.09573003820361991600407236546744e-01
            -2.27556855309253375230227334213851e-01 -9.28915359515299132731058762146858e-01
            -1.58332689882092647604139301620307e-01 -9.43184301638007038803834802820347e-01
            -8.82437662080723245194846526828769e-02 -9.52301898174675032215930059464881e-01
            -1.76728856834525681340775093985940e-02 -9.56218351974743030474712668365100e-01
            5.29945180143149424667470270833292e-02 -9.54912272725669919459789980464848e-01
            1.23372484031681634020216620228894e-01 -9.48390793779403162844232610950712e-01
            1.93076632323337188390510732460825e-01 -9.36689533192483603230016342422459e-01
            2.61726263002730774598347807113896e-01 -9.19872399192572354209573859407101e-01
            3.28946435592832153727016475386336e-01 -8.98031241133873114890207034477498e-01
            3.94370016820999480522402791393688e-01 -8.71285347847809643617722485942068e-01
            4.57639685773602755691769061741070e-01 -8.39780796128794637667169808992185e-01
            5.18409885458946506631150441535283e-01 -8.03689652913433971725964966026368e-01
            5.76348710119725771150456239411142e-01 -7.63209035510588273965026928635780e-01
            6.31139717987182380376509627240011e-01 -7.18560035014983222723117251007352e-01
            6.82483659576307077898604802612681e-01 -6.69986508784322865039939642883837e-01
            7.30100112082760266396519455156522e-01 -6.17753748574960015460533213627059e-01
            7.73729010954984031123160548304440e-01 -5.62147031610321978867261805135058e-01
            8.13132070276600171787606541329296e-01 -5.03470062495640302557831091689877e-01
            8.48094084201455267191249731695279e-01 -4.42043314488714700338789498346159e-01
            8.78424102333324685609738935454516e-01 -3.78202279186107825914575641945703e-01
            9.03956472630759511055487109842943e-01 -3.12295634184387604914689973156783e-01
            9.24551746141095920350494452577550e-01 -2.44683338724001525621432051593729e-01
            9.40097438622275904940295276901452e-01 -1.75734667716732018138969806386740e-01
            9.50508644892771537016074034909252e-01 -1.05826194894180575234443608678703e-01
            9.55728502554243686262225310201757e-01 -3.53397360926343481746236818707985e-02
            9.32021752764031541360623123182449e-01 3.61666885504089846703479338430043e-02
            9.26416464277113660408247142186156e-01 1.08282554930752533683957494758943e-01
            9.15239598167780887827404967538314e-01 1.79747197284738924327740505759721e-01
            8.98558373423934519941269627452129e-01 2.50130818844405911072215076274006e-01
            8.76473112893970451864333881530911e-01 3.19010124228046032524019892662182e-01
            8.49116639933365169312651232758071e-01 3.85970865188438705395412853249582e-01
            8.16653479589387165660241407749709e-01 4.50610331950551779023328435869189e-01
            7.79278869128103957031328263838077e-01 5.12539775155512633553200885216938e-01
            7.37217583854491209649495431222022e-01 5.71386743844994993146713113674195e-01
            6.90722585287301571455031989898998e-01 6.26797325425106133245378714491380e-01
            6.40073499818724300780559133272618e-01 6.78438274138369656895974912913516e-01
            5.85574937008362939039329830848146e-01 7.25999015242921430512978986371309e-01
            5.27554657625500134088269987842068e-01 7.69193512845552596068898765224731e-01
            4.66361602457267154786535456878482e-01 8.07761990155225095833202431094833e-01
            4.02363793737690489393798998207785e-01 8.41472491811261269489818914735224e-01
            3.35946121818674670045368202409009e-01 8.70122278890175349097546586563112e-01
            2.67508030394137119589714757239562e-01 8.93539048201414276562104532786179e-01
            1.97461114198633103100632979476359e-01 9.11581968539019626973640697542578e-01
            1.26226643628191831369989017730404e-01 9.24142527657071610747152590192854e-01
            5.42330311705863377103042921589804e-02 9.31145184875103226751491547474870e-01
            -1.80867451177767965542209083196212e-02 9.32547825388641671295886226289440e-01
            -9.02977455928357375380954863430816e-02 9.28342013552597711267821978253778e-01
            -1.61965684801067655307349468785105e-01 9.18553043614227626711965513095492e-01
            -2.32659543323308265483362333725381e-01 9.03239787590554232821205005166121e-01
            -3.01954159976253022623637889410020e-01 8.82494341205129373406634840648621e-01
            -3.69432788781841159320151746214833e-01 8.56441470013515560033567908249097e-01
            -4.34689605326601613555226322205272e-01 8.25237859048555399965607648482546e-01
            -4.97332147437429927805396800977178e-01 7.89071170498146123861715750535950e-01
            -5.56983675495272168021188008424360e-01 7.48158915082763220638639722892549e-01
            -6.13285438191527476625708459323505e-01 7.02747143920390504590045566146728e-01
            -6.65898830100626004657726753066527e-01 6.53108968746148432771292391407769e-01
            -7.14507428092902907579286875261459e-01 5.99542919386181427654491926659830e-01
            -7.58818894340529292996677668270422e-01 5.42371148364159116894711587519851e-01
            -7.98566734471609973589067976718070e-01 4.81937493438090058806011484193732e-01
            -8.33511900298690155963754477852490e-01 4.18605409719590759731744356031413e-01
            -8.63444227482683013263908833323512e-01 3.52755783812076784133893170292140e-01
            -8.88183699485934452511060044344049e-01 2.84784643113913715772866908082506e-01
            -9.07581530212861253836820196738699e-01 2.15100774063044869466310160532885e-01
            -9.21521058827037276017790645710193e-01 1.44123263647253946340143215820717e-01
            -9.29918451363190512459766523534199e-01 7.22789789657088399543738432839746e-02
            -9.32723204914534087528465988725657e-01 1.14225648738904502591445287930747e-16
            -9.29918451363190512459766523534199e-01 -7.22789789657090342434031526863691e-02
            -9.21521058827037387040093108225847e-01 -1.44123263647253752051113906418323e-01
            -9.07581530212861364859122659254353e-01 -2.15100774063044231088071001067874e-01
            -8.88183699485934452511060044344049e-01 -2.84784643113913493728261983051198e-01
            -8.63444227482683124286211295839166e-01 -3.52755783812076506578137014003005e-01
            -8.33511900298690378008359402883798e-01 -4.18605409719590149109080812195316e-01
            -7.98566734471610084611370439233724e-01 -4.81937493438089836761406559162424e-01
            -7.58818894340529404018980130786076e-01 -5.42371148364158894850106662488542e-01
            -7.14507428092902796556984412745805e-01 -5.99542919386181538676794389175484e-01
            -6.65898830100626226702331678097835e-01 -6.53108968746148321748989928892115e-01
            -6.13285438191528031737220771901775e-01 -7.02747143920390060500835716084111e-01
            -5.56983675495272390065792933455668e-01 -7.48158915082762998594034797861241e-01
            -4.97332147437429816783094338461524e-01 -7.89071170498146234884018213051604e-01
            -4.34689605326602612755948484846158e-01 -8.25237859048554844854095335904276e-01
            -3.69432788781841214831302977472660e-01 -8.56441470013515560033567908249097e-01
            -3.01954159976253244668242814441328e-01 -8.82494341205129262384332378132967e-01
            -2.32659543323308293238937949354295e-01 -9.03239787590554232821205005166121e-01
            -1.61965684801067683062925084414019e-01 -9.18553043614227626711965513095492e-01
            -9.02977455928357514158832941575383e-02 -9.28342013552597711267821978253778e-01
            -1.80867451177770255377197372581577e-02 -9.32547825388641671295886226289440e-01
            5.42330311705863099547286765300669e-02 -9.31145184875103226751491547474870e-01
            1.26226643628190998702720548862999e-01 -9.24142527657071721769455052708508e-01
            1.97461114198633075345057363847445e-01 -9.11581968539019626973640697542578e-01
            2.67508030394137119589714757239562e-01 -8.93539048201414276562104532786179e-01
            3.35946121818674670045368202409009e-01 -8.70122278890175349097546586563112e-01
            4.02363793737690489393798998207785e-01 -8.41472491811261269489818914735224e-01
            4.66361602457266433141569450526731e-01 -8.07761990155225428900109818641795e-01
            5.27554657625500134088269987842068e-01 -7.69193512845552485046596302709077e-01
            5.85574937008362939039329830848146e-01 -7.25999015242921430512978986371309e-01
            6.40073499818723745669046820694348e-01 -6.78438274138369989962882300460478e-01
            6.90722585287301571455031989898998e-01 -6.26797325425106133245378714491380e-01
            7.37217583854490987604890506190713e-01 -5.71386743844995548258225426252466e-01
            7.79278869128103957031328263838077e-01 -5.12539775155512522530898422701284e-01
            8.16653479589387165660241407749709e-01 -4.50610331950551612489874742095708e-01
            8.49116639933364836245743845211109e-01 -3.85970865188439371529227628343506e-01
            8.76473112893970451864333881530911e-01 -3.19010124228045921501717430146527e-01
            8.98558373423934297896664702420821e-01 -2.50130818844406577206029851367930e-01
            9.15239598167780776805102505022660e-01 -1.79747197284739590461555280853645e-01
            9.26416464277113660408247142186156e-01 -1.08282554930752353272715993171005e-01
            9.32021752764031541360623123182449e-01 -3.61666885504096369263749011224718e-02
            9.05091557790183021126040330273099e-01 3.69481531758288073152840524926432e-02
            8.99068322802685115924248293595156e-01 1.10598575664117446115675136297796e-01
            8.87061936462767319788724762474885e-01 1.83512982878841962586236036258924e-01
            8.69152299290607333048797045194078e-01 2.55206141470018688099941073232912e-01
            8.45458596966704001296477599680657e-01 3.25200945295761933984124425478512e-01
            8.16138507170836913218181507545523e-01 3.93031590484941184548972614720697e-01
            7.81387150263123331228598544839770e-01 4.58246675285091220608535422798013e-01
            7.41435790790214044321260189462919e-01 5.20412204066598271801069586217636e-01
            6.96550298457890404435488562739920e-01 5.79114475492012226176541389577324e-01
            6.47029378812039590584959114494268e-01 6.33962835630189736058071048319107e-01
            5.93202585402527682312268098030472e-01 6.84592277693753636924611782887951e-01
            5.35428126658699765627602573658805e-01 7.30665871099040908909216796018882e-01
            4.74090482071380492357093316968530e-01 7.71877003683547280310506266687298e-01
            4.09597843545300155376764905668097e-01 8.07951422159280840951112168113468e-01
            3.42379398949312963029711909257458e-01 8.38649057223146199291363700467627e-01
            2.72882475941942925778960216121050e-01 8.63765621178546161296196714829421e-01
            2.01569565079618484571000180949341e-01 8.83133967436299127662380215042504e-01
            1.28915242018326686723739271656086e-01 8.96625202847611824097384669585153e-01
            5.54030092909205199025457488914981e-02 9.04149545466719106734387878532289e-01
            -1.84779213224636300327841098578574e-02 9.05656922034920208730568447208498e-01
            -9.22358844180890119490712208971672e-02 9.01137301209853136541028106876183e-01
            -1.65380032920761949055687978216156e-01 8.90620760322423876687025767751038e-01
            -2.37423604590131981373346548025438e-01 8.74177285217131117001088114193408e-01
            -3.07887161343092186083225669790409e-01 8.51916304507818189506451744819060e-01
            -3.76301779835119698525147668988211e-01 8.23985961348302264894982727128081e-01
            -4.42212172067768360950168471390498e-01 7.90572127564127535848115257977042e-01
            -5.05179715255178685140435845823959e-01 7.51897166706233410771176295384066e-01
            -5.64785370786352047822731492487947e-01 7.08218454258209506591015269805212e-01
            -6.20632472857969186286197782465024e-01 6.59826664844917365471133052778896e-01
            -6.72349368219866905249659794208128e-01 6.07043837840819056062002800899791e-01
            -7.19591889466098755256950880720979e-01 5.50221234251073387788721902325051e-01
            -7.62045645412238625837630934256595e-01 4.89736999127500571837856568890857e-01
            -7.99428113316841160163050972187193e-01 4.25993645075651794495996682599070e-01
            -8.31490519023674989895766884728801e-01 3.59415373599828447126469654904213e-01
            -8.58019492512685388874160707928240e-01 2.90445252112060792182290924756671e-01
            -8.78838487842275473127529039629735e-01 2.19542265391580893041378885754966e-01
            -8.93808958033419309607836567010963e-01 1.47178261116844538713976930921490e-01
            -9.02831277076948546245205307059223e-01 7.38348097970790429034337876146310e-02
            -9.05845402928206477888295466982527e-01 1.10934067321837248437812520063018e-16
            -9.02831277076948546245205307059223e-01 -7.38348097970788208588288625833229e-02
            -8.93808958033419420630139029526617e-01 -1.47178261116843955846889002714306e-01
            -8.78838487842275473127529039629735e-01 -2.19542265391581059574832579528447e-01
            -8.58019492512685388874160707928240e-01 -2.90445252112060570137685999725363e-01
            -8.31490519023675100918069347244455e-01 -3.59415373599828225081864729872905e-01
            -7.99428113316841271185353434702847e-01 -4.25993645075651627962542988825589e-01
            -7.62045645412238514815328471740941e-01 -4.89736999127500682860159031406511e-01
            -7.19591889466098977301555805752287e-01 -5.50221234251073276766419439809397e-01
            -6.72349368219866794227357331692474e-01 -6.07043837840819167084305263415445e-01
            -6.20632472857969408330802707496332e-01 -6.59826664844917143426528127747588e-01
            -5.64785370786352269867336417519255e-01 -7.08218454258209395568712807289558e-01
            -5.05179715255178907185040770855267e-01 -7.51897166706233188726571370352758e-01
            -4.42212172067768471972470933906152e-01 -7.90572127564127424825812795461388e-01
            -3.76301779835119920569752594019519e-01 -8.23985961348302153872680264612427e-01
            -3.07887161343092019549771976016928e-01 -8.51916304507818189506451744819060e-01
            -2.37423604590132591996010091861535e-01 -8.74177285217130894956483189162100e-01
            -1.65380032920761782522234284442675e-01 -8.90620760322423876687025767751038e-01
            -9.22358844180896225717347647332645e-02 -9.01137301209853136541028106876183e-01
            -1.84779213224632518630663469139108e-02 -9.05656922034920208730568447208498e-01
            5.54030092909200896911237066433387e-02 -9.04149545466719217756690341047943e-01
            1.28915242018326270390105037222384e-01 -8.96625202847611824097384669585153e-01
            2.01569565079618290281970871546946e-01 -8.83133967436299127662380215042504e-01
            2.72882475941942703734355291089742e-01 -8.63765621178546272318499177345075e-01
            3.42379398949312185873594671647879e-01 -8.38649057223146421335968625498936e-01
            4.09597843545300099865613674410270e-01 -8.07951422159280840951112168113468e-01
            4.74090482071379881734429773132433e-01 -7.71877003683547613377413654234260e-01
            5.35428126658699765627602573658805e-01 -7.30665871099040797886914333503228e-01
            5.93202585402528015379175485577434e-01 -6.84592277693753525902309320372296e-01
            6.47029378812039146495749264431652e-01 -6.33962835630190069124978435866069e-01
            6.96550298457890626480093487771228e-01 -5.79114475492011893109634002030361e-01
            7.41435790790213711254352801915957e-01 -5.20412204066598715890279436280252e-01
            7.81387150263123220206296082324116e-01 -4.58246675285091442653140347829321e-01
            8.16138507170836802195879045029869e-01 -3.93031590484941462104728771009832e-01
            8.45458596966704001296477599680657e-01 -3.25200945295762100517578119251993e-01
            8.69152299290607333048797045194078e-01 -2.55206141470018799122243535748567e-01
            8.87061936462767319788724762474885e-01 -1.83512982878841962586236036258924e-01
            8.99068322802685115924248293595156e-01 -1.10598575664118195516216758278460e-01
            9.05091557790183021126040330273099e-01 -3.69481531758286615985120704408473e-02
            8.75277005643476990748297339450801e-01 3.76912690570991582017512655511382e-02
            8.68796760926172084715801702259341e-01 1.12794754202213451388381315609877e-01
            8.55884248956210957892665192048298e-01 1.87063146450626716088549983396661e-01
            8.36635069454528812471494347846601e-01 2.59946588610355855397671120954328e-01
            8.11191736611460822992114572116407e-01 3.30905477175322981775451580688241e-01
            7.79742623961538261490034074085997e-01 3.99414457360923624840154388948577e-01
            7.42520569731744517483207346231211e-01 4.64966312647047075312656261303346e-01
            6.99801152988746233418737574538682e-01 5.27075720031730643455603058100678e-01
            6.51900653347899705636336875613779e-01 5.85282843192868162951469912513858e-01
            5.99173709349635541521195136738243e-01 6.39156736955454829463008081802400e-01
            5.42010692839782204366372297954513e-01 6.88298537858889614149404678755673e-01
            4.80834818792999274528199293854414e-01 7.32344417202486330786825874383794e-01
            4.16099011977173693921372432669159e-01 7.70968274705883027664299333991949e-01
            3.48282553656904136918370795683586e-01 8.03884152841422561230899646034231e-01
            2.77887533162702593525494876303128e-01 8.30848353963642205499695592152420e-01
            2.05435130597257736839722497279581e-01 8.51661244561376928885465531493537e-01
            1.31461758200298733934019423941209e-01 8.66168733274430779900399102189112e-01
            5.65150889400469411127936325556220e-02 8.74263411732096096251609651517356e-01
            -1.88499982658271204860600533947945e-02 8.75885349767150933608661489415681e-01
            -9.40755266795751110553425178295583e-02 8.71022539117849992074127385421889e-01
            -1.68604552807918028900502349642920e-01 8.59710982332893114410410362324910e-01
            -2.41885289816814175178905088614556e-01 8.42034426221150211766541815450182e-01
            -3.13375192768123034259275527801947e-01 8.18123741819590244439552861877019e-01
            -3.82544975432509704038608333576121e-01 7.88155955469909796917704625229817e-01
            -4.48882528939504032994278759360895e-01 7.52352938177436203481818211002974e-01
            -5.11896713252409263361641933443025e-01 7.10979762955828875625741147814551e-01
            -5.71120993397294829385657521925168e-01 6.64342742319228740655034926021472e-01
            -6.26116893524720774522052124666516e-01 6.12787160451571000230330810154555e-01
            -6.76477243231515812382781405176502e-01 5.56694716843293302410700107429875e-01
            -7.21829192107987571702665263728704e-01 4.96480700321851209366741386475042e-01
            -7.61836970191904883087374855676899e-01 4.32590914398539583274327924300451e-01
            -7.96204373891824412901030427747173e-01 3.65498376695264970415166771999793e-01
            -8.24676958974848606231944359024055e-01 2.95699816887569022494375303722336e-01
            -8.47043924382703705688868467404973e-01 2.23711999091900481939632072680979e-01
            -8.63139672929022605529780776123516e-01 1.50067895924897137804876479094673e-01
            -8.72845037322975469962216266139876e-01 7.53127425606028993998464216019784e-02
            -8.76088162442197337931304446101421e-01 1.07289856390572341297603958791920e-16
            -8.72845037322975469962216266139876e-01 -7.53127425606026912330293043851270e-02
            -8.63139672929022605529780776123516e-01 -1.50067895924896943515847169692279e-01
            -8.47043924382703816711170929920627e-01 -2.23711999091900287650602763278584e-01
            -8.24676958974848606231944359024055e-01 -2.95699816887568855960921609948855e-01
            -7.96204373891824301878727965231519e-01 -3.65498376695265136948620465773274e-01
            -7.61836970191904994109677318192553e-01 -4.32590914398539361229722999269143e-01
            -7.21829192107987793747270188760012e-01 -4.96480700321850987322136461443733e-01
            -6.76477243231516034427386330207810e-01 -5.56694716843293191388397644914221e-01
            -6.26116893524720996566657049697824e-01 -6.12787160451570778185725885123247e-01
            -5.71120993397294940407959984440822e-01 -6.64342742319228518610430000990164e-01
            -5.11896713252409485406246858474333e-01 -7.10979762955828764603438685298897e-01
            -4.48882528939504643616942303196993e-01 -7.52352938177435981437213285971666e-01
            -3.82544975432509259949398483513505e-01 -7.88155955469910018962309550261125e-01
            -3.13375192768123422837334146606736e-01 -8.18123741819590244439552861877019e-01
            -2.41885289816814563756963707419345e-01 -8.42034426221150100744239352934528e-01
            -1.68604552807918639523165893479018e-01 -8.59710982332892892365805437293602e-01
            -9.40755266795755135111889444488042e-02 -8.71022539117849881051824922906235e-01
            -1.88499982658275333502473358748830e-02 -8.75885349767150933608661489415681e-01
            5.65150889400465317180533020291477e-02 -8.74263411732096096251609651517356e-01
            1.31461758200298317600385189507506e-01 -8.66168733274430890922701564704766e-01
            2.05435130597258069906629884826543e-01 -8.51661244561376928885465531493537e-01
            2.77887533162702204947436257498339e-01 -8.30848353963642427544300517183729e-01
            3.48282553656903748340312176878797e-01 -8.03884152841422783275504571065539e-01
            4.16099011977174026988279820216121e-01 -7.70968274705882805619694408960640e-01
            4.80834818792998885950140675049624e-01 -7.32344417202486663853733261930756e-01
            5.42010692839781982321767372923205e-01 -6.88298537858889725171707141271327e-01
            5.99173709349635652543497599253897e-01 -6.39156736955454607418403156771092e-01
            6.51900653347899261547127025551163e-01 -5.85282843192868607040679762576474e-01
            6.99801152988746344441040037054336e-01 -5.27075720031730421410998133069370e-01
            7.42520569731744184416299958684249e-01 -4.64966312647047463890714880108135e-01
            7.79742623961537928423126686539035e-01 -3.99414457360924179951666701526847e-01
            8.11191736611460934014417034632061e-01 -3.30905477175322759730846655656933e-01
            8.36635069454528701449191885330947e-01 -2.59946588610356410509183433532598e-01
            8.55884248956210846870362729532644e-01 -1.87063146450627271200062295974931e-01
            8.68796760926172195738104164774995e-01 -1.12794754202213257099352006207482e-01
            8.75277005643476990748297339450801e-01 -3.76912690570997549466270015727787e-02
            8.42827003309541966658002820622642e-01 3.84007288813954447692644578182808e-02
            8.35843073322763863153284091822570e-01 1.14883986110867142294011955527822e-01
            8.21933084392575619148146870429628e-01 1.90415278450213415473157851920405e-01
            8.01212299068022049119974781206110e-01 2.64368729823516612764677802260849e-01
            7.73852416302043155660328466183273e-01 3.36131538642023997009999902729760e-01
            7.40080148699875373097256670007482e-01 4.05109055671106166318651276014862e-01
            7.00175343907004976706787147122668e-01 4.70729711481092272240545071326778e-01
            6.54468665703442753489582628390053e-01 5.32449752651572350004016698221676e-01
            6.03338854019504267078843895433238e-01 5.89757747483486971518118480162229e-01
            5.47209586577469431212250583485002e-01 6.42178823883254534798936674633296e-01
            4.86545968164542153022722459354554e-01 6.89278604302493436151166861236561e-01
            4.21850676628106602272794134478318e-01 7.30666805127189067370352404395817e-01
            3.53659797528770136754161512726569e-01 7.66000470690635038018001523596467e-01
            2.82538381966576879200658822810510e-01 7.94986815112096012470033201680053e-01
            2.09075764389635682105605951619509e-01 8.17385648412825238651180370652582e-01
            1.33880679183281225963497718112194e-01 8.33011366805872843777081016014563e-01
            5.75762165052427984934801941108162e-02 8.41734490667518264750412981811678e-01
            -1.92053408356351665298156206063140e-02 8.43482737446210051324158030183753e-01
            -9.58277566738780228750016476624296e-02 8.38241620618552452093297233659541e-01
            -1.71656113540620741675368776668620e-01 8.26054569729200549588199464778882e-01
            -2.46062073789715146654444311025145e-01 8.07022570519976167879860895482125e-01
            -3.18429086201352240514950153738027e-01 7.81303328130206309332095315767219e-01
            -3.88157494919643686337451526924269e-01 7.49109960302272170906690007541329e-01
            -4.54669508389898280320551293698372e-01 7.10709231420876719198531645815820e-01
            -5.17413987121411289571426550537581e-01 6.66419342019339278060385822755052e-01
            -5.75871010602860056160068324970780e-01 6.16607292069762724651127427932806e-01
            -6.29556185527401113155576695135096e-01 5.61685839905683992334672893775860e-01
            -6.78024659628165049518599971634103e-01 5.02110081976528288549843637156300e-01
            -7.20874807864239963706154412648175e-01 4.38373681775104107050111679200199e-01
            -7.57751560412247671116858782625059e-01 3.71004779186426214554472835516208e-01
            -7.88349344886723701897324190213112e-01 3.00561614154300604795366780308541e-01
            -8.12414618409139976940025462681660e-01 2.27627900929338183866335043603613e-01
            -8.29747968544046088368304481264204e-01 1.52807991228841644204550220820238e-01
            -8.40205765693312289776883972081123e-01 7.67218663881417545225005483189307e-02
            -8.43701353256212982500983343925327e-01 1.03323616170151151899436104222866e-16
            -8.40205765693312289776883972081123e-01 -7.67218663881415602334712389165361e-02
            -8.29747968544046199390606943779858e-01 -1.52807991228841061337462292613054e-01
            -8.12414618409139976940025462681660e-01 -2.27627900929337989577305734201218e-01
            -7.88349344886723812919626652728766e-01 -3.00561614154300382750761855277233e-01
            -7.57751560412247782139161245140713e-01 -3.71004779186425992509867910484900e-01
            -7.20874807864240296773061800195137e-01 -4.38373681775103551938599366621929e-01
            -6.78024659628164938496297509118449e-01 -5.02110081976528510594448562187608e-01
            -6.29556185527401224177879157650750e-01 -5.61685839905683770290067968744552e-01
            -5.75871010602860500249278175033396e-01 -6.16607292069762280561917577870190e-01
            -5.17413987121411400593729013053235e-01 -6.66419342019339167038083360239398e-01
            -4.54669508389898446854004987471853e-01 -7.10709231420876608176229183300165e-01
            -3.88157494919644241448963839502539e-01 -7.49109960302272059884387545025675e-01
            -3.18429086201352407048403847511509e-01 -7.81303328130206198309792853251565e-01
            -2.46062073789715729521532239232329e-01 -8.07022570519975945835255970450817e-01
            -1.71656113540620769430944392297533e-01 -8.26054569729200549588199464778882e-01
            -9.58277566738782310418187648792809e-02 -8.38241620618552341070994771143887e-01
            -1.92053408356357493969035488134978e-02 -8.43482737446210051324158030183753e-01
            5.75762165052427915545862902035879e-02 -8.41734490667518264750412981811678e-01
            1.33880679183280809629863483678491e-01 -8.33011366805872954799383478530217e-01
            2.09075764389635126994093639041239e-01 -8.17385648412825349673482833168237e-01
            2.82538381966576712667205129037029e-01 -7.94986815112096012470033201680053e-01
            3.53659797528769748176102893921779e-01 -7.66000470690635149040303986112121e-01
            4.21850676628106602272794134478318e-01 -7.30666805127189067370352404395817e-01
            4.86545968164542097511571228096727e-01 -6.89278604302493658195771786267869e-01
            5.47209586577468987123040733422386e-01 -6.42178823883254867865844062180258e-01
            6.03338854019504267078843895433238e-01 -5.89757747483486971518118480162229e-01
            6.54468665703442420422675240843091e-01 -5.32449752651572572048621623252984e-01
            7.00175343907004643639879759575706e-01 -4.70729711481092827352057383905048e-01
            7.40080148699875262074954207491828e-01 -4.05109055671106332852104969788343e-01
            7.73852416302042933615723541151965e-01 -3.36131538642024385588058521534549e-01
            8.01212299068022049119974781206110e-01 -2.64368729823516557253526571003022e-01
            8.21933084392575508125844407913974e-01 -1.90415278450213665273338392580627e-01
            8.35843073322763752130981629306916e-01 -1.14883986110867655772160844662722e-01
            8.42827003309541966658002820622642e-01 -3.84007288813955072193095929833362e-02
            8.07934198891021138067003448668402e-01 3.90796677700818995138121181298629e-02
            8.00390734961966665572674628492678e-01 1.16874126981718354234551782155904e-01
            7.85374238394087931247611322760349e-01 1.93577363959741621801668998159585e-01
            7.63024914169865065005637916328851e-01 2.68473221247047422188813925458817e-01
            7.33551431907882522942543346289312e-01 3.40862416403731716130209861148614e-01
            6.97228977570824470788579674263019e-01 4.10069071018820785479164214848424e-01
            6.54396684128284333858971422159811e-01 4.75447021204889297418816340723424e-01
            6.05454465163603572364081628620625e-01 5.36385850656177165518556648748927e-01
            5.50859280988493793529414688237011e-01 5.92316589941169424626821182755521e-01
            4.91120872127728924638745411357377e-01 6.42717028816877422592312996130204e-01
            4.26797000009205396153788569790777e-01 6.87116591965176048972807620884851e-01
            3.58488239295772559422914582683006e-01 7.25100732627758981507781754771713e-01
            2.86832370481420351193690976288053e-01 7.56314803117527967302180513797794e-01
            2.12498425106648292093325380847091e-01 7.80467366068492429675984567438718e-01
            1.36180439191231655859937177410757e-01 7.97332915507932060705797994160093e-01
            5.85909732069036029433739543037518e-02 8.06753982344905362644738033850444e-01
            -1.95455409077810414453235665632747e-02 8.08642604616723215116280698566698e-01
            -9.74995635732681803498067552027351e-02 8.02981148766095276236853806040017e-01
            -1.74543259083495799766083678150608e-01 7.89822474280902908638779535976937e-01
            -2.49957291211775678441142645169748e-01 7.69289440159402926333598315977724e-01
            -3.23037539459328115754033206030726e-01 7.41573757808863476270744286011904e-01
            -3.93101673238664628406979772989871e-01 7.06934201087808578023441441473551e-01
            -4.59495522610437578947539805085398e-01 6.65694190204223379403458693559514e-01
            -5.21599186091909916562769922165899e-01 6.18238772028213312559330461226637e-01
            -5.78832818510073510154256837267894e-01 5.65011025013123280302806961117312e-01
            -6.30662044859801151908129668299807e-01 5.06507922291399292902269735350274e-01
            -6.76602949619288462912436443730257e-01 4.43275691570352792236775485434919e-01
            -7.16226594938897176412240241916152e-01 3.75904715151231916259177978645312e-01
            -7.49163025518286951331958789523924e-01 3.05024017688742654641487206390593e-01
            -7.75104722779375143737468079052633e-01 2.31295393157330164690677065664204e-01
            -7.93809476084443521592959314148175e-01 1.55407225859151065794350188298267e-01
            -8.05102644191603711298910184268607e-01 7.80680631653167811379034901619889e-02
            -8.08878785833017088791052628948819e-01 9.90590815968601867457290776713322e-17
            -8.05102644191603711298910184268607e-01 -7.80680631653165729710863729451376e-02
            -7.93809476084443521592959314148175e-01 -1.55407225859150871505320878895873e-01
            -7.75104722779375032715165616536979e-01 -2.31295393157330358979706375066598e-01
            -7.49163025518287173376563714555232e-01 -3.05024017688742155041126125070150e-01
            -7.16226594938897287434542704431806e-01 -3.75904715151231749725724284871831e-01
            -6.76602949619288573934738906245911e-01 -4.43275691570352625703321791661438e-01
            -6.30662044859801151908129668299807e-01 -5.06507922291399181879967272834620e-01
            -5.78832818510073621176559299783548e-01 -5.65011025013123169280504498601658e-01
            -5.21599186091909472473560072103282e-01 -6.18238772028213645626237848773599e-01
            -4.59495522610437745480993498858879e-01 -6.65694190204223268381156231043860e-01
            -3.93101673238665072496189623052487e-01 -7.06934201087808244956534053926589e-01
            -3.23037539459328004731730743515072e-01 -7.41573757808863587293046748527559e-01
            -2.49957291211775844974596338943229e-01 -7.69289440159402815311295853462070e-01
            -1.74543259083496493655474068873446e-01 -7.89822474280902797616477073461283e-01
            -9.74995635732680138163530614292540e-02 -8.02981148766095387259156268555671e-01
            -1.95455409077812392037998279192834e-02 -8.08642604616723215116280698566698e-01
            5.85909732069035821266922425820667e-02 -8.06753982344905362644738033850444e-01
            1.36180439191231822393390871184238e-01 -7.97332915507932060705797994160093e-01
            2.12498425106647931270842377671215e-01 -7.80467366068492540698287029954372e-01
            2.86832370481420351193690976288053e-01 -7.56314803117527967302180513797794e-01
            3.58488239295772059822553501362563e-01 -7.25100732627759314574689142318675e-01
            4.26797000009205118598032413501642e-01 -6.87116591965176159995110083400505e-01
            4.91120872127728758105291717583896e-01 -6.42717028816877533614615458645858e-01
            5.50859280988493460462507300690049e-01 -5.92316589941169868716031032818137e-01
            6.05454465163603683386384091136279e-01 -5.36385850656176943473951723717619e-01
            6.54396684128284222836668959644157e-01 -4.75447021204889463952270034496905e-01
            6.97228977570824137721672286716057e-01 -4.10069071018821396101827758684522e-01
            7.33551431907882744987148271320621e-01 -3.40862416403731494085604936117306e-01
            7.63024914169864953983335453813197e-01 -2.68473221247047644233418850490125e-01
            7.85374238394087709203006397729041e-01 -1.93577363959742371202210620140249e-01
            8.00390734961966665572674628492678e-01 -1.16874126981718159945522472753510e-01
            8.07934198891021027044700986152748e-01 -3.90796677700822117640377939551399e-02
            7.70753225739730929433335404610261e-01 3.97300948309221163556870237698604e-02
            7.62583049805976354029724006977631e-01 1.18769135603870215622812622768834e-01
            7.46329303835866375571583830605960e-01 1.96549193993121817936042816654663e-01
            7.22164281580141786953674909455003e-01 2.72245782030341831880804193133372e-01
            6.90344138286265840420696804358158e-01 3.45056497051233201922570970054949e-01
            6.51206175389076880044569861638593e-01 4.14209527363393115173550995677942e-01
            6.05165265031668231365813426236855e-01 4.78971833642256594743003006442450e-01
            5.52709452317463378889783598424401e-01 5.38656919330295358427918017696356e-01
            4.94394781910708791539121875757701e-01 5.92632107671308472340854223148199e-01
            4.30839403824704481049678861381835e-01 6.40325248241429112461275963141816e-01
            3.62717020877885598650891552097164e-01 6.81230781885952541010453842318384e-01
            2.90749747276350001268241385332658e-01 7.14915099772143070033791900641518e-01
            2.15700454023631166267094272370741e-01 7.41021139750732138473665600031381e-01
            1.38364682298282803962763409799663e-01 7.59272171303525422736413474922301e-01
            5.95622105194767020863721995738160e-02 7.69474728955739206703867694159271e-01
            -1.98716355081757327372127264197843e-02 7.71520663058161360048359256325057e-01
            -9.90948372559583984253706034905917e-02 7.65388286200337497611201342806453e-01
            -1.77267609076923821076476883717987e-01 7.51142603102517236735025107918773e-01
            -2.53561300142665202450587003113469e-01 7.28934621549447325783432916068705e-01
            -3.27167178348241105556581942437333e-01 6.98999751670288493876626034762012e-01
            -3.97305003073677664993113012315007e-01 6.61655310532681895097084634471685e-01
            -4.63231295928641373382816937009920e-01 6.17297158502893239528930280357599e-01
            -5.24247221808331276271530896337936e-01 5.66395503027452562605503771919757e-01
            -5.79705996719440563857972392725060e-01 5.09489914317245995434291216952261e-01
            -6.29019743851386370359080046910094e-01 4.47183605769052139322639050078578e-01
            -6.71665725216748943360300927452045e-01 3.80137039753472905090347921941429e-01
            -7.07191882803979376959091496246401e-01 3.09060926549503067750634954791167e-01
            -7.35221630504781731296759517135797e-01 2.34708690638768063818631048889074e-01
            -7.55457846020544110388073022477329e-01 1.57868484218588261969173913712439e-01
            -7.67686020432619464770596096059307e-01 7.93548325926185238454735326740774e-02
            -7.71776532050226782288859794789460e-01 9.45153659632354916796228317809296e-17
            -7.67686020432619464770596096059307e-01 -7.93548325926183295564442232716829e-02
            -7.55457846020544221410375484992983e-01 -1.57868484218587762368812832391995e-01
            -7.35221630504781842319061979651451e-01 -2.34708690638767869529601739486679e-01
            -7.07191882803979376959091496246401e-01 -3.09060926549503178772937417306821e-01
            -6.71665725216748832337998464936391e-01 -3.80137039753473016112650384457083e-01
            -6.29019743851386703425987434457056e-01 -4.47183605769051695233429200015962e-01
            -5.79705996719440785902577317756368e-01 -5.09489914317245884411988754436607e-01
            -5.24247221808331387293833358853590e-01 -5.66395503027452451583201309404103e-01
            -4.63231295928641262360514474494266e-01 -6.17297158502893461573535205388907e-01
            -3.97305003073678109082322862377623e-01 -6.61655310532681673052479709440377e-01
            -3.27167178348241272090035636210814e-01 -6.98999751670288382854323572246358e-01
            -2.53561300142665202450587003113469e-01 -7.28934621549447325783432916068705e-01
            -1.77267609076924514965867274440825e-01 -7.51142603102517014690420182887465e-01
            -9.90948372559582457697047175315674e-02 -7.65388286200337497611201342806453e-01
            -1.98716355081760900902487776420458e-02 -7.71520663058161360048359256325057e-01
            5.95622105194765216751306979858782e-02 -7.69474728955739206703867694159271e-01
            1.38364682298282609673734100397269e-01 -7.59272171303525422736413474922301e-01
            2.15700454023631166267094272370741e-01 -7.41021139750732138473665600031381e-01
            2.90749747276350001268241385332658e-01 -7.14915099772143070033791900641518e-01
            3.62717020877885321095135395808029e-01 -6.81230781885952652032756304834038e-01
            4.30839403824704259005073936350527e-01 -6.40325248241429445528183350688778e-01
            4.94394781910708736027970644499874e-01 -5.92632107671308583363156685663853e-01
            5.52709452317463378889783598424401e-01 -5.38656919330295469450220480212010e-01
            6.05165265031667787276603576174239e-01 -4.78971833642257149854515319020720e-01
            6.51206175389076991066872324154247e-01 -4.14209527363393004151248533162288e-01
            6.90344138286265729398394341842504e-01 -3.45056497051233590500629588859738e-01
            7.22164281580142008998279834486311e-01 -2.72245782030341443302745574328583e-01
            7.46329303835866264549281368090305e-01 -1.96549193993121984469496510428144e-01
            7.62583049805976243007421544461977e-01 -1.18769135603870923389990821306128e-01
            7.70753225739730929433335404610261e-01 -3.97300948309220261500662729758915e-02
            7.31411483342695678544487236649729e-01 4.03530960290954809899233168835053e-02
            7.22533138731167534629662441147957e-01 1.20569456165245739165392535596766e-01
            7.04884220584771070683416382962605e-01 1.99322266431263550590102795467828e-01
            6.78678962861945178630662667274009e-01 2.75655574391903412934112793664099e-01
            6.44235461892862293353800851036794e-01 3.48642797092362399791198868115316e-01
            6.01971815120884157224168120592367e-01 4.17397968520168860528940513177076e-01
            5.52401045965969283990659732808126e-01 4.81086494032412936849851803344791e-01
            4.96124876415315274602590989161399e-01 5.38935281204138583177609689300880e-01
            4.33826422933547006799415157729527e-01 5.90242124123125488921459691482596e-01
            3.66261904354212075585195407256833e-01 6.34384227218427798611344314849703e-01
            2.94251462407540909094194603312644e-01 6.70825765154946518364909024967346e-01
            2.18669206310836722328971859496960e-01 6.99124387027147409234828501212178e-01
            1.40432602266675699009823574670008e-01 7.18936585899831226420531038456829e-01
            6.04913366660416798592514453503100e-02 7.30021868516999572484849068132462e-01
            -2.01842118179818806600334113454664e-02 7.32245674564201642908756184624508e-01
            -1.00614751312793057613781400050357e-01 7.25581010048471863882468824158423e-01
            -1.79823964023021032332394497643691e-01 7.10108774968837397345566841977416e-01
            -2.56850357406006479799032149458071e-01 6.86016781299920164194361404952360e-01
            -3.30758935388798025467593788562226e-01 6.53597473208981094572322945168708e-01
            -4.00652547953897375521137291798368e-01 6.13244377179885558071248397027375e-01
            -4.65682781325160777274874135400751e-01 5.65447325134674438906756677170051e-01
            -5.25060256561749927328719422803260e-01 5.10786508537574013288917740283068e-01
            -5.78064211549151996116790996893542e-01 4.49925435656568506459507261752151e-01
            -6.24051250074880492491047334624454e-01 3.83602877471839076584103622735711e-01
            -6.62463151786925719122223199519794e-01 3.12623899996830767467059786213213e-01
            -6.92833648232644927489332076220307e-01 2.37850091867418483859708544514433e-01
            -7.14794082726151747131382307998138e-01 1.60189105823008770546067580653471e-01
            -7.28077885341087971404760992299998e-01 8.05836410318210849546005647425773e-02
            -7.32523808708424040148088351998013e-01 8.97082937633999550468313551661177e-17
            -7.28077885341087971404760992299998e-01 -8.05836410318208906655712553401827e-02
            -7.14794082726151747131382307998138e-01 -1.60189105823008604012613886879990e-01
            -6.92833648232645038511634538735962e-01 -2.37850091867418317326254850740952e-01
            -6.62463151786925830144525662035448e-01 -3.12623899996830323377849936150596e-01
            -6.24051250074880381468744872108800e-01 -3.83602877471839243117557316509192e-01
            -5.78064211549152218161395921924850e-01 -4.49925435656568450948356030494324e-01
            -5.25060256561750038351021885318914e-01 -5.10786508537573902266615277767414e-01
            -4.65682781325160943808327829174232e-01 -5.65447325134674327884454214654397e-01
            -4.00652547953897542054590985571849e-01 -6.13244377179885447048945934511721e-01
            -3.30758935388798192001047482335707e-01 -6.53597473208980983550020482653053e-01
            -2.56850357406006646332485843231552e-01 -6.86016781299920053172058942436706e-01
            -1.79823964023021032332394497643691e-01 -7.10108774968837397345566841977416e-01
            -1.00614751312793085369357015679270e-01 -7.25581010048471863882468824158423e-01
            -2.01842118179818980072681711135374e-02 -7.32245674564201642908756184624508e-01
            6.04913366660410137254366702563857e-02 -7.30021868516999683507151530648116e-01
            1.40432602266675699009823574670008e-01 -7.18936585899831226420531038456829e-01
            2.18669206310836722328971859496960e-01 -6.99124387027147409234828501212178e-01
            2.94251462407540409493833521992201e-01 -6.70825765154946629387211487483000e-01
            3.66261904354212075585195407256833e-01 -6.34384227218427798611344314849703e-01
            4.33826422933546507199054076409084e-01 -5.90242124123125710966064616513904e-01
            4.96124876415315274602590989161399e-01 -5.38935281204138694199912151816534e-01
            5.52401045965969395012962195323780e-01 -4.81086494032412770316398109571310e-01
            6.01971815120883824157260733045405e-01 -4.17397968520169304618150363239693e-01
            6.44235461892862404376103313552449e-01 -3.48642797092362288768896405599662e-01
            6.78678962861945067608360204758355e-01 -2.75655574391903912534473874984542e-01
            7.04884220584770959661113920446951e-01 -1.99322266431264077946039492417185e-01
            7.22533138731167645651964903663611e-01 -1.20569456165245628143090073081112e-01
            7.31411483342695678544487236649729e-01 -4.03530960290959875291783021111769e-02
            6.90015925514976591337301670137094e-01 4.09488939258577516744352919886296e-02
            6.80329614454308839732732394622872e-01 1.22271849067936713706394868950156e-01
            6.61092966907609436155723869887879e-01 2.01878375472300503057354603697604e-01
            6.32576023239182716473294476600131e-01 2.78650972007889796699942053237464e-01
            5.95179098828221841976926498318790e-01 3.51511919706951947439677041984396e-01
            5.49427164518387245450981026806403e-01 4.19438410576959186393253276037285e-01
            4.95962477177912364201262107599177e-01 4.81476905582801095739853280974785e-01
            4.35535563821017379648736778108287e-01 5.36756520244653700935089091217378e-01
            3.68994685853805348685341414238792e-01 5.84501249947074308366268269310240e-01
            2.97273931343532860083200830558781e-01 6.24040863342779306144336715078680e-01
            2.21380102469690892563747297572263e-01 6.54820310931594318226700579543831e-01
            1.42378582228344235938166661981086e-01 6.76407516738753655793914276728174e-01
            6.13783787902126010127545896466472e-02 6.88499443714463699173222721583443e-01
            -2.04834425430678659929562002162129e-02 6.90926347709816091047230202093488e-01
            -1.02057721243303603508856269854732e-01 6.83654160312555214673579939699266e-01
            -1.82199333250567196973435102336225e-01 6.66784967092907354668795960606076e-01
            -2.59783266004857016362450394808548e-01 6.40555574545948802622774564952124e-01
            -3.33720411156380569739354768898920e-01 6.05334185847501204946752295654733e-01
            -4.02972853259431551542490979045397e-01 5.61615232088654603437305468105478e-01
            -4.66568439830108427912591650965624e-01 5.10012431547054778668837116128998e-01
            -5.23614428236203854893915377033409e-01 4.51250174427571981716766913450556e-01
            -5.73310017846845210165440676064463e-01 3.86153354011707083959237252202001e-01
            -6.14957591517974577755012433044612e-01 3.15635786964109432695124723977642e-01
            -6.47972508607857045070943513564998e-01 2.40687385349713262039372807521431e-01
            -6.71891312050141076284148766717408e-01 1.62360260438263070970066337395110e-01
            -6.86378234275161314137392309930874e-01 8.17539533683392105611886790939025e-02
            -6.91229910650603129873559282714268e-01 8.46512497553172027902609844933871e-17
            -6.86378234275161314137392309930874e-01 -8.17539533683393493390667572384700e-02
            -6.71891312050141298328753691748716e-01 -1.62360260438262626880856487332494e-01
            -6.47972508607857156093245976080652e-01 -2.40687385349713095505919113747950e-01
            -6.14957591517974688777314895560266e-01 -3.15635786964109321672822261461988e-01
            -5.73310017846845321187743138580117e-01 -3.86153354011707028448086020944174e-01
            -5.23614428236204187960822764580371e-01 -4.51250174427571593138708294645767e-01
            -4.66568439830108760979499038512586e-01 -5.10012431547054445601929728582036e-01
            -4.02972853259431718075944672818878e-01 -5.61615232088654603437305468105478e-01
            -3.33720411156380458717052306383266e-01 -6.05334185847501204946752295654733e-01
            -2.59783266004857182895904088582029e-01 -6.40555574545948691600472102436470e-01
            -1.82199333250567224729010717965139e-01 -6.66784967092907354668795960606076e-01
            -1.02057721243303936575763657401694e-01 -6.83654160312555103651277477183612e-01
            -2.04834425430680359958568459433081e-02 -6.90926347709816091047230202093488e-01
            6.13783787902121222290752200478892e-02 -6.88499443714463810195525184099097e-01
            1.42378582228344513493922818270221e-01 -6.76407516738753655793914276728174e-01
            2.21380102469691059097200991345744e-01 -6.54820310931594318226700579543831e-01
            2.97273931343532527016293443011818e-01 -6.24040863342779417166639177594334e-01
            3.68994685853805348685341414238792e-01 -5.84501249947074308366268269310240e-01
            4.35535563821016991070678159303498e-01 -5.36756520244653922979694016248686e-01
            4.95962477177912197667808413825696e-01 -4.81476905582801262273306974748266e-01
            5.49427164518387245450981026806403e-01 -4.19438410576959186393253276037285e-01
            5.95179098828221508910019110771827e-01 -3.51511919706952169484281967015704e-01
            6.32576023239182716473294476600131e-01 -2.78650972007889852211093284495291e-01
            6.61092966907609547178026332403533e-01 -2.01878375472300336523900909924123e-01
            6.80329614454308728710429932107218e-01 -1.22271849067936921873211986167007e-01
            6.90015925514976591337301670137094e-01 -4.09488939258577377966474841741729e-02
            6.46657504657023540772797787212767e-01 4.15167892717749273390204223233013e-02
            6.36039406308366861431125016679289e-01 1.23868663283275851072495754578995e-01
            6.14977558492385334432128729531541e-01 2.04186617268199394059635665144015e-01
            5.83817796167931168938025621173438e-01 2.81151832642622889757433313207002e-01
            5.43071761770913541411687219806481e-01 3.53500542697916475542996295189369e-01
            4.93408504059647035067115439233021e-01 4.20044783615160122192122571505024e-01
            4.35643492352735250960904522798955e-01 4.79691900798207837564035571631393e-01
            3.70725226545406072453658907761564e-01 5.31462490231947359831110588856973e-01
            2.99719662767453376428505862349994e-01 5.74506480269151964535012666601688e-01
            2.23792710413056594731529003183823e-01 6.08117089783425823767970541666728e-01
            1.44191087940760603869350120476156e-01 6.31742433495760424833065371785779e-01
            6.22218517908552787298859243492188e-02 6.44994583915556862763196477317251e-01
            -2.07690654452401084195667380072337e-02 6.47655941099297582930205408047186e-01
            -1.03418955200916304337788176326285e-01 6.39682805635602758087543406873010e-01
            -1.84370708571364810834936065475631e-01 6.21206096188356982068512479600031e-01
            -2.62295100004274861493769321896252e-01 5.92529199815867935186020076798741e-01
            -3.35912613146654326357065656338818e-01 5.54122990363756340315148918307386e-01
            -4.04014450467971020231061629601754e-01 5.06618096729428812885487332096091e-01
            -4.65482381682185974991483590201824e-01 4.50794547953017210595305641618324e-01
            -5.19307105058134488295706887583947e-01 3.87568965162105094623967715961044e-01
            -5.64604820126048290163112142181490e-01 3.17979510678153665104161973431474e-01
            -6.00631739656835139662405254057376e-01 2.43168841419884984578203557248344e-01
            -6.26796302627817603081439301604405e-01 1.64365346508266979563828158461547e-01
            -6.42668887638370267545440128742484e-01 8.28629771511088103475017874188779e-02
            -6.47988867281441338619174530322198e-01 7.93557492199336220684249091768725e-17
            -6.42668887638370378567742591258138e-01 -8.28629771511086576918359014598536e-02
            -6.26796302627817603081439301604405e-01 -1.64365346508266840785950080316979e-01
            -6.00631739656835250684707716573030e-01 -2.43168841419884845800325479103776e-01
            -5.64604820126048512207717067212798e-01 -3.17979510678153276526103354626684e-01
            -5.19307105058134599318009350099601e-01 -3.87568965162105039112816484703217e-01
            -4.65482381682186030502634821459651e-01 -4.50794547953017155084154410360497e-01
            -4.04014450467971131253364092117408e-01 -5.06618096729428590840882407064782e-01
            -3.35912613146654714935124275143608e-01 -5.54122990363756118270543993276078e-01
            -2.62295100004275194560676709443214e-01 -5.92529199815867935186020076798741e-01
            -1.84370708571364810834936065475631e-01 -6.21206096188356982068512479600031e-01
            -1.03418955200916040659819827851607e-01 -6.39682805635602758087543406873010e-01
            -2.07690654452401222973545458216904e-02 -6.47655941099297582930205408047186e-01
            6.22218517908548346406760742866027e-02 -6.44994583915556862763196477317251e-01
            1.44191087940760465091472042331588e-01 -6.31742433495760424833065371785779e-01
            2.23792710413056594731529003183823e-01 -6.08117089783425823767970541666728e-01
            2.99719662767453209895052168576512e-01 -5.74506480269151964535012666601688e-01
            3.70725226545406072453658907761564e-01 -5.31462490231947359831110588856973e-01
            4.35643492352735028916299597767647e-01 -4.79691900798208059608640496662701e-01
            4.93408504059646535466754357912578e-01 -4.20044783615160677303634884083294e-01
            5.43071761770913763456292144837789e-01 -3.53500542697916253498391370158060e-01
            5.83817796167931057915723158657784e-01 -2.81151832642623056290887006980483e-01
            6.14977558492385223409826267015887e-01 -2.04186617268199865904421130835544e-01
            6.36039406308366861431125016679289e-01 -1.23868663283276086994888487424760e-01
            6.46657504657023540772797787212767e-01 -4.15167892717755032672144466232567e-02
            6.01414110795411627208295612945221e-01 4.20549714257642884285282036671560e-02
            5.89708269227190551298178888828261e-01 1.25346362095311331108504759868083e-01
            5.66524426981676376691154928266769e-01 2.06198028406046757199376884273079e-01
            5.32313831176948193402154174691532e-01 2.83036284640639457244049026485300e-01
            4.87742352146369240184498039525351e-01 3.54365561543704077340777303106734e-01
            4.33677523029963762901672907901229e-01 4.18797515876172310456126979261171e-01
            3.71171654228650949036705242178869e-01 4.75078052937224604157506746560102e-01
            3.01441351379276467614687362583936e-01 5.22111736091129374770503090985585e-01
            2.25843835509759310875566029608308e-01 5.58983108195317823785330801911186e-01
            1.45850526275600217429584404271736e-01 5.84974509932345676510578869056189e-01
            6.30184024500010236957692200121528e-02 5.99580048232183249190541118878173e-01
            -2.10403028969168431894232185186411e-02 6.02515442905377840432379343837965e-01
            -1.04689482680936307712471489139716e-01 5.93723559833577274602589568530675e-01
            -1.86301000767092772569810676941415e-01 5.73375523020155819509113825915847e-01
            -2.64286381787565360923508706036955e-01 5.41867383856137641018335671105888e-01
            -3.37127729007846321795938138166093e-01 4.99812412430373387284276986974874e-01
            -4.03407268460097723217216980629019e-01 4.48029160924844460645033450418850e-01
            -4.61834944300739902445229745353572e-01 3.87525531427530656181090762402164e-01
            -5.11273528280031142045913838956039e-01 3.19479158264738272166027854837012e-01
            -5.50760754596370194491328220465221e-01 2.45214486688479393894368740802747e-01
            -5.79528049305563786042228002770571e-01 1.66176994056173671365783661713067e-01
            -5.97015489738410232156695656158263e-01 8.39050552580933722834899413101084e-02
            -6.02882702758552824207072262652218e-01 7.38318372194566918557853271765969e-17
            -5.97015489738410232156695656158263e-01 -8.39050552580932473833996709799976e-02
            -5.79528049305563897064530465286225e-01 -1.66176994056173255032149427279364e-01
            -5.50760754596370416535933145496529e-01 -2.45214486688479005316310121997958e-01
            -5.11273528280031253068216301471693e-01 -3.19479158264738216654876623579185e-01
            -4.61834944300740013467532207869226e-01 -3.87525531427530489647637068628683e-01
            -4.03407268460097889750670674402500e-01 -4.48029160924844349622730987903196e-01
            -3.37127729007846654862845525713055e-01 -4.99812412430373220750823293201393e-01
            -2.64286381787565471945811168552609e-01 -5.41867383856137529996033208590234e-01
            -1.86301000767092911347688755085983e-01 -5.73375523020155819509113825915847e-01
            -1.04689482680936335468047104768630e-01 -5.93723559833577274602589568530675e-01
            -2.10403028969173948314885791432971e-02 -6.02515442905377729410076881322311e-01
            6.30184024500007461400130637230177e-02 -5.99580048232183360212843581393827e-01
            1.45850526275599967629403863611515e-01 -5.84974509932345787532881331571843e-01
            2.25843835509759310875566029608308e-01 -5.58983108195317823785330801911186e-01
            3.01441351379276467614687362583936e-01 -5.22111736091129374770503090985585e-01
            3.71171654228651060059007704694523e-01 -4.75078052937224437624053052786621e-01
            4.33677523029963596368219214127748e-01 -4.18797515876172532500731904292479e-01
            4.87742352146369184673346808267524e-01 -3.54365561543704188363079765622388e-01
            5.32313831176948193402154174691532e-01 -2.83036284640639457244049026485300e-01
            5.66524426981676376691154928266769e-01 -2.06198028406046701688225653015252e-01
            5.89708269227190551298178888828261e-01 -1.25346362095311664175412147415045e-01
            6.01414110795411738230598075460875e-01 -4.20549714257639623005147200274223e-02
            5.54352429490106324294629303039983e-01 4.25601442103255428461849874111067e-02
            5.41358878390189812712662842386635e-01 1.26682858922992080952241167324246e-01
            5.15676334015315540604262878332520e-01 2.07836234793915886065462927945191e-01
            4.77906773438115384244895267329412e-01 2.84118105475094362422083804631256e-01
            4.28935483146523799380389618818299e-01 3.53740488571276157081513247248949e-01
            3.69910308678834898188370061689056e-01 4.15071494431882292985847016097978e-01
            3.02214750097152984320558744002483e-01 4.66673576261290301570028304922744e-01
            2.27435533918538268505216137782554e-01 5.07337224997315150432086738874204e-01
            1.47325421590292493512208693573484e-01 5.36109319178495136171136437042151e-01
            6.37621262472074373794939106119273e-02 5.52315465303319319545494181511458e-01
            -2.12956992928401249443037812625334e-02 5.55575805042314518900070652307477e-01
            -1.05854371690861120969273656555742e-01 5.45813918795334473976765821134904e-01
            -1.87931907334453529578865982330171e-01 5.23258616902217199573499328835169e-01
            -2.65604478353824502434576970699709e-01 4.88438576522350231812197307590395e-01
            -3.37051505516498928205493257337366e-01 4.42169949890139468706706793454941e-01
            -4.00598331061475410042049816183862e-01 3.85537234398374950572474517684896e-01
            -4.54755471257771659576718548123608e-01 3.19867852898519711146718691452406e-01
            -4.98253528640649867575973530620104e-01 2.46701040034143476153971619169170e-01
            -5.30072945612299450957038970955182e-01 1.67751763885472165993562043695420e-01
            -5.49467902007791941798586776712909e-01 8.48705285711275625448735127065447e-02
            -5.55983796487619752468845035764389e-01 3.14994782546260769177944404943503e-16
            -5.49467902007791941798586776712909e-01 -8.48705285711274237669954345619772e-02
            -5.30072945612299450957038970955182e-01 -1.67751763885472249260288890582160e-01
            -4.98253528640649923087124761877931e-01 -2.46701040034143337376093541024602e-01
            -4.54755471257771826110172241897089e-01 -3.19867852898519378079811303905444e-01
            -4.00598331061475521064352278699516e-01 -3.85537234398374895061323286427069e-01
            -3.37051505516498872694342026079539e-01 -4.42169949890139524217858024712768e-01
            -2.65604478353824391412274508184055e-01 -4.88438576522350287323348538848222e-01
            -1.87931907334453529578865982330171e-01 -5.23258616902217199573499328835169e-01
            -1.05854371690861509547332275360532e-01 -5.45813918795334362954463358619250e-01
            -2.12956992928402602527349074534868e-02 -5.55575805042314518900070652307477e-01
            6.37621262472074373794939106119273e-02 -5.52315465303319319545494181511458e-01
            1.47325421590292271467603768542176e-01 -5.36109319178495136171136437042151e-01
            2.27435533918538157482913675266900e-01 -5.07337224997315261454389201389858e-01
            3.02214750097153150854012437775964e-01 -4.66673576261290246058877073664917e-01
            3.69910308678834676143765136657748e-01 -4.15071494431882459519300709871459e-01
            4.28935483146523466313482231271337e-01 -3.53740488571276545659571866053739e-01
            4.77906773438115162200290342298103e-01 -2.84118105475094695488991192178219e-01
            5.15676334015315429581960415816866e-01 -2.07836234793916024843341006089759e-01
            5.41358878390189812712662842386635e-01 -1.26682858922992025441089936066419e-01
            5.54352429490106324294629303039983e-01 -4.25601442103257787685777202568715e-02
            5.05528882114032795946911846840521e-01 4.30268489129390988012779928340024e-02
            4.90985736589730825674138259273604e-01 1.27842742634378642163639483442239e-01
            4.62317825359222722703123054088792e-01 2.08980833412922728520300097443396e-01
            4.20349872033075611099661728076171e-01 2.84106926104622681261702155097737e-01
            3.66289218217622392081977977795759e-01 3.51059779804470784014824857877102e-01
            3.01691090495149083494652586523443e-01 4.07913282812276511979376891758875e-01
            2.28413859386716017185747773510229e-01 4.53031863359417641401449827753822e-01
            1.48565577415794208837596102057432e-01 4.85117542030745585446283030250925e-01
            6.44433342752857851731818072948954e-02 5.03247272269134460209727421897696e-01
            -2.15328262606390083422347458963486e-02 5.06899494744342482555055084958440e-01
            -1.06889526589763528274801274164929e-01 4.95969141665342727609555595336133e-01
            -1.89171209852171617882277132594027e-01 4.70770659389374179770726414062665e-01
            -2.66010781830287534877044208769803e-01 4.32028962372755398479995392335695e-01
            -3.35197707939757449935314070899040e-01 3.80858578701824157519695290829986e-01
            -3.94741606284731261222731291127275e-01 3.18731587149110040524391251892666e-01
            -4.42929507321126458840865325328195e-01 2.47435268147256387516463860265503e-01
            -4.78375132871617203544900576162036e-01 1.69020686985064422236391123988142e-01
            -5.00058776824803374871919459110359e-01 8.57436883935025345726543832824973e-02
            -5.07356640223463051242447363620158e-01 6.21332685475819293631474182357132e-17
            -5.00058776824803374871919459110359e-01 -8.57436883935024096725641129523865e-02
            -4.78375132871617203544900576162036e-01 -1.69020686985064311214088661472488e-01
            -4.42929507321126680885470250359504e-01 -2.47435268147256054449556472718541e-01
            -3.94741606284731205711580059869448e-01 -3.18731587149110151546693714408320e-01
            -3.35197707939757560957616533414694e-01 -3.80858578701824102008544059572159e-01
            -2.66010781830287812432800365058938e-01 -4.32028962372755231946541698562214e-01
            -1.89171209852171728904579595109681e-01 -4.70770659389374124259575182804838e-01
            -1.06889526589763431130286619463732e-01 -4.95969141665342727609555595336133e-01
            -2.15328262606392442646274787421135e-02 -5.06899494744342371532752622442786e-01
            6.44433342752854382284866119334765e-02 -5.03247272269134460209727421897696e-01
            1.48565577415793986792991177026124e-01 -4.85117542030745640957434261508752e-01
            2.28413859386716017185747773510229e-01 -4.53031863359417641401449827753822e-01
            3.01691090495149194516955049039098e-01 -4.07913282812276456468225660501048e-01
            3.66289218217622281059675515280105e-01 -3.51059779804470895037127320392756e-01
            4.20349872033075389055056803044863e-01 -2.84106926104622958817458311386872e-01
            4.62317825359222667191971822830965e-01 -2.08980833412922867298178175587964e-01
            4.90985736589730825674138259273604e-01 -1.27842742634378614408063867813325e-01
            5.05528882114032684924609384324867e-01 -4.30268489129393139069890139580821e-02
            4.54989577477985573938923380410415e-01 4.34462369043099941312569001183874e-02
            4.38545068684149885740453100879677e-01 1.28768450513142090896323566084902e-01
            4.06250398490037523124840390664758e-01 2.09436636817503879504087649365829e-01
            3.59272780419406134733151247928618e-01 2.82535237385446280633516380476067e-01
            2.99310107988318307992159361674567e-01 3.45422278335897892098671491112327e-01
            2.28529588409652872904587184166303e-01 3.95824858158322301360243500312208e-01
            1.49489414077827537097320487191610e-01 4.31921296295296242018224575076601e-01
            6.50463028303604057223097356654762e-02 4.52406973424197278443870118280756e-01
            -2.17477512778851377051037019327850e-02 4.56541483798675762351138018857455e-01
            -1.07755784991734451794265225998970e-01 4.44175395441436415833180717527284e-01
            -1.89869243881023413988984316347342e-01 4.15755651005238591189083763310919e-01
            -2.65120333596962187705514679691987e-01 3.72309414100928603996720767099760e-01
            -3.30789283692415336801673220179509e-01 3.15406944928294241670130304555641e-01
            -3.84502647212152326439138505520532e-01 2.47104846981171993869352832007280e-01
            -4.24319083249766415555370713263983e-01 1.69871736038750997810353737804689e-01
            -4.48799522066145872845055464495090e-01 8.64990179593984748196433542943851e-02
            -4.57059176819305634786871905816952e-01 5.59736057912686734819881363272857e-17
            -4.48799522066145928356206695752917e-01 -8.64990179593981695083115823763364e-02
            -4.24319083249766471066521944521810e-01 -1.69871736038750886788051275289035e-01
            -3.84502647212152492972592199294013e-01 -2.47104846981171744069172291347058e-01
            -3.30789283692415392312824451437336e-01 -3.15406944928294186158979073297814e-01
            -2.65120333596962298727817142207641e-01 -3.72309414100928548485569535841933e-01
            -1.89869243881023330722257469460601e-01 -4.15755651005238646700234994568746e-01
            -1.07755784991734451794265225998970e-01 -4.44175395441436415833180717527284e-01
            -2.17477512778853528108147230568648e-02 -4.56541483798675762351138018857455e-01
            6.50463028303601975554926184486249e-02 -4.52406973424197333955021349538583e-01
            1.49489414077827537097320487191610e-01 -4.31921296295296297529375806334428e-01
            2.28529588409652872904587184166303e-01 -3.95824858158322301360243500312208e-01
            2.99310107988318085947554436643259e-01 -3.45422278335898114143276416143635e-01
            3.59272780419405968199697554155136e-01 -2.82535237385446502678121305507375e-01
            4.06250398490037467613689159406931e-01 -2.09436636817503962770814496252569e-01
            4.38545068684149885740453100879677e-01 -1.28768450513142118651899181713816e-01
            4.54989577477985573938923380410415e-01 -4.34462369043103480148459993870347e-02
            4.02768870115933819153752892816556e-01 4.38037543735927681343156336879474e-02
            3.83935845394760222326624443667242e-01 1.29363048250645373826728246058337e-01
            3.47150407256971438307857624749886e-01 2.08873469768199315765855317295063e-01
            2.94132601905812529619055339935585e-01 2.78617199985580266119455927764648e-01
            2.27361482994445224248281078871514e-01 3.35333099592412142708752753605950e-01
            1.49959193832396586731903198597138e-01 3.76369196158274466057491736137308e-01
            6.55449794344180880489858509463375e-02 3.99806687416093264886285396642052e-01
            -2.19340453539011263905944559837735e-02 4.04549662323553327336611573628034e-01
            -1.08387458559412674929944842006080e-01 3.90376344645419814938236413581762e-01
            -1.89772794666693889187314425726072e-01 3.57949462963811193549901190635865e-01
            -2.62284565812672953999395986102172e-01 3.08785262226268897300940352579346e-01
            -3.22532202169608872566186619224027e-01 2.45182605817196058728413277094660e-01
            -3.67698591221890191960142146854196e-01 1.70115483261005118187370044324780e-01
            -3.95671802816267736968569579403265e-01 8.70939497773097898170036046394671e-02
            -4.05143840668580335062642916454934e-01 4.96158107669042149342222282353961e-17
            -3.95671802816267736968569579403265e-01 -8.70939497773096926724889499382698e-02
            -3.67698591221890136448990915596369e-01 -1.70115483261005173698521275582607e-01
            -3.22532202169609094610791544255335e-01 -2.45182605817195836683808352063352e-01
            -2.62284565812672898488244754844345e-01 -3.08785262226268952812091583837173e-01
            -1.89772794666694138987494966386294e-01 -3.57949462963811027016447496862384e-01
            -1.08387458559412855341186343594018e-01 -3.90376344645419759427085182323935e-01
            -2.19340453539014074157975642265228e-02 -4.04549662323553271825460342370206e-01
            6.55449794344179909044711962451402e-02 -3.99806687416093320397436627899879e-01
            1.49959193832396392442873889194743e-01 -3.76369196158274577079794198652962e-01
            2.27361482994445196492705463242601e-01 -3.35333099592412198219903984863777e-01
            2.94132601905812529619055339935585e-01 -2.78617199985580266119455927764648e-01
            3.47150407256971438307857624749886e-01 -2.08873469768199315765855317295063e-01
            3.83935845394760222326624443667242e-01 -1.29363048250645346071152630429424e-01
            4.02768870115933763642601661558729e-01 -4.38037543735930595678595977915393e-02
            3.48885448906217088271830562007381e-01 4.40744819092138348515241830227751e-02
            3.26963693040513425636106603633380e-01 1.29454083934679803347123083767656e-01
            2.84497605852726709319000519826659e-01 2.06699609767712844110576497769216e-01
            2.24155487780209383696927716300706e-01 2.70957438931051730612864503200399e-01
            1.49728856024244155742408679543587e-01 3.18190015694599370732476018019952e-01
            6.58942095800628402368914748876705e-02 3.45429543551035833637286032171687e-01
            -2.20808123939846452643553931238785e-02 3.50964462785165576264034825726412e-01
            -1.08668415717770486250692840712873e-01 3.34446994065499159098919790267246e-01
            -1.88427982827532397580583278795530e-01 2.96914990698693703752297778919456e-01
            -2.56347926786594626502591154348920e-01 2.40726726489338765935244168758800e-01
            -3.08160587723929291215085868316237e-01 1.69412716723688350217713605161407e-01
            -3.40610385599205811590906023411662e-01 8.74538829099002351652458742137242e-02
            -3.51658380269912251847586048825178e-01 4.30657309790890806631768004333595e-17
            -3.40610385599205867102057254669489e-01 -8.74538829098999992428531413679593e-02
            -3.08160587723929291215085868316237e-01 -1.69412716723688405728864836419234e-01
            -2.56347926786594793036044848122401e-01 -2.40726726489338599401790474985319e-01
            -1.88427982827532203291553969393135e-01 -2.96914990698693814774600241435110e-01
            -1.08668415717770638906358726671897e-01 -3.34446994065499103587768559009419e-01
            -2.20808123939845758754163540515947e-02 -3.50964462785165576264034825726412e-01
            6.58942095800626737034377811141894e-02 -3.45429543551035833637286032171687e-01
            1.49728856024243878186652523254452e-01 -3.18190015694599481754778480535606e-01
            2.24155487780209244919049638156139e-01 -2.70957438931051841635166965716053e-01
            2.84497605852726709319000519826659e-01 -2.06699609767712899621727729027043e-01
            3.26963693040513425636106603633380e-01 -1.29454083934679803347123083767656e-01
            3.48885448906217032760679330749554e-01 -4.40744819092139736294022611673427e-02
            2.93333221805267940762718126279651e-01 4.42128693433976593940570865015616e-02
            2.67269277776228553200610349449562e-01 1.28710100564050744509358992218040e-01
            2.17457285524864346593076902536268e-01 2.01770874514614950712143581768032e-01
            1.48323259159036574539314301546256e-01 2.56903420807657101310184089015820e-01
            6.60100603110265610196094598904892e-02 2.89208970759846084597199933341471e-01
            -2.21684220759964557834198473074139e-02 2.95817034487359020733521219881368e-01
            -1.08377142877049414959600426300312e-01 2.76140456528996325324953886592994e-01
            -1.84956078928218553558693315608252e-01 2.31927587185598665930896800091432e-01
            -2.45100855700232073131061838466849e-01 1.67106933923308192957435380776587e-01
            -2.83467345835890838223747323354473e-01 8.74380962452312449073588140890934e-02
            -2.96646518318073093567477371834684e-01 3.63287209136434895930616697673704e-17
            -2.83467345835890893734898554612300e-01 -8.74380962452310367405416968722420e-02
            -2.45100855700232045375486222837935e-01 -1.67106933923308248468586612034414e-01
            -1.84956078928218609069844546866079e-01 -2.31927587185598610419745568833605e-01
            -1.08377142877049345570661387228029e-01 -2.76140456528996325324953886592994e-01
            -2.21684220759966604807900125706510e-02 -2.95817034487359020733521219881368e-01
            6.60100603110265055084582286326622e-02 -2.89208970759846084597199933341471e-01
            1.48323259159036352494709376514948e-01 -2.56903420807657267843637782789301e-01
            2.17457285524864402104228133794095e-01 -2.01770874514614895200992350510205e-01
            2.67269277776228553200610349449562e-01 -1.28710100564050827776085839104780e-01
            2.93333221805267885251566895021824e-01 -4.42128693433979022553437232545548e-02
            2.36059504039933448771293456047715e-01 4.41271689503049749370156007444166e-02
            2.04178359968473138730260529882798e-01 1.26421888167092044685801965897554e-01
            1.44721796991920947927923180031939e-01 1.91642630859048007652134515410580e-01
            6.57197534004491518144774886422965e-02 2.30980974325012911041454799487838e-01
            -2.21581070534783534931033699422187e-02 2.39124057298622127998299902174040e-01
            -1.07043392367523734765022425108327e-01 2.14972111301909296621204248367576e-01
            -1.77471874394421996745663250294456e-01 1.61786990472283120912067033714266e-01
            -2.23931796378749020659526536292105e-01 8.67516400867130998975085276470054e-02
            -2.40148488413206795399901238852181e-01 2.94097077655308920975385014871389e-17
            -2.23931796378749076170677767549932e-01 -8.67516400867129611196304495024378e-02
            -1.77471874394421941234512019036629e-01 -1.61786990472283148667642649343179e-01
            -1.07043392367523998442990773583006e-01 -2.14972111301909157843326170223008e-01
            -2.21581070534783604319972738494471e-02 -2.39124057298622127998299902174040e-01
            6.57197534004490963033262573844695e-02 -2.30980974325012911041454799487838e-01
            1.44721796991920892416771948774112e-01 -1.91642630859048063163285746668407e-01
            2.04178359968473055463533682996058e-01 -1.26421888167092155708104428413208e-01
            2.36059504039933448771293456047715e-01 -4.41271689503049124869704655793612e-02
            1.76907032789037410580590403696988e-01 4.36036673971699137442037397249806e-02
            1.36379763537928910821506178763229e-01 1.20821927471974954748645814106567e-01
            6.46095340146007196535649086399644e-02 1.70361340025020735478022970710299e-01
            -2.19619611221803893996717960135356e-02 1.80873022655044984885464032231539e-01
            -1.03502235636193082313205593436578e-01 1.49948875551017518636953695931879e-01
            -1.61331395303110664007917307571915e-01 8.46732481380985946284312149145990e-02
            -1.82201476560165609441810374846682e-01 -5.86004642521858284461780533235717e-17
            -1.61331395303110775030219770087569e-01 -8.46732481380984142171897133266611e-02
            -1.03502235636193123946569016879948e-01 -1.49948875551017518636953695931879e-01
            -2.19619611221805142997620663436464e-02 -1.80873022655044984885464032231539e-01
            6.46095340146007196535649086399644e-02 -1.70361340025020735478022970710299e-01
            1.36379763537928827554779331876489e-01 -1.20821927471975010259797045364394e-01
            1.76907032789037410580590403696988e-01 -4.36036673971699206830976436322089e-02
            1.15431830394898460312447241449263e-01 4.20137503506077258919049199903384e-02
            6.14199940712301800660455342040223e-02 1.06382550331949862765235081951687e-01
            -2.13309400855655646733755048671810e-02 1.20973772702622633934410600886622e-01
            -9.41008903093328713529430729067826e-02 7.89600223520149357980812965251971e-02
            -1.22839988142460332376515452779131e-01 1.50435598285962871986883627986213e-17
            -9.41008903093329268640943041646096e-02 -7.89600223520148664091422574529133e-02
            -2.13309400855655681428224568207952e-02 -1.20973772702622633934410600886622e-01
            6.14199940712300829215308795028250e-02 -1.06382550331949918276386313209514e-01
            1.15431830394898460312447241449263e-01 -4.20137503506077120141171121758816e-02
            5.02368453377574838980557103695901e-02 3.64992046107086506867567265999241e-02
            -1.91887674314516615270420629713044e-02 5.90569536224634719645543157184875e-02
            -6.20961558126116308642394869821146e-02 7.60458584552701500917923966596694e-18
            -1.91887674314516754048298707857612e-02 -5.90569536224634650256604118112591e-02
            5.02368453377574769591618064623617e-02 -3.64992046107086645645445344143809e-02
            -0.00000000000000000000000000000000e+00 0.00000000000000000000000000000000e+00
            ];
        
    case   49
        
        % DEGREE.             :          49
        % CARDIN.             :        1275
        % LEBESGUE CONST.     : 3.00975e+03
        % ABS.DET.VAND.MATRIX : Inf
        % CONDITIONING VAND.  : 1.45684e+05
        % POINTS OUT DISK     : 0.00000e+00
        
        pts=[
            9.99496542383185082591978698474122e-01 3.17279334980676494537554788166744e-02
            9.95471922573084588847791565058287e-01 9.50560433041826580158328852121485e-02
            9.87438888676394288523852083017118e-01 1.58001395973349889612080687584239e-01
            9.75429786885407046348461790330475e-01 2.20310532786540613781056663356139e-01
            9.59492973614497368650688713387353e-01 2.81732556841429671035115234190016e-01
            9.39692620785908427905042117345147e-01 3.42020143325668657396931848779786e-01
            9.16108457432069589465584158460842e-01 4.00930535406613719473511991964187e-01
            8.88835448654923476752287569979671e-01 4.58226521727410351925158238373115e-01
            8.57983413234977065897624015633482e-01 5.13677391573406305624871492909733e-01
            8.23676581429832799230439377424773e-01 5.67059863862770741071983593428740e-01
            7.86053094742787505921910451434087e-01 6.18158986220605166650443607068155e-01
            7.45264449675754669932814522326225e-01 6.66769000516291510116673180164071e-01
            7.01474887706321270641751652874518e-01 7.12694171378862928456499048479600e-01
            6.54860733945285100610078643512679e-01 7.55749574354258268904516171460273e-01
            6.05609687137666607981145716621540e-01 7.95761840530832098572489030630095e-01
            5.53920063866110368167028354946524e-01 8.32569854634771289170203090179712e-01
            5.00000000000000111022302462515654e-01 8.66025403784438596588302061718423e-01
            4.44066612605774235778000047503156e-01 8.95993774291335864923269127757521e-01
            3.86345125693128566002343404761632e-01 9.22354294104581473590087625780143e-01
            3.27067963317421772639903565504937e-01 9.45000818714668455733374230476329e-01
            2.66473813690035143952883345264127e-01 9.63842158559942041584633898310130e-01
            2.04806668065190794481011948846572e-01 9.78802446214778520960919649951393e-01
            1.42314838273285115821664703616989e-01 9.89821441880932684220795181317953e-01
            7.92499568567884421499414315803733e-02 9.96854775951942384537574071146082e-01
            1.58659638348081534486855304066921e-02 9.99874127673875068289532919152407e-01
            -4.75819158237422781820846751088538e-02 9.98867339183007962866156503878301e-01
            -1.10838199901010986403449010140321e-01 9.93838464461254122994660065160133e-01
            -1.73648177666930303431058746355120e-01 9.84807753012208020315654266596539e-01
            -2.35758935509426947874089819379151e-01 9.71811568323541763447792618535459e-01
            -2.96920375328274810389217464035028e-01 9.54902241444073873744002867169911e-01
            -3.56886221591871777292226397548802e-01 9.34147860265106766419762607256416e-01
            -4.15415013001886546106788955512457e-01 9.09631995354518330110238366614794e-01
            -4.72271074772682597497919232409913e-01 8.81453363447582072254249396792147e-01
            -5.27225467610502485094059466064209e-01 8.49725429949514277083721935923677e-01
            -5.80056909571198042741002609545831e-01 8.14575952050335727605556712660473e-01
            -6.30552667084522511231625685468316e-01 7.76146464291756821296530688414350e-01
            -6.78509411557131958403488170006312e-01 7.34591708657533315474097435071599e-01
            -7.23734038105070198731993968976894e-01 6.90079011482111925879223690571962e-01
            -7.66044443118977902429378445958719e-01 6.42787609686539473941024880332407e-01
            -8.05270257531058630817710763949435e-01 5.92907929054640403521148073195945e-01
            -8.41253532831181094486794336262392e-01 5.40640817455597777474451959278667e-01
            -8.73849377069784938321106437797425e-01 4.86196736100468707153510194984847e-01
            -9.02926538286621060969139307417208e-01 4.29794912089171809999044171490823e-01
            -9.28367933016072455210121461277595e-01 3.71662455660327961659561424312415e-01
            -9.50071117740945436658250855543884e-01 3.12033445698486955333095238529495e-01
            -9.67948701396356248061181304365164e-01 2.51147987181079279661588543604012e-01
            -9.81928697262706595694226052728482e-01 1.89251244360410492140189830934105e-01
            -9.91954812830795340516942815156654e-01 1.26592453573749375017598595150048e-01
            -9.97986676471884326389272246160544e-01 6.34239196565648394310343860524881e-02
            -1.00000000000000000000000000000000e+00 -3.21624529935327320103979552447107e-16
            -9.97986676471884215366969783644890e-01 -6.34239196565645757530660375778098e-02
            -9.91954812830795340516942815156654e-01 -1.26592453573749125217418054489826e-01
            -9.81928697262706706716528515244136e-01 -1.89251244360410270095584905902797e-01
            -9.67948701396356359083483766880818e-01 -2.51147987181079002105832387314877e-01
            -9.50071117740945547680553318059538e-01 -3.12033445698486733288490313498187e-01
            -9.28367933016072677254726386308903e-01 -3.71662455660327351036897880476317e-01
            -9.02926538286621394036046694964170e-01 -4.29794912089171199376380627654726e-01
            -8.73849377069784827298803975281771e-01 -4.86196736100468873686963888758328e-01
            -8.41253532831181205509096798778046e-01 -5.40640817455597555429847034247359e-01
            -8.05270257531058741840013226465089e-01 -5.92907929054640292498845610680291e-01
            -7.66044443118978124473983370990027e-01 -6.42787609686539251896419955301099e-01
            -7.23734038105070309754296431492548e-01 -6.90079011482111814856921228056308e-01
            -6.78509411557132624537302945100237e-01 -7.34591708657532871384887585008983e-01
            -6.30552667084522400209323222952662e-01 -7.76146464291756932318833150930004e-01
            -5.80056909571198264785607534577139e-01 -8.14575952050335616583254250144819e-01
            -5.27225467610502707138664391095517e-01 -8.49725429949514166061419473408023e-01
            -4.72271074772682430964465538636432e-01 -8.81453363447582183276551859307801e-01
            -4.15415013001886379573335261738976e-01 -9.09631995354518441132540829130448e-01
            -3.56886221591871999336831322580110e-01 -9.34147860265106655397460144740762e-01
            -2.96920375328275254478427314097644e-01 -9.54902241444073762721700404654257e-01
            -2.35758935509427836052509519504383e-01 -9.71811568323541541403187693504151e-01
            -1.73648177666930331186634361984034e-01 -9.84807753012208020315654266596539e-01
            -1.10838199901011222325841742986086e-01 -9.93838464461254122994660065160133e-01
            -4.75819158237418618484504406751512e-02 -9.98867339183007962866156503878301e-01
            1.58659638348081291625568667313928e-02 -9.99874127673875068289532919152407e-01
            7.92499568567884143943658159514598e-02 -9.96854775951942384537574071146082e-01
            1.42314838273284866021484162956767e-01 -9.89821441880932795243097643833607e-01
            2.04806668065190183858348405010474e-01 -9.78802446214778854027827037498355e-01
            2.66473813690034311285614876396721e-01 -9.63842158559942263629238823341439e-01
            3.27067963317421550595298640473629e-01 -9.45000818714668566755676692991983e-01
            3.86345125693128343957738479730324e-01 -9.22354294104581473590087625780143e-01
            4.44066612605773625155336503667058e-01 -8.95993774291336086967874052788829e-01
            4.99999999999999333866185224906076e-01 -8.66025403784439040677511911781039e-01
            5.53920063866110146122423429915216e-01 -8.32569854634771400192505552695366e-01
            6.05609687137666385936540791590232e-01 -7.95761840530832320617093955661403e-01
            6.54860733945284545498566330934409e-01 -7.55749574354258712993726021522889e-01
            7.01474887706320604507936877780594e-01 -7.12694171378863483568011361057870e-01
            7.45264449675754003798999747232301e-01 -6.66769000516292398295092880289303e-01
            7.86053094742787727966515376465395e-01 -6.18158986220604833583536219521193e-01
            8.23676581429832910252741839940427e-01 -5.67059863862770519027378668397432e-01
            8.57983413234976954875321553117828e-01 -5.13677391573406416647173955425387e-01
            8.88835448654923365729985107464017e-01 -4.58226521727410629480914394662250e-01
            9.16108457432069367420979233429534e-01 -4.00930535406614108051570610768977e-01
            9.39692620785908427905042117345147e-01 -3.42020143325668601885780617521959e-01
            9.59492973614497368650688713387353e-01 -2.81732556841429782057417696705670e-01
            9.75429786885406935326159327814821e-01 -2.20310532786540919092388435274188e-01
            9.87438888676394288523852083017118e-01 -1.58001395973350444723593000162509e-01
            9.95471922573084477825489102542633e-01 -9.50560433041834351719501228217268e-02
            9.99496542383185082591978698474122e-01 -3.17279334980686694711593531792460e-02
            9.91387624706691172882244700304000e-01 3.27965464432971379182824023246212e-02
            9.87052538870086260125447097379947e-01 9.82462283769677535705255877473974e-02
            9.78401323424231361691738584340783e-01 1.63266304551475477380151346551429e-01
            9.65471807933077075247751963615883e-01 2.27572458717257924964982862547913e-01
            9.48320529878111995181200200022431e-01 2.90883496424048537676299019949511e-01
            9.27022487434341346812516349018551e-01 3.52922574612660633341931770701194e-01
            9.01670811522349957556343724718317e-01 4.13418412179246519411179860981065e-01
            8.72376358570482790533162642532261e-01 4.72106476218540072053997391776647e-01
            8.39267225767889479826067145040724e-01 5.28730138758944701038444691221230e-01
            8.02488190928109190735995071008801e-01 5.83041798931357213575665809912607e-01
            7.62200079412528652689218233717838e-01 6.34803965664769154209068346972344e-01
            7.18579060881997633281059734144947e-01 6.83790296174294209841093561408343e-01
            6.71815878951724343437490460928530e-01 7.29786585700576195812061541801086e-01
            6.22115017117981117245051336794859e-01 7.72591704172699955677217076299712e-01
            5.69693804603801035035814948059851e-01 8.12018475698816022401160807930864e-01
            5.14781466033584100827624752128031e-01 8.47894497038692018797689797793282e-01
            4.57618119092136677039661663002335e-01 8.80062891479215569923155726428377e-01
            3.98453724551132149045429287070874e-01 9.08382994816345656907685679470887e-01
            3.37546993254254412697434872825397e-01 9.32730970443886753251661048125243e-01
            2.75164254840505884125434477027738e-01 9.53000350859458889019037997059058e-01
            2.11578293152458213333133585365431e-01 9.69102503219796185263135157583747e-01
            1.47067153421917007349861705733929e-01 9.80967016909619071718395844072802e-01
            8.19129264488680508549123260308988e-02 9.88542011429339728678655774274375e-01
            1.64005150901822202569313446929300e-02 9.91794363255286581804170964460354e-01
            -4.91836115480856761461581072580884e-02 9.90709850680445036630317190429196e-01
            -1.14552670767211595137524682286312e-01 9.85293216002364080630115950043546e-01
            -1.79420820303573508303074390823895e-01 9.75568144786295943227116822527023e-01
            -2.43504408244141462569487543987634e-01 9.61577162294245058049568797287066e-01
            -3.06523213364122359969599074247526e-01 9.43381447532818051548986204579705e-01
            -3.68201670463077612716062958497787e-01 9.21060565732993330456679359485861e-01
            -4.28270075341428191340042985757464e-01 8.94712120431611190873866235051537e-01
            -4.86465764148299228963878704234958e-01 8.64451326675940601163006249407772e-01
            -5.42534261943706241915208465798059e-01 8.30410507217593241158226646803087e-01
            -5.96230395452721606552870525774779e-01 7.92738513898797347856373107788386e-01
            -6.47319365145822778195849878102308e-01 7.51600076761166691063920097803930e-01
            -6.95577771957493706800335075968178e-01 7.07175083723140973646081874903757e-01
            -7.40794594153498020538961554848356e-01 6.59657793975889306103965736838290e-01
            -7.82772110075230287407066498417407e-01 6.09255988537292902940123440203024e-01
            -8.21326762726220849231140164192766e-01 5.56190061678423552926631145965075e-01
            -8.56289962420178185631414180534193e-01 5.00692057195470496822053974028677e-01
            -8.87508823980791228258624414593214e-01 4.43004653741262022226266026336816e-01
            -9.14846835269706448734439163672505e-01 3.83380103653260917440093180630356e-01
            -9.38184454119373678615545486536575e-01 3.22079129918278472821668856340693e-01
            -9.57419631060530074151415647065733e-01 2.59369786097187859930102149519371e-01
            -9.72468255558563310358977105352096e-01 1.95526284194906085911469517668593e-01
            -9.83264523807478418859773228177801e-01 1.30827795601069385433845582156209e-01
            -9.89761226473198973963008029386401e-01 6.55572303445728643556122960944776e-02
            -9.91929955127972995398977218428627e-01 1.21476384452584976870127390222705e-16
            -9.89761226473198973963008029386401e-01 -6.55572303445721843440097131860966e-02
            -9.83264523807478418859773228177801e-01 -1.30827795601069579722874891558604e-01
            -9.72468255558563310358977105352096e-01 -1.95526284194906280200498827070987e-01
            -9.57419631060530296196020572097041e-01 -2.59369786097187193796287374425447e-01
            -9.38184454119373789637847949052230e-01 -3.22079129918278250777063931309385e-01
            -9.14846835269706559756741626188159e-01 -3.83380103653260695395488255599048e-01
            -8.87508823980791450303229339624522e-01 -4.43004653741261411603602482500719e-01
            -8.56289962420178074609111718018539e-01 -5.00692057195470607844356436544331e-01
            -8.21326762726220960253442626708420e-01 -5.56190061678423330882026220933767e-01
            -7.82772110075230509451671423448715e-01 -6.09255988537292791917820977687370e-01
            -7.40794594153498464628171404910972e-01 -6.59657793975888750992453424260020e-01
            -6.95577771957493817822637538483832e-01 -7.07175083723140862623779412388103e-01
            -6.47319365145823000240454803133616e-01 -7.51600076761166469019315172772622e-01
            -5.96230395452721828597475450806087e-01 -7.92738513898797236834070645272732e-01
            -5.42534261943706463959813390829368e-01 -8.30410507217593130135924184287433e-01
            -4.86465764148299062430425010461477e-01 -8.64451326675940712185308711923426e-01
            -4.28270075341428801962706529593561e-01 -8.94712120431610857806958847504575e-01
            -3.68201670463077224138004339692998e-01 -9.21060565732993441478981822001515e-01
            -3.06523213364122804058808924310142e-01 -9.43381447532817940526683742064051e-01
            -2.43504408244141462569487543987634e-01 -9.61577162294245058049568797287066e-01
            -1.79420820303573314014045081421500e-01 -9.75568144786295943227116822527023e-01
            -1.14552670767212261271339457380236e-01 -9.85293216002364080630115950043546e-01
            -4.91836115480861410520496690423897e-02 -9.90709850680444925608014727913542e-01
            1.64005150901821994402496329712449e-02 -9.91794363255286581804170964460354e-01
            8.19129264488680230993367104019853e-02 -9.88542011429339728678655774274375e-01
            1.47067153421917201638891015136323e-01 -9.80967016909618960696093381557148e-01
            2.11578293152457574954894425900420e-01 -9.69102503219796296285437620099401e-01
            2.75164254840505440036224626965122e-01 -9.53000350859459000041340459574712e-01
            3.37546993254254357186283641567570e-01 -9.32730970443886753251661048125243e-01
            3.98453724551132149045429287070874e-01 -9.08382994816345656907685679470887e-01
            4.57618119092136066416998119166237e-01 -8.80062891479215902990063113975339e-01
            5.14781466033583656738414902065415e-01 -8.47894497038692240842294722824590e-01
            5.69693804603800812991210023028543e-01 -8.12018475698816133423463270446518e-01
            6.22115017117980340088934099185281e-01 -7.72591704172700399766426926362328e-01
            6.71815878951723788325978148350259e-01 -7.29786585700576750923573854379356e-01
            7.18579060881997744303362196660601e-01 -6.83790296174294098818791098892689e-01
            7.62200079412528541666915771202184e-01 -6.34803965664769487275975734519307e-01
            8.02488190928109079713692608493147e-01 -5.83041798931357435620270734943915e-01
            8.39267225767889035736857294978108e-01 -5.28730138758945478194561928830808e-01
            8.72376358570482457466255254985299e-01 -4.72106476218540738187812166870572e-01
            9.01670811522350068578646187233971e-01 -4.13418412179246186344272473434103e-01
            9.27022487434341235790213886502897e-01 -3.52922574612660966408839158248156e-01
            9.48320529878111995181200200022431e-01 -2.90883496424048704209752713722992e-01
            9.65471807933077075247751963615883e-01 -2.27572458717257952720558478176827e-01
            9.78401323424231250669436121825129e-01 -1.63266304551476171269541737274267e-01
            9.87052538870086260125447097379947e-01 -9.82462283769673927480425845715217e-02
            9.91387624706691172882244700304000e-01 -3.27965464432974709851897898715833e-02
            9.76485248558058849255303357494995e-01 3.37245956600853366569303659616708e-02
            9.71831851659734069492913022259017e-01 1.01013073923838986312162546710169e-01
            9.62547233418450276509759078180650e-01 1.67820178889243720732338260859251e-01
            9.48675639268319215169356084516039e-01 2.33827544277350446444430076553544e-01
            9.30283173672555530053784877964063e-01 2.98720614932495409643564698853879e-01
            9.07457485105606087572027718124446e-01 3.62190145820864395354021780804032e-01
            8.80307348368254083403883214486996e-01 4.23933675723908331978151409202837e-01
            8.48962146226157399198086750402581e-01 4.83656968603789538807546932730475e-01
            8.13571252842049785769518166489433e-01 5.41075415772097167987908505892847e-01
            7.74303321939831534770348753227154e-01 5.95915392179856340248988999519497e-01
            7.31345483092769033106606002547778e-01 6.47915560365495912797939581651008e-01
            6.84902449965861470637662478111451e-01 6.96828115846864437621377419418423e-01
            6.35195544761999686400599784974474e-01 7.42419968022437259946855192538351e-01
            5.82461643520881033886382738273824e-01 7.84473850954182205796882954018656e-01
            5.26952047296806003195968060026644e-01 8.22789358738696297024262094055302e-01
            4.68931284594714392621739307287498e-01 8.57183900532599518662379978195531e-01
            4.08675850771391901972151572408620e-01 8.87493570681055277127313729579328e-01
            3.46472890409181222270973421473172e-01 9.13573929802858231141726719215512e-01
            2.82618828941280819666559409597539e-01 9.35300693109862524288189433718799e-01
            2.17417960049565650582081843822380e-01 9.52570322680596603959202184341848e-01
            1.51180995566618042724726933556667e-01 9.65300520865609246179417368693976e-01
            8.42235847923471087073110652454488e-02 9.73430622473248852166705091804033e-01
            1.68648102813302967761810435831649e-02 9.76921883866926688000376088893972e-01
            -5.05743327308695797550619488447410e-02 9.75757667596190425562951986648841e-01
            -1.17772466016181714953958703517856e-01 9.69943521681751130714133068977389e-01
            -1.84409359867639788266302502961480e-01 9.59507153176638816205468174302951e-01
            -2.50167459139766235054480603139382e-01 9.44498296129476222482423963811016e-01
            -3.14733396543455001825861927500227e-01 9.24988474579089281490951179875992e-01
            -3.77799485983810523492820721003227e-01 9.01070661709889919599447694054106e-01
            -4.39065188824509955445307696209056e-01 8.72858836792311909569264116726117e-01
            -4.98238546091269329796347165029147e-01 8.40487442019682062799290633847704e-01
            -5.55037569789313178780787438881816e-01 8.04110741829944464242885260318872e-01
            -6.09191586704586618417067711561685e-01 7.63902087765361836879662860155804e-01
            -6.60442528284884033951129822526127e-01 7.20053092373472480858254129998386e-01
            -7.08546160454024631647484966379125e-01 6.72772716086041944194562347547617e-01
            -7.53273247498448039749519011820666e-01 6.22286271427445303316972058382817e-01
            -7.94410644479783933924466055032099e-01 5.68834349297881791684972085931804e-01
            -8.31762312967548655961991244112141e-01 5.12671672448170245850462833914207e-01
            -8.65150255251540989398506553698098e-01 4.54065881609842791899467329130857e-01
            -8.94415362581992279267240064655198e-01 3.93296260065174874132054583242279e-01
            -9.19418173395215920784551144606667e-01 3.30652402735160944047265729750507e-01
            -9.40039537911469325059954371681670e-01 2.66432836127834749007092796091456e-01
            -9.56181185937914568384599078854080e-01 2.00943595723510698425329223937297e-01
            -9.67766195170839282901908973144600e-01 1.34496767576352455053623202729796e-01
            -9.74739357765464609073546853323933e-01 6.74090010821996321599414159209118e-02
            -9.77067443426466009093189768464072e-01 1.19656251714330914832446250111997e-16
            -9.74739357765464609073546853323933e-01 -6.74090010821993962375486830751470e-02
            -9.67766195170839282901908973144600e-01 -1.34496767576352205253442662069574e-01
            -9.56181185937914568384599078854080e-01 -2.00943595723510476380724298905989e-01
            -9.40039537911469214037651909166016e-01 -2.66432836127834971051697721122764e-01
            -9.19418173395216031806853607122321e-01 -3.30652402735160722002660804719198e-01
            -8.94415362581992390289542527170852e-01 -3.93296260065174652087449658210971e-01
            -8.65150255251541100420809016213752e-01 -4.54065881609842569854862404099549e-01
            -8.31762312967548766984293706627795e-01 -5.12671672448170134828160371398553e-01
            -7.94410644479784378013675905094715e-01 -5.68834349297881236573459773353534e-01
            -7.53273247498447928727216549305012e-01 -6.22286271427445414339274520898471e-01
            -7.08546160454024742669787428894779e-01 -6.72772716086041833172259885031963e-01
            -6.60442528284883811906524897494819e-01 -7.20053092373472591880556592514040e-01
            -6.09191586704586840461672636592994e-01 -7.63902087765361614835057935124496e-01
            -5.55037569789313400825392363913124e-01 -8.04110741829944353220582797803218e-01
            -4.98238546091269551840952090060455e-01 -8.40487442019681951776988171332050e-01
            -4.39065188824510177489912621240364e-01 -8.72858836792311798546961654210463e-01
            -3.77799485983811356160089189870632e-01 -9.01070661709889586532540306507144e-01
            -3.14733396543454835292408233726746e-01 -9.24988474579089392513253642391646e-01
            -2.50167459139766901188295378233306e-01 -9.44498296129476111460121501295362e-01
            -1.84409359867639593977273193559085e-01 -9.59507153176638816205468174302951e-01
            -1.17772466016182394965561286426237e-01 -9.69943521681751130714133068977389e-01
            -5.05743327308700377220596067218139e-02 -9.75757667596190425562951986648841e-01
            1.68648102813298422786303376597061e-02 -9.76921883866926799022678551409626e-01
            8.42235847923466507403134073683759e-02 -9.73430622473248852166705091804033e-01
            1.51180995566617570879941467865137e-01 -9.65300520865609246179417368693976e-01
            2.17417960049565428537476918791072e-01 -9.52570322680596603959202184341848e-01
            2.82618828941280542110803253308404e-01 -9.35300693109862635310491896234453e-01
            3.46472890409181000226368496441864e-01 -9.13573929802858342164029181731166e-01
            4.08675850771391901972151572408620e-01 -8.87493570681055388149616192094982e-01
            4.68931284594713615465622069677920e-01 -8.57183900532599851729287365742493e-01
            5.26952047296806114218270522542298e-01 -8.22789358738696186001959631539648e-01
            5.82461643520880367752567963179899e-01 -7.84473850954182649886092804081272e-01
            6.35195544761999242311389934911858e-01 -7.42419968022437704036065042600967e-01
            6.84902449965861692682267403142760e-01 -6.96828115846864215576772494387114e-01
            7.31345483092768700039698615000816e-01 -6.47915560365496245864846969197970e-01
            7.74303321939831201703441365680192e-01 -5.95915392179856673315896387066459e-01
            8.13571252842049230658005853911163e-01 -5.41075415772098167188630668533733e-01
            8.48962146226157621242691675433889e-01 -4.83656968603789039207185851410031e-01
            8.80307348368253972381580751971342e-01 -4.23933675723908498511605102976318e-01
            9.07457485105605976549725255608791e-01 -3.62190145820864561887475474577514e-01
            9.30283173672555530053784877964063e-01 -2.98720614932495576177018392627360e-01
            9.48675639268318993124751159484731e-01 -2.33827544277351334622849776678777e-01
            9.62547233418450276509759078180650e-01 -1.67820178889243692976762645230338e-01
            9.71831851659734069492913022259017e-01 -1.01013073923838889167647892008972e-01
            9.76485248558058960277605820010649e-01 -3.37245956600851701234766721881897e-02
            9.57130400156424143709443796979031e-01 3.45772582954767745966329073326051e-02
            9.52140365435744429056796889199177e-01 1.03551505072189631295742628935841e-01
            9.42186311724853564619763801601948e-01 1.71985882249520383169283377355896e-01
            9.27320134850715627194972512370441e-01 2.39523604672439854867960207229771e-01
            9.07619340175979116835947024810594e-01 3.05812561928625048501828587177442e-01
            8.83186638521902711573829947155900e-01 3.70507154089109003169966172208660e-01
            8.54149410681692700109124416485429e-01 4.33270093506285869366934093704913e-01
            8.20659043316029346293305479775881e-01 4.93774163275528477079490130563499e-01
            7.82890139693114495145209730253555e-01 5.51703923192616518811348669260042e-01
            7.41039609388080111607166600151686e-01 6.06757354312900343273895487072878e-01
            6.95325641687638218435552062146598e-01 6.58647433538234405858702302793972e-01
            6.45986568052171250542414782103151e-01 7.07103630022506868257892165274825e-01
            5.93279619565851845663928543217480e-01 7.51873315594207669576576336112339e-01
            5.37479585852878471996518783271313e-01 7.92723081842737209434801570751006e-01
            4.78877382451611599556429155200021e-01 8.29439957001784189394300028652651e-01
            4.17778534115662070203001121626585e-01 8.61832516285500394026541925995843e-01
            3.54501581949292432494047488944489e-01 8.89731879888698728997553644148866e-01
            2.89376422681598355346466178161791e-01 9.12992593447958800112473909393884e-01
            2.22742588737714602986628165126604e-01 9.31493386373328013938532876636600e-01
            1.54947478073967387368625736598915e-01 9.45137804097024858407394276582636e-01
            8.63445430057874219187397102359682e-02 9.53854710942893313507795483019436e-01
            1.72914474709982175781863844576947e-02 9.57598660994879669061674576369114e-01
            -5.18517976643436268036069236586627e-02 9.56350135030996195695252026780508e-01
            -1.20724711535907594517347263263218e-01 9.50115642287506334540125862986315e-01
            -1.88968222661398288497736075441935e-01 9.38927686522780580169467157247709e-01
            -2.56226540973003680257136238651583e-01 9.22844596557751084553444798075361e-01
            -3.22149012742062978986723464913666e-01 9.01950222176447491406747758446727e-01
            -3.86391948725242850848360376403434e-01 8.76353496972048451318926254316466e-01
            -4.48620416001112853887633491467568e-01 8.46187870417566934122532984474674e-01
            -5.08509984155311234310659074253635e-01 8.11610612122090180342581788863754e-01
            -5.65748416710501467186134050280089e-01 7.72801991899858875534334856638452e-01
            -6.20037298982790585633040336688282e-01 7.29964339926927108237464381090831e-01
            -6.71093593877711724893231348687550e-01 6.83320991885311368463362668990158e-01
            -7.18651117514580661804757255595177e-01 6.33115124594155642689941032585921e-01
            -7.62461926985995241956572954222793e-01 5.79608488198397275859008459519828e-01
            -8.02297613017349031672154069383396e-01 5.23080041524710548372922858106904e-01
            -8.37950490787027546524257104465505e-01 4.63824497719351191982184445805615e-01
            -8.69234682698901695019344515458215e-01 4.02150787750277127763354201306356e-01
            -8.95987087462047249175611796090379e-01 3.38380449784124570644650020767585e-01
            -9.18068230425352793666604611644289e-01 2.72845952835093552568679342584801e-01
            -9.35362990733769494866578497749288e-01 2.05888963425451987365732975376886e-01
            -9.47781201515144222646824800904142e-01 1.37858564294491114932128539294354e-01
            -9.55258119968540264643763748608762e-01 6.91094344427635315364355506062566e-02
            -9.57754764903223421157463235431351e-01 1.17291130720685842324964222243774e-16
            -9.55258119968540264643763748608762e-01 -6.91094344427633094918306255749485e-02
            -9.47781201515144222646824800904142e-01 -1.37858564294490892887523614263046e-01
            -9.35362990733769605888880960264942e-01 -2.05888963425451348987493815911876e-01
            -9.18068230425352682644302149128634e-01 -2.72845952835093719102133036358282e-01
            -8.95987087462047360197914258606033e-01 -3.38380449784124404111196326994104e-01
            -8.69234682698901806041646977973869e-01 -4.02150787750276905718749276275048e-01
            -8.37950490787027657546559566981159e-01 -4.63824497719351025448730752032134e-01
            -8.02297613017349364739061456930358e-01 -5.23080041524709993261410545528634e-01
            -7.62461926985995130934270491707139e-01 -5.79608488198397386881310922035482e-01
            -7.18651117514580772827059718110831e-01 -6.33115124594155531667638570070267e-01
            -6.71093593877712057960138736234512e-01 -6.83320991885310924374152818927541e-01
            -6.20037298982790363588435411656974e-01 -7.29964339926927219259766843606485e-01
            -5.65748416710501578208436512795743e-01 -7.72801991899858653489729931607144e-01
            -5.08509984155310679199146761675365e-01 -8.11610612122090513409489176410716e-01
            -4.48620416001112742865331028951914e-01 -8.46187870417567045144835446990328e-01
            -3.86391948725242850848360376403434e-01 -8.76353496972048451318926254316466e-01
            -3.22149012742063201031328389944974e-01 -9.01950222176447380384445295931073e-01
            -2.56226540973004346390951013745507e-01 -9.22844596557750862508839873044053e-01
            -1.88968222661399148920580159938254e-01 -9.38927686522780469147164694732055e-01
            -1.20724711535907594517347263263218e-01 -9.50115642287506334540125862986315e-01
            -5.18517976643440708928167737212789e-02 -9.56350135030996195695252026780508e-01
            1.72914474709984083977687419064750e-02 -9.57598660994879669061674576369114e-01
            8.63445430057871998741347852046601e-02 -9.53854710942893313507795483019436e-01
            1.54947478073966971034991502165212e-01 -9.45137804097024969429696739098290e-01
            2.22742588737714797275657474528998e-01 -9.31493386373327902916230414120946e-01
            2.89376422681598355346466178161791e-01 -9.12992593447958800112473909393884e-01
            3.54501581949292265960593795171008e-01 -8.89731879888698840019856106664520e-01
            4.17778534115662236736454815400066e-01 -8.61832516285500283004239463480189e-01
            4.78877382451611821601034080231329e-01 -8.29439957001784078371997566136997e-01
            5.37479585852878360974216320755659e-01 -7.92723081842737320457104033266660e-01
            5.93279619565851512597021155670518e-01 -7.51873315594207891621181261143647e-01
            6.45986568052170695430902469524881e-01 -7.07103630022507423369404477853095e-01
            6.95325641687638218435552062146598e-01 -6.58647433538234405858702302793972e-01
            7.41039609388079778540259212604724e-01 -6.06757354312900676340802874619840e-01
            7.82890139693114162078302342706593e-01 -5.51703923192616851878256056807004e-01
            8.20659043316029346293305479775881e-01 -4.93774163275528477079490130563499e-01
            8.54149410681692589086821953969775e-01 -4.33270093506286091411539018736221e-01
            8.83186638521902489529225022124592e-01 -3.70507154089109558281478484786930e-01
            9.07619340175978894791342099779285e-01 -3.05812561928625714635643362271367e-01
            9.27320134850715627194972512370441e-01 -2.39523604672440021401413901003252e-01
            9.42186311724853453597461339086294e-01 -1.71985882249520827258493227418512e-01
            9.52140365435744429056796889199177e-01 -1.03551505072189464762288935162360e-01
            9.57130400156424143709443796979031e-01 -3.45772582954768856189353698482591e-02
            9.34163240067124034382572972390335e-01 3.53754539980497065276843215997360e-02
            9.28812437625192499623949515807908e-01 1.05923734597224789011349344036717e-01
            9.18141481653151791952893745474285e-01 1.75865293637006619986706823510758e-01
            9.02211494420455339948716755316127e-01 2.44799512201074320749683010944864e-01
            8.81113721451363796077771439740900e-01 3.12331541328127737511266559522483e-01
            8.54969008878844083376691287412541e-01 3.78074563670980579033198409888428e-01
            8.23927111248864862957930199627299e-01 4.41652009151295543709636604035040e-01
            7.88165833739917998101986995607149e-01 5.02699711918890290718309188378043e-01
            7.47890013711058121437247336871224e-01 5.60867996260750012460505331546301e-01
            7.03330347412060574718850602948805e-01 6.15823679511843358191924835409736e-01
            6.54742068576193658735462577169528e-01 6.67251980495256802328185585793108e-01
            6.02403486464508253206417975889053e-01 7.14858322560268155676510559715098e-01
            5.46614391735594562504729765350930e-01 7.58370020890726803663994814996840e-01
            4.87694339271838417371185414594947e-01 7.97537844418984454009091678017285e-01
            4.25980817797993072115758650397765e-01 8.32137443398882514777881169720786e-01
            3.61827316776327234659760279100738e-01 8.61970634460779483454473393067019e-01
            2.95601301650996572956131558385096e-01 8.86866535787945831081913183879806e-01
            2.27682109039257396521094278796227e-01 9.06682545912135151588984172121854e-01
            1.58458773925674284432929539434554e-01 9.21305160521880162072250186611200e-01
            8.83278013049616228524740790817305e-02 9.30650622604910049417981099395547e-01
            1.76908950372783521642894299930049e-02 9.34665402200731576520809085195651e-01
            -5.30473430751037255959090543910861e-02 9.33326503015395769757844846026273e-01
            -1.23481730810281867261046784278733e-01 9.26641594142186386662274344416801e-01
            -1.93208826373798325803932129929308e-01 9.14648966133748353435350963991368e-01
            -2.61829239276702319116907347051892e-01 8.97417311677270124192773437243886e-01
            -3.28949918008103248112661276536528e-01 8.75045332128991715237020798667800e-01
            -3.94186401398629482351054775790544e-01 8.47661172161774834066250150499400e-01
            -4.57165020779190411914782998792361e-01 8.15421685764020964803933111397782e-01
            -5.17525040321274443222421268728795e-01 7.78511537794231212039619549614144e-01
            -5.74920723299105485004645288427128e-01 7.37142146237419249032996049209032e-01
            -6.29023312438300008508917926519644e-01 6.91550471222038942720189425017452e-01
            -6.79522913007761353298974427161738e-01 6.41997657733828330783865112607600e-01
            -7.26130267868636103401058790041134e-01 5.88767539800979733399799442850053e-01
            -7.68578414313011104574968612723751e-01 5.32165014718529505444166716188192e-01
            -8.06624213202127959831955195113551e-01 4.72514296624264529267378520671627e-01
            -8.40049741645350067642539215739816e-01 4.10157059429502035552417282815441e-01
            -8.68663541242747472281848786224145e-01 3.45450479741865545957324457049253e-01
            -8.92301714741472240532971227366943e-01 2.78765190990022282413463017292088e-01
            -9.10828864824380302067652337427717e-01 2.10483160468969920930959460747545e-01
            -9.24138869653602368359202046121936e-01 1.40995501465959821585371969376865e-01
            -9.32155490726821578384431177255465e-01 7.07002329990071703980092365782184e-02
            -9.34832809564509981115065784251783e-01 -3.00665162944306869582448110398621e-16
            -9.32155490726821578384431177255465e-01 -7.07002329990069344756165037324536e-02
            -9.24138869653602479381504508637590e-01 -1.40995501465959183207132809911855e-01
            -9.10828864824380413089954799943371e-01 -2.10483160468969698886354535716237e-01
            -8.92301714741472351555273689882597e-01 -2.78765190990022060368858092260780e-01
            -8.68663541242747694326453711255454e-01 -3.45450479741864935334660913213156e-01
            -8.40049741645349956620236753224162e-01 -4.10157059429502202085870976588922e-01
            -8.06624213202128070854257657629205e-01 -4.72514296624264307222773595640319e-01
            -7.68578414313011215597271075239405e-01 -5.32165014718529283399561791156884e-01
            -7.26130267868636325445663715072442e-01 -5.88767539800979178288287130271783e-01
            -6.79522913007761464321276889677392e-01 -6.41997657733828219761562650091946e-01
            -6.29023312438299897486615464003989e-01 -6.91550471222039164764794350048760e-01
            -5.74920723299105485004645288427128e-01 -7.37142146237419360055298511724686e-01
            -5.17525040321274998333933581307065e-01 -7.78511537794230767950409699551528e-01
            -4.57165020779190300892480536276707e-01 -8.15421685764021075826235573913436e-01
            -3.94186401398630037462567088368814e-01 -8.47661172161774500999342762952438e-01
            -3.28949918008103081579207582763047e-01 -8.75045332128991826259323261183454e-01
            -2.61829239276702929739570890887990e-01 -8.97417311677270013170470974728232e-01
            -1.93208826373798769893141979991924e-01 -9.14648966133748353435350963991368e-01
            -1.23481730810281478682988165473944e-01 -9.26641594142186497684576806932455e-01
            -5.30473430751041627462250005464739e-02 -9.33326503015395769757844846026273e-01
            1.76908950372777068471563666207658e-02 -9.34665402200731576520809085195651e-01
            8.83278013049611787632642290191143e-02 -9.30650622604910049417981099395547e-01
            1.58458773925674062388324614403246e-01 -9.21305160521880162072250186611200e-01
            2.27682109039256980187460044362524e-01 -9.06682545912135262611286634637509e-01
            2.95601301650996350911526633353787e-01 -8.86866535787945942104215646395460e-01
            3.61827316776327012615155354069429e-01 -8.61970634460779594476775855582673e-01
            4.25980817797992850071153725366457e-01 -8.32137443398882625800183632236440e-01
            4.87694339271838195326580489563639e-01 -7.97537844418984565031394140532939e-01
            5.46614391735594451482427302835276e-01 -7.58370020890726914686297277512494e-01
            6.02403486464508031161813050857745e-01 -7.14858322560268377721115484746406e-01
            6.54742068576193547713160114653874e-01 -6.67251980495256802328185585793108e-01
            7.03330347412060463696548140433151e-01 -6.15823679511843358191924835409736e-01
            7.47890013711058121437247336871224e-01 -5.60867996260750012460505331546301e-01
            7.88165833739917887079684533091495e-01 -5.02699711918890401740611650893698e-01
            8.23927111248864862957930199627299e-01 -4.41652009151295543709636604035040e-01
            8.54969008878844083376691287412541e-01 -3.78074563670980579033198409888428e-01
            8.81113721451363463010864052193938e-01 -3.12331541328128459156232565874234e-01
            9.02211494420455450971019217831781e-01 -2.44799512201074265238531779687037e-01
            9.18141481653151569908288820442976e-01 -1.75865293637007369387248445491423e-01
            9.28812437625192388601647053292254e-01 -1.05923734597225469022951926945098e-01
            9.34163240067124034382572972390335e-01 -3.53754539980503657226051927864319e-02
            9.08070339613100352416097393870587e-01 3.61302768629648274334442703548120e-02
            9.02329226554106744728755984397139e-01 1.08162403345679586363914381763607e-01
            8.90883297601348100869245172361843e-01 1.79510692289328172011053652568080e-01
            8.73804917602916453311934219527757e-01 2.49724056839156771658849720552098e-01
            8.51202061575898283329877358482918e-01 3.18358585497841795053375335555756e-01
            8.23217632053551806592395223560743e-01 3.84980348676901951154860626047594e-01
            7.90028555609480931387622604233911e-01 4.49168142139269921386812711716630e-01
            7.51844664270872375944065879593836e-01 5.10516149988093137501721230364637e-01
            7.08907368892859324205346638336778e-01 5.68636510365496561369980099698296e-01
            6.61488132881368984250514131417731e-01 6.23161767640125985323606983001810e-01
            6.09886755914066047701282968773739e-01 6.73747195579961211109321084222756e-01
            5.54429478510264583945854610647075e-01 7.20072976822545562924915429903194e-01
            4.95466919433324715082989087022725e-01 7.61846224863323318032826136914082e-01
            4.33371858965942102770441124448553e-01 7.98802835778422704038348456379026e-01
            3.68536882073175364737949166737963e-01 8.30709157974696021931038103502942e-01
            3.01371896353898272025162441423163e-01 8.57363469410320266916869513806887e-01
            2.32301540472978934603887068988115e-01 8.78597252946494822190004470030544e-01
            1.61762499458921071848749306809623e-01 8.94276261767049551743014035309898e-01
            9.02007438405135753001218290592078e-02 9.04301368130041027804111308796564e-01
            1.80687100775581768741240296094475e-02 9.08609190085252871327270440815482e-01
            -5.41775598881011136165319896917936e-02 9.07172492195292168304376900778152e-01
            -1.26081301876566298503234975214582e-01 9.00000357726793431822898128302768e-01
            -1.97187917280094215932706447347300e-01 8.87138131223083381549088244355517e-01
            -2.67047847181863640120269565159106e-01 8.68667131821377336287071102560731e-01
            -3.35219414612191402014218510885257e-01 8.44704139127011588428217692126054e-01
            -4.01271616972541989021294739359291e-01 8.15400654895179544112693292845506e-01
            -4.64786850972725928965445518770139e-01 7.80941945188055042237351699441206e-01
            -5.25363552853355120220157914445736e-01 7.41545869063098384010856989334570e-01
            -5.82618737201222147703560949594248e-01 6.97461501197950917152468264248455e-01
            -6.36190418306394334102549237286439e-01 6.48967557160125663173744214873295e-01
            -6.85739898752417698091221609502099e-01 5.96370631277454821272954177402426e-01
            -7.30953910770435477672890556277707e-01 5.40003258250033479903606803418370e-01
            -7.71546596818887375768269976106239e-01 4.80221810758777734040592122255475e-01
            -8.07261316866923261947874834731920e-01 4.17404246362596154096280542944442e-01
            -8.37872270955309139672806395537918e-01 3.51947717929011472115519154613139e-01
            -8.63185926776470879850933215493569e-01 2.84266062705858413295345599181019e-01
            -8.83042243248053804194341864786111e-01 2.14787185908962174885061813256470e-01
            -8.97315682344174248008528138598194e-01 1.43950355367588544996948485277244e-01
            -9.05916002787238827664850759902038e-01 7.22034243317971752285089337419777e-02
            -9.08788830582355933174198980850633e-01 1.11294533247354843114578471320665e-16
            -9.05916002787238827664850759902038e-01 -7.22034243317969531839040087106696e-02
            -8.97315682344174359030830601113848e-01 -1.43950355367588350707919175874849e-01
            -8.83042243248053804194341864786111e-01 -2.14787185908961952840456888225162e-01
            -8.63185926776470990873235678009223e-01 -2.84266062705858246761891905407538e-01
            -8.37872270955309250695108858053572e-01 -3.51947717929011305582065460839658e-01
            -8.07261316866923372970177297247574e-01 -4.17404246362595932051675617913133e-01
            -7.71546596818887708835177363653202e-01 -4.80221810758777234440231040935032e-01
            -7.30953910770435588695193018793361e-01 -5.40003258250033257859001878387062e-01
            -6.85739898752417698091221609502099e-01 -5.96370631277454710250651714886772e-01
            -6.36190418306394223080246774770785e-01 -6.48967557160125774196046677388949e-01
            -5.82618737201222369748165874625556e-01 -6.97461501197950806130165801732801e-01
            -5.25363552853355342264762839477044e-01 -7.41545869063098272988554526818916e-01
            -4.64786850972726151010050443801447e-01 -7.80941945188054931215049236925552e-01
            -4.01271616972542211065899664390599e-01 -8.15400654895179433090390830329852e-01
            -3.35219414612191957125730823463527e-01 -8.44704139127011366383612767094746e-01
            -2.67047847181863917676025721448241e-01 -8.68667131821377225264768640045077e-01
            -1.97187917280094215932706447347300e-01 -8.87138131223083381549088244355517e-01
            -1.26081301876566131969781281441101e-01 -9.00000357726793431822898128302768e-01
            -5.41775598881017381169833413423476e-02 -9.07172492195292057282074438262498e-01
            1.80687100775579548295191045781394e-02 -9.08609190085252871327270440815482e-01
            9.02007438405137418335755228326889e-02 -9.04301368130041027804111308796564e-01
            1.61762499458920655515115072375920e-01 -8.94276261767049662765316497825552e-01
            2.32301540472978740314857759585720e-01 -8.78597252946494822190004470030544e-01
            3.01371896353898272025162441423163e-01 -8.57363469410320266916869513806887e-01
            3.68536882073174976159890547933173e-01 -8.30709157974696132953340566018596e-01
            4.33371858965941714192382505643764e-01 -7.98802835778422926082953381410334e-01
            4.95466919433324604060686624507071e-01 -7.61846224863323318032826136914082e-01
            5.54429478510264139856644760584459e-01 -7.20072976822545895991822817450156e-01
            6.09886755914065714634375581226777e-01 -6.73747195579961433153926009254064e-01
            6.61488132881368873228211668902077e-01 -6.23161767640126096345909445517464e-01
            7.08907368892858991138439250789816e-01 -5.68636510365497116481492412276566e-01
            7.51844664270872042877158492046874e-01 -5.10516149988093581590931080427254e-01
            7.90028555609480931387622604233911e-01 -4.49168142139270032409115174232284e-01
            8.23217632053551806592395223560743e-01 -3.84980348676901951154860626047594e-01
            8.51202061575898061285272433451610e-01 -3.18358585497842294653736416876200e-01
            8.73804917602916453311934219527757e-01 -2.49724056839157076970181492470147e-01
            8.90883297601348100869245172361843e-01 -1.79510692289328199766629268196994e-01
            9.02329226554106633706453521881485e-01 -1.08162403345680155353214502156334e-01
            9.08070339613100352416097393870587e-01 -3.61302768629651674392455618090025e-02
            8.79180318669380178597805297613377e-01 3.68485730493052152101363105884957e-02
            8.73013500424101973607093896134757e-01 1.10287252883637998390753409694298e-01
            8.60723119732683228377823070331942e-01 1.82952346880273869489386129316699e-01
            8.42395384785047829367954363988247e-01 2.54334161614624576497334373925696e-01
            8.18158851473394510556147452007281e-01 3.23932004944091578302334255567985e-01
            7.88183521664978847809379658428952e-01 3.91257698003700249422820434119785e-01
            7.52679650761162388761249530944042e-01 4.55838999430081159847105709559401e-01
            7.11896272906839211458418503752910e-01 5.17222917795329251156033478764584e-01
            6.66119454194840976413161115488037e-01 5.74978889016396710331946451333351e-01
            6.15670286117833587269387862761505e-01 6.28701796452776018320207640499575e-01
            5.60902633342199696819818655058043e-01 6.78014812508656694589603830536362e-01
            5.02200651601656389289018989074975e-01 7.22572041807759579690184637001948e-01
            4.39976093120797440150226975674741e-01 7.62060947400877042312572484661359e-01
            3.74665418469083244534800769542926e-01 7.96204542988012353710303159459727e-01
            3.06726735103540093518859066534787e-01 8.24763335778261663655541724438081e-01
            2.36636584074100625452174995189125e-01 8.47537006359665778809642233682098e-01
            1.64886597430532577668316207564203e-01 8.64365813795955451048769191402243e-01
            9.19800497768461233771830620753462e-02 8.75131716094446954201657717931084e-01
            1.84283281615494898275642299267929e-02 8.79759198185806501335548546194332e-01
            -5.52526549350647044889228709507734e-02 8.78215801608004276168628621235257e-01
            -1.28546080356287228951828183198813e-01 8.70512352179104831328970703907544e-01
            -2.00937847384041856635406020359369e-01 8.56702884061930958203845420939615e-01
            -2.71920179786041604774737834304688e-01 8.36884260753235631469237887358759e-01
            -3.40995187501221874715184867454809e-01 8.11195495655868015205669507849962e-01
            -4.07678358980784971699051766336197e-01 7.79816776999634142519823853945127e-01
            -4.71501959688594873831846143730218e-01 7.42968203950328920370793639449403e-01
            -5.32018312922880043380757797422120e-01 7.00908242772230072326067329413490e-01
            -5.88802939946641457069631542253774e-01 6.53931913872961678713124911155319e-01
            -6.41457537401005639665640956081916e-01 6.02368722447306548239964740787400e-01
            -6.89612771117106837515109418745851e-01 5.46580347235013253026636448339559e-01
            -7.32930866729913921275851862446871e-01 4.86958103604303971234656955857645e-01
            -7.71107978922711767566511298355181e-01 4.23920198755725230466140374119277e-01
            -8.03876322683685029524269793910207e-01 3.57908798299117925090229164197808e-01
            -8.31006051625373443059174860536586e-01 2.89386924779558796227973971326719e-01
            -8.52306870191934073943684779806063e-01 2.18835209906889593955980899409042e-01
            -8.67629368445739679316375259077176e-01 1.46748523269604941310362278272805e-01
            -8.76866070070739467290366064844420e-01 7.36325011802529127979966006023460e-02
            -8.79952186241595102345058876380790e-01 1.07763062828348502077176784220907e-16
            -8.76866070070739467290366064844420e-01 -7.36325011802526907533916755710379e-02
            -8.67629368445739568294072796561522e-01 -1.46748523269605107843815972046286e-01
            -8.52306870191934184965987242321717e-01 -2.18835209906889371911375974377734e-01
            -8.31006051625373332036872398020932e-01 -2.89386924779558962761427665100200e-01
            -8.03876322683685140546572256425861e-01 -3.57908798299117758556775470424327e-01
            -7.71107978922711878588813760870835e-01 -4.23920198755725008421535449087969e-01
            -7.32930866729913810253549399931217e-01 -4.86958103604304193279261880888953e-01
            -6.89612771117106948537411881261505e-01 -5.46580347235013142004333985823905e-01
            -6.41457537401006083754850806144532e-01 -6.02368722447306104150754890724784e-01
            -5.88802939946641346047329079738120e-01 -6.53931913872961789735427373670973e-01
            -5.32018312922880487469967647484737e-01 -7.00908242772229739259159941866528e-01
            -4.71501959688594762809543681214564e-01 -7.42968203950329031393096101965057e-01
            -4.07678358980785471299412847656640e-01 -7.79816776999633809452916466398165e-01
            -3.40995187501222096759789792486117e-01 -8.11195495655867904183367045334307e-01
            -2.71920179786041826819342759335996e-01 -8.36884260753235520446935424843105e-01
            -2.00937847384042078680010945390677e-01 -8.56702884061930958203845420939615e-01
            -1.28546080356288200396974730210786e-01 -8.70512352179104720306668241391890e-01
            -5.52526549350647322444984865796869e-02 -8.78215801608004276168628621235257e-01
            1.84283281615488792049006860906957e-02 -8.79759198185806501335548546194332e-01
            9.19800497768462899106367558488273e-02 -8.75131716094446954201657717931084e-01
            1.64886597430532161334681973130500e-01 -8.64365813795955562071071653917897e-01
            2.36636584074100431163145685786731e-01 -8.47537006359665778809642233682098e-01
            3.06726735103539926985405372761306e-01 -8.24763335778261774677844186953735e-01
            3.74665418469083189023649538285099e-01 -7.96204542988012353710303159459727e-01
            4.39976093120796940549865894354298e-01 -7.62060947400877264357177409692667e-01
            5.02200651601656389289018989074975e-01 -7.22572041807759579690184637001948e-01
            5.60902633342199252730608804995427e-01 -6.78014812508657027656511218083324e-01
            6.15670286117833809313992787792813e-01 -6.28701796452775796275602715468267e-01
            6.66119454194840754368556190456729e-01 -5.74978889016397043398853838880314e-01
            7.11896272906839211458418503752910e-01 -5.17222917795329473200638403795892e-01
            7.52679650761162277738947068428388e-01 -4.55838999430081270869408172075055e-01
            7.88183521664978847809379658428952e-01 -3.91257698003700304933971665377612e-01
            8.18158851473394177489240064460319e-01 -3.23932004944092299947300261919736e-01
            8.42395384785047940390256826503901e-01 -2.54334161614624354452729448894388e-01
            8.60723119732683117355520607816288e-01 -1.82952346880274369089747210637142e-01
            8.73013500424101973607093896134757e-01 -1.10287252883637582057119175260596e-01
            8.79180318669380178597805297613377e-01 -3.68485730493054788881046590631740e-02
            8.47734455827822031004359359940281e-01 3.75348702512605797432243548428232e-02
            8.41099784310113784968621075677220e-01 1.12310849502407661404390637471806e-01
            8.27882366574943628911853465979220e-01 1.86207844079520706825903175740677e-01
            8.08185646836926507852183476643404e-01 2.58647509806785524943961718236096e-01
            7.82163778633811923590712922305102e-01 3.29062908082557614708463233910152e-01
            7.50020418366042274094240838167025e-01 3.96902942942603365050757702192641e-01
            7.12007131409291171841857703839196e-01 4.61636674133224400584651903045597e-01
            6.68421423274314974172227721282979e-01 5.22757472438617254439918724528980e-01
            6.19604411222956397153893703944050e-01 5.79786984741401445475617038027849e-01
            5.65938154563069173441647308209212e-01 6.32278877784336668099740563775413e-01
            5.07842664516416464337567049369682e-01 6.79822331333223339733251577854389e-01
            4.45772617061390152848332490975736e-01 7.22045253402244679996613285766216e-01
            3.80213794477006483685244120351854e-01 7.58617192378256866014396564423805e-01
            3.11679283437925003230617448934936e-01 7.89251923252705211986324229656020e-01
            2.40705459415550687696239151591726e-01 8.13709687720394092558251486480003e-01
            1.67847788812726411711295781969966e-01 8.31799070613300828291869493114064e-01
            9.36764816859991938935436905921961e-02 8.43378497983796826531488477485254e-01
            1.87720290788113593205554963105897e-02 8.48357345112740079962065919971792e-01
            -5.62793401079762362071434722565755e-02 8.46696645770776190609296918410109e-01
            -1.30890247152069261193929605724406e-01 8.38409397181915427843534871499287e-01
            -2.04476760544641089634154695886537e-01 8.23560458302632469873572063079337e-01
            -2.76462966046113090001767886860762e-01 8.02266042212593122329167272255290e-01
            -3.46285473995931292190419981125160e-01 7.74692806589738380829146535688778e-01
            -4.13397828600533201459654719656100e-01 7.41056549387991592148239305970492e-01
            -4.77274784690843723033992773707723e-01 7.01620519925679864137180175021058e-01
            -5.37416418477879576087730129074771e-01 6.56693358602689958303244566195644e-01
            -5.93352040134215719113797149475431e-01 6.06626681370871279064260761515470e-01
            -6.44643877580072466315641577239148e-01 5.51812327862472584705244571523508e-01
            -6.90890502643392467874150497664232e-01 4.92679294713744830858104251092300e-01
            -7.31729972779563864193619338038843e-01 4.29690378084605584252386734078755e-01
            -7.66842663762570597718593035097001e-01 3.63338551651208041537444159985171e-01
            -7.95953771177925206714576233935077e-01 2.94143108418524201752575208956841e-01
            -8.18835461139803877372855822613928e-01 2.22645596548499663525078062775719e-01
            -8.35308653400113287901262992818374e-01 1.49405581011426147330922731271130e-01
            -8.45244422894237068533129786374047e-01 7.49962642313647120939634760361514e-02
            -8.48565008754469274343534834770253e-01 1.03919242183960661007349900546499e-16
            -8.45244422894237068533129786374047e-01 -7.49962642313645178049341666337568e-02
            -8.35308653400113398923565455334028e-01 -1.49405581011425953041893421868735e-01
            -8.18835461139803988395158285129583e-01 -2.22645596548499496991624369002238e-01
            -7.95953771177925095692273771419423e-01 -2.94143108418524312774877671472495e-01
            -7.66842663762570819763197960128309e-01 -3.63338551651207541937083078664728e-01
            -7.31729972779563753171316875523189e-01 -4.29690378084605750785840427852236e-01
            -6.90890502643392467874150497664232e-01 -4.92679294713744664324650557318819e-01
            -6.44643877580072688360246502270456e-01 -5.51812327862472584705244571523508e-01
            -5.93352040134215608091494686959777e-01 -6.06626681370871390086563224031124e-01
            -5.37416418477879687110032591590425e-01 -6.56693358602689736258639641164336e-01
            -4.77274784690844222634353855028166e-01 -7.01620519925679420047970324958442e-01
            -4.13397828600532701859293638335657e-01 -7.41056549387991703170541768486146e-01
            -3.46285473995931847301932293703430e-01 -7.74692806589738047762239148141816e-01
            -2.76462966046113312046372811892070e-01 -8.02266042212593011306864809739636e-01
            -2.04476760544641644745667008464807e-01 -8.23560458302632358851269600563683e-01
            -1.30890247152069816305441918302677e-01 -8.38409397181915316821232408983633e-01
            -5.62793401079762570238251839782606e-02 -8.46696645770776190609296918410109e-01
            1.87720290788109603341560216449579e-02 -8.48357345112740079962065919971792e-01
            9.36764816859988053154850717874069e-02 -8.43378497983796826531488477485254e-01
            1.67847788812726383955720166341052e-01 -8.31799070613300828291869493114064e-01
            2.40705459415550687696239151591726e-01 -8.13709687720394092558251486480003e-01
            3.11679283437925336297524836481898e-01 -7.89251923252705100964021767140366e-01
            3.80213794477006594707546582867508e-01 -7.58617192378256754992094101908151e-01
            4.45772617061389486714517715881811e-01 -7.22045253402245013063520673313178e-01
            5.07842664516416353315264586854028e-01 -6.79822331333223450755554040370043e-01
            5.65938154563068840374739920662250e-01 -6.32278877784337001166647951322375e-01
            6.19604411222956064086986316397088e-01 -5.79786984741401778542524425574811e-01
            6.68421423274314863149925258767325e-01 -5.22757472438617365462221187044634e-01
            7.12007131409291060819555241323542e-01 -4.61636674133224567118105596819078e-01
            7.50020418366042274094240838167025e-01 -3.96902942942603254028455239676987e-01
            7.82163778633811923590712922305102e-01 -3.29062908082557614708463233910152e-01
            8.08185646836926507852183476643404e-01 -2.58647509806785802499717874525231e-01
            8.27882366574943739934155928494874e-01 -1.86207844079520373758995788193715e-01
            8.41099784310113895990923538192874e-01 -1.12310849502407550382088174956152e-01
            8.47734455827822031004359359940281e-01 -3.75348702512614332271745354319137e-02
            8.13919550979645078925273082859349e-01 3.81922282261567061500961983711022e-02
            8.06766796700178701051697771617910e-01 1.14241050003571098514498771692161e-01
            7.92524146803039730713180688326247e-01 1.89285917325879654571352261882566e-01
            7.71316766207635895469252318434883e-01 2.62667333200725328090641141898232e-01
            7.43331026137176609225321044505108e-01 3.33740419106882901800759100297000e-01
            7.08812866281661957401638574083336e-01 4.01880582209890591105505563973566e-01
            6.68065633471044084679135721671628e-01 4.66489004306337717853381263921619e-01
            6.21447415852378615142015405581333e-01 5.26997904259767002699277327337768e-01
            5.69367895998312611993696918943897e-01 5.82875527681717464645316795213148e-01
            5.12284750601905369826738478877814e-01 6.33630820008409645360814010928152e-01
            4.50699628397393414758198559866287e-01 6.78817741905909044497491322545102e-01
            3.85153741653077641426961008619401e-01 7.18039189079830220130418183543952e-01
            3.16223109978448158052799499273533e-01 7.50950482042154421336022096511442e-01
            2.44513498243145638300077848725778e-01 7.77262395166963604431487055990146e-01
            1.70655093093504878209998310012452e-01 7.96743698415640411170102197502274e-01
            9.52969648496493904055171242362121e-02 8.09223189394761788229004650929710e-01
            1.91013634521777497798922240690445e-02 8.14591197888888118860961640166352e-01
            -5.72621014141237935635153633029404e-02 8.12800549646359726807531842496246e-01
            -1.33122344874270409631478173650976e-01 8.03866980948316878219372938474407e-01
            -2.07812704381087787197657235083170e-01 7.87869000317695244994808945193654e-01
            -2.80676798369647984010555319400737e-01 7.64947198583503462643307102553081e-01
            -3.51074294562063904390214474915410e-01 7.35303013363562296689224240253679e-01
            -4.18386537230569233170029974644422e-01 6.99196958823477210387409286340699e-01
            -4.82021983966301026391931827674853e-01 6.56946336268783070977406168822199e-01
            -5.41421404175255971402691557159415e-01 6.08922445689662472645409252436366e-01
            -5.96062793616860320256023442198057e-01 5.55547322763281781199395936710062e-01
            -6.45465961796004794592818143428303e-01 4.97290029989084281236699780492927e-01
            -6.89196751894380232883463577309158e-01 4.34662534550680990097504263758310e-01
            -7.26870856156208611231761551607633e-01 3.68215209129832299339568635332398e-01
            -7.58157193198619960838868792052381e-01 2.98531995211528844436088547809049e-01
            -7.82780817566747222358003455155995e-01 2.26225271385229215193035656739085e-01
            -8.00525335964271222977117759000976e-01 1.51930471739794625829489405077766e-01
            -8.11234808925489159214805567899020e-01 7.63005016458676715851439098514675e-02
            -8.14815121216945659199382134829648e-01 9.97860730095195098746697494150033e-17
            -8.11234808925489159214805567899020e-01 -7.63005016458674634183267926346161e-02
            -8.00525335964271333999420221516630e-01 -1.51930471739794403784884480046458e-01
            -7.82780817566747333380305917671649e-01 -2.26225271385229048659581962965603e-01
            -7.58157193198620071861171254568035e-01 -2.98531995211528677902634854035568e-01
            -7.26870856156208833276366476638941e-01 -3.68215209129831744228056322754128e-01
            -6.89196751894380121861161114793504e-01 -4.34662534550681156630957957531791e-01
            -6.45465961796004905615120605943957e-01 -4.97290029989084114703246086719446e-01
            -5.96062793616860431278325904713711e-01 -5.55547322763281559154791011678753e-01
            -5.41421404175256082424994019675069e-01 -6.08922445689662472645409252436366e-01
            -4.82021983966301192925385521448334e-01 -6.56946336268782848932801243790891e-01
            -4.18386537230569399703483668417903e-01 -6.99196958823477099365106823825045e-01
            -3.51074294562063793367912012399756e-01 -7.35303013363562296689224240253679e-01
            -2.80676798369648539122067631979007e-01 -7.64947198583503240598702177521773e-01
            -2.07812704381087953731110928856651e-01 -7.87869000317695244994808945193654e-01
            -1.33122344874270409631478173650976e-01 -8.03866980948316878219372938474407e-01
            -5.72621014141236339689555734366877e-02 -8.12800549646359726807531842496246e-01
            1.91013634521775485519690107594215e-02 -8.14591197888888118860961640166352e-01
            9.52969648496491961164878148338175e-02 -8.09223189394761899251307113445364e-01
            1.70655093093505016987876388157019e-01 -7.96743698415640411170102197502274e-01
            2.44513498243145110944141151776421e-01 -7.77262395166963715453789518505801e-01
            3.16223109978447991519345805500052e-01 -7.50950482042154532358324559027096e-01
            3.85153741653077641426961008619401e-01 -7.18039189079830220130418183543952e-01
            4.50699628397392970668988709803671e-01 -6.78817741905909266542096247576410e-01
            5.12284750601905480849040941393469e-01 -6.33630820008409423316209085896844e-01
            5.69367895998312500971394456428243e-01 -5.82875527681717464645316795213148e-01
            6.21447415852378282075108018034371e-01 -5.26997904259767446788487177400384e-01
            6.68065633471044306723740646702936e-01 -4.66489004306337440297625107632484e-01
            7.08812866281661846379336111567682e-01 -4.01880582209890868661261720262701e-01
            7.43331026137176387180716119473800e-01 -3.33740419106883567934573875390925e-01
            7.71316766207636006491554780950537e-01 -2.62667333200725161557187448124751e-01
            7.92524146803039730713180688326247e-01 -1.89285917325879987638259649429529e-01
            8.06766796700178701051697771617910e-01 -1.14241050003571251170164657651185e-01
            8.13919550979645078925273082859349e-01 -3.81922282261566437000510632060468e-02
            7.77885607142136614733374244678998e-01 3.88226566514173754285366158001125e-02
            7.70154630498315784237206571560819e-01 1.16082132950626540357497162858635e-01
            7.54769511129850245723105217621196e-01 1.92187932860445692684336904676456e-01
            7.31883153265083907790256034786580e-01 2.66383682749379457899152612299076e-01
            7.01723011810612473659887200483354e-01 3.37931991921166630099548910948215e-01
            6.64588831802233048762218459160067e-01 4.06121781134806403290582466070191e-01
            6.20849669404112014525765061989659e-01 4.70275349629522110284085556486389e-01
            5.70940224062820411710106327518588e-01 5.29755110419390717879650765098631e-01
            5.15356518268936358850851320312358e-01 5.83969926919258308650739763834281e-01
            4.54650967862686494758150956840836e-01 6.32380987925701965046698660444235e-01
            3.89426891877141689857211304115481e-01 6.74507162564841333818321800208651e-01
            3.20332516482615181629967082699295e-01 7.09929781987119756792026237235405e-01
            2.48054532623751572417702959683083e-01 7.38296800286427190584959134866949e-01
            1.73311271376412556755042260192567e-01 7.59326293290477294384288597939303e-01
            9.68455648507190042240111438331951e-02 7.72809260449892287958562064886792e-01
            1.94173635918098407004972472122972e-02 7.78611701979560422159920562990010e-01
            -5.82038161500982656471059328850970e-02 7.76675950608701315402981890656520e-01
            -1.35246540217924759996748207413475e-01 7.67021244704112148404817617119988e-01
            -2.10945123406960949319355336228909e-01 7.49743537070634902264032461971510e-01
            -2.84547239188432554701790877516032e-01 7.25014541329072503828001572401263e-01
            -3.55321396668539679630782757158158e-01 6.93080025349080863783512995723868e-01
            -4.22564210473596602035684099973878e-01 6.54257368697663488354976379923755e-01
            -4.85607391309883118513113231529132e-01 6.08932408378445977348292217357084e-01
            -5.43824387722889102114720571989892e-01 5.57555604210189126312968710408313e-01
            -5.96636613047158981260054133599624e-01 5.00637561954732857039118698594393e-01
            -6.43519195660514076173797093360918e-01 4.38743958687534851836886673481786e-01
            -6.84006195394042726398708964552497e-01 3.72489920844753852335884403146338e-01
            -7.17695234254830949360837166750571e-01 3.02533910820370233185627739658230e-01
            -7.44251495439232746420543662679847e-01 2.29571182871086826304818373500893e-01
            -7.63411050892687903512978664366528e-01 1.54326873367168937445370602290495e-01
            -7.74983484345301509854664345766651e-01 7.75487940614179305232056549357367e-02
            -7.78853783754283601759027533262270e-01 9.53820793278488263023691190749934e-17
            -7.74983484345301509854664345766651e-01 -7.75487940614177362341763455333421e-02
            -7.63411050892688014535281126882182e-01 -1.54326873367168743156341292888101e-01
            -7.44251495439232968465148587711155e-01 -2.29571182871086326704457292180450e-01
            -7.17695234254830838338534704234917e-01 -3.02533910820370344207930202173884e-01
            -6.84006195394042837421011427068152e-01 -3.72489920844753685802430709372857e-01
            -6.43519195660514187196099555876572e-01 -4.38743958687534796325735442223959e-01
            -5.96636613047159203304659058630932e-01 -5.00637561954732746016816236078739e-01
            -5.43824387722889324159325497021200e-01 -5.57555604210189126312968710408313e-01
            -4.85607391309883285046566925302614e-01 -6.08932408378445755303687292325776e-01
            -4.22564210473596546524532868716051e-01 -6.54257368697663488354976379923755e-01
            -3.55321396668540123719992607220775e-01 -6.93080025349080641738908070692560e-01
            -2.84547239188433220835605652609956e-01 -7.25014541329072281783396647369955e-01
            -2.10945123406960644008023564310861e-01 -7.49743537070634902264032461971510e-01
            -1.35246540217924787752323823042389e-01 -7.67021244704112148404817617119988e-01
            -5.82038161500986195306950321537443e-02 -7.76675950608701315402981890656520e-01
            1.94173635918096498809148897635168e-02 -7.78611701979560422159920562990010e-01
            9.68455648507184768680744468838384e-02 -7.72809260449892398980864527402446e-01
            1.73311271376412390221588566419086e-01 -7.59326293290477294384288597939303e-01
            2.48054532623751711195581037827651e-01 -7.38296800286427079562656672351295e-01
            3.20332516482614848563059695152333e-01 -7.09929781987119867814328699751059e-01
            3.89426891877141911901816229146789e-01 -6.74507162564841222796019337692996e-01
            4.54650967862686161691243569293874e-01 -6.32380987925702187091303585475544e-01
            5.15356518268935803739339007734088e-01 -5.83969926919258752739949613896897e-01
            5.70940224062820522732408790034242e-01 -5.29755110419390495835045840067323e-01
            6.20849669404111903503462599474005e-01 -4.70275349629522165795236787744216e-01
            6.64588831802233048762218459160067e-01 -4.06121781134806347779431234812364e-01
            7.01723011810612362637584737967700e-01 -3.37931991921166796633002604721696e-01
            7.31883153265083685745651109755272e-01 -2.66383682749380013010664924877346e-01
            7.54769511129850245723105217621196e-01 -1.92187932860445970240093060965592e-01
            7.70154630498315784237206571560819e-01 -1.16082132950626498724133739415265e-01
            7.77885607142136614733374244678998e-01 -3.88226566514177154343379072543030e-02
            7.39756288517634197354766456555808e-01 3.94273190378126581201456701819552e-02
            7.31374554177114499786682699777884e-01 1.17835229834382243518930977188575e-01
            7.14706053895324378011366661667125e-01 1.94908020392359465633447257459920e-01
            6.89939648440851205357660091976868e-01 2.69772425197997933743465637235204e-01
            6.57355951083647638277795977046480e-01 3.41580200630551333862428009524592e-01
            6.17324148134555716893601129413582e-01 4.09517735901437696099947061156854e-01
            5.70297815916885553200188496703049e-01 4.72815271589576258115528162306873e-01
            5.16809781565432113659142032702221e-01 5.30755621323208304218610464886297e-01
            4.57466085882131667794681106897769e-01 5.82682297788062908416861773730488e-01
            3.92939116651613462583014779738733e-01 6.28006950990945944646171028580284e-01
            3.23959990218928017835509081123746e-01 6.66216034500256348849234200315550e-01
            2.51310267649218099794694580850773e-01 6.96876624132258482013924094644608e-01
            1.75813099328554600653262696141610e-01 7.19641323155071788164605095516890e-01
            9.83238983411488520758325648785103e-02 7.34252198432455593923862124938751e-01
            1.97206482973012360571107848272732e-02 7.40543702909307599568933255795855e-01
            -5.91060445717258714504183103599644e-02 7.38444551325947440290065060253255e-01
            -1.37263042338178403722892539917666e-01 7.27978527908593076034549085306935e-01
            -2.13864794987410289373030991555424e-01 7.09264216884573750476761233585421e-01
            -2.88043374053398915091150911393925e-01 6.82513658875650852664307421946432e-01
            -3.58958306595070053557350320261321e-01 6.48029948393046395516137181402883e-01
            -4.25806098090557361146579751220997e-01 6.06203799655519626199406957312021e-01
            -4.87829336351194742249504088249523e-01 5.57509119641147798951408276479924e-01
            -5.44325273304260615070404583093477e-01 5.02497638531900658875883891596459e-01
            -5.94653787409446077383279316563858e-01 4.41792658390218251351910794255673e-01
            -6.38244636491684724788342464307789e-01 3.76081990897585871636010779184289e-01
            -6.74603918812856084841200754453894e-01 3.06110164173344856397562807615031e-01
            -7.03319669175828998675115144578740e-01 2.32669986973604109303792597529537e-01
            -7.24066526654759234915559318324085e-01 1.56593565851243093911548953656165e-01
            -7.36609421064386760136244447494391e-01 7.87428770561737489952491841904703e-02
            -7.40806236399164430572739092895063e-01 9.07225986194634127612563215997807e-17
            -7.36609421064386871158546910010045e-01 -7.87428770561732493948881028700271e-02
            -7.24066526654759123893256855808431e-01 -1.56593565851243232689427031800733e-01
            -7.03319669175829109697417607094394e-01 -2.32669986973603887259187672498228e-01
            -6.74603918812856306885805679485202e-01 -3.06110164173344412308352957552415e-01
            -6.38244636491684835810644926823443e-01 -3.76081990897585705102557085410808e-01
            -5.94653787409445966360976854048204e-01 -4.41792658390218362374213256771327e-01
            -5.44325273304260948137311970640440e-01 -5.02497638531900325808976504049497e-01
            -4.87829336351194908782957782023004e-01 -5.57509119641147687929105813964270e-01
            -4.25806098090557194613126057447516e-01 -6.06203799655519737221709419827675e-01
            -3.58958306595069942535047857745667e-01 -6.48029948393046395516137181402883e-01
            -2.88043374053399414691511992714368e-01 -6.82513658875650741642004959430778e-01
            -2.13864794987410289373030991555424e-01 -7.09264216884573750476761233585421e-01
            -1.37263042338178264945014461773098e-01 -7.27978527908593076034549085306935e-01
            -5.91060445717265514620208932683454e-02 -7.38444551325947440290065060253255e-01
            1.97206482973012187098760250592022e-02 -7.40543702909307599568933255795855e-01
            9.83238983411486716645910632905725e-02 -7.34252198432455593923862124938751e-01
            1.75813099328553934519447921047686e-01 -7.19641323155072010209210020548198e-01
            2.51310267649217933261240887077292e-01 -6.96876624132258593036226557160262e-01
            3.23959990218927851302055387350265e-01 -6.66216034500256348849234200315550e-01
            3.92939116651613296049561085965252e-01 -6.28006950990946055668473491095938e-01
            4.57466085882131501261227413124288e-01 -5.82682297788063019439164236246143e-01
            5.16809781565432002636839570186567e-01 -5.30755621323208526263215389917605e-01
            5.70297815916885775244793421734357e-01 -4.72815271589576036070923237275565e-01
            6.17324148134555605871298666897928e-01 -4.09517735901438029166854448703816e-01
            6.57355951083647527255493514530826e-01 -3.41580200630551666929335397071554e-01
            6.89939648440851205357660091976868e-01 -2.69772425197997600676558249688242e-01
            7.14706053895324266989064199151471e-01 -1.94908020392359881967081491893623e-01
            7.31374554177114610808985162293538e-01 -1.17835229834382035352113859971723e-01
            7.39756288517634197354766456555808e-01 -3.94273190378124915866919764084741e-02
            6.99635518845239112728506825078512e-01 4.00066064255785100445272917113471e-02
            6.90514699902463835456956076086499e-01 1.19498271979758902139323595292808e-01
            6.72391965840327121561870171717601e-01 1.97432094809629310461218665295746e-01
            6.45503574212478725691255476704100e-01 2.72792088350181149980500094898161e-01
            6.10200056324282980035889067949029e-01 3.44595819837356653891902169561945e-01
            5.66941647521184699520802041661227e-01 4.11907217821565696524999111716170e-01
            5.16292287317142273295189625059720e-01 4.73848775290568235973864830157254e-01
            4.58912267580629085195198513247306e-01 5.29612989315352056252095280797221e-01
            3.95549624620340767311432728092768e-01 5.78472888085730163609810006164480e-01
            3.27030387387938548116039783053566e-01 6.19791508099645560569967983610695e-01
            2.54247808927414664648125608437113e-01 6.53030197956531721636963538912823e-01
            1.78150721455610810961545098507486e-01 6.77755640502079037545968276390340e-01
            9.97311668832178699339863214845536e-02 6.93645501780015716342120413173689e-01
            2.00114640313398262083666168109630e-02 7.00492633148172783030815935489954e-01
            -5.99691188577770178946835244460090e-02 6.98207771777828334336390980752185e-01
            -1.39167912571635216112397870347195e-01 6.86820704331189912927868590486469e-01
            -2.16552439715229944061647415765037e-01 6.66479878646699885891280246141832e-01
            -2.91113874632862645874809004453709e-01 6.37450468494439204114598851447226e-01
            -3.61880194993363435429500896134414e-01 6.00110916630503643531824309320655e-01
            -4.27928853587694169036126368155237e-01 5.54948001216924780010231188498437e-01
            -4.88398805142672809420645307909581e-01 5.02550489923895726818159346294124e-01
            -5.42501731362907912981086155923549e-01 4.43601464442787196684747641484137e-01
            -5.89532317865356536579213297954993e-01 3.78869415471661363792321708388044e-01
            -6.28877449030947222041731947683729e-01 3.09198224263766530128805243293755e-01
            -6.60024200904313129711908914032392e-01 2.35496161344852850128006593877217e-01
            -6.82566527941967149395452452154132e-01 1.58724045817846354244906592612097e-01
            -6.96210556436927419099447433836758e-01 7.98827196164607206130270355970424e-02
            -7.00778415611909455407158020534553e-01 8.58206043590678539149861842925588e-17
            -6.96210556436927419099447433836758e-01 -7.98827196164605402017855340091046e-02
            -6.82566527941967260417754914669786e-01 -1.58724045817846187711452898838616e-01
            -6.60024200904313240734211376548046e-01 -2.35496161344852683594552900103736e-01
            -6.28877449030947222041731947683729e-01 -3.09198224263766641151107705809409e-01
            -5.89532317865356758623818222986301e-01 -3.78869415471660975214263089583255e-01
            -5.42501731362908024003388618439203e-01 -4.43601464442787030151293947710656e-01
            -4.88398805142672975954099001683062e-01 -5.02550489923895615795856883778470e-01
            -4.27928853587694557614184986960026e-01 -5.54948001216924446943323800951475e-01
            -3.61880194993363879518710746197030e-01 -6.00110916630503421487219384289347e-01
            -2.91113874632862701385960235711536e-01 -6.37450468494439204114598851447226e-01
            -2.16552439715230082839525493909605e-01 -6.66479878646699885891280246141832e-01
            -1.39167912571635549179305257894157e-01 -6.86820704331189801905566127970815e-01
            -5.99691188577774966783628940447670e-02 -6.98207771777828223314088518236531e-01
            2.00114640313396527360190191302536e-02 -7.00492633148172783030815935489954e-01
            9.97311668832177034005326277110726e-02 -6.93645501780015827364422875689343e-01
            1.78150721455610339116759632815956e-01 -6.77755640502079259590573201421648e-01
            2.54247808927414775670428070952767e-01 -6.53030197956531610614661076397169e-01
            3.27030387387938381582586089280085e-01 -6.19791508099645560569967983610695e-01
            3.95549624620340489755676571803633e-01 -5.78472888085730274632112468680134e-01
            4.58912267580629196217500975762960e-01 -5.29612989315351945229792818281567e-01
            5.16292287317142384317492087575374e-01 -4.73848775290568180462713598899427e-01
            5.66941647521184921565406966692535e-01 -4.11907217821565418969242955427035e-01
            6.10200056324282757991284142917721e-01 -3.44595819837356986958809557108907e-01
            6.45503574212478503646650551672792e-01 -2.72792088350181594069709944960778e-01
            6.72391965840327121561870171717601e-01 -1.97432094809629393727945512182487e-01
            6.90514699902463835456956076086499e-01 -1.19498271979759138061716328138573e-01
            6.99635518845239112728506825078512e-01 -4.00066064255789055614798144233646e-02
            6.57611821947631680629342554311734e-01 4.05601088363415351878416004183237e-02
            6.47643097059486194666533265262842e-01 1.21065476603764057839107692871039e-01
            6.27856762990940731050670819968218e-01 1.99735615153225160023353623728326e-01
            5.98552760397396133029701559280511e-01 2.75377965376238542649645069104736e-01
            5.60175308087315193539268420863664e-01 3.46845866348989506633415658143349e-01
            5.13306169117897725939769770775456e-01 4.13055937543098050657164321819437e-01
            4.58655831860150631218431271918234e-01 4.73004501770091789758510003593983e-01
            3.97052739719415126451451669709058e-01 5.25782799904490949494118012808030e-01
            3.29430732777809986977501921501243e-01 5.70590766745812993931963319482747e-01
            2.56814891730491989818574438686483e-01 6.06749159191469544794017565436661e-01
            1.80305998707225578758794881650829e-01 6.33709852869820400300682194938418e-01
            1.01063850537372573734629099817539e-01 6.51064151146919734003404300892726e-01
            2.02896774121895176468122201640654e-02 6.58548980550884177631587590440176e-01
            -6.07920665404038523815799521798908e-02 6.56050878697564621155891018133843e-01
            -1.40952264732265297730862130265450e-01 6.43607714264632591039116960018873e-01
            -2.18975770269612707297213205492881e-01 6.21408112941027934716942127124639e-01
            -2.93679826341282368407092917550472e-01 5.89788598053788915009931770327967e-01
            -3.63931995606349312222249636761262e-01 5.49228489217447268799787707393989e-01
            -4.28667326789873459613744444141048e-01 5.00342636337263835244471010810230e-01
            -4.86904498258675322297506227187114e-01 4.43872099111407625304792645692942e-01
            -5.37760693856992211259182568028336e-01 3.80672913321326134017397180286935e-01
            -5.80464985499504648736035505862674e-01 3.11703114201894670998171932296827e-01
            -6.14370019655270271918823254964082e-01 2.38008213603821655590664363444375e-01
            -6.38961830567376320999528616084717e-01 1.60705351099728582786596575715521e-01
            -6.53867631449907005247723645879887e-01 8.09663592869787201999898229587416e-02
            -6.58861465555620084977306305518141e-01 8.06872584874224201937077891033343e-17
            -6.53867631449907005247723645879887e-01 -8.09663592869785536665361291852605e-02
            -6.38961830567376320999528616084717e-01 -1.60705351099728721564474653860088e-01
            -6.14370019655270271918823254964082e-01 -2.38008213603821516812786285299808e-01
            -5.80464985499504759758337968378328e-01 -3.11703114201894504464718238523346e-01
            -5.37760693856992211259182568028336e-01 -3.80672913321326022995094717771281e-01
            -4.86904498258675377808657458444941e-01 -4.43872099111407458771338951919461e-01
            -4.28667326789873293080290750367567e-01 -5.00342636337263946266773473325884e-01
            -3.63931995606349478755703330534743e-01 -5.49228489217447268799787707393989e-01
            -2.93679826341282257384790455034818e-01 -5.89788598053789026032234232843621e-01
            -2.18975770269612846075091283637448e-01 -6.21408112941027934716942127124639e-01
            -1.40952264732265603042193902183499e-01 -6.43607714264632480016814497503219e-01
            -6.07920665404038662593677599943476e-02 -6.56050878697564621155891018133843e-01
            2.02896774121893580522524302978127e-02 -6.58548980550884177631587590440176e-01
            1.01063850537372698634719370147650e-01 -6.51064151146919734003404300892726e-01
            1.80305998707225578758794881650829e-01 -6.33709852869820400300682194938418e-01
            2.56814891730492211863179363717791e-01 -6.06749159191469433771715102921007e-01
            3.29430732777810097999804384016898e-01 -5.70590766745812882909660856967093e-01
            3.97052739719414959917997975935577e-01 -5.25782799904491060516420475323685e-01
            4.58655831860150742240733734433888e-01 -4.73004501770091678736207541078329e-01
            5.13306169117897725939769770775456e-01 -4.13055937543098161679466784335091e-01
            5.60175308087314971494663495832356e-01 -3.46845866348989784189171814432484e-01
            5.98552760397396133029701559280511e-01 -2.75377965376238487138493837846909e-01
            6.27856762990940620028368357452564e-01 -1.99735615153225298801231701872894e-01
            6.47643097059486194666533265262842e-01 -1.21065476603763877427866191283101e-01
            6.57611821947631680629342554311734e-01 -4.05601088363415837600989277689223e-02
            6.13761225853891145831653375353198e-01 4.10864798618947660302502811191516e-02
            6.02808642238255143475100794603350e-01 1.22526250379192000461436862224218e-01
            5.81098924121075444126915954257129e-01 2.01779537055771784892499454144854e-01
            5.49019481936466213767289445968345e-01 2.77432063113345339644411069457419e-01
            5.07142774090187820057451517641312e-01 3.48133807432173758567017785026110e-01
            4.56216091425834580075360236151027e-01 4.12623095709931941854620163212530e-01
            3.97148221802027467930429338593967e-01 4.69749115069523714982580031573889e-01
            3.30993232751547128422942023462383e-01 5.18492450342136756979982692428166e-01
            2.58931661621240205573002413075301e-01 5.57983275555080204810565192019567e-01
            1.82249448855097362365285107443924e-01 5.87516875996874077259235491510481e-01
            1.02314990356565480023043335222610e-01 6.06566223867970544247896214073990e-01
            2.05547184312338329648106594049750e-02 6.14791383104322464170365947211394e-01
            -6.15723529314536402456958796847175e-02 6.12045575544499453890523454901995e-01
            -1.42600664197403054211932271755359e-01 5.98377800189455966162199729296844e-01
            -2.21084263232477651328622414439451e-01 5.74031958814198439711162791354582e-01
            -2.95622608352584970159426802638336e-01 5.39442503534832029643553141795564e-01
            -3.64885561023210958087048538800445e-01 4.95226684000256267559336720296415e-01
            -4.27637122213078313404110986084561e-01 4.42173532557558035538392005037167e-01
            -4.82757488826141722970675118631334e-01 3.81229783951084644222362385335146e-01
            -5.29263036614365356413713925576303e-01 3.13482980818503231823513033305062e-01
            -5.66323872975731612555705396516714e-01 2.40142066466665637936017674292088e-01
            -5.93278646407384369076964958367171e-01 1.62515811249659247739174361413461e-01
            -6.09646348338865218252635713724885e-01 8.19894575308316719830514784916886e-02
            -6.15134896741448944368357842904516e-01 -1.97842472011284620558879754249174e-16
            -6.09646348338865218252635713724885e-01 -8.19894575308312417716294362435292e-02
            -5.93278646407384369076964958367171e-01 -1.62515811249659108961296283268894e-01
            -5.66323872975731723578007859032368e-01 -2.40142066466665499158139596147521e-01
            -5.29263036614365356413713925576303e-01 -3.13482980818503065290059339531581e-01
            -4.82757488826141833992977581146988e-01 -3.81229783951084533200059922819491e-01
            -4.27637122213078368915262217342388e-01 -4.42173532557557869004938311263686e-01
            -3.64885561023210791553594845026964e-01 -4.95226684000256323070487951554242e-01
            -2.95622608352584859137124340122682e-01 -5.39442503534832029643553141795564e-01
            -2.21084263232477901128802955099673e-01 -5.74031958814198328688860328838928e-01
            -1.42600664197403470545566506189061e-01 -5.98377800189455966162199729296844e-01
            -6.15723529314539247403459398810810e-02 -6.12045575544499453890523454901995e-01
            2.05547184312335484701605992086115e-02 -6.14791383104322464170365947211394e-01
            1.02314990356565327367377449263586e-01 -6.06566223867970544247896214073990e-01
            1.82249448855097112565104566783702e-01 -5.87516875996874188281537954026135e-01
            2.58931661621240039039548719301820e-01 -5.57983275555080315832867654535221e-01
            3.30993232751547017400639560946729e-01 -5.18492450342136868002285154943820e-01
            3.97148221802027412419278107336140e-01 -4.69749115069523770493731262831716e-01
            4.56216091425834524564209004893200e-01 -4.12623095709931941854620163212530e-01
            5.07142774090187820057451517641312e-01 -3.48133807432173758567017785026110e-01
            5.49019481936465991722684520937037e-01 -2.77432063113345839244772150777862e-01
            5.81098924121075444126915954257129e-01 -2.01779537055771757136923838515941e-01
            6.02808642238255143475100794603350e-01 -1.22526250379191931072497823151934e-01
            6.13761225853891145831653375353198e-01 -4.10864798618952101194601311817678e-02
            5.68149158136194598611723449721467e-01 4.15831586441172684764921996247722e-02
            5.56040045222807810532117400725838e-01 1.23863203100462490602318155197281e-01
            5.32079904114543755788702128484147e-01 2.03503318427848717275807644000452e-01
            4.96779403620721149437144958938006e-01 2.78806113835276481172087414961425e-01
            4.50890912622393891240335506154224e-01 3.48166640975601293650498746501398e-01
            3.95392464635877682876952121659997e-01 4.10106600633121654020385449257446e-01
            3.31466912726362250563028055694303e-01 4.63305850104812122491892978359829e-01
            2.60476719048438110082344110196573e-01 5.06630539750072217408671804150799e-01
            1.83934916330709657961151037852687e-01 5.39157279027282831940226515143877e-01
            1.03472860210037626016443823573354e-01 5.60192816960055739450297096482245e-01
            2.08054597184177056390375071259768e-02 5.69288817578207706482373851031298e-01
            -6.23053730256966920020289535386837e-02 5.66251415420586212690068350639194e-01
            -1.44088274915255720731721567062777e-01 5.51145347440794575177847036684398e-01
            -2.22800185383886073520187665053527e-01 5.24292573251418980717630802246276e-01
            -2.96763496715649943702430846315110e-01 4.86265413113855904381210848441697e-01
            -3.64401809340929971892109051623265e-01 4.37874349925575168107627632707590e-01
            -4.24273530056389791553783652489074e-01 3.80150755184279820486636936038849e-01
            -4.75102597081280164648120489800931e-01 3.14324907095049066452219221901032e-01
            -5.15805677098861936613616308022756e-01 2.41799769326343921838073924845958e-01
            -5.45515254625221213125030317314668e-01 1.64121089275170772836531796201598e-01
            -5.63598121595673573480667073454242e-01 8.29444531449626820673870497557800e-02
            -5.69668873095317107591029071045341e-01 6.97643162010059795795605273292453e-17
            -5.63598121595673573480667073454242e-01 -8.29444531449625432895089716112125e-02
            -5.45515254625221213125030317314668e-01 -1.64121089275170661814229333685944e-01
            -5.15805677098861936613616308022756e-01 -2.41799769326343783060195846701390e-01
            -4.75102597081280386692725414832239e-01 -3.14324907095048788896463065611897e-01
            -4.24273530056389847064934883746901e-01 -3.80150755184279653953183242265368e-01
            -3.64401809340929805358655357849784e-01 -4.37874349925575223618778863965417e-01
            -2.96763496715650332280489465119899e-01 -4.86265413113855682336605923410389e-01
            -2.22800185383886073520187665053527e-01 -5.24292573251418980717630802246276e-01
            -1.44088274915255748487297182691691e-01 -5.51145347440794575177847036684398e-01
            -6.23053730256969556799973020133621e-02 -5.66251415420586212690068350639194e-01
            2.08054597184174350221752547440701e-02 -5.69288817578207706482373851031298e-01
            1.03472860210037237438385204768565e-01 -5.60192816960055739450297096482245e-01
            1.83934916330709630205575422223774e-01 -5.39157279027282831940226515143877e-01
            2.60476719048437999060041647680919e-01 -5.06630539750072328430974266666453e-01
            3.31466912726362084029574361920822e-01 -4.63305850104812178003044209617656e-01
            3.95392464635877405321195965370862e-01 -4.10106600633121931576141605546582e-01
            4.50890912622393946751486737412051e-01 -3.48166640975601238139347515243571e-01
            4.96779403620721149437144958938006e-01 -2.78806113835276536683238646219252e-01
            5.32079904114543755788702128484147e-01 -2.03503318427848828298110106516106e-01
            5.56040045222807810532117400725838e-01 -1.23863203100462226924349806722603e-01
            5.68149158136194598611723449721467e-01 -4.15831586441176015433995871717343e-02
            5.20831523932158479972542863833951e-01 4.20458674025403836282954728176264e-02
            5.07342261042524333980452411196893e-01 1.25048636327573070570196023254539e-01
            4.80713100086513966946455411743955e-01 2.04812711256747354005014472022594e-01
            4.41633722345233459272151321783895e-01 2.79272244547537851211416182195535e-01
            3.91116263174729528184769833387691e-01 3.46498773399506021508642561457236e-01
            3.30469098231918334551693305911613e-01 4.04751166027856268403439798930776e-01
            2.61262957232328674184174133188208e-01 4.52520716062088046438560695605702e-01
            1.85290242875537580768963152877404e-01 4.88570217248504412577148059426690e-01
            1.04518608556755168703666925011930e-01 5.11966006442308940727059507480590e-01
            2.10399971774513291911112844445597e-02 5.22102144992624306318873550480930e-01
            -6.29835390769467318161645152940764e-02 5.18716112235266146868184478080366e-01
            -1.45375834752982130426701701253478e-01 5.01895604640048786926342927472433e-01
            -2.24002972671327266196428240618843e-01 4.72076264518282162629958520483342e-01
            -2.96828551260831186020539007586194e-01 4.30030397115741869207283798459684e-01
            -3.61966426289542064775872631798848e-01 3.76846968312475660844995672960067e-01
            -4.17729561009567151863564049563138e-01 3.13903400978518931641048084202339e-01
            -4.62673719522684656624278431991115e-01 2.42829900445086566129759830801049e-01
            -4.95634871731484683010648950585164e-01 1.65467233042802891462841330394440e-01
            -5.15759341107455693276051533757709e-01 8.38190512206480886625570292380871e-02
            -5.22525914464657459390650728892069e-01 6.39909688620686405823622875184202e-17
            -5.15759341107455804298353996273363e-01 -8.38190512206479498846789510935196e-02
            -4.95634871731484738521800181842991e-01 -1.65467233042802780440538867878786e-01
            -4.62673719522684712135429663248942e-01 -2.42829900445086455107457368285395e-01
            -4.17729561009567262885866512078792e-01 -3.13903400978518820618745621686685e-01
            -3.61966426289542175798175094314502e-01 -3.76846968312475549822693210444413e-01
            -2.96828551260831297042841470101848e-01 -4.30030397115741813696132567201857e-01
            -2.24002972671327182929701393732103e-01 -4.72076264518282218141109751741169e-01
            -1.45375834752982130426701701253478e-01 -5.01895604640048786926342927472433e-01
            -6.29835390769469677385572481398412e-02 -5.18716112235266146868184478080366e-01
            2.10399971774510863298246476915665e-02 -5.22102144992624417341176012996584e-01
            1.04518608556755043803576654681819e-01 -5.11966006442308940727059507480590e-01
            1.85290242875537469746660690361750e-01 -4.88570217248504468088299290684517e-01
            2.61262957232328396628417976899073e-01 -4.52520716062088212972014389379183e-01
            3.30469098231918001484785918364651e-01 -4.04751166027856490448044723962084e-01
            3.91116263174729361651316139614210e-01 -3.46498773399506188042096255230717e-01
            4.41633722345233348249848859268241e-01 -2.79272244547538017744869875969016e-01
            4.80713100086513911435304180486128e-01 -2.04812711256747437271741318909335e-01
            5.07342261042524333980452411196893e-01 -1.25048636327573098325771638883452e-01
            5.20831523932158479972542863833951e-01 -4.20458674025403281171442415597994e-02
            4.71854966508331807872878016496543e-01 4.24677156383132595185436741758167e-02
            4.56689159641194331040736642535194e-01 1.26038199591771565843956182106922e-01
            4.26844987418096732945116400514962e-01 2.05557712105774281763359567776206e-01
            3.83281666090156014625733860157197e-01 2.78470430619248532355669567550649e-01
            3.27399356648872374986325439749635e-01 3.42432880366386638293363375851186e-01
            2.60994162499806003907565354893450e-01 3.95389255583836529694963246583939e-01
            1.86200401221283617925195130737848e-01 4.35637494799458846461703842578572e-01
            1.05422005841308771834086144281173e-01 4.61883986488501929734695750084938e-01
            2.12552604520789278907955122122075e-02 4.73285146812394474924445830765762e-01
            -6.35946464969672775602305136999348e-02 4.69474533097420876348593310467550e-01
            -1.46400569181751538661018230413902e-01 4.50574621603763603161496575921774e-01
            -2.24501057114244728651897275994997e-01 4.17192871037727786021065412569442e-01
            -2.95385896351001042692274722867296e-01 3.70402198329101761675730131173623e-01
            -3.56776789834711061111249819077784e-01 3.11706494198234429493510333486483e-01
            -4.06700583736213039376394817736582e-01 2.42992286870878149152019886969356e-01
            -4.43552686242078109124520324257901e-01 1.66468107508772222846715749255964e-01
            -4.66148640455756990697011588054011e-01 8.45935062009192939580515258057858e-02
            -4.73762193816808840907128796970937e-01 5.80191354214782862465413085107622e-17
            -4.66148640455756990697011588054011e-01 -8.45935062009191829357490632901317e-02
            -4.43552686242078109124520324257901e-01 -1.66468107508772139579988902369223e-01
            -4.06700583736213150398697280252236e-01 -2.42992286870877899351839346309134e-01
            -3.56776789834711172133552281593438e-01 -3.11706494198234318471207870970829e-01
            -2.95385896351001153714577185382950e-01 -3.70402198329101650653427668657969e-01
            -2.24501057114244839674199738510652e-01 -4.17192871037727730509914181311615e-01
            -1.46400569181751621927745077300642e-01 -4.50574621603763547650345344663947e-01
            -6.35946464969674024603207840300456e-02 -4.69474533097420820837442079209723e-01
            2.12552604520788133990460977429393e-02 -4.73285146812394530435597062023589e-01
            1.05422005841308660811783681765519e-01 -4.61883986488501929734695750084938e-01
            1.86200401221283506902892668222194e-01 -4.35637494799458901972855073836399e-01
            2.60994162499805837374111661119969e-01 -3.95389255583836640717265709099593e-01
            3.27399356648872263964022977233981e-01 -3.42432880366386693804514607109013e-01
            3.83281666090155959114582628899370e-01 -2.78470430619248643377972030066303e-01
            4.26844987418096677433965169257135e-01 -2.05557712105774392785662030291860e-01
            4.56689159641194331040736642535194e-01 -1.26038199591771676866258644622576e-01
            4.71854966508331752361726785238716e-01 -4.24677156383133774797400405986991e-02
            4.21256070487713907279925251714303e-01 4.28375554218125495498092902835197e-02
            4.04009797466460207626681722103967e-01 1.26758891713269594703206166741438e-01
            3.70223315867794111611033258668613e-01 2.05490704084448028154952226032037e-01
            3.21279848218107955126754404773237e-01 2.75809702886276597588732784060994e-01
            2.59183145833593087115076514237444e-01 3.34837020045676891921715423450223e-01
            1.86475455005924439788600466272328e-01 3.80156070262727852071549250467797e-01
            1.06133437140377456797679656119726e-01 4.09911486296781091276386632671347e-01
            2.14463038881542618352415985327752e-02 4.22885077919289475989472748551634e-01
            -6.41188435650839605450812541675987e-02 4.18545704764895332150587137221009e-01
            -1.47058958029123137967175694029720e-01 3.97071021280394176322658950084588e-01
            -2.23978461472756296135599995977827e-01 3.59340203530809587650907133138389e-01
            -2.91728260387342841486457700739265e-01 3.06897955627992602423148582602153e-01
            -3.47534670045056615084178019969841e-01 2.41891269362786764940409511837061e-01
            -3.89112969477535763918041311626439e-01 1.66981526108851169309943429652776e-01
            -4.14760938220771979700884912745096e-01 8.52355395565229656540395808406174e-02
            -4.23428545420908797325409977929667e-01 5.18550412817335620920962855715784e-17
            -4.14760938220771979700884912745096e-01 -8.52355395565228546317371183249634e-02
            -3.89112969477535819429192542884266e-01 -1.66981526108851058287640967137122e-01
            -3.47534670045056670595329251227668e-01 -2.41891269362786653918107049321407e-01
            -2.91728260387343008019911394512746e-01 -3.06897955627992435889694888828672e-01
            -2.23978461472756407157902458493481e-01 -3.59340203530809532139755901880562e-01
            -1.47058958029123332256205003432115e-01 -3.97071021280394065300356487568934e-01
            -6.41188435650840715673837166832527e-02 -4.18545704764895332150587137221009e-01
            2.14463038881543451019684454195158e-02 -4.22885077919289475989472748551634e-01
            1.06133437140377262508650346717332e-01 -4.09911486296781146787537863929174e-01
            1.86475455005924189988419925612106e-01 -3.80156070262728018605002944241278e-01
            2.59183145833592920581622820463963e-01 -3.34837020045677058455169117223704e-01
            3.21279848218107955126754404773237e-01 -2.75809702886276486566430321545340e-01
            3.70223315867794000588730796152959e-01 -2.05490704084448250199557151063345e-01
            4.04009797466460152115530490846140e-01 -1.26758891713269844503386707401660e-01
            4.21256070487713907279925251714303e-01 -4.28375554218124593441885394895507e-02
            3.69058829985714487165182617900427e-01 4.31367906029070657947244171737111e-02
            3.49162772933867049385270320271957e-01 1.27084856261776402153174103659694e-01
            3.10443260415739663571343953663018e-01 2.04181744424884376032380828291934e-01
            2.54987671373356816761912568836124e-01 2.70271141895572220015253606106853e-01
            1.85785630966137677022587126884900e-01 3.21790152149592112440501523451530e-01
            1.06567839104715844644744038305362e-01 3.55961372008951226764139619263005e-01
            2.16049474531016909295555450398751e-02 3.70942622166140711925663708825596e-01
            -6.45226725079411506102999851464119e-02 3.65926259547434684638034241288551e-01
            -1.47171858493009843904530953295762e-01 3.41182717560044368454441610083450e-01
            -2.21886971492704532238349202089012e-01 2.98045926957137385926444039796479e-01
            -2.84640100425925801630455680424348e-01 2.38841403285658171462557675113203e-01
            -3.32048207868841316336983027213137e-01 1.66760877741256419160009727420402e-01
            -3.61555510478072605895505375883658e-01 8.56902301133790345044616287850658e-02
            -3.71571261932275298534023022511974e-01 4.55043556580503736243804429122333e-17
            -3.61555510478072605895505375883658e-01 -8.56902301133789512377347818983253e-02
            -3.32048207868841371848134258470964e-01 -1.66760877741256335893282880533661e-01
            -2.84640100425925801630455680424348e-01 -2.38841403285658226973708906371030e-01
            -2.21886971492704615505076048975752e-01 -2.98045926957137330415292808538652e-01
            -1.47171858493009871660106568924675e-01 -3.41182717560044368454441610083450e-01
            -6.45226725079412477548146398476092e-02 -3.65926259547434629126883010030724e-01
            2.16049474531014341904811004724252e-02 -3.70942622166140767436814940083423e-01
            1.06567839104715844644744038305362e-01 -3.55961372008951226764139619263005e-01
            1.85785630966137677022587126884900e-01 -3.21790152149592112440501523451530e-01
            2.54987671373356872273063800093951e-01 -2.70271141895572164504102374849026e-01
            3.10443260415739497037890259889537e-01 -2.04181744424884625832561368952156e-01
            3.49162772933866882851816626498476e-01 -1.27084856261776651953354644319916e-01
            3.69058829985714487165182617900427e-01 -4.31367906029069964057853781014273e-02
            3.15268697195630720475634234389872e-01 4.33326850288173609504482897136768e-02
            2.91886660182952228925756799071678e-01 1.26784268071708172698208727524616e-01
            2.46856724877123789863020419943496e-01 2.00832841951153501236504439475539e-01
            1.83518555581531850329213284567231e-01 2.59986562692199885127308789378731e-01
            1.06569654559986223829604057300457e-01 2.99858269437749902497358789332793e-01
            2.17169697834560804228232200330240e-02 3.17490860099407357086676029211958e-01
            -6.47463632933870519847729951834481e-02 3.11576606091532093412155290934606e-01
            -1.46407754799662725986308942083269e-01 2.82554140577976342640909024339635e-01
            -2.17210752903358977894399117758439e-01 2.32575927056935333192555503956100e-01
            -2.71904223137288236777919792075409e-01 1.65348620990151490284247870476975e-01
            -3.06431801020177807526323476849939e-01 8.58581641241365489669590260746190e-02
            -3.18232734053612076330352920194855e-01 3.89722699142666948999976330082823e-17
            -3.06431801020177752015172245592112e-01 -8.58581641241365906003224495179893e-02
            -2.71904223137288347800222254591063e-01 -1.65348620990151295995218561074580e-01
            -2.17210752903358950138823502129526e-01 -2.32575927056935388703706735213927e-01
            -1.46407754799662920275338251485664e-01 -2.82554140577976287129757793081808e-01
            -6.47463632933869964736217639256211e-02 -3.11576606091532093412155290934606e-01
            2.17169697834560040949902770535118e-02 -3.17490860099407357086676029211958e-01
            1.06569654559986154440665018228174e-01 -2.99858269437749902497358789332793e-01
            1.83518555581531794818062053309404e-01 -2.59986562692199940638460020636558e-01
            2.46856724877123734351869188685669e-01 -2.00832841951153584503231286362279e-01
            2.91886660182952173414605567813851e-01 -1.26784268071708311476086805669183e-01
            3.15268697195630720475634234389872e-01 -4.33326850288172776837214428269363e-02
            2.59858829151201120577496794794570e-01 4.33627691672632611941118341292167e-02
            2.31699092887489910275178317533573e-01 1.25389278619827793104235524879186e-01
            1.78431164727568591921169627312338e-01 1.93827914118812505428479653346585e-01
            1.05827451224631122195241061945126e-01 2.41262287573057732092962623937638e-01
            2.17556912994095151547835342853432e-02 2.62552148598657053568672381516080e-01
            -6.46736353524350743304793809329567e-02 2.55390410407256185365554301824886e-01
            -1.44094570098995233831118412126671e-01 2.20553158457711118156652219113312e-01
            -2.07900622317705618957717206285452e-01 1.61815549554414600530449774851149e-01
            -2.49177416197760348559597787243547e-01 8.55427150299462868421329631019034e-02
            -2.63451970646807809295353308698395e-01 3.22635612581675629695565926857539e-17
            -2.49177416197760348559597787243547e-01 -8.55427150299463284754963865452737e-02
            -2.07900622317705729980019668801106e-01 -1.61815549554414489508147312335495e-01
            -1.44094570098995206075542796497757e-01 -2.20553158457711145912227834742225e-01
            -6.46736353524351298416306121907837e-02 -2.55390410407256129854403070567059e-01
            2.17556912994095082158896303781148e-02 -2.62552148598657053568672381516080e-01
            1.05827451224630914028423944728274e-01 -2.41262287573057815359689470824378e-01
            1.78431164727568619676745242941251e-01 -1.93827914118812505428479653346585e-01
            2.31699092887489827008451470646833e-01 -1.25389278619827959637689218652667e-01
            2.59858829151201120577496794794570e-01 -4.33627691672632195607484106858465e-02
            2.02735788474807915315878403816896e-01 4.30928221256660637372704059089301e-02
            1.67680928850695937226689125054691e-01 1.21827325945471687251853154521086e-01
            1.03632513294882960819265349527996e-01 1.79496778342794399696558116374945e-01
            2.16650947185575599995832618560598e-02 2.06129607087609523219384755066130e-01
            -6.40484155558129902852115833411517e-02 1.97120754138285114720474666683003e-01
            -1.38687372918994827886152165774547e-01 1.54027932012619078738779876402987e-01
            -1.89346023569253507634613242771593e-01 8.43022811421378082119559849161305e-02
            -2.07265026589765866127379467798164e-01 1.17426807026636125216713481340702e-16
            -1.89346023569253507634613242771593e-01 -8.43022811421378359675316005450441e-02
            -1.38687372918994966664030243919115e-01 -1.54027932012618995472053029516246e-01
            -6.40484155558130319185750067845220e-02 -1.97120754138285086964899051054090e-01
            2.16650947185574593856216552012484e-02 -2.06129607087609523219384755066130e-01
            1.03632513294882960819265349527996e-01 -1.79496778342794399696558116374945e-01
            1.67680928850695909471113509425777e-01 -1.21827325945471728885216577964457e-01
            2.02735788474807915315878403816896e-01 -4.30928221256659943483313668366463e-02
            1.43641239515525848124966046270856e-01 4.21768734002637910029953616231069e-02
            9.80361608898461245331645841361023e-02 1.13139760903754563181600190091558e-01
            2.13052938720523846183318994462752e-02 1.48181573727653559391370663433918e-01
            -6.21898534141049272316870144550194e-02 1.36176783893990849261257380931056e-01
            -1.25940161653790516638196095300373e-01 8.09368273531626408745509593245515e-02
            -1.49705358419057743546431993308943e-01 8.48161531309504079899228215534703e-17
            -1.25940161653790544393771710929286e-01 -8.09368273531625992411875358811812e-02
            -6.21898534141050521317772847851302e-02 -1.36176783893990793750106149673229e-01
            2.13052938720523464544154279565191e-02 -1.48181573727653587146946279062831e-01
            9.80361608898460412664377372493618e-02 -1.13139760903754632570539229163842e-01
            1.43641239515525848124966046270856e-01 -4.21768734002638048807831694375636e-02
            8.18116876478963694907520221022423e-02 3.93984322930362937387194222083053e-02
            2.02058181947346454654379499515926e-02 8.85274737808961487139924884104403e-02
            -5.66154444826389782741138390065316e-02 7.09935218803740553106251809367677e-02
            -9.08041227199840594863644582801498e-02 1.11202978238411925342043253361417e-17
            -5.66154444826389990907955507282168e-02 -7.09935218803740275550495653078542e-02
            2.02058181947345448514763432967811e-02 -8.85274737808961764695681040393538e-02
            8.18116876478963972463276377311558e-02 -3.93984322930362382275681909504783e-02
            1.52952143007616982173235697928249e-02 2.64920882815733310655659238364024e-02
            -3.05904286015233894957532356784213e-02 3.74624704714012628125598433773448e-18
            1.52952143007616982173235697928249e-02 -2.64920882815733310655659238364024e-02
            ];
        
    case   50
        
        % DEGREE.             :          50
        % CARDIN.             :        1326
        % LEBESGUE CONST.     : 3.66114e+03
        % ABS.DET.VAND.MATRIX : Inf
        % CONDITIONING VAND.  : 1.02176e+05
        % POINTS OUT DISK     : 0.00000e+00
        
        pts=[
            9.99516282291988078512190440960694e-01 3.10998622698369156513997779711644e-02
            9.95649347969018605475355343514821e-01 9.31792674840715706707783283491153e-02
            9.87930439740756671795907095656730e-01 1.54898180214084663086637760898157e-01
            9.76389420563607002279127300425898e-01 2.16017821976483503920718476365437e-01
            9.61070940398724538056285382481292e-01 2.76301732750830253415585957554867e-01
            9.42034263469989197048448659188580e-01 3.35516685797524916168299569108058e-01
            9.19353038982236303588990722346352e-01 3.93433589966752372824032590870047e-01
            8.93115016186791565999669728626031e-01 4.49828376007635810651663632597774e-01
            8.63421704896663477768470329465345e-01 5.04482863448639795578287703392562e-01
            8.30387982764797527579503366723657e-01 5.57185604695428549071323232055875e-01
            7.94141650844753521631957937643165e-01 6.07732703080531622141791103786090e-01
            7.54822939153257044253564345126506e-01 6.55928601699939939351224893471226e-01
            7.12583964147506909725393597909715e-01 7.01586839984776666767629649257287e-01
            6.67588140216153647088503930717707e-01 7.44530775081015172567333593178773e-01
            6.20009547460775078953076899779262e-01 7.84594265246365774046921615081374e-01
            5.70032258213782783151657440612325e-01 8.21622312620400530036590680538211e-01
            5.17849624898325311406210857967380e-01 8.55471662881163830149944260483608e-01
            4.63663531985327337370250688763917e-01 8.86011359468314774190389471186791e-01
            4.07683614941688809985009811498458e-01 9.13123250228618843493677559308708e-01
            3.50126449191390798354461821872974e-01 9.36702444523675015197738957795082e-01
            2.91214712227252259246768062439514e-01 9.56657719031419606636745811556466e-01
            2.31176322114969773346970782768039e-01 9.72911870671437362112499158683931e-01
            1.70243555722398631768754739823635e-01 9.85402015288681321081298847275320e-01
            1.08652150085474491492121273950033e-01 9.94079830940052588950095469044754e-01
            4.66403903874176087307468208109640e-02 9.98911744842610804795413059764542e-01
            -1.55518119203506659242730592040971e-02 9.99879063260149303360435624199454e-01
            -7.76838472890061110254222853654937e-02 9.96978043825629267615795470192097e-01
            -1.39515338943923011827408231511072e-01 9.90219910019669469214420587377390e-01
            -2.00807072855718332649033186498855e-01 9.79630807749081733426521623187000e-01
            -2.61321923212860574015081738252775e-01 9.65251704193435644540954854164738e-01
            -3.20825769815367700665831307560438e-01 9.47138229311000112708995857246919e-01
            -3.79088403840379450926434401480947e-01 9.25360460617241531444676638784586e-01
            -4.35884418475371071544088863447541e-01 9.00002652068530029083603949402459e-01
            -4.90994080973322089000987489271211e-01 8.71162908099950561435775853169616e-01
            -5.44204182756027110556829029519577e-01 8.38952804078301306311971075047040e-01
            -5.95308864276666072079535751981894e-01 8.03496954638675653370682994136587e-01
            -6.44110411450397712940230121603236e-01 7.64932531574647689431856178998714e-01
            -6.90420020571746673176960484852316e-01 7.23408733147249849437798729923088e-01
            -7.34058528759460204859976784064202e-01 6.79086206865885944061744794453261e-01
            -7.74857107102889797189959608658683e-01 6.32136427974326453593789665319491e-01
            -8.12657913828250144661069498397410e-01 5.82741036046301008610726057668217e-01
            -8.47314704957777609095614934631158e-01 5.31091132257275000405627451982582e-01
            -8.78693400099268773217886518978048e-01 4.77386540051127017392218476743437e-01
            -9.06672601177072490230557377799414e-01 4.21835032062062353919174029215355e-01
            -9.31144062097659652721404199837707e-01 3.64651526282654958599493966175942e-01
            -9.52013107532729829785012043430470e-01 3.06057254587887683783264947123826e-01
            -9.69198999199666011428178080677753e-01 2.46278906832001820426114591100486e-01
            -9.82635248222263668615994447463891e-01 1.85547753829493428101571339539078e-01
            -9.92269872363276461690873020415893e-01 1.24098752613259658006406027652702e-01
            -9.98065597133594328838057663233485e-01 6.21696374314805247363047158160043e-02
            -1.00000000000000000000000000000000e+00 1.22464679914735320717376402945840e-16
            -9.98065597133594328838057663233485e-01 -6.21696374314802749361241751557827e-02
            -9.92269872363276461690873020415893e-01 -1.24098752613259408206225486992480e-01
            -9.82635248222263668615994447463891e-01 -1.85547753829493178301390798878856e-01
            -9.69198999199666122450480543193407e-01 -2.46278906832001154292299816006562e-01
            -9.52013107532729829785012043430470e-01 -3.06057254587887406227508790834690e-01
            -9.31144062097659652721404199837707e-01 -3.64651526282654736554889041144634e-01
            -9.06672601177072490230557377799414e-01 -4.21835032062062575963778954246663e-01
            -8.78693400099268884240188981493702e-01 -4.77386540051126795347613551712129e-01
            -8.47314704957777720117917397146812e-01 -5.31091132257274778361022526951274e-01
            -8.12657913828250366705674423428718e-01 -5.82741036046300786566121132636908e-01
            -7.74857107102889908212262071174337e-01 -6.32136427974326231549184740288183e-01
            -7.34058528759460315882279246579856e-01 -6.79086206865885722017139869421953e-01
            -6.90420020571746784199262947367970e-01 -7.23408733147249738415496267407434e-01
            -6.44110411450397823962532584118890e-01 -7.64932531574647356364948791451752e-01
            -5.95308864276665961057233289466240e-01 -8.03496954638675764392985456652241e-01
            -5.44204182756027665668341342097847e-01 -8.38952804078300973245063687500078e-01
            -4.90994080973322200023289951786865e-01 -8.71162908099950228368868465622654e-01
            -4.35884418475370905010635169674060e-01 -9.00002652068530140105906411918113e-01
            -3.79088403840379672971039326512255e-01 -9.25360460617241420422374176268931e-01
            -3.20825769815367700665831307560438e-01 -9.47138229311000112708995857246919e-01
            -2.61321923212860407481628044479294e-01 -9.65251704193435644540954854164738e-01
            -2.00807072855718776738243036561471e-01 -9.79630807749081622404219160671346e-01
            -1.39515338943923039582983847139985e-01 -9.90219910019669469214420587377390e-01
            -7.76838472890068049148126760883315e-02 -9.96978043825629267615795470192097e-01
            -1.55518119203511325648880969652055e-02 -9.99879063260149303360435624199454e-01
            4.66403903874175809751712051820505e-02 -9.98911744842610804795413059764542e-01
            1.08652150085474019647335808258504e-01 -9.94079830940052588950095469044754e-01
            1.70243555722398381968574199163413e-01 -9.85402015288681321081298847275320e-01
            2.31176322114969745591395167139126e-01 -9.72911870671437362112499158683931e-01
            2.91214712227251648624104518603417e-01 -9.56657719031419828681350736587774e-01
            3.50126449191390576309856896841666e-01 -9.36702444523675126220041420310736e-01
            4.07683614941688143851195036404533e-01 -9.13123250228619065538282484340016e-01
            4.63663531985327725948309307568707e-01 -8.86011359468314552145784546155483e-01
            5.17849624898325311406210857967380e-01 -8.55471662881163941172246722999262e-01
            5.70032258213782117017842665518401e-01 -8.21622312620400974125800530600827e-01
            6.20009547460774856908471974747954e-01 -7.84594265246366107113829002628336e-01
            6.67588140216152869932386693108128e-01 -7.44530775081015838701148368272698e-01
            7.12583964147507131769998522941023e-01 -7.01586839984776444723024724225979e-01
            7.54822939153256822208959420095198e-01 -6.55928601699940161395829818502534e-01
            7.94141650844753521631957937643165e-01 -6.07732703080531622141791103786090e-01
            8.30387982764797194512595979176695e-01 -5.57185604695428993160533082118491e-01
            8.63421704896663366746167866949691e-01 -5.04482863448639906600590165908216e-01
            8.93115016186791565999669728626031e-01 -4.49828376007635755140512401339947e-01
            9.19353038982236525633595647377660e-01 -3.93433589966751984245973972065258e-01
            9.42034263469989086026146196672926e-01 -3.35516685797525138212904494139366e-01
            9.61070940398724316011680457449984e-01 -2.76301732750831030571703195164446e-01
            9.76389420563606891256824837910244e-01 -2.16017821976483948009928326428053e-01
            9.87930439740756560773604633141076e-01 -1.54898180214085690042935539167956e-01
            9.95649347969018605475355343514821e-01 -9.31792674840713902595368267611775e-02
            9.99516282291988078512190440960694e-01 -3.10998622698373181072462045904103e-02
            9.91660286686394054633808536891593e-01 3.21286848406078587303547067222098e-02
            9.87500918817709849584218773088651e-01 9.62512956520944762406344352712040e-02
            9.79199628914665609613621199969202e-01 1.59970195079925409098464683665952e-01
            9.66791235472016619034718587499810e-01 2.23018123916016830499131629039766e-01
            9.50327783604083320412314606073778e-01 2.85130637236125417111054503038758e-01
            9.29878326749453587574123503145529e-01 3.46047213573761613947255000311998e-01
            9.05528637036864925136114834458567e-01 4.05512347637758119311968130205059e-01
            8.77380845527087505075769513496198e-01 4.63276621990254822147647928431979e-01
            8.45553013839762335202010490320390e-01 5.19097753190112531918032345856773e-01
            8.10178638961940089657787211763207e-01 5.72741608013863978676738497597398e-01
            7.71406093315322949344192693388322e-01 6.23983185491820413481889318063622e-01
            7.29398002430765246550947722425917e-01 6.72607560640331669787883583921939e-01
            6.84330562840281042547019296762301e-01 7.18410785931859807718069532711525e-01
            6.36392803047555521978040360409068e-01 7.61200746721785281856398341915337e-01
            5.85785790676708995050603334675543e-01 8.00797967043992420244080676638987e-01
            5.32721789124805500392767498851754e-01 8.37036362395442545825119395885849e-01
            4.77423367255398189978876644090633e-01 8.69763936352298649978820321848616e-01
            4.20122465867368455327834908530349e-01 8.98843418095749413510020531248301e-01
            3.61059424854608401744826551293954e-01 9.24152838173528334841932974086376e-01
            3.00481975136984824636954272136791e-01 9.45586040082183498789447639865102e-01
            2.38644199590765299090477924437437e-01 9.63053125524345743357912397186738e-01
            1.75805467336737658579082221876888e-01 9.76480831473429122802087931631831e-01
            1.12229345855979115165190762581915e-01 9.85812837464225322214872448967071e-01
            4.81824954962444956807487983496685e-02 9.91010001820507691050465837179217e-01
            -1.60664489942020823065593759793046e-02 9.92050525828823470675388307427056e-01
            -8.02480052140817357031465917316382e-02 9.88930045169873928045944921905175e-01
            -1.44092973411939301309203642631473e-01 9.81661648223986826877762723597698e-01
            -2.07333565603457586901114950705960e-01 9.70275821173899544191954191774130e-01
            -2.69704528767325146798583546114969e-01 9.54820320135114974924306352477288e-01
            -3.30944257408590514213386768460623e-01 9.35359970850156097199601390457246e-01
            -3.90795890823021574433937530557159e-01 9.11976396786873699795705761061981e-01
            -4.49008390460164108493046342118760e-01 8.84767676781255896223399304290069e-01
            -5.05337592866265561397653982567135e-01 8.53847933660705549208103093405953e-01
            -5.59547233790653630869371681910707e-01 8.19346855573240051562322605605004e-01
            -6.11409939160107773759023075399455e-01 7.81409152030331455307532451115549e-01
            -6.60708178764744080702087103418307e-01 7.40193946944922909203512517706258e-01
            -7.07235178655310603446082495793235e-01 6.95874111210439516561621076107258e-01
            -7.50795788424990950815640644577798e-01 6.48635537620183444396104732732056e-01
            -7.91207299738028502211761860962724e-01 5.98676361168357651365568017354235e-01
            -8.28300212671983060452873814938357e-01 5.46206128003042357121898930927273e-01
            -8.61918946659310014624111317971256e-01 4.91444916516829644059782822296256e-01
            -8.91922493046331310573293649213156e-01 4.34622414261558065451396259959438e-01
            -9.18185006532528991129993301001377e-01 3.75976954558903786463019969232846e-01
            -9.40596333009473761777030631492380e-01 3.15754516847597088702315204500337e-01
            -9.59062471585434450638274483935675e-01 2.54207694960176255882799978280673e-01
            -9.73505968857786174730506445484934e-01 1.91594637656671812342423777408840e-01
            -9.83866243779498717003662022762001e-01 1.28177965858989467706763321075414e-01
            -9.90099841757100196382168633135734e-01 6.42236711275012278621332484362938e-02
            -9.92180616914344004619863426341908e-01 1.21507081668019769385425929066430e-16
            -9.90099841757100196382168633135734e-01 -6.42236711275014360289503656531451e-02
            -9.83866243779498828025964485277655e-01 -1.28177965858989245662158396044106e-01
            -9.73505968857786285752808908000588e-01 -1.91594637656671146208609002314915e-01
            -9.59062471585434450638274483935675e-01 -2.54207694960176477927404903311981e-01
            -9.40596333009473761777030631492380e-01 -3.15754516847596866657710279469029e-01
            -9.18185006532529213174598226032685e-01 -3.75976954558903120329205194138922e-01
            -8.91922493046331199550991186697502e-01 -4.34622414261558231984849953732919e-01
            -8.61918946659310347691018705518218e-01 -4.91444916516829088948270509717986e-01
            -8.28300212671982949430571352422703e-01 -5.46206128003042579166503855958581e-01
            -7.91207299738028724256366785994032e-01 -5.98676361168357429320963092322927e-01
            -7.50795788424991394904850494640414e-01 -6.48635537620182889284592420153785e-01
            -7.07235178655310714468384958308889e-01 -6.95874111210439405539318613591604e-01
            -6.60708178764744191724389565933961e-01 -7.40193946944922798181210055190604e-01
            -6.11409939160108328870535387977725e-01 -7.81409152030331011218322601052932e-01
            -5.59547233790653519847069219395053e-01 -8.19346855573240162584625068120658e-01
            -5.05337592866265783442258907598443e-01 -8.53847933660705438185800630890299e-01
            -4.49008390460163941959592648345279e-01 -8.84767676781256007245701766805723e-01
            -3.90795890823021407900483836783678e-01 -9.11976396786873810818008223577635e-01
            -3.30944257408591402391806468585855e-01 -9.35359970850155764132694002910284e-01
            -2.69704528767325146798583546114969e-01 -9.54820320135114974924306352477288e-01
            -2.07333565603457392612085641303565e-01 -9.70275821173899544191954191774130e-01
            -1.44092973411939967443018417725398e-01 -9.81661648223986715855460261082044e-01
            -8.02480052140815414141172823292436e-02 -9.88930045169873928045944921905175e-01
            -1.60664489942029843627668839189937e-02 -9.92050525828823470675388307427056e-01
            4.81824954962449120143830327833712e-02 -9.91010001820507580028163374663563e-01
            1.12229345855979323332007879798766e-01 -9.85812837464225322214872448967071e-01
            1.75805467336736992445267446782964e-01 -9.76480831473429233824390394147485e-01
            2.38644199590765493379507233839831e-01 -9.63053125524345632335609934671083e-01
            3.00481975136984158503139497042866e-01 -9.45586040082183720834052564896410e-01
            3.61059424854607957655616701231338e-01 -9.24152838173528445864235436602030e-01
            4.20122465867367844705171364694252e-01 -8.98843418095749635554625456279609e-01
            4.77423367255397801400818025285844e-01 -8.69763936352298872023425246879924e-01
            5.32721789124805056303557648789138e-01 -8.37036362395442767869724320917157e-01
            5.85785790676708550961393484612927e-01 -8.00797967043992753310988064185949e-01
            6.36392803047555744022645285440376e-01 -7.61200746721785059811793416884029e-01
            6.84330562840280709480111909215339e-01 -7.18410785931860140784976920258487e-01
            7.29398002430764913484040334878955e-01 -6.72607560640332002854790971468901e-01
            7.71406093315322727299587768357014e-01 -6.23983185491820635526494243094930e-01
            8.10178638961939867613182286731899e-01 -5.72741608013864311743645885144360e-01
            8.45553013839762557246615415351698e-01 -5.19097753190112087828822495794157e-01
            8.77380845527087283031164588464890e-01 -4.63276621990255155214555315978942e-01
            9.05528637036864814113812371942913e-01 -4.05512347637758396867724286494195e-01
            9.29878326749453476551821040629875e-01 -3.46047213573761947014162387858960e-01
            9.50327783604083209390012143558124e-01 -2.85130637236125694666810659327894e-01
            9.66791235472016730057021050015464e-01 -2.23018123916016275387619316461496e-01
            9.79199628914665498591318737453548e-01 -1.59970195079925714409796455584001e-01
            9.87500918817709849584218773088651e-01 -9.62512956520947260408149759314256e-02
            9.91660286686394054633808536891593e-01 -3.21286848406081085305352473824314e-02
            9.77216590953861485857601110183168e-01 3.30234919954705899436397942281474e-02
            9.72757775783874678587892503855983e-01 9.89197973667092222971319870339357e-02
            9.63860489994846969530328806285979e-01 1.64364754390822292995366638024279e-01
            9.50565329861151053769674490467878e-01 2.29059752739373345686857419423177e-01
            9.32932958149097157907192467973800e-01 2.92709603973351939476543748241966e-01
            9.11043827326644350961259988253005e-01 3.55023888420316291458789237367455e-01
            8.84997812477241074802236653340515e-01 4.15718280292747988102775025254232e-01
            8.54913755592727642174111224449007e-01 4.74515845001407365888468348202878e-01
            8.20928923324584447485108285036404e-01 5.31148302744346878512260445859283e-01
            7.83198380667685101208519427018473e-01 5.85357252606113598325521252263570e-01
            7.41894283434290646717101935792016e-01 6.36895351581861057788103153143311e-01
            6.97205092746563170891249683336355e-01 6.85527443146748072244633931404678e-01
            6.49334715131691719847140120691620e-01 7.31031630221228079236084340664092e-01
            5.98501572143176785445461973722558e-01 7.73200287636526706336326242308132e-01
            5.44937603753377519666400985443033e-01 8.11841009480667175068901997292414e-01
            4.88887210064617605542736100687762e-01 8.46777487002515982794648152776062e-01
            4.30606136167572317585694463559776e-01 8.77850313068176735242786890012212e-01
            3.70360305235078901553436026006239e-01 9.04917709499179268028967726422707e-01
            3.08424605175689536817884572883486e-01 9.27856173973790943065864667005371e-01
            2.45081634383194829629459832176508e-01 9.46561043539783431022271997790085e-01
            1.80620412304967947747513790091034e-01 9.60946972167478707937959825358121e-01
            1.15335060712516826453288842913025e-01 9.70948320164107259166996755084256e-01
            4.95234616913000913474007802506094e-02 9.76519453672671122745896354899742e-01
            -1.65141015269058659409306955012653e-02 9.77634952888766561862610160460463e-01
            -8.24763146875207714403543945991260e-02 9.74289728045321656857424841291504e-01
            -1.48062207340996176974101672385586e-01 9.66499042636035698983221209346084e-01
            -2.12972526101943421261708522251865e-01 9.54298443771558591031123341963394e-01
            -2.76911100073696014867152825900121e-01 9.37743599986178177907447661709739e-01
            -3.39586192208181369966979445962352e-01 9.16910047235065417403632181958528e-01
            -4.00711830435157900787146445509279e-01 8.91892844241037097141600042959908e-01
            -4.60009112487181126560642496770015e-01 8.62806138763405949809737194300396e-01
            -5.17207478466680470319261075928807e-01 8.29782646767935228027113225834910e-01
            -5.72045945348716333711536208284087e-01 7.92973046874328013622346134070540e-01
            -6.24274297786665322007593204034492e-01 7.52545292844243096652689928305335e-01
            -6.73654229787455038902521664567757e-01 7.08683847246804665687136548513081e-01
            -7.19960432047153875423362023866503e-01 6.61588839798206707065730824979255e-01
            -7.62981619985647951942553390836110e-01 6.11475154215719629569036897009937e-01
            -8.02521497789720039683913910266710e-01 5.58571447752573613243498584779445e-01
            -8.38399654065821842152672616066411e-01 5.03119107887358918418385655968450e-01
            -8.70452385015884400054630987142446e-01 4.45371150928324466278240834071767e-01
            -8.98533441380201747250566768343560e-01 3.85591067557993716352626734078513e-01
            -9.22514695739258483442313263367396e-01 3.24051620585617705661007903472637e-01
            -9.42286727129757917253982668626122e-01 2.61033600393035469799940528901061e-01
            -9.57759320307381423198478387348587e-01 1.96824543752562863829780326341279e-01
            -9.68861877378255464954293074697489e-01 1.31717421862652506181490252856747e-01
            -9.75543739920949781740944217744982e-01 6.60093035875098377296410490089329e-02
            -9.77774420129234989040867276344215e-01 5.53961901036737849431388577995479e-16
            -9.75543739920949781740944217744982e-01 -6.60093035875095879294605083487113e-02
            -9.68861877378255575976595537213143e-01 -1.31717421862652284136885327825439e-01
            -9.57759320307381423198478387348587e-01 -1.96824543752563058118809635743673e-01
            -9.42286727129757917253982668626122e-01 -2.61033600393035247755335603869753e-01
            -9.22514695739258594464615725883050e-01 -3.24051620585617428105251747183502e-01
            -8.98533441380201636228264305827906e-01 -3.85591067557993938397231659109821e-01
            -8.70452385015884511076933449658100e-01 -4.45371150928324244233635909040459e-01
            -8.38399654065821953174975078582065e-01 -5.03119107887358807396083193452796e-01
            -8.02521497789720261728518835298019e-01 -5.58571447752573391198893659748137e-01
            -7.62981619985648062964855853351764e-01 -6.11475154215719407524431971978629e-01
            -7.19960432047153764401059561350849e-01 -6.61588839798206818088033287494909e-01
            -6.73654229787455149924824127083411e-01 -7.08683847246804554664834085997427e-01
            -6.24274297786665877119105516612763e-01 -7.52545292844242763585782540758373e-01
            -5.72045945348716444733838670799742e-01 -7.92973046874327902600043671554886e-01
            -5.17207478466680692363866000960115e-01 -8.29782646767935117004810763319256e-01
            -4.60009112487181737183306040606112e-01 -8.62806138763405616742829806753434e-01
            -4.00711830435158122831751370540587e-01 -8.91892844241037097141600042959908e-01
            -3.39586192208181814056189296024968e-01 -9.16910047235065195359027256927220e-01
            -2.76911100073695792822547900868813e-01 -9.37743599986178177907447661709739e-01
            -2.12972526101943449017284137880779e-01 -9.54298443771558591031123341963394e-01
            -1.48062207340996621063311522448203e-01 -9.66499042636035698983221209346084e-01
            -8.24763146875207991959300102280395e-02 -9.74289728045321656857424841291504e-01
            -1.65141015269058867576124072229504e-02 -9.77634952888766561862610160460463e-01
            4.95234616912996333804031223735365e-02 -9.76519453672671122745896354899742e-01
            1.15335060712516798697713227284112e-01 -9.70948320164107259166996755084256e-01
            1.80620412304967753458484480688639e-01 -9.60946972167478818960262287873775e-01
            2.45081634383195273718669682239124e-01 -9.46561043539783319999969535274431e-01
            3.08424605175689703351338266656967e-01 -9.27856173973790832043562204489717e-01
            3.70360305235078679508831100974930e-01 -9.04917709499179268028967726422707e-01
            4.30606136167572650652601851106738e-01 -8.77850313068176513198181964980904e-01
            4.88887210064617605542736100687762e-01 -8.46777487002515982794648152776062e-01
            5.44937603753377297621796060411725e-01 -8.11841009480667286091204459808068e-01
            5.98501572143176341356252123659942e-01 -7.73200287636526928380931167339440e-01
            6.49334715131691830869442583207274e-01 -7.31031630221228079236084340664092e-01
            6.97205092746562837824342295789393e-01 -6.85527443146748294289238856435986e-01
            7.41894283434290202627892085729400e-01 -6.36895351581861390855010540690273e-01
            7.83198380667685101208519427018473e-01 -5.85357252606113598325521252263570e-01
            8.20928923324584225440503360005096e-01 -5.31148302744347100556865370890591e-01
            8.54913755592727309107203836902045e-01 -4.74515845001407976511131892038975e-01
            8.84997812477240741735329265793553e-01 -4.15718280292748765258892262863810e-01
            9.11043827326644239938957525737351e-01 -3.55023888420316569014545393656590e-01
            9.32932958149097268929494930489454e-01 -2.92709603973351717431938823210658e-01
            9.50565329861150942747372027952224e-01 -2.29059752739373401198008650681004e-01
            9.63860489994846858508026343770325e-01 -1.64364754390822653817849641200155e-01
            9.72757775783874567565590041340329e-01 -9.89197973667098884309467621278600e-02
            9.77216590953861485857601110183168e-01 -3.30234919954715475109985334256635e-02
            9.58453953098260535981012253614608e-01 3.38463272457236799550805983471946e-02
            9.53678983715623096450997309148079e-01 1.01370361037354805855414952020510e-01
            9.44152833607624142331360417301767e-01 1.68389372789381847050904639218061e-01
            9.29922961574921824734474284923635e-01 2.34569477156414851748422734090127e-01
            9.11060260124198828535213579016272e-01 2.99580968187457663542971886272426e-01
            8.87658702285259892938995562872151e-01 3.63099961904370827081578454453847e-01
            8.59834873442124614228987411479466e-01 4.24810009875559391190336100407876e-01
            8.27727390510508365117914308939362e-01 4.84403675746140238711490155765205e-01
            7.91496211355320888891640151996398e-01 5.41584066870398839199651774833910e-01
            7.51321837888629828761111184576293e-01 5.96066313416014681436649880197365e-01
            7.07404416818213754858390984736616e-01 6.47578987571238440246190748439403e-01
            6.59962742526732260017752196290530e-01 6.95865455784594355570504831121070e-01
            6.09233167049116564051303157611983e-01 7.40685157300327245977200618654024e-01
            5.55468422578621390250930289766984e-01 7.81814802619984594578284031740623e-01
            4.98936362367749630664093274390325e-01 8.19049485919468023276124313269975e-01
            4.39918626296823100929600514064077e-01 8.52203705879541195677973064448452e-01
            3.78709237758264427586851752494113e-01 8.81112289844070639688311530335341e-01
            3.15613138846847496310488168091979e-01 9.05631216701891172959903997252695e-01
            2.50944671153518594763909277389757e-01 9.25638334392736683575719780492363e-01
            1.85026009731403179303654837895010e-01 9.41033968462659742293396902823588e-01
            1.18185558035896892681293479654414e-01 9.51741418637148006709480796416756e-01
            5.07563118351698552843664913325483e-02 9.57707340938033224730929759971332e-01
            -1.69257997580001817716777168243425e-02 9.58902013440507516861543990671635e-01
            -8.45235878681694502434496030218725e-02 9.55319484346257352669340434658807e-01
            -1.51700283715244660376342267227301e-01 9.46977601635023757964404467202257e-01
            -2.18121216379606741586627549622790e-01 9.33917924146864253387434473552275e-01
            -2.83455480115796243367753959319089e-01 9.16205514538103393817891628714278e-01
            -3.47377582908292292795948696948471e-01 8.93928615142450699870835251203971e-01
            -4.09569068056362117768998132305569e-01 8.67198208352133459442256935290061e-01
            -4.69720100709325405485827786833397e-01 8.36147463709200344794680859195068e-01
            -5.27531011448193476454093797656242e-01 8.00931074461562642063938710634829e-01
            -5.82713789223642253389812140085269e-01 7.61724486889014174018086578143993e-01
            -6.34993516212572384205259368172847e-01 7.18723026238690221312310768553289e-01
            -6.84109737444875354306361714407103e-01 6.72140923624511277267856712569483e-01
            -7.29817758376993253044417997443816e-01 6.22210248738549798197539075772511e-01
            -7.71889863947824994561131006776122e-01 5.69179753691499090706429342390038e-01
            -8.10116453043707829273500919953221e-01 5.13313633742168651252768540871330e-01
            -8.44307082720622270599619696440641e-01 4.54890211089994445092798969199066e-01
            -8.74291416981358593396578271494946e-01 3.94200548287842400529967790134833e-01
            -8.99920075380887474203461806609994e-01 3.31546998183010421801242273431853e-01
            -9.21065377232223370107533355621854e-01 2.67241697610551220964936192103778e-01
            -9.37621977705184073137445466272766e-01 2.01605012343261086327217412872415e-01
            -9.49507392649035275589142202079529e-01 1.34963941045517760164429432734323e-01
            -9.56662409524381418535199372854549e-01 6.76504861823780528906624454066332e-02
            -9.59051382397057672335449751699343e-01 1.17449920567040101525727282635293e-16
            -9.56662409524381418535199372854549e-01 -6.76504861823778030904819047464116e-02
            -9.49507392649035386611444664595183e-01 -1.34963941045517510364248892074102e-01
            -9.37621977705184073137445466272766e-01 -2.01605012343261280616246722274809e-01
            -9.21065377232223592152138280653162e-01 -2.67241697610550610342272648267681e-01
            -8.99920075380887363181159344094340e-01 -3.31546998183010588334695967205334e-01
            -8.74291416981358482374275808979291e-01 -3.94200548287842567063421483908314e-01
            -8.44307082720622270599619696440641e-01 -4.54890211089994278559345275425585e-01
            -8.10116453043707940295803382468875e-01 -5.13313633742168540230466078355676e-01
            -7.71889863947825105583433469291776e-01 -5.69179753691498868661824417358730e-01
            -7.29817758376993697133627847506432e-01 -6.22210248738549465130631688225549e-01
            -6.84109737444875576350966639438411e-01 -6.72140923624511055223251787538175e-01
            -6.34993516212572495227561830688501e-01 -7.18723026238689999267705843521981e-01
            -5.82713789223641809300602290022653e-01 -7.61724486889014618107296428206610e-01
            -5.27531011448193698498698722687550e-01 -8.00931074461562531041636248119175e-01
            -4.69720100709325627530432711864705e-01 -8.36147463709200233772378396679414e-01
            -4.09569068056362339813603057336877e-01 -8.67198208352133348419954472774407e-01
            -3.47377582908292126262495003174990e-01 -8.93928615142450810893137713719625e-01
            -2.83455480115796687456963809381705e-01 -9.16205514538103282795589166198624e-01
            -2.18121216379607185675837399685406e-01 -9.33917924146864142365132011036621e-01
            -1.51700283715244882420947192258609e-01 -9.46977601635023646942102004686603e-01
            -8.45235878681692559544202936194779e-02 -9.55319484346257463691642897174461e-01
            -1.69257997579999874826484074219479e-02 -9.58902013440507516861543990671635e-01
            5.07563118351691960894456201458524e-02 -9.57707340938033224730929759971332e-01
            1.18185558035896434714295821777341e-01 -9.51741418637148117731783258932410e-01
            1.85026009731402985014625528492616e-01 -9.41033968462659742293396902823588e-01
            2.50944671153517762096640808522352e-01 -9.25638334392736905620324705523672e-01
            3.15613138846847662843941861865460e-01 -9.05631216701891172959903997252695e-01
            3.78709237758264039008793133689323e-01 -8.81112289844070861732916455366649e-01
            4.39918626296822656840390664001461e-01 -8.52203705879541306700275526964106e-01
            4.98936362367749519641790811874671e-01 -8.19049485919468134298426775785629e-01
            5.55468422578621390250930289766984e-01 -7.81814802619984594578284031740623e-01
            6.09233167049116786095908082643291e-01 -7.40685157300327134954898156138370e-01
            6.59962742526731815928542346227914e-01 -6.95865455784594799659714681183686e-01
            7.07404416818213532813786059705308e-01 -6.47578987571238662290795673470711e-01
            7.51321837888629717738808722060639e-01 -5.96066313416014903481254805228673e-01
            7.91496211355320999913942614512052e-01 -5.41584066870398728177349312318256e-01
            8.27727390510508032051006921392400e-01 -4.84403675746140738311851237085648e-01
            8.59834873442124392184382486448158e-01 -4.24810009875559835279545950470492e-01
            8.87658702285260114983600487903459e-01 -3.63099961904370438503519835649058e-01
            9.11060260124198828535213579016272e-01 -2.99580968187457774565274348788080e-01
            9.29922961574921824734474284923635e-01 -2.34569477156414823992847118461214e-01
            9.44152833607624031309057954786113e-01 -1.68389372789382485429143798683072e-01
            9.53678983715623096450997309148079e-01 -1.01370361037355277700200417712040e-01
            9.58453953098260535981012253614608e-01 -3.38463272457231456602499974906095e-02
            9.36186882351257909640196430700598e-01 3.46171504431005278012989379021747e-02
            9.31073754242855988749738571641501e-01 1.03662384457825204608916180859524e-01
            9.20875424158692945653115202730987e-01 1.72141450475809670850324550883670e-01
            9.05647591841197252549022778111976e-01 2.39680339585057328166683987547003e-01
            8.85473426429907783941075649636332e-01 3.05910177793820570180116646952229e-01
            8.60463112220473891333938354364363e-01 3.70469240692428369854383163328748e-01
            8.30753246876241191465339852584293e-01 4.33004929066576782492603570062784e-01
            7.96506095379183487459329171542777e-01 4.93175694671965092474863467941759e-01
            7.57908703794838545242384952871362e-01 5.50652905652368240829730439145351e-01
            7.15171877691561985734836071060272e-01 6.05122641412874084920758832595311e-01
            6.68529030793613365801775216823444e-01 6.56287407145314860557050451461691e-01
            6.18234910156335804032323721912690e-01 7.03867758641746332770594563044142e-01
            5.64564204826078275267775552492822e-01 7.47603828521808844165263963077450e-01
            5.07810045583880098618578813329805e-01 7.87256745538243096760311345860828e-01
            4.48282403966792364347071497832076e-01 8.22609939208809759492169177974574e-01
            3.86306399310834103211220735829556e-01 8.53470322649163115613646368728951e-01
            3.22220523061918562301997326358105e-01 8.79669347146455837815892664366402e-01
            2.56374790052957934882726931391517e-01 9.01063922713960407939737251581391e-01
            1.89128826844217640124057311368233e-01 9.17537199598958075341670337365940e-01
            1.20849907567756001403047605435859e-01 9.28999206475566996488169024814852e-01
            5.19109480034719988905678178525704e-02 9.35387341836925290117221720720408e-01
            -1.73115311575657189469001906445556e-02 9.36666715902913282754127521911869e-01
            -8.64394607385677582467309321145876e-02 9.32830341176032917793747856194386e-01
            -1.55095287959763988849815063986171e-01 9.23899170604696506892139495903393e-01
            -2.22904038500760792729238346510101e-01 9.09921983145488999511485417315271e-01
            -2.89495364480251815564315620576963e-01 8.90975117349420919765634607756510e-01
            -3.54505567167715363030566777524655e-01 8.67162054427236039799709033104591e-01
            -4.17579583379763030759335151742562e-01 8.38612853070921926423864078969928e-01
            -4.78372924712120617396493571504834e-01 8.05483439118235389209132790711010e-01
            -5.36553559015833902989811576844659e-01 7.67954753939846468391294820321491e-01
            -5.91803723841725748400222073541954e-01 7.26231766200318928916601635137340e-01
            -6.43821661948704493383388580696192e-01 6.80542352390338889378540443431120e-01
            -6.92323269397171592309803145326441e-01 6.31136052244347434125870677235071e-01
            -7.37043647226222842228082754445495e-01 5.78282705841040467475977493450046e-01
            -7.77738548239911398063384240231244e-01 5.22270979830435577717651085549733e-01
            -8.14185711000736000997335395368282e-01 4.63406790836727200399991488666274e-01
            -8.46186073744536582097452992456965e-01 4.02011634647772286843547817625222e-01
            -8.73564861586823115935374062246410e-01 3.38420830316578991059373038297053e-01
            -8.96172541082586260330344885005616e-01 2.72981688764921626155768308308325e-01
            -9.13885636926120903389403338223929e-01 2.06051615891520323309293871716363e-01
            -9.26607406330327676435842931823572e-01 1.37996160544963553107322695723269e-01
            -9.34268367402268928856301499763504e-01 6.91870180226558523228774788549345e-02
            -9.36826678629173237311533739557490e-01 1.14728179333906312627325012788889e-16
            -9.34268367402268928856301499763504e-01 -6.91870180226556164004847460091696e-02
            -9.26607406330327676435842931823572e-01 -1.37996160544963331062717770691961e-01
            -9.13885636926120903389403338223929e-01 -2.06051615891520073509113331056142e-01
            -8.96172541082586371352647347521270e-01 -2.72981688764920960021953533214401e-01
            -8.73564861586823004913071599730756e-01 -3.38420830316579157592826732070534e-01
            -8.46186073744536582097452992456965e-01 -4.02011634647772064798942892593914e-01
            -8.14185711000735889975032932852628e-01 -4.63406790836727366933445182439755e-01
            -7.77738548239911620107989165262552e-01 -5.22270979830435355673046160518425e-01
            -7.37043647226222953250385216961149e-01 -5.78282705841040356453675030934392e-01
            -6.92323269397171703332105607842095e-01 -6.31136052244347212081265752203763e-01
            -6.43821661948704715427993505727500e-01 -6.80542352390338778356237980915466e-01
            -5.91803723841726636578641773667186e-01 -7.26231766200318151760484397527762e-01
            -5.36553559015834125034416501875967e-01 -7.67954753939846468391294820321491e-01
            -4.78372924712121172508005884083104e-01 -8.05483439118235056142225403164048e-01
            -4.17579583379762864225881457969081e-01 -8.38612853070922037446166541485582e-01
            -3.54505567167715363030566777524655e-01 -8.67162054427236039799709033104591e-01
            -2.89495364480252037608920545608271e-01 -8.90975117349420808743332145240856e-01
            -2.22904038500761458863053121604025e-01 -9.09921983145488777466880492283963e-01
            -1.55095287959764405183449298419873e-01 -9.23899170604696395869837033387739e-01
            -8.64394607385686047917872087964497e-02 -9.32830341176032806771445393678732e-01
            -1.73115311575659513998459715367062e-02 -9.36666715902913282754127521911869e-01
            5.19109480034715617402518716971827e-02 -9.35387341836925290117221720720408e-01
            1.20849907567756181814289107023797e-01 -9.28999206475566996488169024814852e-01
            1.89128826844217834413086620770628e-01 -9.17537199598958075341670337365940e-01
            2.56374790052957712838122006360209e-01 -9.01063922713960407939737251581391e-01
            3.22220523061918395768543632584624e-01 -8.79669347146455948838195126882056e-01
            3.86306399310833492588557191993459e-01 -8.53470322649163448680553756275913e-01
            4.48282403966791809235559185253805e-01 -8.22609939208810092559076565521536e-01
            5.07810045583879987596276350814151e-01 -7.87256745538243096760311345860828e-01
            5.64564204826078053223170627461514e-01 -7.47603828521809066209868888108758e-01
            6.18234910156336026076928646943998e-01 -7.03867758641746110725989638012834e-01
            6.68529030793613476824077679339098e-01 -6.56287407145314749534747988946037e-01
            7.15171877691561985734836071060272e-01 -6.05122641412874084920758832595311e-01
            7.57908703794838434220082490355708e-01 -5.50652905652368462874335364176659e-01
            7.96506095379183154392421783995815e-01 -4.93175694671965536564073318004375e-01
            8.30753246876240969420734927552985e-01 -4.33004929066577337604115882641054e-01
            8.60463112220473891333938354364363e-01 -3.70469240692428425365534394586575e-01
            8.85473426429907672918773187120678e-01 -3.05910177793820736713570340725710e-01
            9.05647591841197141526720315596322e-01 -2.39680339585057716744742606351792e-01
            9.20875424158692834630812740215333e-01 -1.72141450475810225961836863461940e-01
            9.31073754242856099772041034157155e-01 -1.03662384457825135219977141787240e-01
            9.36186882351257909640196430700598e-01 -3.46171504431006665791770160467422e-02
            9.10887178327161151081270418217173e-01 3.53465708127736824573084106759779e-02
            9.05408995657693949077327033592155e-01 1.05827134002419429026353725475929e-01
            8.94485576753920597070646181236953e-01 1.75671240356086721945416684320662e-01
            8.78182616342426336508708573092008e-01 2.44458839199998556601656218845164e-01
            8.56598162345404201545306932530366e-01 3.11776233820855175338238041149452e-01
            8.29862026208914360658752684685169e-01 3.77218569486544696989227531958022e-01
            7.98135002201573517943700153409736e-01 4.40392268290139610176225914983661e-01
            7.61607900378903690530307812878164e-01 5.00917396173738427300747844128637e-01
            7.20500399029206151091386800544569e-01 5.58429947896595724188273379695602e-01
            6.75059723502488662205678338068537e-01 6.12584036205469195657258296705550e-01
            6.25559159368119122035523105296306e-01 6.63053972041260264447259942244273e-01
            5.72296408843256609877414575748844e-01 7.09536223271336696782896069635171e-01
            5.15591800376688058626939437090186e-01 7.51751240167494283461735449236585e-01
            4.55786362155846114241342093009735e-01 7.89445136650913759090997245948529e-01
            3.93239771123162773491799271141645e-01 8.22391217192913970279732893686742e-01
            3.28328189836616823882309290638659e-01 8.50391340188533684241178889351431e-01
            2.61442004183848775156207011605147e-01 8.73277109603459389397528411791427e-01
            1.92983475555498384945707357474021e-01 8.90910887727588751694440816208953e-01
            1.23364321597869266988745096114144e-01 9.03186622944415429259379379800521e-01
            5.30032400945597420571786528853409e-02 9.10030487537927701424678161856718e-01
            -1.76766091312735573737313643505331e-02 9.11401321701181377221701040980406e-01
            -8.82501491498838969151918831812509e-02 9.07290881076219801748550253250869e-01
            -1.58292942387604357312724800976866e-01 8.97723886336614373959719159756787e-01
            -2.27383743244359198820703227283957e-01 8.82757874514423890310865772335092e-01
            -2.95107031514266926475187347023166e-01 8.62482852965714030801791523117572e-01
            -3.61055511373051751800034026018693e-01 8.37020758055727176483173934684601e-01
            -4.24832560903052824929915232132771e-01 8.06524721819234735598058705363655e-01
            -4.86054617424108326151355186084402e-01 7.71178151006460810279463657934684e-01
            -5.44353484284641919721536851284327e-01 7.31193624053307900112486095167696e-01
            -5.99378545239653393039702677924652e-01 6.86811612609627308856374838796910e-01
            -6.50798873098067054421278498921311e-01 6.38299035314425444731512016005581e-01
            -6.98305219957799927499308978440240e-01 5.85947652515758976576876193576027e-01
            -7.41611877059030311087894915544894e-01 5.30072311589675271292776415066328e-01
            -7.80458393070299627503061401512241e-01 4.71009053411041878067777588512399e-01
            -8.14611140473463168909518117288826e-01 4.09113091364189440657384011501563e-01
            -8.43864720627075404202344088844256e-01 3.44756675047819816093408462620573e-01
            -8.68043199057986991640234464284731e-01 2.78326851522119778081787444534712e-01
            -8.87001163551967786169427654385800e-01 2.10223137562199346994873394578462e-01
            -9.00624598679873211715118941356195e-01 1.40855116917197153991736513489741e-01
            -9.08831571499850610074133783200523e-01 7.06399770254198811070267538525513e-02
            -9.11572724311692006438079260988161e-01 1.11635461901834636329865870287215e-16
            -9.08831571499850610074133783200523e-01 -7.06399770254200753960560632549459e-02
            -9.00624598679873322737421403871849e-01 -1.40855116917196959702707204087346e-01
            -8.87001163551967897191730116901454e-01 -2.10223137562198736372209850742365e-01
            -8.68043199057986991640234464284731e-01 -2.78326851522119611548333750761230e-01
            -8.43864720627075515224646551359911e-01 -3.44756675047819538537652306331438e-01
            -8.14611140473463501976425504835788e-01 -4.09113091364188885545871698923293e-01
            -7.80458393070299738525363864027895e-01 -4.71009053411041656023172663481091e-01
            -7.41611877059030422110197378060548e-01 -5.30072311589675049248171490035020e-01
            -6.98305219957799927499308978440240e-01 -5.85947652515759087599178656091681e-01
            -6.50798873098067165443580961436965e-01 -6.38299035314425222686907090974273e-01
            -5.99378545239653837128912527987268e-01 -6.86811612609626975789467451249948e-01
            -5.44353484284642141766141776315635e-01 -7.31193624053307678067881170136388e-01
            -4.86054617424108215129052723568748e-01 -7.71178151006460921301766120450338e-01
            -4.24832560903053768619486163515830e-01 -8.06524721819234291508848855301039e-01
            -3.61055511373051807311185257276520e-01 -8.37020758055727176483173934684601e-01
            -2.95107031514267148519792272054474e-01 -8.62482852965713919779489060601918e-01
            -2.27383743244359226576278842912870e-01 -8.82757874514423890310865772335092e-01
            -1.58292942387604385068300416605780e-01 -8.97723886336614373959719159756787e-01
            -8.82501491498839107929796909957076e-02 -9.07290881076219801748550253250869e-01
            -1.76766091312737794183362893818412e-02 -9.11401321701181377221701040980406e-01
            5.30032400945597212404969411636557e-02 -9.10030487537927701424678161856718e-01
            1.23364321597868462077052242875652e-01 -9.03186622944415429259379379800521e-01
            1.92983475555498357190131741845107e-01 -8.90910887727588751694440816208953e-01
            2.61442004183848775156207011605147e-01 -8.73277109603459389397528411791427e-01
            3.28328189836616823882309290638659e-01 -8.50391340188533684241178889351431e-01
            3.93239771123162773491799271141645e-01 -8.22391217192913970279732893686742e-01
            4.55786362155845392596376086657983e-01 -7.89445136650914203180207096011145e-01
            5.15591800376688058626939437090186e-01 -7.51751240167494172439432986720931e-01
            5.72296408843256609877414575748844e-01 -7.09536223271336696782896069635171e-01
            6.25559159368118566924010792718036e-01 -6.63053972041260597514167329791235e-01
            6.75059723502488662205678338068537e-01 -6.12584036205469084634955834189896e-01
            7.20500399029205818024479412997607e-01 -5.58429947896596168277483229758218e-01
            7.61607900378903690530307812878164e-01 -5.00917396173738316278445381612983e-01
            7.98135002201573517943700153409736e-01 -4.40392268290139443642772221210180e-01
            8.29862026208914027591845297138207e-01 -3.77218569486545363123042307051946e-01
            8.56598162345404201545306932530366e-01 -3.11776233820855064315935578633798e-01
            8.78182616342426225486406110576354e-01 -2.44458839199999222735470993939089e-01
            8.94485576753920597070646181236953e-01 -1.75671240356087360323655843785673e-01
            9.05408995657693949077327033592155e-01 -1.05827134002419262492900031702447e-01
            9.10887178327161151081270418217173e-01 -3.53465708127743208355475701409887e-02
            8.82873538055825135550946924922755e-01 3.60411567627665352375743168522604e-02
            8.76998160323944175864596672909101e-01 1.07883622336415685438737455115188e-01
            8.65286504529618749614883199683391e-01 1.79008140202960797093822975512012e-01
            8.47816509809872997927016058383742e-01 2.48941388430719390267853441400803e-01
            8.24704436097220550117015136493137e-01 3.17217972790909519265056815129356e-01
            7.96104090428995436745651659293799e-01 3.83383523879457732697062510851538e-01
            7.62205803386894586992639233358204e-01 4.46997720870417225569326546974480e-01
            7.23235162478359838722496988339117e-01 5.07637221778416636297492914309260e-01
            6.79451510888933962739599792257650e-01 5.64898480729727037186194138485007e-01
            6.31146221596150747146225512551609e-01 6.18400433493469847689993912354112e-01
            5.78640758330441817847145102859940e-01 6.67787033401203489191289008886088e-01
            5.22284536287049183655994966102298e-01 7.12729620778757122501190224284073e-01
            4.62452596825548789549742423332646e-01 7.52929110122138478544684403459541e-01
            3.99543111631482483758759371994529e-01 7.88117980462215816928051026479807e-01
            3.33974732949481767363408835080918e-01 8.18062055672631238678604859160259e-01
            2.66183807521654769434604759226204e-01 8.42562062873283834640858458442381e-01
            1.96621472772007893636825315297756e-01 8.61454958558470096363635093439370e-01
            1.25750654561323060853794686408946e-01 8.74615013624513326639942079054890e-01
            5.40429864919300118053513415361522e-02 8.81954650076205437514431650924962e-01
            -1.80243287361016892023091173768989e-02 8.83425023843914969390311853203457e-01
            -8.99716950301993473315675942103553e-02 8.79016349832812626807765354897128e-01
            -1.61320314538156012185154963844980e-01 8.68757967041062229007764017296722e-01
            -2.31595373968839640665962065213535e-01 8.52718143313628718082952673285035e-01
            -3.00329204396307780644548302007024e-01 8.31003621031033645749630522914231e-01
            -3.67064393519348941552493670315016e-01 8.03758906756423807671296799526317e-01
            -4.31356829664881202823778494348517e-01 7.71165309568234813575315911293728e-01
            -4.92778657277861020791220880710171e-01 7.33439734478189664379499390634010e-01
            -5.50921124229412306760877982014790e-01 6.90833238964230433865054692432750e-01
            -6.05397301994804126756832829414634e-01 6.43629362224425571881170071719680e-01
            -6.55844660598944639851026749965968e-01 5.92142238270387255560933681408642e-01
            -7.01927481193551416893683381204028e-01 5.36714505417251963592661923030391e-01
            -7.43339090210697883698287569131935e-01 4.77715026082225102666001248508110e-01
            -7.79803900224808832497558341856347e-01 4.15536432066052674461076321676956e-01
            -8.11079243941511318638504235423170e-01 3.50592511653165850304958439664915e-01
            -8.36956989108438853541827029403066e-01 2.83315455918919989475313059301698e-01
            -8.57264923601032791111720143817365e-01 2.14152982569293715009450806974201e-01
            -8.71867901465818495587711822736310e-01 1.43565356453424219917991422335035e-01
            -8.80668742294427486783092717814725e-01 7.20223265769733139718411507601559e-02
            -8.83608877943181880709744291380048e-01 1.08210878407130200435915188352474e-16
            -8.80668742294427486783092717814725e-01 -7.20223265769730919272362257288478e-02
            -8.71867901465818606610014285251964e-01 -1.43565356453423637050903494127851e-01
            -8.57264923601032791111720143817365e-01 -2.14152982569293881542904500747682e-01
            -8.36956989108438853541827029403066e-01 -2.83315455918919822941859365528217e-01
            -8.11079243941511429660806697938824e-01 -3.50592511653165628260353514633607e-01
            -7.79803900224808943519860804372001e-01 -4.15536432066052452416471396645647e-01
            -7.43339090210697772675985106616281e-01 -4.77715026082225158177152479765937e-01
            -7.01927481193551638938288306235336e-01 -5.36714505417251741548056997999083e-01
            -6.55844660598944528828724287450314e-01 -5.92142238270387366583236143924296e-01
            -6.05397301994804348801437754445942e-01 -6.43629362224425349836565146688372e-01
            -5.50921124229412528805482907046098e-01 -6.90833238964230211820449767401442e-01
            -4.92778657277861242835825805741479e-01 -7.33439734478189442334894465602702e-01
            -4.31356829664881369357232188121998e-01 -7.71165309568234813575315911293728e-01
            -3.67064393519349163597098595346324e-01 -8.03758906756423696648994337010663e-01
            -3.00329204396307614111094608233543e-01 -8.31003621031033645749630522914231e-01
            -2.31595373968840251288625609049632e-01 -8.52718143313628496038347748253727e-01
            -1.61320314538155845651701270071499e-01 -8.68757967041062229007764017296722e-01
            -8.99716950301999579542311380464525e-02 -8.79016349832812515785462892381474e-01
            -1.80243287361013179714852583401807e-02 -8.83425023843914969390311853203457e-01
            5.40429864919295954717171071024495e-02 -8.81954650076205437514431650924962e-01
            1.25750654561322644520160451975244e-01 -8.74615013624513437662244541570544e-01
            1.96621472772007699347796005895361e-01 -8.61454958558470096363635093439370e-01
            2.66183807521654547389999834194896e-01 -8.42562062873283945663160920958035e-01
            3.33974732949480990207291597471340e-01 -8.18062055672631571745512246707221e-01
            3.99543111631482428247608140736702e-01 -7.88117980462215816928051026479807e-01
            4.62452596825548234438230110754375e-01 -7.52929110122138811611591791006504e-01
            5.22284536287049183655994966102298e-01 -7.12729620778757011478887761768419e-01
            5.78640758330442150914052490406903e-01 -6.67787033401203378168986546370434e-01
            6.31146221596150303057015662488993e-01 -6.18400433493470291779203762416728e-01
            6.79451510888934184784204717288958e-01 -5.64898480729726704119286750938045e-01
            7.23235162478359505655589600792155e-01 -5.07637221778417080386702764371876e-01
            7.62205803386894586992639233358204e-01 -4.46997720870417447613931472005788e-01
            7.96104090428995325723349196778145e-01 -3.83383523879457954741667435882846e-01
            8.24704436097220550117015136493137e-01 -3.17217972790909685798510508902837e-01
            8.47816509809872997927016058383742e-01 -2.48941388430719473534580288287543e-01
            8.65286504529618749614883199683391e-01 -1.79008140202960797093822975512012e-01
            8.76998160323944175864596672909101e-01 -1.07883622336416407083703461466939e-01
            8.82873538055825135550946924922755e-01 -3.60411567627663964596962387076928e-02
            8.52380000094841050461980103136739e-01 3.67052758330442541190308247678331e-02
            8.46069276795660796253173430159222e-01 1.09844074478910980197099434008123e-01
            8.33494552584679748719054259709083e-01 1.82169626028395981176544182744692e-01
            8.14748926320446820170673163374886e-01 2.53146457402310953721524811044219e-01
            7.89971184061305176093981117446674e-01 3.22249080973771639957448087443481e-01
            7.59344771541972218820149009843590e-01 3.88965885094735619453842900838936e-01
            7.23096436005501885802004835568368e-01 4.52802921889647491671126999790431e-01
            6.81494547446029774739884032896953e-01 5.13287564272691287925454162177630e-01
            6.34847111691229870622521502809832e-01 5.69972005113377755414205694250995e-01
            5.83499490034929069182112471025903e-01 6.22436572643862873199793739331653e-01
            5.27831842302918463616379085578956e-01 6.70292837561888399378062786126975e-01
            4.68256312282609832298163610175834e-01 7.13186488825434783400680771592306e-01
            4.05213976354629190623768408840988e-01 7.50799956847715277419297308370005e-01
            3.39171577917615096886549963528523e-01 7.82854764671287006727595780830598e-01
            2.70618071783392810658597227302380e-01 8.09113589714015035703198464034358e-01
            2.00061004126618813270255259340047e-01 8.29382020822437393547943429439329e-01
            1.28022754790477893971356593283417e-01 8.43509997623927532117704686243087e-01
            5.50366697690890804839369820911088e-02 8.51392921521191281541973694402259e-01
            -1.83568874996336041383049320074861e-02 8.52972430103685619329212386219297e-01
            -9.16145367958188239221328785788501e-02 8.48236829242487333502253932238091e-01
            -1.64193904114673744354391260458215e-01 8.37221179669531800904280771646881e-01
            -2.35557637213856418956225979854935e-01 8.20007037400220295531028114055516e-01
            -3.05177383981473260288197479894734e-01 7.96721849921216529466505562595557e-01
            -3.72537704170263384018113583806553e-01 7.67538012613844689013831157353707e-01
            -4.37139885536850680836096216808073e-01 7.32671592399002591378120996523649e-01
            -4.98505636132712648400655552904936e-01 6.92380728053273108990595119394129e-01
            -5.56180625410423568055762189032976e-01 6.46963719039739704186331437085755e-01
            -6.09737847928074838677048319368623e-01 5.96756817003124773179933981737122e-01
            -6.58780784748168923847799760551425e-01 5.42131736280258458293701551156119e-01
            -7.02946339125104402434374151198426e-01 4.83492901857177970192935845261673e-01
            -7.41907524746441726648527037468739e-01 4.21274455148029525197728162311250e-01
            -7.75375886625159993492673038417706e-01 3.55937039763928098068390681874007e-01
            -8.03103636719458835457885470532347e-01 2.87964391068827540998142922035186e-01
            -8.24885488468726113531204191531288e-01 2.17859754772128932920338684198214e-01
            -8.40560176663409763797574214549968e-01 1.46142161073519016856181451657903e-01
            -8.50011651396207268405191825877409e-01 7.33425819449640137293044972466305e-02
            -8.53169937254976806784156906360295e-01 1.04483183278805546842961192939192e-16
            -8.50011651396207268405191825877409e-01 -7.33425819449638055624873800297792e-02
            -8.40560176663409763797574214549968e-01 -1.46142161073518822567152142255509e-01
            -8.24885488468726224553506654046942e-01 -2.17859754772128738631309374795819e-01
            -8.03103636719458835457885470532347e-01 -2.87964391068827318953537997003878e-01
            -7.75375886625159882470370575902052e-01 -3.55937039763928264601844375647488e-01
            -7.41907524746441837670829499984393e-01 -4.21274455148029303153123237279942e-01
            -7.02946339125104624478979076229734e-01 -4.83492901857177803659482151488191e-01
            -6.58780784748169034870102223067079e-01 -5.42131736280258458293701551156119e-01
            -6.09737847928074949699350781884277e-01 -5.96756817003124662157631519221468e-01
            -5.56180625410423679078064651548630e-01 -6.46963719039739482141726512054447e-01
            -4.98505636132712814934109246678418e-01 -6.92380728053272997968292656878475e-01
            -4.37139885536851235947608529386343e-01 -7.32671592399002258311213608976686e-01
            -3.72537704170262884417752502486110e-01 -7.67538012613844911058436082385015e-01
            -3.05177383981473648866256098699523e-01 -7.96721849921216418444203100079903e-01
            -2.35557637213856779778708983030810e-01 -8.20007037400220184508725651539862e-01
            -1.64193904114674327221479188665398e-01 -8.37221179669531578859675846615573e-01
            -9.16145367958192125001914973836392e-02 -8.48236829242487222479951469722437e-01
            -1.83568874996340031247044066731178e-02 -8.52972430103685619329212386219297e-01
            5.50366697690886780280905554718629e-02 -8.51392921521191281541973694402259e-01
            1.28022754790477505393297974478628e-01 -8.43509997623927643140007148758741e-01
            2.00061004126619146337162646887009e-01 -8.29382020822437282525640966923675e-01
            2.70618071783392422080538608497591e-01 -8.09113589714015257747803389065666e-01
            3.39171577917614708308491344723734e-01 -7.82854764671287228772200705861906e-01
            4.05213976354629523690675796387950e-01 -7.50799956847715055374692383338697e-01
            4.68256312282609443720104991371045e-01 -7.13186488825435116467588159139268e-01
            5.27831842302918130549471698031994e-01 -6.70292837561888621422667711158283e-01
            5.83499490034929291226717396057211e-01 -6.22436572643862651155188814300345e-01
            6.34847111691229426533311652747216e-01 -5.69972005113378088481113081797957e-01
            6.81494547446029885762186495412607e-01 -5.13287564272691065880849237146322e-01
            7.23096436005501552735097448021406e-01 -4.52802921889647880249185618595220e-01
            7.59344771541971885753241622296628e-01 -3.88965885094736174565355213417206e-01
            7.89971184061305287116283579962328e-01 -3.22249080973771417912843162412173e-01
            8.14748926320446820170673163374886e-01 -2.53146457402311453321885892364662e-01
            8.33494552584679637696751797193429e-01 -1.82169626028396536288056495322962e-01
            8.46069276795660907275475892674876e-01 -1.09844074478910785908070124605729e-01
            8.52380000094841050461980103136739e-01 -3.67052758330448369861187529750168e-02
            8.19587805211789866000060555961682e-01 3.73419088126641235403369023515552e-02
            8.12796442539331587262552147876704e-01 1.11716299621224243732164893572190e-01
            7.99269992564370035381671186769381e-01 1.85164973987533620913836784893647e-01
            7.79120539711376403069209573004628e-01 2.57079313064092485063838466885500e-01
            7.52515048692497634519327220914420e-01 3.26863411988830676602191260826658e-01
            7.19673980985367944818165142351063e-01 3.93939017740467467554310587729560e-01
            6.80869468019873913533501763595268e-01 4.57750320725159032253515078991768e-01
            6.36423056211422255579179818596458e-01 5.17768560389837761981368657870917e-01
            5.86703042526074303175676050159382e-01 5.73496406698681515656801366276341e-01
            5.32121422655896014752840983419446e-01 6.24472081166417947173385982750915e-01
            4.73130477092899626168076565591036e-01 6.70273183300284847163652557355817e-01
            4.10219023390448245258710358029930e-01 7.10520190743541779632153065904276e-01
            3.43908365667060400561183541867649e-01 7.44879604117244964456290290399920e-01
            2.74747974916308035364664874578011e-01 7.73066710501131293398202615207992e-01
            2.03310935917113161375269214659056e-01 7.94847942654543060392313691409072e-01
            1.30189198472785760962722179101547e-01 8.10042814428142299298940542939818e-01
            5.59886723285252102533249285443162e-02 8.18525416328986787917187939456198e-01
            -1.86757935875503100486838548022206e-02 8.20225458846241428645384985429700e-01
            -9.31855059962623383240654106884904e-02 8.15128854892202103776810417912202e-01
            -1.66923053954731281933732134348247e-01 8.03277836532340749897684872848913e-01
            -2.39277424917895914502352638919547e-01 7.84770605037110713375625437038252e-01
            -3.09649067780891629197981274046469e-01 7.59760517155292136592947827011812e-01
            -3.77454860948325754410603849464678e-01 7.28454814351674251327040110481903e-01
            -4.42132944263464111589456706497003e-01 6.91112905539010058397764169058064e-01
            -5.03147374758439624997663486283273e-01 6.48044217534067934494146356882993e-01
            -5.59992567646473760056835544673959e-01 5.99605631049577092461788652144605e-01
            -6.12197485756645010113174976140726e-01 5.46198523468248375856148868479067e-01
            -6.59329542696235226806322771153646e-01 4.88265442903371371663467925827717e-01
            -7.00998187397817384969300746888621e-01 4.26286441105774183135679322731448e-01
            -7.36858140348399026642312037438387e-01 3.60775095603827922197126554237911e-01
            -7.66612254684207794497297072666697e-01 2.92274254038304592828723116326728e-01
            -7.90013978443187547817672111705178e-01 2.21351535955861433713209862617077e-01
            -8.06869397572203883584052164223976e-01 1.48594629334713540513845941859472e-01
            -8.17038842759960082240411338716513e-01 7.46064208169603254594548502609541e-02
            -8.20438046780896268472815791028552e-01 1.00474682788893106788668596681304e-16
            -8.17038842759960082240411338716513e-01 -7.46064208169601311704255408585595e-02
            -8.06869397572203994606354626739630e-01 -1.48594629334712957646758013652288e-01
            -7.90013978443187547817672111705178e-01 -2.21351535955861267179756168843596e-01
            -7.66612254684207905519599535182351e-01 -2.92274254038304426295269422553247e-01
            -7.36858140348399137664614499954041e-01 -3.60775095603827755663672860464430e-01
            -7.00998187397817718036208134435583e-01 -4.26286441105773628024167010153178e-01
            -6.59329542696235226806322771153646e-01 -4.88265442903371538196921619601198e-01
            -6.12197485756645010113174976140726e-01 -5.46198523468248153811543943447759e-01
            -5.59992567646474204146045394736575e-01 -5.99605631049576648372578802081989e-01
            -5.03147374758439847042268411314581e-01 -6.48044217534067823471843894367339e-01
            -4.42132944263464333634061631528311e-01 -6.91112905539009947375461706542410e-01
            -3.77454860948326254010964930785121e-01 -7.28454814351674029282435185450595e-01
            -3.09649067780891795731434967819951e-01 -7.59760517155292025570645364496158e-01
            -2.39277424917896441858289335868903e-01 -7.84770605037110602353322974522598e-01
            -1.66923053954731309689307749977161e-01 -8.03277836532340749897684872848913e-01
            -9.31855059962625464908825279053417e-02 -8.15128854892202103776810417912202e-01
            -1.86757935875508790379839751949476e-02 -8.20225458846241428645384985429700e-01
            5.59886723285251963755371207298595e-02 -8.18525416328986787917187939456198e-01
            1.30189198472785372384663560296758e-01 -8.10042814428142410321243005455472e-01
            2.03310935917112606263756902080786e-01 -7.94847942654543060392313691409072e-01
            2.74747974916307868831211180804530e-01 -7.73066710501131293398202615207992e-01
            3.43908365667060067494276154320687e-01 -7.44879604117245186500895215431228e-01
            4.10219023390448245258710358029930e-01 -7.10520190743541779632153065904276e-01
            4.73130477092899570656925334333209e-01 -6.70273183300284958185955019871471e-01
            5.32121422655895681685933595872484e-01 -6.24472081166418280240293370297877e-01
            5.86703042526074303175676050159382e-01 -5.73496406698681515656801366276341e-01
            6.36423056211422033534574893565150e-01 -5.17768560389837984025973582902225e-01
            6.80869468019873580466594376048306e-01 -4.57750320725159587365027391570038e-01
            7.19673980985367833795862679835409e-01 -3.93939017740467689598915512760868e-01
            7.52515048692497412474722295883112e-01 -3.26863411988831065180249879631447e-01
            7.79120539711376403069209573004628e-01 -2.57079313064092429552687235627673e-01
            7.99269992564370035381671186769381e-01 -1.85164973987533870714017325553868e-01
            8.12796442539331476240249685361050e-01 -1.11716299621224757210313782707090e-01
            8.19587805211789866000060555961682e-01 -3.73419088126641859903820375166106e-02
            7.84642545151285952798048128897790e-01 3.79530536334182697077999080192967e-02
            7.77316549117605837260214229900157e-01 1.13504803464371875620919638549822e-01
            7.62732957901329999828021755092777e-01 1.87996789527579061251927328157763e-01
            7.41027934564310819531840479612583e-01 2.60733500219938185704648958562757e-01
            7.12404133061346311883710313850315e-01 3.31035812471551837976591059486964e-01
            6.77128806114807635374575056630420e-01 3.98247332534851061769387570166145e-01
            6.35531309947975908691830682073487e-01 4.61740524556160991664910397958010e-01
            5.88000029174727489866825180797605e-01 5.20922569708885396799757927510655e-01
            5.34978750557037141533101021195762e-01 5.75240901183165509458206088311272e-01
            4.76962519487554637009907310130075e-01 6.24188363353301300939790507982252e-01
            4.14493017884154879570957064061076e-01 6.67307946953184849547824342153035e-01
            3.48153506651820321415868875192245e-01 7.04197056048681546691625499079237e-01
            2.78563379932721233434023133668234e-01 7.34511266967394660376555748371175e-01
            2.06372381989997549789350728133286e-01 7.57967544089694911235710605978966e-01
            1.32254540720637220330146988089837e-01 7.74346882476040110354631451627938e-01
            5.69018744386097646836830676875252e-02 7.83496352657089056847894426027779e-01
            -1.89820693136775360543300195104166e-02 7.85330528494951440876548076630570e-01
            -9.46887825992223375326517498251633e-02 7.79832284784020779433433290250832e-01
            -1.69511412234138653110093741815945e-01 7.67052957144405245237805957003729e-01
            -2.42751359485382567360289840507903e-01 7.47111862715074015461880208022194e-01
            -3.13724802698896021446728354931111e-01 7.20195186121878827556486157845939e-01
            -3.81769081958145684030370148320799e-01 6.86554241121867692143609929189552e-01
            -4.46248886161217883650209614643245e-01 6.46503124154447772475862166174920e-01
            -5.06562184749404287309459959942615e-01 6.00415781707559048641087429132313e-01
            -5.62145848704318273902913460915443e-01 5.48722518880071730151826159271877e-01
            -6.12480908331813678202593109745067e-01 4.91905981739016284759458130793064e-01
            -6.57097398742190863529799571551848e-01 4.30496650983297646231306998743094e-01
            -6.95578747785744910814287322864402e-01 3.65067888988341360256839607245638e-01
            -7.27565665474690259628687272197567e-01 2.96230586476076140911573020275682e-01
            -7.52759498576969887650989221583586e-01 2.24627458792859613367909332737327e-01
            -7.70925019061015515120516283786856e-01 1.50927045049460639702942899020854e-01
            -7.81892620356500089862095137505094e-01 7.58174661515077508155968644132372e-02
            -7.85559900925186571640779220615514e-01 9.62033418206541693147065455252023e-17
            -7.81892620356500089862095137505094e-01 -7.58174661515075426487797471963859e-02
            -7.70925019061015515120516283786856e-01 -1.50927045049460445413913589618460e-01
            -7.52759498576969776628686759067932e-01 -2.24627458792859779901363026510808e-01
            -7.27565665474690481673292197228875e-01 -2.96230586476075641311211938955239e-01
            -6.95578747785745021836589785380056e-01 -3.65067888988341193723385913472157e-01
            -6.57097398742190974552102034067502e-01 -4.30496650983297479697853304969613e-01
            -6.12480908331813789224895572260721e-01 -4.91905981739016118226004437019583e-01
            -5.62145848704318384925215923431097e-01 -5.48722518880071619129523696756223e-01
            -5.06562184749403954242552572395653e-01 -6.00415781707559381707994816679275e-01
            -4.46248886161218050183663308416726e-01 -6.46503124154447661453559703659266e-01
            -3.81769081958146128119579998383415e-01 -6.86554241121867359076702541642589e-01
            -3.13724802698895854913274661157629e-01 -7.20195186121878938578788620361593e-01
            -2.42751359485382733893743534281384e-01 -7.47111862715073904439577745506540e-01
            -1.69511412234139374755059748167696e-01 -7.67052957144405134215503494488075e-01
            -9.46887825992221848769858638661390e-02 -7.79832284784020890455735752766486e-01
            -1.89820693136777268739123769591970e-02 -7.85330528494951440876548076630570e-01
            5.69018744386097369281074520586117e-02 -7.83496352657089056847894426027779e-01
            1.32254540720637359108025066234404e-01 -7.74346882476040110354631451627938e-01
            2.06372381989997188966867724957410e-01 -7.57967544089694911235710605978966e-01
            2.78563379932721233434023133668234e-01 -7.34511266967394660376555748371175e-01
            3.48153506651819877326659025129629e-01 -7.04197056048681768736230424110545e-01
            4.14493017884154657526352139029768e-01 -6.67307946953184960570126804668689e-01
            4.76962519487554470476453616356594e-01 -6.24188363353301522984395433013560e-01
            5.34978750557036808466193633648800e-01 -5.75240901183165842525113475858234e-01
            5.88000029174727600889127643313259e-01 -5.20922569708885174755153002479346e-01
            6.35531309947975908691830682073487e-01 -4.61740524556161158198364091731491e-01
            6.77128806114807191285365206567803e-01 -3.98247332534851672392051114002243e-01
            7.12404133061346533928315238881623e-01 -3.31035812471551615931986134455656e-01
            7.41027934564310708509538017096929e-01 -2.60733500219938407749253883594065e-01
            7.62732957901329777783416830061469e-01 -1.87996789527579782896893334509514e-01
            7.77316549117605837260214229900157e-01 -1.13504803464371667454102521332970e-01
            7.84642545151285952798048128897790e-01 -3.79530536334185680802377760301169e-02
            7.47664312903386418796003454190213e-01 3.85399282952576527350174728780985e-02
            7.39738885189544892462265579524683e-01 1.15211252058233584727453546747711e-01
            7.23972041267243682227672252338380e-01 1.90661307888194381243707198336779e-01
            7.00530913604390015336775832111016e-01 2.64090306423570064797701206771308e-01
            6.69663983985678612498304573819041e-01 3.34719882012893266143294113135198e-01
            6.31698449543859341659413075831253e-01 4.01801343584339665238047700768220e-01
            5.87036754388732706644304926157929e-01 4.64623610957341670602005478940555e-01
            5.36152323599469626813629474781919e-01 5.22520752469398108708276140532689e-01
            4.79584544800997880642512427584734e-01 5.74879044017362006435689636418829e-01
            4.17933050520994331389346143623698e-01 6.21143474685609486840576209942810e-01
            3.51851361935919537682337931983056e-01 6.60823629999816919422528371796943e-01
            2.82039961383971859998354148046928e-01 6.93498890442388549182339829712873e-01
            2.09238867078040735592026067024563e-01 7.18822890123982150001324953336734e-01
            1.34219788728557609669422845399822e-01 7.36527188348100159132059161493089e-01
            5.77779472285844392098752564379538e-02 7.46424115149254441270443294342840e-01
            -1.92763548854789773523421558820701e-02 7.48408760641285808468126106163254e-01
            -9.61263228423616528095507760554028e-02 7.42460087088257170151450736739207e-01
            -1.71957327863691000757739857363049e-01 7.28641151909687034837759256333811e-01
            -2.45965542431699546455092786345631e-01 7.07098439256215738346611487941118e-01
            -3.17366461060881788203147380045266e-01 6.78060307241168835901135025778785e-01
            -3.85403216251303193384813994271099e-01 6.41834567287745683117350381508004e-01
            -4.49354601472386150362581247463822e-01 5.98805221251359376388734290230786e-01
            -5.08542716131548333535761230450589e-01 5.49428390904441621422904518112773e-01
            -5.62340151489126638395532609138172e-01 4.94227482932184380981510685160174e-01
            -6.10176641347098258627568156953203e-01 4.33787640691469078557673810792039e-01
            -6.51545107012646340649553167168051e-01 3.68749541545716097434848279590369e-01
            -6.86007032458448406941897701472044e-01 2.99802605525451959511684663084452e-01
            -7.13197112701657642830355143814813e-01 2.27677687304477710528161082947918e-01
            -7.32827126127597372473587711283471e-01 1.53139328958510678724280751339393e-01
            -7.44688989710578286285169724578736e-01 7.69776556289863411741691834322410e-02
            -7.48656964745734843091895527322777e-01 9.16840355535236981419145217085242e-17
            -7.44688989710578286285169724578736e-01 -7.69776556289861607629276818443032e-02
            -7.32827126127597483495890173799125e-01 -1.53139328958510179123919670018950e-01
            -7.13197112701657753852657606330467e-01 -2.27677687304477543994707389174437e-01
            -6.86007032458448406941897701472044e-01 -2.99802605525452070533987125600106e-01
            -6.51545107012646229627250704652397e-01 -3.68749541545716208457150742106023e-01
            -6.10176641347098591694475544500165e-01 -4.33787640691468634468463960729423e-01
            -5.62340151489126749417835071653826e-01 -4.94227482932184269959208222644520e-01
            -5.08542716131548444558063692966243e-01 -5.49428390904441399378299593081465e-01
            -4.49354601472386039340278784948168e-01 -5.98805221251359487411036752746440e-01
            -3.85403216251303581962872613075888e-01 -6.41834567287745350050442993961042e-01
            -3.17366461060881954736601073818747e-01 -6.78060307241168724878832563263131e-01
            -2.45965542431699546455092786345631e-01 -7.07098439256215738346611487941118e-01
            -1.71957327863691666891554632456973e-01 -7.28641151909686812793154331302503e-01
            -9.61263228423615140316726979108353e-02 -7.42460087088257170151450736739207e-01
            -1.92763548854793242970373512434890e-02 -7.48408760641285808468126106163254e-01
            5.77779472285842587986337548500160e-02 -7.46424115149254441270443294342840e-01
            1.34219788728557443135969151626341e-01 -7.36527188348100159132059161493089e-01
            2.09238867078040735592026067024563e-01 -7.18822890123982150001324953336734e-01
            2.82039961383971859998354148046928e-01 -6.93498890442388549182339829712873e-01
            3.51851361935919260126581775693921e-01 -6.60823629999817141467133296828251e-01
            4.17933050520994053833589987334562e-01 -6.21143474685609708885181134974118e-01
            4.79584544800997825131361196326907e-01 -5.74879044017362117457992098934483e-01
            5.36152323599469515791327012266265e-01 -5.22520752469398219730578603048343e-01
            5.87036754388732262555095076095313e-01 -4.64623610957342170202366560260998e-01
            6.31698449543859452681715538346907e-01 -4.01801343584339554215745238252566e-01
            6.69663983985678501476002111303387e-01 -3.34719882012893654721352731939987e-01
            7.00530913604390126359078294626670e-01 -2.64090306423569676219642587966518e-01
            7.23972041267243682227672252338380e-01 -1.90661307888194547777160892110260e-01
            7.39738885189544781439963117009029e-01 -1.15211252058234264739056129656092e-01
            7.47664312903386418796003454190213e-01 -3.85399282952575625293967220841296e-02
            7.08754117370797409591887117130682e-01 3.91030543143388864546494687601808e-02
            7.00150802489686863161466590099735e-01 1.16834504834041716381243247724342e-01
            6.83048605315763279755003622994991e-01 1.93147742733273758419798582508520e-01
            6.57655123355467829959764003433520e-01 2.67116428680589934607780833175639e-01
            6.24278599080876128724071350006852e-01 3.37842683029227319746468083394575e-01
            5.83324178283643912656941665773047e-01 4.04467984859716411794039458982297e-01
            5.35288992153920895056273820955539e-01 4.66183593260861006690731755952584e-01
            4.80756122781134498378463604240096e-01 5.22240364348849461784141112730140e-01
            4.20387525327287459031566640987876e-01 5.71957844859188435648889026197139e-01
            3.54915992788000622670807615577360e-01 6.14732531927566161478182493738132e-01
            2.85136260878212199898484868754167e-01 6.50045198797099321730286192178028e-01
            2.11895361017177624729512785961560e-01 6.77467197527797826417383930674987e-01
            1.36082338514457196199103350409132e-01 6.96665662201895075078539321111748e-01
            5.86174607641922612577545237400045e-02 7.07407549465176921366094120458001e-01
            -1.95589535544333226191326957632555e-02 7.09562467357613191332177393633174e-01
            -9.74979486721687244044076692262024e-02 7.03104258095118783700172571116127e-01
            -1.74253450767245327002186172649090e-01 6.88111315589618466326271573052509e-01
            -2.48893752019987368750975065267994e-01 6.64765633853150794685404889605707e-01
            -3.20512820283618438121919780314784e-01 6.33350597837097795128613597626099e-01
            -3.88241297087178749425362411784590e-01 5.94247543522758880918388513237005e-01
            -4.51257050469699216854735368542606e-01 5.47931129019109119937525065324735e-01
            -5.08795154548517869486090603459161e-01 4.94963572856344735662048606172903e-01
            -5.60157174683298952899690448248293e-01 4.35987829414528904603542969198315e-01
            -6.04719645526442861616089885501424e-01 3.71719784328385649541104385207291e-01
            -6.41941639047836076770181534811854e-01 3.02939564605460509572054661475704e-01
            -6.71371330668378063499801555735758e-01 2.30482068941034207165685643303732e-01
            -6.92651483798311984330098312057089e-01 1.55226833178948420144394049202674e-01
            -7.05523786205499714441202740999870e-01 7.80873539379109415925483972387156e-02
            -7.09831985576001134319312768639065e-01 8.69293469068059928603042353913844e-17
            -7.05523786205499714441202740999870e-01 -7.80873539379107611813068956507777e-02
            -6.92651483798311984330098312057089e-01 -1.55226833178948281366515971058107e-01
            -6.71371330668378174522104018251412e-01 -2.30482068941034040632231949530251e-01
            -6.41941639047836298814786459843162e-01 -3.02939564605460065482844811413088e-01
            -6.04719645526442750593787422985770e-01 -3.71719784328385816074558078980772e-01
            -5.60157174683299063921992910763947e-01 -4.35987829414528793581240506682661e-01
            -5.08795154548517980508393065974815e-01 -4.94963572856344680150897374915075e-01
            -4.51257050469699383388189062316087e-01 -5.47931129019109008915222602809081e-01
            -3.88241297087178915958816105558071e-01 -5.94247543522758880918388513237005e-01
            -3.20512820283618549144222242830438e-01 -6.33350597837097795128613597626099e-01
            -2.48893752019987507528853143412562e-01 -6.64765633853150683663102427090053e-01
            -1.74253450767245327002186172649090e-01 -6.88111315589618466326271573052509e-01
            -9.74979486721687382821954770406592e-02 -7.03104258095118783700172571116127e-01
            -1.95589535544333399663674555313264e-02 -7.09562467357613191332177393633174e-01
            5.86174607641916228795153642749938e-02 -7.07407549465176921366094120458001e-01
            1.36082338514457196199103350409132e-01 -6.96665662201895075078539321111748e-01
            2.11895361017177624729512785961560e-01 -6.77467197527797826417383930674987e-01
            2.85136260878211755809275018691551e-01 -6.50045198797099543774891117209336e-01
            3.54915992788000622670807615577360e-01 -6.14732531927566161478182493738132e-01
            4.20387525327287014942356790925260e-01 -5.71957844859188768715796413744101e-01
            4.80756122781134498378463604240096e-01 -5.22240364348849461784141112730140e-01
            5.35288992153921006078576283471193e-01 -4.66183593260860840157278062179103e-01
            5.83324178283643690612336740741739e-01 -4.04467984859716911394400540302740e-01
            6.24278599080876239746373812522506e-01 -3.37842683029227208724165620878921e-01
            6.57655123355467607915159078402212e-01 -2.67116428680590489719293145753909e-01
            6.83048605315763168732701160479337e-01 -1.93147742733274258020159663828963e-01
            7.00150802489686974183769052615389e-01 -1.16834504834041605358940785208688e-01
            7.08754117370797409591887117130682e-01 -3.91030543143393791161166461733956e-02
            6.67998118923665118451538091903785e-01 3.96422504220650395723168912809342e-02
            6.58620889603912185172873705596430e-01 1.18370260967153931308537551103655e-01
            6.39998066708915347433617171191145e-01 1.95436612519076041705190505126666e-01
            6.12391073850389267008154092764016e-01 2.69759462433568408812334382673725e-01
            5.76187452692793034003670982201584e-01 3.40295480815527739970605125563452e-01
            5.31895422717862831341051332856296e-01 4.06054496583730495373742996889632e-01
            4.80136746937119607281374555896036e-01 4.66113397302331533555985743078054e-01
            4.21638003702108521419944509034394e-01 5.19629087655975485660064805415459e-01
            3.57220387137022421519816361978883e-01 5.65850324659937453652958083694102e-01
            2.87788179373278329986618473412818e-01 6.04128263464882575561887279036455e-01
            2.14316056410602417958699561495450e-01 6.33925565716266237181741871609120e-01
            1.37835405802511468120741255916073e-01 6.54823942606971076685340449330397e-01
            5.94198482358887225540655663280631e-02 6.66530026735258740444578506867401e-01
            -1.98298337500520879816967578790354e-02 6.68879490340020810279497709416319e-01
            -9.88011483376739774175945285605849e-02 6.61839352102334355087975836795522e-01
            -1.76385511377422893319888430596620e-01 6.45508440130883043295284551277291e-01
            -2.51493808479242297870825950667495e-01 6.20116004631945494374178906582529e-01
            -3.23071683791240016336843154931557e-01 5.86018499739021647698677952575963e-01
            -3.90114340844673557207045178074623e-01 5.43694579678155931468097605829826e-01
            -4.51680647693829318001235151314177e-01 4.93738379511825697942839497045497e-01
            -5.06906348345554147449831816629739e-01 4.36851174785025053726172927781590e-01
            -5.55016195018926850046625531831523e-01 3.73831537153827331287914148560958e-01
            -5.95334830924737268276203394634649e-01 3.05564124189825703226119912869763e-01
            -6.27296270794408195037306086305762e-01 2.33007260727019466228782107464212e-01
            -6.50451846072509276552864321274683e-01 1.57179486081821029319627314180252e-01
            -6.64476503239783466980838966264855e-01 7.91452559937159128011785469425377e-02
            -6.69173366852029438689442031318322e-01 8.19501021789995423242755229578692e-17
            -6.64476503239783466980838966264855e-01 -7.91452559937160515790566250871052e-02
            -6.50451846072509498597469246305991e-01 -1.57179486081820557474841848488722e-01
            -6.27296270794408306059608548821416e-01 -2.33007260727019299695328413690731e-01
            -5.95334830924737379298505857150303e-01 -3.05564124189825592203817450354109e-01
            -5.55016195018926850046625531831523e-01 -3.73831537153827220265611686045304e-01
            -5.06906348345554369494436741661048e-01 -4.36851174785024665148114308976801e-01
            -4.51680647693829595556991307603312e-01 -4.93738379511825420387083340756362e-01
            -3.90114340844673668229347640590277e-01 -5.43694579678155820445795143314172e-01
            -3.23071683791239905314540692415903e-01 -5.86018499739021758720980415091617e-01
            -2.51493808479242408893128413183149e-01 -6.20116004631945383351876444066875e-01
            -1.76385511377422921075464046225534e-01 -6.45508440130883043295284551277291e-01
            -9.88011483376742827289263004786335e-02 -6.61839352102334355087975836795522e-01
            -1.98298337500522510457034996989023e-02 -6.68879490340020810279497709416319e-01
            5.94198482358882576481740045437618e-02 -6.66530026735258740444578506867401e-01
            1.37835405802511745676497412205208e-01 -6.54823942606970965663037986814743e-01
            2.14316056410602584492153255268931e-01 -6.33925565716266237181741871609120e-01
            2.87788179373277996919711085865856e-01 -6.04128263464882686584189741552109e-01
            3.57220387137022421519816361978883e-01 -5.65850324659937453652958083694102e-01
            4.21638003702108132841885890229605e-01 -5.19629087655975818726972192962421e-01
            4.80136746937119440747920862122555e-01 -4.66113397302331700089439436851535e-01
            5.31895422717862831341051332856296e-01 -4.06054496583730495373742996889632e-01
            5.76187452692792811959066057170276e-01 -3.40295480815527962015210050594760e-01
            6.12391073850389267008154092764016e-01 -2.69759462433568464323485613931553e-01
            6.39998066708915458455919633706799e-01 -1.95436612519075902927312426982098e-01
            6.58620889603912074150571243080776e-01 -1.18370260967154139475354668320506e-01
            6.67998118923665118451538091903785e-01 -3.96422504220650187556351795592491e-02
            6.25470488626356235783987358445302e-01 4.01565377112375332391280835508951e-02
            6.15200280495176388129152655892540e-01 1.19810243894681506260369019400969e-01
            5.94828500766395595888980096788146e-01 1.97496669185707768301440978575556e-01
            5.64689653499952148862917056248989e-01 2.71940204628794868213503832521383e-01
            5.25278617734727504284819588065147e-01 3.41918489430069916235055416109390e-01
            4.77242521588409962518539941811468e-01 4.06282482087749974297707922232803e-01
            4.21370116431692254277407982954173e-01 4.63975327621834743307971393733169e-01
            3.58578825612571872039069376114639e-01 5.14049711103659268118803993274923e-01
            2.89899680390339753444095549639314e-01 5.55683412540833088222314017912140e-01
            2.16460390430807669837065532192355e-01 5.88192807706783504784198157722130e-01
            1.39466826844771990545623907564732e-01 6.11044093231656426645770352479303e-01
            6.01832218177138431047801248041651e-02 6.23862051638891301763578667305410e-01
            -2.00885900477363425753463133105470e-02 6.26436212405812931081072747474536e-01
            -1.00030547819981593948845954855642e-01 6.18724307883795066054233302565990e-01
            -1.78330006762516535268048301077215e-01 6.00852967331881981927210745197954e-01
            -2.53701291924210092787461690022610e-01 5.73115637667856336889826707192697e-01
            -3.24906808886459064211749137029983e-01 5.35967765077961399988737412058981e-01
            -3.90777365029325751688560330876498e-01 4.90019316603115095976050952231162e-01
            -4.50231367642034363552028253252502e-01 4.36024764496960814952331020322163e-01
            -5.02292583645378654111368632584345e-01 3.74870697812321740371999112539925e-01
            -5.46106169311894040774291170237120e-01 3.07561264633464170881183008532389e-01
            -5.80952706776228011698037789756199e-01 2.35201683992315252469396114065603e-01
            -6.06260016856600802981347442255355e-01 1.58980098202513769889421268999286e-01
            -6.21612554221151025757308161701076e-01 8.01480635954693182432251319369243e-02
            -6.26758230630796608906507572100963e-01 7.67557460981263691719088102223315e-17
            -6.21612554221151025757308161701076e-01 -8.01480635954691655875592459779000e-02
            -6.06260016856600802981347442255355e-01 -1.58980098202513631111543190854718e-01
            -5.80952706776228011698037789756199e-01 -2.35201683992315113691518035921035e-01
            -5.46106169311894151796593632752774e-01 -3.07561264633463782303124389727600e-01
            -5.02292583645378876155973557615653e-01 -3.74870697812321629349696650024271e-01
            -4.50231367642034419063179484510329e-01 -4.36024764496960759441179789064336e-01
            -3.90777365029325918222014024649980e-01 -4.90019316603114984953748489715508e-01
            -3.24906808886459397278656524576945e-01 -5.35967765077961177944132487027673e-01
            -2.53701291924210370343217846311745e-01 -5.73115637667856225867524244677043e-01
            -1.78330006762516535268048301077215e-01 -6.00852967331881981927210745197954e-01
            -1.00030547819981344148665414195420e-01 -6.18724307883795066054233302565990e-01
            -2.00885900477363564531341211250037e-02 -6.26436212405812931081072747474536e-01
            6.01832218177134059544641786487773e-02 -6.23862051638891301763578667305410e-01
            1.39466826844771851767745829420164e-01 -6.11044093231656426645770352479303e-01
            2.16460390430807669837065532192355e-01 -5.88192807706783504784198157722130e-01
            2.89899680390339586910641855865833e-01 -5.55683412540833199244616480427794e-01
            3.58578825612571872039069376114639e-01 -5.14049711103659268118803993274923e-01
            4.21370116431692032232803057922865e-01 -4.63975327621834965352576318764477e-01
            4.77242521588409462918178860491025e-01 -4.06282482087750529409220234811073e-01
            5.25278617734727615307122050580801e-01 -3.41918489430069694190450491078082e-01
            5.64689653499952037840614593733335e-01 -2.71940204628795034746957526294864e-01
            5.94828500766395484866677634272492e-01 -1.97496669185708240146226444267086e-01
            6.15200280495176388129152655892540e-01 -1.19810243894681742182761752246734e-01
            6.25470488626356235783987358445302e-01 -4.01565377112380952895343000363937e-02
            5.81235317719430599758823063893942e-01 4.06439327570931527300324148654909e-02
            5.69922233405396605476767035725061e-01 1.21140710351950911527474374906888e-01
            5.47516261095058465180329676513793e-01 1.99279621815323632061378589241940e-01
            5.14453507553021216480715338548180e-01 2.73539782117271201844488359711249e-01
            4.71377501668655884969894032110460e-01 3.42475801707196436662883343160502e-01
            4.19126668898271215191186911397381e-01 4.04745919377341667466652097573387e-01
            3.58718012267301322726353873804328e-01 4.59138118118466498351892823848175e-01
            2.91327317563239651665440987926559e-01 5.04593715652283836270441952365218e-01
            2.18266268002721530727683330042055e-01 5.40227970477774044333330039080465e-01
            1.40956913809730688402765963473939e-01 5.65347302358122805188145321153570e-01
            6.09039936255462086012180122907012e-02 5.79462792071095744717013076297008e-01
            -2.03343535172933291554908663556489e-02 5.82299697665561555304236662777839e-01
            -1.01176915598903308102229914311465e-01 5.73802802001055933800444108783267e-01
            -1.80050184105416205548877428554988e-01 5.54137487486613178333527685026638e-01
            -2.55418980582366228482271708344342e-01 5.23686517100292903137415123637766e-01
            -3.25816337137064426787702586807427e-01 4.83042584343199854490791267380700e-01
            -3.89872049299980316661162760283332e-01 4.32996777134662225172689886676380e-01
            -4.46339345496155004422433876243304e-01 3.74523180185732385005792366428068e-01
            -4.94119154035727703444536018650979e-01 3.08759915548290297948597071808763e-01
            -5.32281495294201989487703485792736e-01 2.36986990363899502343159042538900e-01
            -5.60083582708001626038196718582185e-01 1.60601382980781443032824995498231e-01
            -5.76984280270022797942885972588556e-01 8.10898523593077541482543324491417e-02
            -5.82654635126479192308579513337463e-01 7.13546133916011743824412029228128e-17
            -5.76984280270022797942885972588556e-01 -8.10898523593076292481640621190309e-02
            -5.60083582708001737060499181097839e-01 -1.60601382980781054454766376693442e-01
            -5.32281495294202211532308410824044e-01 -2.36986990363899141520676039363025e-01
            -4.94119154035727758955687249908806e-01 -3.08759915548290242437445840550936e-01
            -4.46339345496155115444736338758958e-01 -3.74523180185732273983489903912414e-01
            -3.89872049299980427683465222798986e-01 -4.32996777134662058639236192902899e-01
            -3.25816337137064704343458743096562e-01 -4.83042584343199687957337573607219e-01
            -2.55418980582366339504574170859996e-01 -5.23686517100292903137415123637766e-01
            -1.80050184105416344326755506699556e-01 -5.54137487486613067311225222510984e-01
            -1.01176915598903321980017722125922e-01 -5.73802802001055933800444108783267e-01
            -2.03343535172938634503214672122340e-02 -5.82299697665561444281934200262185e-01
            6.09039936255459310454618560015660e-02 -5.79462792071095855739315538812662e-01
            1.40956913809730438602585422813718e-01 -5.65347302358122916210447783669224e-01
            2.18266268002721530727683330042055e-01 -5.40227970477774044333330039080465e-01
            2.91327317563239651665440987926559e-01 -5.04593715652283836270441952365218e-01
            3.58718012267301433748656336319982e-01 -4.59138118118466387329590361332521e-01
            4.19126668898270993146581986366073e-01 -4.04745919377341834000105791346869e-01
            4.71377501668655829458742800852633e-01 -3.42475801707196603196337036933983e-01
            5.14453507553021216480715338548180e-01 -2.73539782117271201844488359711249e-01
            5.47516261095058465180329676513793e-01 -1.99279621815323548794651742355200e-01
            5.69922233405396494454464573209407e-01 -1.21140710351951230716593954639393e-01
            5.81235317719430710781125526409596e-01 -4.06439327570928404798067390402139e-02
            5.35347786014324533709896059008315e-01 4.11010717431243705055621262545174e-02
            5.22799687649891486884712321625557e-01 1.22339840943367278436326728296990e-01
            4.97997607711412659803329461283283e-01 2.00711067962338535197730493564450e-01
            4.61522885931377802037900437426288e-01 2.74377797663085232215962605550885e-01
            4.14230458873770357453025781069300e-01 3.41613344338446700554356993961846e-01
            3.57228820945618252835629391483963e-01 4.00841763760559188778387351703714e-01
            2.91854042227609189463777283890522e-01 4.50674791977848931967542966958717e-01
            2.19638452123800648196905171971594e-01 4.89944385045418651092319350937032e-01
            1.42274722859129620911033953234437e-01 5.17730096985128285247412804892519e-01
            6.15761946771040055703672067011212e-02 5.33380654259188347054987389128655e-01
            -2.05656273185905597022937740803172e-02 5.36529221069892203743734171439428e-01
            -1.02225408440554665912003429184551e-01 5.27101997679798484064406238758238e-01
            -1.81489112630910748302781598795264e-01 5.05319950215026736373147286940366e-01
            -2.56498865844236867417293979087844e-01 4.71693631406544133799485507552163e-01
            -3.25496503040531848238714474064182e-01 4.27011213666874944738793828946655e-01
            -3.86864778083599591962382646670449e-01 3.72320014996776249560639371338766e-01
            -4.39165270619768843829433535574935e-01 3.08901950738964647946716013393598e-01
            -4.81172101431833532103610195918009e-01 2.38243486568984280671301689835673e-01
            -5.11900666008897831105173281684984e-01 1.62000796999642343587666459825414e-01
            -5.30630712841598795037612035230268e-01 8.19609460541374096331779242063931e-02
            -5.36923225507029533432046264351811e-01 3.04195941916069364648878482146147e-16
            -5.30630712841598795037612035230268e-01 -8.19609460541372708552998460618255e-02
            -5.11900666008897831105173281684984e-01 -1.62000796999642426854393306712154e-01
            -4.81172101431833587614761427175836e-01 -2.38243486568984169648999227320019e-01
            -4.39165270619769010362887229348416e-01 -3.08901950738964314879808625846636e-01
            -3.86864778083599758495836340443930e-01 -3.72320014996776194049488140080939e-01
            -3.25496503040531792727563242806355e-01 -4.27011213666875000249945060204482e-01
            -2.56498865844236700883840285314363e-01 -4.71693631406544189310636738809990e-01
            -1.81489112630910748302781598795264e-01 -5.05319950215026736373147286940366e-01
            -1.02225408440555040612274240174884e-01 -5.27101997679798373042103776242584e-01
            -2.05656273185906915412779483176564e-02 -5.36529221069892203743734171439428e-01
            6.15761946771039986314733027938928e-02 -5.33380654259188347054987389128655e-01
            1.42274722859129371110853412574215e-01 -5.17730096985128396269715267408174e-01
            2.19638452123800509419027093827026e-01 -4.89944385045418706603470582194859e-01
            2.91854042227609355997230977664003e-01 -4.50674791977848876456391735700890e-01
            3.57228820945618030791024466452654e-01 -4.00841763760559355311841045477195e-01
            4.14230458873769968874967162264511e-01 -3.41613344338447033621264381508809e-01
            4.61522885931377579993295512394980e-01 -2.74377797663085565282869993097847e-01
            4.97997607711412604292178230025456e-01 -2.00711067962338646220032956080104e-01
            5.22799687649891486884712321625557e-01 -1.22339840943367222925175497039163e-01
            5.35347786014324533709896059008315e-01 -4.11010717431245994890609551930538e-02
            4.87854635500729993946578133545700e-01 4.15225488312099058618720448521344e-02
            4.73819945872072934012209088905365e-01 1.23373118363670167263457244644087e-01
            4.46154319082480266267509705357952e-01 2.01674467905678805879077231111296e-01
            4.05653644844008676173530147934798e-01 2.74174010193820538727749180907267e-01
            3.53483053815106973427617731431383e-01 3.38786065396049718145832230220549e-01
            2.91143398912920681187443960880046e-01 3.93651862323071255467255014082184e-01
            2.20428078507461627788543978567759e-01 4.37193011891199634355587022582768e-01
            1.43371443615735338905636808704003e-01 4.68156914502531218413849956050399e-01
            6.21902733269145205352579353075271e-02 4.85652795054773656069357912201667e-01
            -2.07799978959757811192154974833102e-02 4.89177328919108422855543949481216e-01
            -1.03152466413446011750387754091207e-01 4.78629121673361246358524567767745e-01
            -1.82557426281424128866603950882563e-01 4.54311626034919646688337024897919e-01
            -2.56710541376755030373857380254776e-01 4.16924412078548911608777416404337e-01
            -3.23478561588382895752857848492567e-01 3.67543041879044518616126424603863e-01
            -3.80940692539047665032825307207531e-01 3.07588127548611756090224389481591e-01
            -4.27443853342336754774777318743872e-01 2.38784462812899944683664443800808e-01
            -4.61650232730031861994035580210038e-01 1.63111403835837692755106331787829e-01
            -4.82575775446546784142043406973244e-01 8.27459267466039705141156446188688e-02
            -4.89618491726967253185875961207785e-01 5.99609718696785313137725898686661e-17
            -4.82575775446546784142043406973244e-01 -8.27459267466038456140253742887580e-02
            -4.61650232730031861994035580210038e-01 -1.63111403835837581732803869272175e-01
            -4.27443853342336921308231012517354e-01 -2.38784462812899639372332671882759e-01
            -3.80940692539047609521674075949704e-01 -3.07588127548611867112526851997245e-01
            -3.23478561588383006775160311008221e-01 -3.67543041879044463104975193346036e-01
            -2.56710541376755307929613536543911e-01 -4.16924412078548745075323722630856e-01
            -1.82557426281424239888906413398217e-01 -4.54311626034919591177185793640092e-01
            -1.03152466413445914605873099390010e-01 -4.78629121673361246358524567767745e-01
            -2.07799978959760101027143264218466e-02 -4.89177328919108367344392718223389e-01
            6.21902733269141805294566438533366e-02 -4.85652795054773656069357912201667e-01
            1.43371443615735116861031883672695e-01 -4.68156914502531273925001187308226e-01
            2.20428078507461627788543978567759e-01 -4.37193011891199634355587022582768e-01
            2.91143398912920736698595192137873e-01 -3.93651862323071199956103782824357e-01
            3.53483053815106862405315268915729e-01 -3.38786065396049829168134692736203e-01
            4.05653644844008454128925222903490e-01 -2.74174010193820816283505337196402e-01
            4.46154319082480210756358474100125e-01 -2.01674467905678944656955309255864e-01
            4.73819945872072934012209088905365e-01 -1.23373118363670139507881629015174e-01
            4.87854635500729938435426902287873e-01 -4.15225488312101209675830659762141e-02
            4.38793816039416639807058118094574e-01 4.18997291970212501488468603838555e-02
            4.22934664261615689273554608007544e-01 1.24184822209203779563857494849799e-01
            3.91789551771880406594306123224669e-01 2.01981552186347418365031103348883e-01
            3.46484144083388956314450979334651e-01 2.72478142609675233476451694514253e-01
            2.88655896672091738519583259403589e-01 3.33126663024213454100674880464794e-01
            2.20394873069462093884141040689428e-01 3.81735117884001884380751334902016e-01
            1.44168204520861181761048896987631e-01 4.16546670982314126696621769951889e-01
            6.27309214342834792210723549032991e-02 4.36303142089560114236235222051619e-01
            -2.09736205967510115633078982000370e-02 4.40290480864940658722872512953472e-01
            -1.03920121333183276823852736470144e-01 4.28364574496203631692736735203653e-01
            -1.83110678123399428507411812461214e-01 4.00956456312161091393164724649978e-01
            -2.55683137916017211299646305633360e-01 3.59056727115139862060999575987807e-01
            -3.19014542928432287549611601207289e-01 3.04179752286999782739940201281570e-01
            -3.70815931175129342989293945720419e-01 2.38308928678593323624568256491330e-01
            -4.09215065517672282879857448278926e-01 1.63824999479884908515359143166279e-01
            -4.32824101192952892525056540762307e-01 8.34200079581008252516127754461195e-02
            -4.40789746138924076745979618863203e-01 5.39811751706007746327932078904241e-17
            -4.32824101192952948036207772020134e-01 -8.34200079581005338180688113425276e-02
            -4.09215065517672338391008679536753e-01 -1.63824999479884825248632296279538e-01
            -3.70815931175129509522747639493900e-01 -2.38308928678593101579963331460021e-01
            -3.19014542928432343060762832465116e-01 -3.04179752286999727228788970023743e-01
            -2.55683137916017322321948768149014e-01 -3.59056727115139806549848344729980e-01
            -1.83110678123399345240684965574474e-01 -4.00956456312161146904315955907805e-01
            -1.03920121333183290701640544284601e-01 -4.28364574496203631692736735203653e-01
            -2.09736205967512197301250154168883e-02 -4.40290480864940658722872512953472e-01
            6.27309214342832710542552376864478e-02 -4.36303142089560169747386453309446e-01
            1.44168204520861181761048896987631e-01 -4.16546670982314182207773001209716e-01
            2.20394873069462093884141040689428e-01 -3.81735117884001884380751334902016e-01
            2.88655896672091460963827103114454e-01 -3.33126663024213620634128574238275e-01
            3.46484144083388789780997285561170e-01 -2.72478142609675400009905388287734e-01
            3.91789551771880351083154891966842e-01 -2.01981552186347501631757950235624e-01
            4.22934664261615689273554608007544e-01 -1.24184822209203835075008726107626e-01
            4.38793816039416584295906886836747e-01 -4.18997291970215901546481518380460e-02
            3.88192874819421107623895750293741e-01 4.22185193539764205827857779240730e-02
            3.70041407438257252682234366147895e-01 1.24681467019451430733312236043275e-01
            3.34587215116765646083507590446970e-01 2.01314447860594575301362851860176e-01
            2.83488096483394680369372053974075e-01 2.68534188864714862265969941290678e-01
            2.19133389532849581771145608399820e-01 3.23197569651835825421670733703650e-01
            1.44532248837018262310749605603633e-01 3.62748591290335764547592134476872e-01
            6.31729408216248483620702813823300e-02 3.85337891966201939730751746537862e-01
            -2.11402636949066455307466583235509e-02 3.89909221086035207015640935424017e-01
            -1.04464972976780104407801275101519e-01 3.76248828380859490216892027092399e-01
            -1.82905016226737521245482298581919e-01 3.44995458631132900784166395169450e-01
            -2.52792624202257676380156681261724e-01 2.97610484670726926914596788265044e-01
            -3.10859930028902275989111103626783e-01 2.36309575217414385983616398334561e-01
            -3.54391771023392976314170255136560e-01 1.63959092666164318874422178851091e-01
            -3.81352646682993234872327548146131e-01 8.39420651692878994065694087112206e-02
            -3.90481896426721486470512445521308e-01 4.78202404583972787558744948584253e-17
            -3.81352646682993234872327548146131e-01 -8.39420651692878022620547540100233e-02
            -3.54391771023392920803019023878733e-01 -1.63959092666164374385573410108918e-01
            -3.10859930028902442522564797400264e-01 -2.36309575217414163939011473303253e-01
            -2.52792624202257565357854218746070e-01 -2.97610484670726982425748019522871e-01
            -1.82905016226737771045662839242141e-01 -3.44995458631132734250712701395969e-01
            -1.04464972976780284819042776689457e-01 -3.76248828380859434705740795834572e-01
            -2.11402636949069161476089107054577e-02 -3.89909221086035151504489704166190e-01
            6.31729408216247650953434344955895e-02 -3.85337891966201995241902977795689e-01
            1.44532248837018095777295911830151e-01 -3.62748591290335875569894596992526e-01
            2.19133389532849526259994377141993e-01 -3.23197569651835880932821964961477e-01
            2.83488096483394680369372053974075e-01 -2.68534188864714862265969941290678e-01
            3.34587215116765646083507590446970e-01 -2.01314447860594575301362851860176e-01
            3.70041407438257252682234366147895e-01 -1.24681467019451389099948812599905e-01
            3.88192874819421107623895750293741e-01 -4.22185193539767050774358381204365e-02
            3.36065030843542666971757171268109e-01 4.24548864639369208373587127880455e-02
            3.14948828994916329993003500931081e-01 1.24697062737131214582575466920389e-01
            2.74043233919770701234597254369874e-01 1.99104063954834681338113000492740e-01
            2.15918494596932575291248213034123e-01 2.61000624580730589130439511791337e-01
            1.44226802165893674967378501605708e-01 3.06497556071067600580448697655811e-01
            6.34728093256974740254960920537997e-02 3.32736118894298438242174142942531e-01
            -2.12694135610959136895026233560202e-02 3.38067647649555658162512372655328e-01
            -1.04675200970414231105287683476490e-01 3.22157142777155347523887485294836e-01
            -1.81503860534301536544532496009197e-01 2.86004319812973972769754027467570e-01
            -2.46927965016313366586331312646507e-01 2.31880793584633426718255577725358e-01
            -2.96836677318820352233785797579912e-01 1.63187344297465591891338476671081e-01
            -3.28094049496451434233534882878303e-01 8.42402340070178418107715856422146e-02
            -3.38736065898712745969589832384372e-01 4.14832038858625498954237686075806e-17
            -3.28094049496451545255837345393957e-01 -8.42402340070176197661666606109065e-02
            -2.96836677318820352233785797579912e-01 -1.63187344297465647402489707928908e-01
            -2.46927965016313505364209390791075e-01 -2.31880793584633287940377499580791e-01
            -1.81503860534301342255503186606802e-01 -2.86004319812974083792056489983224e-01
            -1.04675200970414383760953569435515e-01 -3.22157142777155292012736254037009e-01
            -2.12694135610958477700105362373506e-02 -3.38067647649555658162512372655328e-01
            6.34728093256973213698302060947753e-02 -3.32736118894298493753325374200358e-01
            1.44226802165893397411622345316573e-01 -3.06497556071067711602751160171465e-01
            2.15918494596932408757794519260642e-01 -2.61000624580730700152741974306991e-01
            2.74043233919770701234597254369874e-01 -1.99104063954834764604839847379480e-01
            3.14948828994916329993003500931081e-01 -1.24697062737131186826999851291475e-01
            3.36065030843542666971757171268109e-01 -4.24548864639370526763428870253847e-02
            2.82400292430454114001037169146002e-01 4.25649953828064128713570823947521e-02
            2.57307787154737288570771625018097e-01 1.23912899515251306858942825783743e-01
            2.09352355813696627828690566275327e-01 1.94250598742963187515186973541859e-01
            1.42795048930927898078735438502918e-01 2.47328279817650958927188753477822e-01
            6.35497753048953756271899351304455e-02 2.78429757848261683061963367435965e-01
            -2.13421747405724802904014580917647e-02 2.84791530025187367147765371555579e-01
            -1.04337778901749403392962278758205e-01 2.65848324972330796178709988453193e-01
            -1.78062513528704752241438313831168e-01 2.23283329589524404124034617780126e-01
            -2.35965612414164749299771983714891e-01 1.60878630509936032533246930142923e-01
            -2.72902131118591961822517077962402e-01 8.41791591052986065690788564097602e-02
            -2.85590097861855740646319645748008e-01 3.49746999214701010036961969256031e-17
            -2.72902131118592017333668309220229e-01 -8.41791591052984122800495470073656e-02
            -2.35965612414164721544196368085977e-01 -1.60878630509936088044398161400750e-01
            -1.78062513528704807752589545088995e-01 -2.23283329589524348612883386522299e-01
            -1.04337778901749334004023239685921e-01 -2.65848324972330796178709988453193e-01
            -2.13421747405726745794307674941592e-02 -2.84791530025187367147765371555579e-01
            6.35497753048953201160387038726185e-02 -2.78429757848261683061963367435965e-01
            1.42795048930927676034130513471609e-01 -2.47328279817651069949491215993476e-01
            2.09352355813696711095417413162068e-01 -1.94250598742963132004035742284032e-01
            2.57307787154737233059620393760270e-01 -1.23912899515251376247881864856026e-01
            2.82400292430454114001037169146002e-01 -4.25649953828066487937498152405169e-02
            2.27144411943816126875361760539818e-01 4.24606494143393853324397468895768e-02
            1.96467300460167110243148158588156e-01 1.21647402257030953776073545213876e-01
            1.39256191386478711535801267018542e-01 1.84404999353384890792284522831324e-01
            6.32377620208518648192708155875152e-02 2.22257679463688240240060167707270e-01
            -2.13212775182270684870555754741872e-02 2.30093228390103266001176507415948e-01
            -1.03000760383192099811644482088013e-01 2.06853411831842221024757577652053e-01
            -1.70769419811491129923552989566815e-01 1.55676895791367120303050342045026e-01
            -2.15474722828226689097519397364522e-01 8.34753523388093443546864591553458e-02
            -2.31078970540353312301817823026795e-01 2.82990121622509208304414067071837e-17
            -2.15474722828226744608670628622349e-01 -8.34753523388092055768083810107782e-02
            -1.70769419811491074412401758308988e-01 -1.55676895791367148058625957673939e-01
            -1.03000760383192349611825022748235e-01 -2.06853411831842082246879499507486e-01
            -2.13212775182270754259494793814156e-02 -2.30093228390103266001176507415948e-01
            6.32377620208518231859073921441450e-02 -2.22257679463688240240060167707270e-01
            1.39256191386478683780225651389628e-01 -1.84404999353384946303435754089151e-01
            1.96467300460167026976421311701415e-01 -1.21647402257031064798376007729530e-01
            2.27144411943816126875361760539818e-01 -4.24606494143393228823946117245214e-02
            1.70143127221436846197022418891720e-01 4.19365144071176323969929455870442e-02
            1.31165387221967022490787257993361e-01 1.16202393160467556953996393076523e-01
            6.21392377242176441320964386250125e-02 1.63847704031401059099337658153672e-01
            -2.11222622771554541243332892008766e-02 1.73957480487628018961387965646281e-01
            -9.95449065416872669320724753561080e-02 1.44215694579040792921986735564133e-01
            -1.55163012363689734041116707885521e-01 8.14358310299213156158160131781187e-02
            -1.75235141970177976666889207990607e-01 -5.63599201643088376659134775782496e-17
            -1.55163012363689817307843554772262e-01 -8.14358310299211352045745115901809e-02
            -9.95449065416873085654358987994783e-02 -1.44215694579040792921986735564133e-01
            -2.11222622771555755549766075773732e-02 -1.73957480487628018961387965646281e-01
            6.21392377242176441320964386250125e-02 -1.63847704031401059099337658153672e-01
            1.31165387221966966979636026735534e-01 -1.16202393160467612465147624334350e-01
            1.70143127221436846197022418891720e-01 -4.19365144071176393358868494942726e-02
            1.10967210959101961198491892446327e-01 4.03887617686514363568583974029025e-02
            5.90444196881608901472660022591299e-02 1.02267934803314752834069167874986e-01
            -2.05059117605011151375116185135994e-02 1.16294804562014977844519592053985e-01
            -9.04612991986008252442985622110427e-02 7.59060427933635623043429063727672e-02
            -1.18088839376321752538956388889346e-01 1.44617119157238364724527465665270e-17
            -9.04612991986008807554497934688698e-02 -7.59060427933634929154038673004834e-02
            -2.05059117605011186069585704672136e-02 -1.16294804562014977844519592053985e-01
            5.90444196881607999416452514651610e-02 -1.02267934803314808345220399132813e-01
            1.10967210959101961198491892446327e-01 -4.03887617686514224790705895884457e-02
            4.82726719824452671359082955859776e-02 3.50721491356993375632100651273504e-02
            -1.84385199695193194302511585647153e-02 5.67479293600667844543750106822699e-02
            -5.96683040258518815335264662280679e-02 7.30725975358106375722478013391626e-18
            -1.84385199695193333080389663791721e-02 -5.67479293600667775154811067750416e-02
            4.82726719824452601970143916787492e-02 -3.50721491356993514409978729418071e-02
            -0.00000000000000000000000000000000e+00 0.00000000000000000000000000000000e+00
            ];
        
    otherwise
        
        pts=pointset_disk_cg(deg);
        
end



stats_matrix=[
    1    3 1.666667e+00 1.86632e+00 3.155e+00   0
    2    6 1.988854e+00 3.74729e+01 7.657e+00   0
    3   10 2.624243e+00 4.82512e+03 1.721e+01   0
    4   15 3.234295e+00 6.73314e+06 2.450e+01   0
    5   21 3.720900e+00 9.15320e+10 3.180e+01   0
    6   28 4.323847e+00 1.62089e+16 5.006e+01   0
    7   36 4.983226e+00 3.21745e+22 5.893e+01   0
    8   45 5.554802e+00 1.26214e+30 8.059e+01   0
    9   55 6.182261e+00 7.59815e+38 9.148e+01   0
    10   66 6.749062e+00 1.36055e+49 1.113e+02   0
    11   78 7.405524e+00 2.10822e+60 1.354e+02   0
    12   91 8.162840e+00 1.19551e+73 1.451e+02   0
    13  105 8.991463e+00 1.46592e+87 1.833e+02   0
    14  120 1.004867e+01 4.27756e+102 2.124e+02   0
    15  136 1.121936e+01 2.96279e+119 2.387e+02   0
    16  153 1.249401e+01 5.96370e+137 2.378e+02   0
    17  171 1.421432e+01 2.75326e+157 2.975e+02   0
    18  190 1.599920e+01 4.26516e+178 3.211e+02   0
    19  210 1.815374e+01 1.70801e+201 2.889e+02   0
    20  231 2.081821e+01 2.01425e+225 5.217e+02   0
    21  253 2.387934e+01 7.50287e+250 4.540e+02   0
    22  276 2.730824e+01 1.00108e+278 5.901e+02   0
    23  300 3.185851e+01 3.22677e+306 6.236e+02   0
    24  325 3.690146e+01 Inf 8.785e+02   0
    25  351 4.283253e+01 Inf 9.040e+02   0
    26  378 5.019800e+01 Inf 1.282e+03   0
    27  406 5.901037e+01 Inf 1.358e+03   0
    28  435 6.911262e+01 Inf 2.130e+03   0
    29  465 8.156621e+01 Inf 2.412e+03   0
    30  496 9.696407e+01 Inf 2.405e+03   0
    31  528 1.141081e+02 Inf 4.344e+03   0
    32  561 1.349488e+02 Inf 4.528e+03   0
    33  595 1.615081e+02 Inf 6.554e+03   0
    34  630 1.914702e+02 Inf 5.393e+03   0
    35  666 2.274826e+02 Inf 9.606e+03   0
    36  703 2.726611e+02 Inf 1.053e+04   0
    37  741 3.282607e+02 Inf 9.916e+03   0
    38  780 3.925808e+02 Inf 8.837e+03   0
    39  820 4.681878e+02 Inf 1.088e+04   0
    40  861 5.585461e+02 Inf 2.359e+04   0
    41  903 6.790970e+02 Inf 2.848e+04   0
    42  946 8.178868e+02 Inf 2.721e+04   0
    43  990 9.811301e+02 Inf 5.077e+04   0
    44 1035 1.172621e+03 Inf 4.139e+04   0
    45 1081 1.401024e+03 Inf 7.527e+04   0
    46 1128 1.682256e+03 Inf 4.567e+04   0
    47 1176 2.043017e+03 Inf 1.131e+05   0
    48 1225 2.478395e+03 Inf 6.670e+04   0
    49 1275 3.009753e+03 Inf 1.457e+05   0
    50 1326 3.661137e+03 Inf 1.022e+05   0
    ];





function [pts_cart,pts_polar]=pointset_disk_cg(n,e_exp)


if nargin < 2
    e_exp=[];
end

if isempty(e_exp)
    e_exp=1.5;
end

lmax=floor(n/2)+1;
pts_polar=[];
for l=1:lmax
    lcg=l-1;
    jmax=2*(n-2*lcg)+1;
    r=1-(2*lcg/n)^e_exp;
    theta=[];
    for j=1:jmax
        jcg=j-1;
        theta(j,1)=(2*jcg+1)*pi/(2*(n-2*lcg)+1);
    end
    pts_polar_loc=[theta r*ones(size(theta))];
    pts_polar=[pts_polar; pts_polar_loc];
end

TH=pts_polar(:,1); R=pts_polar(:,2);

[X,Y]=pol2cart(TH,R);
pts_cart=[X Y];


