function [pts,t,table,stats_matrix]=pts_leb_symm_gll(deg)

%--------------------------------------------------------------------------
% PURPOSE:
%-----------
% SET OF POINTS FOR THE UNIT SIMPLEX, HAVING VERTICES
% [0,0], [1,0], [0,1], SYMMETRIES AND ASSIGNED DISTRIBUTION ON THE
% SIDES (Gauss-Legendre-Lobatto).
% THE LEBESGUE CONSTANTS ARE PARTICULARLY LOW.
%--------------------------------------------------------------------------
% INPUT:
%---------
% deg: DEGREE OF THE SET.
%--------------------------------------------------------------------------
% OUTPUT:
%---------
% pts: CARTESIAN COORDINATES, STORED IN A "n x 2" MATRIX.
% pts_bar: BARYCENTRIC COORDINATES, STORED IN A "n x 3" MATRIX.
% t: DESCRIBES THE SYMMETRY.
% stats_matrix: MATRIX WITH STATISTICS WITH COLUMNS THAT CONSIST OF
% DEGREE, LEBESGUE CONSTANT, ABS. VALUE OF VANDERMONDE MATRIX "V"
% DETERMINANT (w.r.t DUBINER BASIS), CONDITIONING OF "V".
%--------------------------------------------------------------------------

% ---------------------------------------------------------------
% |DEGR|  LEBESGUE   | ABS.DET.VAND.| COND. VAND. |  MAX. LAGR. |
% ---------------------------------------------------------------
% |  1 | 1.00000e+00 | 5.87878e+01 | 3.70699e+00 | 1.00000e+00 |
% |  2 | 1.66667e+00 | 3.13712e+04 | 1.01810e+01 | 1.00000e+00 |
% |  3 | 2.11244e+00 | 3.44701e+08 | 2.03638e+01 | 1.00000e+00 |
% |  4 | 2.58801e+00 | 8.98221e+13 | 3.95876e+01 | 1.02814e+00 |
% |  5 | 3.08116e+00 | 6.69351e+20 | 5.28526e+01 | 1.05314e+00 |
% |  6 | 3.59605e+00 | 1.87536e+29 | 7.13009e+01 | 1.02909e+00 |
% |  7 | 4.14590e+00 | 1.94719e+39 | 9.41441e+01 | 1.02500e+00 |
% |  8 | 4.77382e+00 | 7.59934e+50 | 1.18408e+02 | 1.03994e+00 |
% |  9 | 5.49425e+00 | 1.43106e+64 | 1.41026e+02 | 1.03863e+00 |
% | 10 | 6.28492e+00 | 2.40480e+79 | 1.84334e+02 | 1.08256e+00 |
% | 11 | 7.00203e+00 | 2.11926e+96 | 2.62281e+02 | 1.18378e+00 |
% | 12 | 7.25934e+00 | 2.07917e+115 | 2.28046e+02 | 1.04342e+00 |
% | 13 | 8.57673e+00 | 2.16493e+135 | 3.32262e+02 | 1.09934e+00 |
% | 14 | 8.81565e+00 | 1.23824e+158 | 4.80175e+02 | 1.18945e+00 |
% | 15 | 8.90865e+00 | 9.40546e+182 | 3.96741e+02 | 1.09615e+00 |
% | 16 | 1.06553e+01 | 1.73095e+208 | 4.54660e+02 | 1.18671e+00 |
% | 17 | 1.14147e+01 | 2.25105e+236 | 5.47919e+02 | 1.08768e+00 |
% | 18 | 1.26889e+01 | 1.11594e+267 | 4.72717e+02 | 1.07067e+00 |
% ---------------------------------------------------------------

%--------------------------------------------------------------------------
%% Copyright (C) 2011
%% Francesca Rapetti, Alvise Sommariva, Marco Vianello.
%%
%% This program is free software; you can redistribute it and/or modify
%% it under the terms of the GNU General Public License as published by
%% the Free Software Foundation; either version 2 of the License, or
%% (at your option) any later version.
%%
%% This program is distributed in the hope that it will be useful,
%% but WITHOUT ANY WARRANTY; without even the implied warranty of
%% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%% GNU General Public License for more details.
%%
%% You should have received a copy of the GNU General Public License
%% along with this program; if not, write to the Free Software
%% Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
%%
%% Author:
%%          Francesca Rapetti <frapetti@unice.fr>
%%          Alvise Sommariva  <alvise@math.unipd.it>
%%          Marco Vianello  <marcov@math.unipd.it>
%%
%% Date: October 23, 2011.
%--------------------------------------------------------------------------

switch deg


    case  1

    	 % PASSED (I).

     	 % DEGREE:   1
     	 % POINTS:      3
     	 % LEBESGUE CONSTANT: 1.00000e+00
     	 % DETERMINANT: -5.87878e+01
     	 % CONDITIONING: 3.70699e+00
     	 % MAX LAGRANGE POLYNOMIALS: 1.00000e+00
     	 % VANDERMONDE: ORTHONORMAL DUBINER LEGENDRE.

     	 table=[
       	  0	  0	  0
      	 ];

     	 t=[
         	 ];

     	 pts=[
         	 1.000000000000000000000000000000e+00 0.000000000000000000000000000000e+00 0.000000000000000000000000000000e+00
         	 0.000000000000000000000000000000e+00 1.000000000000000000000000000000e+00 0.000000000000000000000000000000e+00
         	 0.000000000000000000000000000000e+00 0.000000000000000000000000000000e+00 1.000000000000000000000000000000e+00
         	 ];


    case  2

    	 % PASSED (I).

     	 % DEGREE:   2
     	 % POINTS:      6
     	 % LEBESGUE CONSTANT: 1.66667e+00
     	 % DETERMINANT: 3.13712e+04
     	 % CONDITIONING: 1.01810e+01
     	 % MAX LAGRANGE POLYNOMIALS: 1.00000e+00
     	 % VANDERMONDE: ORTHONORMAL DUBINER LEGENDRE.

     	 table=[
       	  0	  0	  0
      	 ];

     	 t=[
         	 ];

     	 pts=[
         	 1.000000000000000000000000000000e+00 0.000000000000000000000000000000e+00 0.000000000000000000000000000000e+00
         	 0.000000000000000000000000000000e+00 1.000000000000000000000000000000e+00 0.000000000000000000000000000000e+00
         	 0.000000000000000000000000000000e+00 0.000000000000000000000000000000e+00 1.000000000000000000000000000000e+00
         	 5.000000000000000000000000000000e-01 5.000000000000000000000000000000e-01 0.000000000000000000000000000000e+00
         	 5.000000000000000000000000000000e-01 0.000000000000000000000000000000e+00 5.000000000000000000000000000000e-01
         	 0.000000000000000000000000000000e+00 5.000000000000000000000000000000e-01 5.000000000000000000000000000000e-01
         	 ];


    case  3

    	 % PASSED (I).

     	 % DEGREE:   3
     	 % POINTS:     10
     	 % LEBESGUE CONSTANT: 2.11244e+00
     	 % DETERMINANT: -3.44701e+08
     	 % CONDITIONING: 2.03638e+01
     	 % MAX LAGRANGE POLYNOMIALS: 1.00000e+00
     	 % VANDERMONDE: ORTHONORMAL DUBINER LEGENDRE.

     	 table=[
       	  1	  0	  0
      	 ];

     	 t=[
         	 ];

     	 pts=[
         	 3.333333333333333148296162562474e-01 3.333333333333333148296162562474e-01 3.333333333333333148296162562474e-01
         	 1.000000000000000000000000000000e+00 0.000000000000000000000000000000e+00 0.000000000000000000000000000000e+00
         	 0.000000000000000000000000000000e+00 1.000000000000000000000000000000e+00 0.000000000000000000000000000000e+00
         	 0.000000000000000000000000000000e+00 0.000000000000000000000000000000e+00 1.000000000000000000000000000000e+00
         	 2.763932022500210639037732107681e-01 7.236067977499789360962267892319e-01 0.000000000000000000000000000000e+00
         	 7.236067977499789360962267892319e-01 2.763932022500210639037732107681e-01 0.000000000000000000000000000000e+00
         	 2.763932022500210639037732107681e-01 0.000000000000000000000000000000e+00 7.236067977499789360962267892319e-01
         	 7.236067977499789360962267892319e-01 0.000000000000000000000000000000e+00 2.763932022500210639037732107681e-01
         	 0.000000000000000000000000000000e+00 2.763932022500210639037732107681e-01 7.236067977499789360962267892319e-01
         	 0.000000000000000000000000000000e+00 7.236067977499789360962267892319e-01 2.763932022500210639037732107681e-01
         	 ];


    case  4

    	 % PASSED (I).

     	 % DEGREE:   4
     	 % POINTS:     15
     	 % LEBESGUE CONSTANT: 2.58801e+00
     	 % DETERMINANT: -8.98221e+13
     	 % CONDITIONING: 3.95876e+01
     	 % MAX LAGRANGE POLYNOMIALS: 1.02814e+00
     	 % VANDERMONDE: ORTHONORMAL DUBINER LEGENDRE.

     	 table=[
       	  0	  1	  0
      	 ];

     	 t=[
         	 -7.113198907115936275857848158921e-01
         	 ];

     	 pts=[
         	 2.371066302371978573582111948781e-01 2.371066302371978573582111948781e-01 5.257867395256041742612751477282e-01
         	 2.371066302371978573582111948781e-01 5.257867395256041742612751477282e-01 2.371066302371978573582111948781e-01
         	 5.257867395256041742612751477282e-01 2.371066302371978573582111948781e-01 2.371066302371978573582111948781e-01
         	 1.000000000000000000000000000000e+00 0.000000000000000000000000000000e+00 0.000000000000000000000000000000e+00
         	 0.000000000000000000000000000000e+00 1.000000000000000000000000000000e+00 0.000000000000000000000000000000e+00
         	 0.000000000000000000000000000000e+00 0.000000000000000000000000000000e+00 1.000000000000000000000000000000e+00
         	 1.726731646460114566465904317738e-01 8.273268353539885433534095682262e-01 0.000000000000000000000000000000e+00
         	 5.000000000000000000000000000000e-01 5.000000000000000000000000000000e-01 0.000000000000000000000000000000e+00
         	 8.273268353539885433534095682262e-01 1.726731646460114566465904317738e-01 0.000000000000000000000000000000e+00
         	 1.726731646460114566465904317738e-01 0.000000000000000000000000000000e+00 8.273268353539885433534095682262e-01
         	 5.000000000000000000000000000000e-01 0.000000000000000000000000000000e+00 5.000000000000000000000000000000e-01
         	 8.273268353539885433534095682262e-01 0.000000000000000000000000000000e+00 1.726731646460114566465904317738e-01
         	 0.000000000000000000000000000000e+00 1.726731646460114566465904317738e-01 8.273268353539885433534095682262e-01
         	 0.000000000000000000000000000000e+00 5.000000000000000000000000000000e-01 5.000000000000000000000000000000e-01
         	 0.000000000000000000000000000000e+00 8.273268353539885433534095682262e-01 1.726731646460114566465904317738e-01
         	 ];


    case  5

    	 % PASSED (I).

     	 % DEGREE:   5
     	 % POINTS:     21
     	 % LEBESGUE CONSTANT: 3.08116e+00
     	 % DETERMINANT: 6.69351e+20
     	 % CONDITIONING: 5.28526e+01
     	 % MAX LAGRANGE POLYNOMIALS: 1.05314e+00
     	 % VANDERMONDE: ORTHONORMAL DUBINER LEGENDRE.

     	 table=[
       	  0	  2	  0
      	 ];

     	 t=[
         	 -1.237022082059360705841299932217e+00
         	 -5.213955589468205475967010897875e-01
         	 ];

     	 pts=[
         	 4.123406940197869019470999774057e-01 4.123406940197869019470999774057e-01 1.753186119604261961058000451885e-01
         	 1.737985196489401640285166195099e-01 1.737985196489401640285166195099e-01 6.524029607021195609206642984645e-01
         	 4.123406940197869019470999774057e-01 1.753186119604261961058000451885e-01 4.123406940197869019470999774057e-01
         	 1.737985196489401640285166195099e-01 6.524029607021195609206642984645e-01 1.737985196489401640285166195099e-01
         	 1.753186119604261961058000451885e-01 4.123406940197869019470999774057e-01 4.123406940197869019470999774057e-01
         	 6.524029607021195609206642984645e-01 1.737985196489401640285166195099e-01 1.737985196489401640285166195099e-01
         	 1.000000000000000000000000000000e+00 0.000000000000000000000000000000e+00 0.000000000000000000000000000000e+00
         	 0.000000000000000000000000000000e+00 1.000000000000000000000000000000e+00 0.000000000000000000000000000000e+00
         	 0.000000000000000000000000000000e+00 0.000000000000000000000000000000e+00 1.000000000000000000000000000000e+00
         	 1.174723380352677426508023472707e-01 8.825276619647322018380464214715e-01 0.000000000000000000000000000000e+00
         	 3.573842417596774789778635295079e-01 6.426157582403224655109852392343e-01 0.000000000000000000000000000000e+00
         	 6.426157582403225765332877017499e-01 3.573842417596774234667122982501e-01 0.000000000000000000000000000000e+00
         	 8.825276619647324238826513465028e-01 1.174723380352675761173486534972e-01 0.000000000000000000000000000000e+00
         	 1.174723380352677426508023472707e-01 0.000000000000000000000000000000e+00 8.825276619647322018380464214715e-01
         	 3.573842417596774789778635295079e-01 0.000000000000000000000000000000e+00 6.426157582403224655109852392343e-01
         	 6.426157582403225765332877017499e-01 0.000000000000000000000000000000e+00 3.573842417596774234667122982501e-01
         	 8.825276619647324238826513465028e-01 0.000000000000000000000000000000e+00 1.174723380352675761173486534972e-01
         	 0.000000000000000000000000000000e+00 1.174723380352677426508023472707e-01 8.825276619647322018380464214715e-01
         	 0.000000000000000000000000000000e+00 3.573842417596774789778635295079e-01 6.426157582403224655109852392343e-01
         	 0.000000000000000000000000000000e+00 6.426157582403225765332877017499e-01 3.573842417596774234667122982501e-01
         	 0.000000000000000000000000000000e+00 8.825276619647324238826513465028e-01 1.174723380352675761173486534972e-01
         	 ];


    case  6

    	 % PASSED (I).

     	 % DEGREE:   6
     	 % POINTS:     28
     	 % LEBESGUE CONSTANT: 3.59605e+00
     	 % DETERMINANT: -1.87536e+29
     	 % CONDITIONING: 7.13009e+01
     	 % MAX LAGRANGE POLYNOMIALS: 1.02909e+00
     	 % VANDERMONDE: ORTHONORMAL DUBINER LEGENDRE.

     	 table=[
       	  1	  1	  1
      	 ];

     	 t=[
         	 -3.710100618799806460046397660335e-01
         	 3.869879153567130636304227664368e-01
         	 2.171028049671443471702048100269e-01
         	 ];

     	 pts=[
         	 3.333333333333333148296162562474e-01 3.333333333333333148296162562474e-01 3.333333333333333148296162562474e-01
         	 1.236700206266602153348799220112e-01 1.236700206266602153348799220112e-01 7.526599587466795693302401559777e-01
         	 1.236700206266602153348799220112e-01 7.526599587466795693302401559777e-01 1.236700206266602153348799220112e-01
         	 7.526599587466795693302401559777e-01 1.236700206266602153348799220112e-01 1.236700206266602153348799220112e-01
         	 3.254637175704040430446184473112e-01 5.425665225375484457259744885960e-01 1.319697598920475112294070640928e-01
         	 3.254637175704040430446184473112e-01 1.319697598920475112294070640928e-01 5.425665225375484457259744885960e-01
         	 5.425665225375484457259744885960e-01 3.254637175704040430446184473112e-01 1.319697598920475112294070640928e-01
         	 5.425665225375484457259744885960e-01 1.319697598920475112294070640928e-01 3.254637175704040430446184473112e-01
         	 1.319697598920475112294070640928e-01 3.254637175704040430446184473112e-01 5.425665225375484457259744885960e-01
         	 1.319697598920475112294070640928e-01 5.425665225375484457259744885960e-01 3.254637175704040430446184473112e-01
         	 1.000000000000000000000000000000e+00 0.000000000000000000000000000000e+00 0.000000000000000000000000000000e+00
         	 0.000000000000000000000000000000e+00 1.000000000000000000000000000000e+00 0.000000000000000000000000000000e+00
         	 0.000000000000000000000000000000e+00 0.000000000000000000000000000000e+00 1.000000000000000000000000000000e+00
         	 8.488805186071646247114586003590e-02 9.151119481392835375288541399641e-01 0.000000000000000000000000000000e+00
         	 2.655756032646428010934869234916e-01 7.344243967353571989065130765084e-01 0.000000000000000000000000000000e+00
         	 5.000000000000001110223024625157e-01 4.999999999999998889776975374843e-01 0.000000000000000000000000000000e+00
         	 7.344243967353571989065130765084e-01 2.655756032646428010934869234916e-01 0.000000000000000000000000000000e+00
         	 9.151119481392833154842492149328e-01 8.488805186071668451575078506721e-02 0.000000000000000000000000000000e+00
         	 8.488805186071646247114586003590e-02 0.000000000000000000000000000000e+00 9.151119481392835375288541399641e-01
         	 2.655756032646428010934869234916e-01 0.000000000000000000000000000000e+00 7.344243967353571989065130765084e-01
         	 5.000000000000001110223024625157e-01 0.000000000000000000000000000000e+00 4.999999999999998889776975374843e-01
         	 7.344243967353571989065130765084e-01 0.000000000000000000000000000000e+00 2.655756032646428010934869234916e-01
         	 9.151119481392833154842492149328e-01 0.000000000000000000000000000000e+00 8.488805186071668451575078506721e-02
         	 0.000000000000000000000000000000e+00 8.488805186071646247114586003590e-02 9.151119481392835375288541399641e-01
         	 0.000000000000000000000000000000e+00 2.655756032646428010934869234916e-01 7.344243967353571989065130765084e-01
         	 0.000000000000000000000000000000e+00 5.000000000000001110223024625157e-01 4.999999999999998889776975374843e-01
         	 0.000000000000000000000000000000e+00 7.344243967353571989065130765084e-01 2.655756032646428010934869234916e-01
         	 0.000000000000000000000000000000e+00 9.151119481392833154842492149328e-01 8.488805186071668451575078506721e-02
         	 ];


    case  7

    	 % PASSED (I).

     	 % DEGREE:   7
     	 % POINTS:     36
     	 % LEBESGUE CONSTANT: 4.14590e+00
     	 % DETERMINANT: 1.94719e+39
     	 % CONDITIONING: 9.41441e+01
     	 % MAX LAGRANGE POLYNOMIALS: 1.02500e+00
     	 % VANDERMONDE: ORTHONORMAL DUBINER LEGENDRE.

     	 table=[
       	  0	  3	  1
      	 ];

     	 t=[
         	 -8.224753183886709395622460760933e-01
         	 -2.637438419436463621359223452600e-01
         	 2.999553236873908068638172608189e-01
         	 3.076665664768104546666904752783e-01
         	 3.814606641657357632979596928635e-01
         	 ];

     	 pts=[
         	 2.741584394628903131874153586978e-01 2.741584394628903131874153586978e-01 4.516831210742193736251692826045e-01
         	 8.791461398121544479344890987704e-02 8.791461398121544479344890987704e-02 8.241707720375690549019509489881e-01
         	 2.741584394628903131874153586978e-01 4.516831210742193736251692826045e-01 2.741584394628903131874153586978e-01
         	 8.791461398121544479344890987704e-02 8.241707720375690549019509489881e-01 8.791461398121544479344890987704e-02
         	 4.516831210742193736251692826045e-01 2.741584394628903131874153586978e-01 2.741584394628903131874153586978e-01
         	 8.241707720375690549019509489881e-01 8.791461398121544479344890987704e-02 8.791461398121544479344890987704e-02
         	 4.500074460521015229375052513205e-01 4.500074460521015229375052513205e-01 9.998510789579695412498949735891e-02
         	 4.500074460521015229375052513205e-01 9.998510789579695412498949735891e-02 4.500074460521015229375052513205e-01
         	 9.998510789579695412498949735891e-02 4.500074460521015229375052513205e-01 4.500074460521015229375052513205e-01
         	 2.574575396908898028414114378393e-01 6.389182038566255661393711307028e-01 1.036242564524846310192174314579e-01
         	 2.574575396908898028414114378393e-01 1.036242564524846310192174314579e-01 6.389182038566255661393711307028e-01
         	 6.389182038566255661393711307028e-01 2.574575396908898028414114378393e-01 1.036242564524846310192174314579e-01
         	 6.389182038566255661393711307028e-01 1.036242564524846310192174314579e-01 2.574575396908898028414114378393e-01
         	 1.036242564524846310192174314579e-01 2.574575396908898028414114378393e-01 6.389182038566255661393711307028e-01
         	 1.036242564524846310192174314579e-01 6.389182038566255661393711307028e-01 2.574575396908898028414114378393e-01
         	 1.000000000000000000000000000000e+00 0.000000000000000000000000000000e+00 0.000000000000000000000000000000e+00
         	 0.000000000000000000000000000000e+00 1.000000000000000000000000000000e+00 0.000000000000000000000000000000e+00
         	 0.000000000000000000000000000000e+00 0.000000000000000000000000000000e+00 1.000000000000000000000000000000e+00
         	 6.412992574519671418187272138312e-02 9.358700742548032858181272786169e-01 0.000000000000000000000000000000e+00
         	 2.041499092834289652564905281906e-01 7.958500907165710902546607030672e-01 0.000000000000000000000000000000e+00
         	 3.953503910487606298751472877484e-01 6.046496089512394256360039435094e-01 0.000000000000000000000000000000e+00
         	 6.046496089512393146137014809938e-01 3.953503910487606853862985190062e-01 0.000000000000000000000000000000e+00
         	 7.958500907165713122992656280985e-01 2.041499092834286877007343719015e-01 0.000000000000000000000000000000e+00
         	 9.358700742548031747958248161012e-01 6.412992574519682520417518389877e-02 0.000000000000000000000000000000e+00
         	 6.412992574519671418187272138312e-02 0.000000000000000000000000000000e+00 9.358700742548032858181272786169e-01
         	 2.041499092834289652564905281906e-01 0.000000000000000000000000000000e+00 7.958500907165710902546607030672e-01
         	 3.953503910487606298751472877484e-01 0.000000000000000000000000000000e+00 6.046496089512394256360039435094e-01
         	 6.046496089512393146137014809938e-01 0.000000000000000000000000000000e+00 3.953503910487606853862985190062e-01
         	 7.958500907165713122992656280985e-01 0.000000000000000000000000000000e+00 2.041499092834286877007343719015e-01
         	 9.358700742548031747958248161012e-01 0.000000000000000000000000000000e+00 6.412992574519682520417518389877e-02
         	 0.000000000000000000000000000000e+00 6.412992574519671418187272138312e-02 9.358700742548032858181272786169e-01
         	 0.000000000000000000000000000000e+00 2.041499092834289652564905281906e-01 7.958500907165710902546607030672e-01
         	 0.000000000000000000000000000000e+00 3.953503910487606298751472877484e-01 6.046496089512394256360039435094e-01
         	 0.000000000000000000000000000000e+00 6.046496089512393146137014809938e-01 3.953503910487606853862985190062e-01
         	 0.000000000000000000000000000000e+00 7.958500907165713122992656280985e-01 2.041499092834286877007343719015e-01
         	 0.000000000000000000000000000000e+00 9.358700742548031747958248161012e-01 6.412992574519682520417518389877e-02
         	 ];


    case  8

    	 % PASSED (I).

     	 % DEGREE:   8
     	 % POINTS:     45
     	 % LEBESGUE CONSTANT: 4.77382e+00
     	 % DETERMINANT: 7.59934e+50
     	 % CONDITIONING: 1.18408e+02
     	 % MAX LAGRANGE POLYNOMIALS: 1.03994e+00
     	 % VANDERMONDE: ORTHONORMAL DUBINER LEGENDRE.

     	 table=[
       	  0	  3	  2
      	 ];

     	 t=[
         	 -6.714343268839856326835047184431e-01
         	 -1.163743150370817991401395374851e+00
         	 -2.024983409269499046168050426786e-01
         	 2.554502949718992499406056140288e-01
         	 5.775713840017694389317171044240e-01
         	 4.958527275015719437689654114365e-01
         	 1.780416127569382223061467129810e-01
         	 ];

     	 pts=[
         	 2.238114422946618775611682394810e-01 2.238114422946618775611682394810e-01 5.523771154106762448776635210379e-01
         	 3.879143834569392934596976374451e-01 3.879143834569392934596976374451e-01 2.241712330861213020583022625942e-01
         	 6.749944697564996820560168089287e-02 6.749944697564996820560168089287e-02 8.650011060487001746110991007299e-01
         	 2.238114422946618775611682394810e-01 5.523771154106762448776635210379e-01 2.238114422946618775611682394810e-01
         	 3.879143834569392934596976374451e-01 2.241712330861213020583022625942e-01 3.879143834569392934596976374451e-01
         	 6.749944697564996820560168089287e-02 8.650011060487001746110991007299e-01 6.749944697564996820560168089287e-02
         	 5.523771154106762448776635210379e-01 2.238114422946618775611682394810e-01 2.238114422946618775611682394810e-01
         	 2.241712330861213020583022625942e-01 3.879143834569392934596976374451e-01 3.879143834569392934596976374451e-01
         	 8.650011060487001746110991007299e-01 6.749944697564996820560168089287e-02 6.749944697564996820560168089287e-02
         	 2.106241399947925418967287214400e-01 7.064768674963645134212697485054e-01 8.289899250884291692642591442564e-02
         	 3.702480264146488231347120745340e-01 5.482896391715870176852831718861e-01 8.146233441376415918000475357985e-02
         	 2.106241399947925418967287214400e-01 8.289899250884291692642591442564e-02 7.064768674963645134212697485054e-01
         	 3.702480264146488231347120745340e-01 8.146233441376415918000475357985e-02 5.482896391715870176852831718861e-01
         	 7.064768674963645134212697485054e-01 2.106241399947925418967287214400e-01 8.289899250884291692642591442564e-02
         	 5.482896391715870176852831718861e-01 3.702480264146488231347120745340e-01 8.146233441376415918000475357985e-02
         	 7.064768674963645134212697485054e-01 8.289899250884291692642591442564e-02 2.106241399947925418967287214400e-01
         	 5.482896391715870176852831718861e-01 8.146233441376415918000475357985e-02 3.702480264146488231347120745340e-01
         	 8.289899250884291692642591442564e-02 2.106241399947925418967287214400e-01 7.064768674963645134212697485054e-01
         	 8.146233441376415918000475357985e-02 3.702480264146488231347120745340e-01 5.482896391715870176852831718861e-01
         	 8.289899250884291692642591442564e-02 7.064768674963645134212697485054e-01 2.106241399947925418967287214400e-01
         	 8.146233441376415918000475357985e-02 5.482896391715870176852831718861e-01 3.702480264146488231347120745340e-01
         	 1.000000000000000000000000000000e+00 0.000000000000000000000000000000e+00 0.000000000000000000000000000000e+00
         	 0.000000000000000000000000000000e+00 1.000000000000000000000000000000e+00 0.000000000000000000000000000000e+00
         	 0.000000000000000000000000000000e+00 0.000000000000000000000000000000e+00 1.000000000000000000000000000000e+00
         	 5.012100229426996733650412352290e-02 9.498789977057300326634958764771e-01 0.000000000000000000000000000000e+00
         	 1.614068602446310785047955960181e-01 8.385931397553689770063556352397e-01 0.000000000000000000000000000000e+00
         	 3.184412680869108669412526069209e-01 6.815587319130891330587473930791e-01 0.000000000000000000000000000000e+00
         	 5.000000000000001110223024625157e-01 4.999999999999998889776975374843e-01 0.000000000000000000000000000000e+00
         	 6.815587319130891330587473930791e-01 3.184412680869108669412526069209e-01 0.000000000000000000000000000000e+00
         	 8.385931397553689770063556352397e-01 1.614068602446310229936443647603e-01 0.000000000000000000000000000000e+00
         	 9.498789977057298106188909514458e-01 5.012100229427018938110904855421e-02 0.000000000000000000000000000000e+00
         	 5.012100229426996733650412352290e-02 0.000000000000000000000000000000e+00 9.498789977057300326634958764771e-01
         	 1.614068602446310785047955960181e-01 0.000000000000000000000000000000e+00 8.385931397553689770063556352397e-01
         	 3.184412680869108669412526069209e-01 0.000000000000000000000000000000e+00 6.815587319130891330587473930791e-01
         	 5.000000000000001110223024625157e-01 0.000000000000000000000000000000e+00 4.999999999999998889776975374843e-01
         	 6.815587319130891330587473930791e-01 0.000000000000000000000000000000e+00 3.184412680869108669412526069209e-01
         	 8.385931397553689770063556352397e-01 0.000000000000000000000000000000e+00 1.614068602446310229936443647603e-01
         	 9.498789977057298106188909514458e-01 0.000000000000000000000000000000e+00 5.012100229427018938110904855421e-02
         	 0.000000000000000000000000000000e+00 5.012100229426996733650412352290e-02 9.498789977057300326634958764771e-01
         	 0.000000000000000000000000000000e+00 1.614068602446310785047955960181e-01 8.385931397553689770063556352397e-01
         	 0.000000000000000000000000000000e+00 3.184412680869108669412526069209e-01 6.815587319130891330587473930791e-01
         	 0.000000000000000000000000000000e+00 5.000000000000001110223024625157e-01 4.999999999999998889776975374843e-01
         	 0.000000000000000000000000000000e+00 6.815587319130891330587473930791e-01 3.184412680869108669412526069209e-01
         	 0.000000000000000000000000000000e+00 8.385931397553689770063556352397e-01 1.614068602446310229936443647603e-01
         	 0.000000000000000000000000000000e+00 9.498789977057298106188909514458e-01 5.012100229427018938110904855421e-02
         	 ];


    case  9

    	 % PASSED (I).

     	 % DEGREE:   9
     	 % POINTS:     55
     	 % LEBESGUE CONSTANT: 5.49425e+00
     	 % DETERMINANT: 1.43106e+64
     	 % CONDITIONING: 1.41026e+02
     	 % MAX LAGRANGE POLYNOMIALS: 1.03863e+00
     	 % VANDERMONDE: ORTHONORMAL DUBINER LEGENDRE.

     	 table=[
       	  1	  3	  3
      	 ];

     	 t=[
         	 -1.562514848923899635213530245892e-01
         	 -5.507526984062848240952803280379e-01
         	 1.933329877948434250001241707650e-01
         	 2.936590082976052173968639635859e-01
         	 2.127801337098002287806508547874e-01
         	 4.826958373702860405352055295225e-01
         	 1.460576926879813830506549265920e-01
         	 5.894739799261580204259303172876e-01
         	 3.132005004155614669159035656776e-01
         	 ];

     	 pts=[
         	 3.333333333333333148296162562474e-01 3.333333333333333148296162562474e-01 3.333333333333333148296162562474e-01
         	 5.208382829746331654785507225824e-02 5.208382829746331654785507225824e-02 8.958323434050733391487142398546e-01
         	 1.835842328020949321132349041363e-01 1.835842328020949321132349041363e-01 6.328315343958100802623789604695e-01
         	 5.208382829746331654785507225824e-02 8.958323434050733391487142398546e-01 5.208382829746331654785507225824e-02
         	 1.835842328020949321132349041363e-01 6.328315343958100802623789604695e-01 1.835842328020949321132349041363e-01
         	 8.958323434050733391487142398546e-01 5.208382829746331654785507225824e-02 5.208382829746331654785507225824e-02
         	 6.328315343958100802623789604695e-01 1.835842328020949321132349041363e-01 1.835842328020949321132349041363e-01
         	 4.677778353675260958333126382058e-01 4.677778353675260958333126382058e-01 6.444432926494780833337472358835e-02
         	 4.677778353675260958333126382058e-01 6.444432926494780833337472358835e-02 4.677778353675260958333126382058e-01
         	 6.444432926494780833337472358835e-02 4.677778353675260958333126382058e-01 4.677778353675260958333126382058e-01
         	 3.335906038202737233788752746477e-01 4.796482965082551341851058168686e-01 1.867610996714711424360189084837e-01
         	 1.723053623095807118659195111832e-01 7.617793422357387322918498284707e-01 6.591529545468055584223066034610e-02
         	 3.093824727565271937024249382375e-01 6.225829731720886606183285039151e-01 6.803455407138414567924655784736e-02
         	 3.335906038202737233788752746477e-01 1.867610996714711424360189084837e-01 4.796482965082551341851058168686e-01
         	 1.723053623095807118659195111832e-01 6.591529545468055584223066034610e-02 7.617793422357387322918498284707e-01
         	 3.093824727565271937024249382375e-01 6.803455407138414567924655784736e-02 6.225829731720886606183285039151e-01
         	 4.796482965082551341851058168686e-01 3.335906038202737233788752746477e-01 1.867610996714711424360189084837e-01
         	 7.617793422357387322918498284707e-01 1.723053623095807118659195111832e-01 6.591529545468055584223066034610e-02
         	 6.225829731720886606183285039151e-01 3.093824727565271937024249382375e-01 6.803455407138414567924655784736e-02
         	 4.796482965082551341851058168686e-01 1.867610996714711424360189084837e-01 3.335906038202737233788752746477e-01
         	 7.617793422357387322918498284707e-01 6.591529545468055584223066034610e-02 1.723053623095807118659195111832e-01
         	 6.225829731720886606183285039151e-01 6.803455407138414567924655784736e-02 3.093824727565271937024249382375e-01
         	 1.867610996714711424360189084837e-01 3.335906038202737233788752746477e-01 4.796482965082551341851058168686e-01
         	 6.591529545468055584223066034610e-02 1.723053623095807118659195111832e-01 7.617793422357387322918498284707e-01
         	 6.803455407138414567924655784736e-02 3.093824727565271937024249382375e-01 6.225829731720886606183285039151e-01
         	 1.867610996714711424360189084837e-01 4.796482965082551341851058168686e-01 3.335906038202737233788752746477e-01
         	 6.591529545468055584223066034610e-02 7.617793422357387322918498284707e-01 1.723053623095807118659195111832e-01
         	 6.803455407138414567924655784736e-02 6.225829731720886606183285039151e-01 3.093824727565271937024249382375e-01
         	 1.000000000000000000000000000000e+00 0.000000000000000000000000000000e+00 0.000000000000000000000000000000e+00
         	 0.000000000000000000000000000000e+00 1.000000000000000000000000000000e+00 0.000000000000000000000000000000e+00
         	 0.000000000000000000000000000000e+00 0.000000000000000000000000000000e+00 1.000000000000000000000000000000e+00
         	 4.023304591677051567089051786752e-02 9.597669540832294288179582508747e-01 0.000000000000000000000000000000e+00
         	 1.306130674472475994285503020365e-01 8.693869325527523450602984667057e-01 0.000000000000000000000000000000e+00
         	 2.610375250947778447141445212765e-01 7.389624749052221552858554787235e-01 0.000000000000000000000000000000e+00
         	 4.173605211668064973729030953109e-01 5.826394788331934471159456734313e-01 0.000000000000000000000000000000e+00
         	 5.826394788331933360936432109156e-01 4.173605211668066639063567890844e-01 0.000000000000000000000000000000e+00
         	 7.389624749052223773304604037548e-01 2.610375250947776226695395962452e-01 0.000000000000000000000000000000e+00
         	 8.693869325527523450602984667057e-01 1.306130674472476549397015332943e-01 0.000000000000000000000000000000e+00
         	 9.597669540832292067733533258433e-01 4.023304591677079322664667415665e-02 0.000000000000000000000000000000e+00
         	 4.023304591677051567089051786752e-02 0.000000000000000000000000000000e+00 9.597669540832294288179582508747e-01
         	 1.306130674472475994285503020365e-01 0.000000000000000000000000000000e+00 8.693869325527523450602984667057e-01
         	 2.610375250947778447141445212765e-01 0.000000000000000000000000000000e+00 7.389624749052221552858554787235e-01
         	 4.173605211668064973729030953109e-01 0.000000000000000000000000000000e+00 5.826394788331934471159456734313e-01
         	 5.826394788331933360936432109156e-01 0.000000000000000000000000000000e+00 4.173605211668066639063567890844e-01
         	 7.389624749052223773304604037548e-01 0.000000000000000000000000000000e+00 2.610375250947776226695395962452e-01
         	 8.693869325527523450602984667057e-01 0.000000000000000000000000000000e+00 1.306130674472476549397015332943e-01
         	 9.597669540832292067733533258433e-01 0.000000000000000000000000000000e+00 4.023304591677079322664667415665e-02
         	 0.000000000000000000000000000000e+00 4.023304591677051567089051786752e-02 9.597669540832294288179582508747e-01
         	 0.000000000000000000000000000000e+00 1.306130674472475994285503020365e-01 8.693869325527523450602984667057e-01
         	 0.000000000000000000000000000000e+00 2.610375250947778447141445212765e-01 7.389624749052221552858554787235e-01
         	 0.000000000000000000000000000000e+00 4.173605211668064973729030953109e-01 5.826394788331934471159456734313e-01
         	 0.000000000000000000000000000000e+00 5.826394788331933360936432109156e-01 4.173605211668066639063567890844e-01
         	 0.000000000000000000000000000000e+00 7.389624749052223773304604037548e-01 2.610375250947776226695395962452e-01
         	 0.000000000000000000000000000000e+00 8.693869325527523450602984667057e-01 1.306130674472476549397015332943e-01
         	 0.000000000000000000000000000000e+00 9.597669540832292067733533258433e-01 4.023304591677079322664667415665e-02
         	 ];


    case 10

    	 % PASSED (I).

     	 % DEGREE:  10
     	 % POINTS:     66
     	 % LEBESGUE CONSTANT: 6.28165e+00
     	 % DETERMINANT: -2.40480e+79
     	 % CONDITIONING: 1.84334e+02
     	 % MAX LAGRANGE POLYNOMIALS: 1.08256e+00
     	 % VANDERMONDE: ORTHONORMAL DUBINER LEGENDRE.

     	 table=[
       	  0	  4	  4
      	 ];

     	 t=[
         	 -3.941296677205794463105803515646e-01
         	 -1.636027060985902337186814747838e-01
         	 7.018962099628419659680389486311e-01
         	 -6.764721019762361953198137598520e-01
         	 3.602674209254750348208062860067e-01
         	 5.627790901876089657562829415838e-01
         	 2.881894190600281513425784396532e-01
         	 6.928644040417395455477844734560e-01
         	 3.929759822700094051839414532878e-01
         	 1.357879977214336009172512831356e-01
         	 5.988917676419173163893105993338e-01
         	 2.111864495824385956623814308841e-01
         	 ];

     	 pts=[
         	 1.312733767493933778602865913854e-01 1.312733767493933778602865913854e-01 7.374532465012133553017292797449e-01
         	 5.386953019930516839419709640424e-02 5.386953019930516839419709640424e-02 8.922609396013896354560301915626e-01
         	 2.252378431088206955923425311994e-01 2.252378431088206955923425311994e-01 5.495243137823585533041637063434e-01
         	 1.312733767493933778602865913854e-01 7.374532465012133553017292797449e-01 1.312733767493933778602865913854e-01
         	 5.386953019930516839419709640424e-02 8.922609396013896354560301915626e-01 5.386953019930516839419709640424e-02
         	 2.252378431088206955923425311994e-01 5.495243137823585533041637063434e-01 2.252378431088206955923425311994e-01
         	 7.374532465012133553017292797449e-01 1.312733767493933778602865913854e-01 1.312733767493933778602865913854e-01
         	 8.922609396013896354560301915626e-01 5.386953019930516839419709640424e-02 5.386953019930516839419709640424e-02
         	 5.495243137823585533041637063434e-01 2.252378431088206955923425311994e-01 2.252378431088206955923425311994e-01
         	 3.824877939073025312488596227922e-01 3.824877939073025312488596227922e-01 2.350244121853949375022807544156e-01
         	 3.824877939073025312488596227922e-01 2.350244121853949375022807544156e-01 3.824877939073025312488596227922e-01
         	 2.350244121853949375022807544156e-01 3.824877939073025312488596227922e-01 3.824877939073025312488596227922e-01
         	 2.622175009707391479807370160415e-01 6.564279951505325172433913394343e-01 8.135450387872833477587164452416e-02
         	 3.776961071421849336360310189775e-01 5.223502436193665499075677871588e-01 9.995364923844851645640119386371e-02
         	 1.820746613840211192147933161323e-01 7.792454007990795572524689305283e-01 3.867993781689926802158652208163e-02
         	 3.779628077066509161952012618713e-01 5.892534012902733708827440750611e-01 3.278379100307571292205466306768e-02
         	 2.622175009707391479807370160415e-01 8.135450387872833477587164452416e-02 6.564279951505325172433913394343e-01
         	 3.776961071421849336360310189775e-01 9.995364923844851645640119386371e-02 5.223502436193665499075677871588e-01
         	 1.820746613840211192147933161323e-01 3.867993781689926802158652208163e-02 7.792454007990795572524689305283e-01
         	 3.779628077066509161952012618713e-01 3.278379100307571292205466306768e-02 5.892534012902733708827440750611e-01
         	 6.564279951505325172433913394343e-01 2.622175009707391479807370160415e-01 8.135450387872833477587164452416e-02
         	 5.223502436193665499075677871588e-01 3.776961071421849336360310189775e-01 9.995364923844851645640119386371e-02
         	 7.792454007990795572524689305283e-01 1.820746613840211192147933161323e-01 3.867993781689926802158652208163e-02
         	 5.892534012902733708827440750611e-01 3.779628077066509161952012618713e-01 3.278379100307571292205466306768e-02
         	 6.564279951505325172433913394343e-01 8.135450387872833477587164452416e-02 2.622175009707391479807370160415e-01
         	 5.223502436193665499075677871588e-01 9.995364923844851645640119386371e-02 3.776961071421849336360310189775e-01
         	 7.792454007990795572524689305283e-01 3.867993781689926802158652208163e-02 1.820746613840211192147933161323e-01
         	 5.892534012902733708827440750611e-01 3.278379100307571292205466306768e-02 3.779628077066509161952012618713e-01
         	 8.135450387872833477587164452416e-02 2.622175009707391479807370160415e-01 6.564279951505325172433913394343e-01
         	 9.995364923844851645640119386371e-02 3.776961071421849336360310189775e-01 5.223502436193665499075677871588e-01
         	 3.867993781689926802158652208163e-02 1.820746613840211192147933161323e-01 7.792454007990795572524689305283e-01
         	 3.278379100307571292205466306768e-02 3.779628077066509161952012618713e-01 5.892534012902733708827440750611e-01
         	 8.135450387872833477587164452416e-02 6.564279951505325172433913394343e-01 2.622175009707391479807370160415e-01
         	 9.995364923844851645640119386371e-02 5.223502436193665499075677871588e-01 3.776961071421849336360310189775e-01
         	 3.867993781689926802158652208163e-02 7.792454007990795572524689305283e-01 1.820746613840211192147933161323e-01
         	 3.278379100307571292205466306768e-02 5.892534012902733708827440750611e-01 3.779628077066509161952012618713e-01
         	 1.000000000000000000000000000000e+00 0.000000000000000000000000000000e+00 0.000000000000000000000000000000e+00
         	 0.000000000000000000000000000000e+00 1.000000000000000000000000000000e+00 0.000000000000000000000000000000e+00
         	 0.000000000000000000000000000000e+00 0.000000000000000000000000000000e+00 1.000000000000000000000000000000e+00
         	 3.299928479597025177127989081782e-02 9.670007152040297482287201091822e-01 0.000000000000000000000000000000e+00
         	 1.077582631684279035333418050868e-01 8.922417368315720409555069636554e-01 0.000000000000000000000000000000e+00
         	 2.173823365018974773654747423279e-01 7.826176634981025781456764889299e-01 0.000000000000000000000000000000e+00
         	 3.521209322065304014870434912154e-01 6.478790677934695985129565087846e-01 0.000000000000000000000000000000e+00
         	 5.000000000000000000000000000000e-01 5.000000000000000000000000000000e-01 0.000000000000000000000000000000e+00
         	 6.478790677934695985129565087846e-01 3.521209322065304014870434912154e-01 0.000000000000000000000000000000e+00
         	 7.826176634981024671233740264142e-01 2.173823365018975328766259735858e-01 0.000000000000000000000000000000e+00
         	 8.922417368315722630001118886867e-01 1.077582631684277369998881113133e-01 0.000000000000000000000000000000e+00
         	 9.670007152040296372064176466665e-01 3.299928479597036279358235333348e-02 0.000000000000000000000000000000e+00
         	 3.299928479597025177127989081782e-02 0.000000000000000000000000000000e+00 9.670007152040297482287201091822e-01
         	 1.077582631684279035333418050868e-01 0.000000000000000000000000000000e+00 8.922417368315720409555069636554e-01
         	 2.173823365018974773654747423279e-01 0.000000000000000000000000000000e+00 7.826176634981025781456764889299e-01
         	 3.521209322065304014870434912154e-01 0.000000000000000000000000000000e+00 6.478790677934695985129565087846e-01
         	 5.000000000000000000000000000000e-01 0.000000000000000000000000000000e+00 5.000000000000000000000000000000e-01
         	 6.478790677934695985129565087846e-01 0.000000000000000000000000000000e+00 3.521209322065304014870434912154e-01
         	 7.826176634981024671233740264142e-01 0.000000000000000000000000000000e+00 2.173823365018975328766259735858e-01
         	 8.922417368315722630001118886867e-01 0.000000000000000000000000000000e+00 1.077582631684277369998881113133e-01
         	 9.670007152040296372064176466665e-01 0.000000000000000000000000000000e+00 3.299928479597036279358235333348e-02
         	 0.000000000000000000000000000000e+00 3.299928479597025177127989081782e-02 9.670007152040297482287201091822e-01
         	 0.000000000000000000000000000000e+00 1.077582631684279035333418050868e-01 8.922417368315720409555069636554e-01
         	 0.000000000000000000000000000000e+00 2.173823365018974773654747423279e-01 7.826176634981025781456764889299e-01
         	 0.000000000000000000000000000000e+00 3.521209322065304014870434912154e-01 6.478790677934695985129565087846e-01
         	 0.000000000000000000000000000000e+00 5.000000000000000000000000000000e-01 5.000000000000000000000000000000e-01
         	 0.000000000000000000000000000000e+00 6.478790677934695985129565087846e-01 3.521209322065304014870434912154e-01
         	 0.000000000000000000000000000000e+00 7.826176634981024671233740264142e-01 2.173823365018975328766259735858e-01
         	 0.000000000000000000000000000000e+00 8.922417368315722630001118886867e-01 1.077582631684277369998881113133e-01
         	 0.000000000000000000000000000000e+00 9.670007152040296372064176466665e-01 3.299928479597036279358235333348e-02
         	 ];


    case 11

    	 % PASSED (I).

     	 % DEGREE:  11
     	 % POINTS:     78
     	 % LEBESGUE CONSTANT: 7.00203e+00
     	 % DETERMINANT: 2.11926e+96
     	 % CONDITIONING: 2.62281e+02
     	 % MAX LAGRANGE POLYNOMIALS: 1.18378e+00
     	 % VANDERMONDE: ORTHONORMAL DUBINER LEGENDRE.

     	 table=[
       	  0	  5	  5
      	 ];

     	 t=[
         	 -3.152463688745791303702503682871e-01
         	 -1.288695190284177560791079031333e-01
         	 1.154388974551071866958551481730e-01
         	 -6.585658916636439874636721469869e-01
         	 4.279140581569053636279420516075e-01
         	 2.115507172136908142778821684260e-01
         	 2.252651292397381821430712989240e-01
         	 5.557219669972541797875464908429e-01
         	 1.616291212703208080014860570373e-01
         	 4.502502408490319241174404396588e-01
         	 5.075466665047008163469399733003e-01
         	 6.703650761235949717686821713869e-01
         	 3.550727951796225356773106796027e-01
         	 9.738902423906496685912514976735e-02
         	 2.635582359824958920135884454794e-01
         	 ];

     	 pts=[
         	 1.050821229581930388308208534909e-01 1.050821229581930388308208534909e-01 7.898357540836139500939339086472e-01
         	 4.295650634280591406710669843960e-02 4.295650634280591406710669843960e-02 9.140869873143881996213622187497e-01
         	 2.195219638878813106508403052430e-01 2.195219638878813106508403052430e-01 5.609560722242372676760169269983e-01
         	 1.050821229581930388308208534909e-01 7.898357540836139500939339086472e-01 1.050821229581930388308208534909e-01
         	 4.295650634280591406710669843960e-02 9.140869873143881996213622187497e-01 4.295650634280591406710669843960e-02
         	 2.195219638878813106508403052430e-01 5.609560722242372676760169269983e-01 2.195219638878813106508403052430e-01
         	 7.898357540836139500939339086472e-01 1.050821229581930388308208534909e-01 1.050821229581930388308208534909e-01
         	 9.140869873143881996213622187497e-01 4.295650634280591406710669843960e-02 4.295650634280591406710669843960e-02
         	 5.609560722242372676760169269983e-01 2.195219638878813106508403052430e-01 2.195219638878813106508403052430e-01
         	 4.807601837574821401766200779093e-01 4.807601837574821401766200779093e-01 3.847963248503571964675984418136e-02
         	 4.286809903071824301434844528558e-01 4.286809903071824301434844528558e-01 1.426380193856351397130310942885e-01
         	 4.807601837574821401766200779093e-01 3.847963248503571964675984418136e-02 4.807601837574821401766200779093e-01
         	 4.286809903071824301434844528558e-01 1.426380193856351397130310942885e-01 4.286809903071824301434844528558e-01
         	 3.847963248503571964675984418136e-02 4.807601837574821401766200779093e-01 4.807601837574821401766200779093e-01
         	 1.426380193856351397130310942885e-01 4.286809903071824301434844528558e-01 4.286809903071824301434844528558e-01
         	 1.994095640340481923047377676994e-01 7.069562305387490086516777409997e-01 9.363420542720279904358449130086e-02
         	 1.474224961654246879305674156058e-01 8.177875722890196596992495869927e-01 3.478993154555565237018299740157e-02
         	 3.075960627730014995684371115203e-01 6.626688579526240907568990223808e-01 2.973507927437446518581509735668e-02
         	 3.278085121320318262583271007315e-01 4.251975363710968069952400583134e-01 2.469939514968714222575840722129e-01
         	 3.205222948140067362743366174982e-01 5.840805307965026837990762942354e-01 9.539717438949057992658708826639e-02
         	 1.994095640340481923047377676994e-01 9.363420542720279904358449130086e-02 7.069562305387490086516777409997e-01
         	 1.474224961654246879305674156058e-01 3.478993154555565237018299740157e-02 8.177875722890196596992495869927e-01
         	 3.075960627730014995684371115203e-01 2.973507927437446518581509735668e-02 6.626688579526240907568990223808e-01
         	 3.278085121320318262583271007315e-01 2.469939514968714222575840722129e-01 4.251975363710968069952400583134e-01
         	 3.205222948140067362743366174982e-01 9.539717438949057992658708826639e-02 5.840805307965026837990762942354e-01
         	 7.069562305387490086516777409997e-01 1.994095640340481923047377676994e-01 9.363420542720279904358449130086e-02
         	 8.177875722890196596992495869927e-01 1.474224961654246879305674156058e-01 3.478993154555565237018299740157e-02
         	 6.626688579526240907568990223808e-01 3.075960627730014995684371115203e-01 2.973507927437446518581509735668e-02
         	 4.251975363710968069952400583134e-01 3.278085121320318262583271007315e-01 2.469939514968714222575840722129e-01
         	 5.840805307965026837990762942354e-01 3.205222948140067362743366174982e-01 9.539717438949057992658708826639e-02
         	 7.069562305387490086516777409997e-01 9.363420542720279904358449130086e-02 1.994095640340481923047377676994e-01
         	 8.177875722890196596992495869927e-01 3.478993154555565237018299740157e-02 1.474224961654246879305674156058e-01
         	 6.626688579526240907568990223808e-01 2.973507927437446518581509735668e-02 3.075960627730014995684371115203e-01
         	 4.251975363710968069952400583134e-01 2.469939514968714222575840722129e-01 3.278085121320318262583271007315e-01
         	 5.840805307965026837990762942354e-01 9.539717438949057992658708826639e-02 3.205222948140067362743366174982e-01
         	 9.363420542720279904358449130086e-02 1.994095640340481923047377676994e-01 7.069562305387490086516777409997e-01
         	 3.478993154555565237018299740157e-02 1.474224961654246879305674156058e-01 8.177875722890196596992495869927e-01
         	 2.973507927437446518581509735668e-02 3.075960627730014995684371115203e-01 6.626688579526240907568990223808e-01
         	 2.469939514968714222575840722129e-01 3.278085121320318262583271007315e-01 4.251975363710968069952400583134e-01
         	 9.539717438949057992658708826639e-02 3.205222948140067362743366174982e-01 5.840805307965026837990762942354e-01
         	 9.363420542720279904358449130086e-02 7.069562305387490086516777409997e-01 1.994095640340481923047377676994e-01
         	 3.478993154555565237018299740157e-02 8.177875722890196596992495869927e-01 1.474224961654246879305674156058e-01
         	 2.973507927437446518581509735668e-02 6.626688579526240907568990223808e-01 3.075960627730014995684371115203e-01
         	 2.469939514968714222575840722129e-01 4.251975363710968069952400583134e-01 3.278085121320318262583271007315e-01
         	 9.539717438949057992658708826639e-02 5.840805307965026837990762942354e-01 3.205222948140067362743366174982e-01
         	 1.000000000000000000000000000000e+00 0.000000000000000000000000000000e+00 0.000000000000000000000000000000e+00
         	 0.000000000000000000000000000000e+00 1.000000000000000000000000000000e+00 0.000000000000000000000000000000e+00
         	 0.000000000000000000000000000000e+00 0.000000000000000000000000000000e+00 1.000000000000000000000000000000e+00
         	 2.755036388855880424841870990349e-02 9.724496361114411957515812900965e-01 0.000000000000000000000000000000e+00
         	 9.036033917799679571203341765795e-02 9.096396608220032042879665823421e-01 0.000000000000000000000000000000e+00
         	 1.835619234840696889499156441161e-01 8.164380765159302555389331246261e-01 0.000000000000000000000000000000e+00
         	 3.002345295173255435017267700459e-01 6.997654704826744564982732299541e-01 0.000000000000000000000000000000e+00
         	 4.317235335725362888048550757958e-01 5.682764664274637667062961554620e-01 0.000000000000000000000000000000e+00
         	 5.682764664274635446616912304307e-01 4.317235335725364553383087695693e-01 0.000000000000000000000000000000e+00
         	 6.997654704826742344536683049228e-01 3.002345295173257655463316950772e-01 0.000000000000000000000000000000e+00
         	 8.164380765159302555389331246261e-01 1.835619234840697444610668753739e-01 0.000000000000000000000000000000e+00
         	 9.096396608220034263325715073734e-01 9.036033917799657366742849262664e-02 0.000000000000000000000000000000e+00
         	 9.724496361114410847292788275809e-01 2.755036388855891527072117241914e-02 0.000000000000000000000000000000e+00
         	 2.755036388855880424841870990349e-02 0.000000000000000000000000000000e+00 9.724496361114411957515812900965e-01
         	 9.036033917799679571203341765795e-02 0.000000000000000000000000000000e+00 9.096396608220032042879665823421e-01
         	 1.835619234840696889499156441161e-01 0.000000000000000000000000000000e+00 8.164380765159302555389331246261e-01
         	 3.002345295173255435017267700459e-01 0.000000000000000000000000000000e+00 6.997654704826744564982732299541e-01
         	 4.317235335725362888048550757958e-01 0.000000000000000000000000000000e+00 5.682764664274637667062961554620e-01
         	 5.682764664274635446616912304307e-01 0.000000000000000000000000000000e+00 4.317235335725364553383087695693e-01
         	 6.997654704826742344536683049228e-01 0.000000000000000000000000000000e+00 3.002345295173257655463316950772e-01
         	 8.164380765159302555389331246261e-01 0.000000000000000000000000000000e+00 1.835619234840697444610668753739e-01
         	 9.096396608220034263325715073734e-01 0.000000000000000000000000000000e+00 9.036033917799657366742849262664e-02
         	 9.724496361114410847292788275809e-01 0.000000000000000000000000000000e+00 2.755036388855891527072117241914e-02
         	 0.000000000000000000000000000000e+00 2.755036388855880424841870990349e-02 9.724496361114411957515812900965e-01
         	 0.000000000000000000000000000000e+00 9.036033917799679571203341765795e-02 9.096396608220032042879665823421e-01
         	 0.000000000000000000000000000000e+00 1.835619234840696889499156441161e-01 8.164380765159302555389331246261e-01
         	 0.000000000000000000000000000000e+00 3.002345295173255435017267700459e-01 6.997654704826744564982732299541e-01
         	 0.000000000000000000000000000000e+00 4.317235335725362888048550757958e-01 5.682764664274637667062961554620e-01
         	 0.000000000000000000000000000000e+00 5.682764664274635446616912304307e-01 4.317235335725364553383087695693e-01
         	 0.000000000000000000000000000000e+00 6.997654704826742344536683049228e-01 3.002345295173257655463316950772e-01
         	 0.000000000000000000000000000000e+00 8.164380765159302555389331246261e-01 1.835619234840697444610668753739e-01
         	 0.000000000000000000000000000000e+00 9.096396608220034263325715073734e-01 9.036033917799657366742849262664e-02
         	 0.000000000000000000000000000000e+00 9.724496361114410847292788275809e-01 2.755036388855891527072117241914e-02
         	 ];


    case 12

    	 % PASSED (I).

     	 % DEGREE:  12
     	 % POINTS:     91
     	 % LEBESGUE CONSTANT: 7.25934e+00
     	 % DETERMINANT: -2.07917e+115
     	 % CONDITIONING: 2.28046e+02
     	 % MAX LAGRANGE POLYNOMIALS: 1.04342e+00
     	 % VANDERMONDE: ORTHONORMAL DUBINER LEGENDRE.

     	 table=[
       	  1	  4	  7
      	 ];

     	 t=[
         	 5.732457074978517530539079416485e-01
         	 -1.232501304548562076623952066257e-01
         	 -7.590487583656501113793524382345e-01
         	 -2.782566584847177004746754391817e-01
         	 4.082326513053914363027274703200e-01
         	 7.359701736438680752527830009058e-01
         	 1.710298433054033284683725923969e-01
         	 4.744218201482424679404914513725e-01
         	 5.656716429705143101003272931848e-01
         	 1.564640902238183806094440342349e-01
         	 1.971296386045695570032876275945e-01
         	 3.593432219822729201119670960907e-01
         	 1.438413457475649359640357261014e-01
         	 5.479923914497029091563717884128e-01
         	 4.494109745798199329058775219892e-01
         	 1.035481326141956537334465338063e-01
         	 3.680558944717389757705916508712e-01
         	 7.163382303410626983364295483625e-01
         	 ];

     	 pts=[
         	 3.333333333333333148296162562474e-01 3.333333333333333148296162562474e-01 3.333333333333333148296162562474e-01
         	 4.108337681828540255413173554189e-02 4.108337681828540255413173554189e-02 9.178332463634292226473121445451e-01
         	 2.530162527885500001190166585729e-01 2.530162527885500001190166585729e-01 4.939674944228998887396642203385e-01
         	 9.275221949490589090636660785094e-02 9.275221949490589090636660785094e-02 8.144955610101881626761155530403e-01
         	 4.108337681828540255413173554189e-02 9.178332463634292226473121445451e-01 4.108337681828540255413173554189e-02
         	 2.530162527885500001190166585729e-01 4.939674944228998887396642203385e-01 2.530162527885500001190166585729e-01
         	 9.275221949490589090636660785094e-02 8.144955610101881626761155530403e-01 9.275221949490589090636660785094e-02
         	 9.178332463634292226473121445451e-01 4.108337681828540255413173554189e-02 4.108337681828540255413173554189e-02
         	 4.939674944228998887396642203385e-01 2.530162527885500001190166585729e-01 2.530162527885500001190166585729e-01
         	 8.144955610101881626761155530403e-01 9.275221949490589090636660785094e-02 9.275221949490589090636660785094e-02
         	 4.044590487503580411576820097252e-01 4.044590487503580411576820097252e-01 1.910819024992839176846359805495e-01
         	 4.044590487503580411576820097252e-01 1.910819024992839176846359805495e-01 4.044590487503580411576820097252e-01
         	 1.910819024992839176846359805495e-01 4.044590487503580411576820097252e-01 4.044590487503580411576820097252e-01
         	 2.815910345568075623390313921846e-01 6.409342565390805379621497195330e-01 7.747470890411189969881888828240e-02
         	 4.080479136914563764726437966601e-01 5.518892594390213401922551383905e-01 4.006282686952233884625229620724e-02
         	 1.791741767343328906036958869663e-01 7.271665681840357997600676753791e-01 9.365925508163130963623643765459e-02
         	 2.625999784981004614436983501946e-01 7.120109530779203943495758721838e-01 2.538906842397914420672577762161e-02
         	 3.930958962903537967648048834235e-01 4.966440289045495060094026484876e-01 1.102600748050966972257924680889e-01
         	 2.367253835467234002187808528106e-01 6.047812780184623759893725036818e-01 1.584933384348142793029978747654e-01
         	 1.274088629870740174698795499353e-01 8.437470933281366880507334826689e-01 2.884404368478932223496258302475e-02
         	 2.815910345568075623390313921846e-01 7.747470890411189969881888828240e-02 6.409342565390805379621497195330e-01
         	 4.080479136914563764726437966601e-01 4.006282686952233884625229620724e-02 5.518892594390213401922551383905e-01
         	 1.791741767343328906036958869663e-01 9.365925508163130963623643765459e-02 7.271665681840357997600676753791e-01
         	 2.625999784981004614436983501946e-01 2.538906842397914420672577762161e-02 7.120109530779203943495758721838e-01
         	 3.930958962903537967648048834235e-01 1.102600748050966972257924680889e-01 4.966440289045495060094026484876e-01
         	 2.367253835467234002187808528106e-01 1.584933384348142793029978747654e-01 6.047812780184623759893725036818e-01
         	 1.274088629870740174698795499353e-01 2.884404368478932223496258302475e-02 8.437470933281366880507334826689e-01
         	 6.409342565390805379621497195330e-01 2.815910345568075623390313921846e-01 7.747470890411189969881888828240e-02
         	 5.518892594390213401922551383905e-01 4.080479136914563764726437966601e-01 4.006282686952233884625229620724e-02
         	 7.271665681840357997600676753791e-01 1.791741767343328906036958869663e-01 9.365925508163130963623643765459e-02
         	 7.120109530779203943495758721838e-01 2.625999784981004614436983501946e-01 2.538906842397914420672577762161e-02
         	 4.966440289045495060094026484876e-01 3.930958962903537967648048834235e-01 1.102600748050966972257924680889e-01
         	 6.047812780184623759893725036818e-01 2.367253835467234002187808528106e-01 1.584933384348142793029978747654e-01
         	 8.437470933281366880507334826689e-01 1.274088629870740174698795499353e-01 2.884404368478932223496258302475e-02
         	 6.409342565390805379621497195330e-01 7.747470890411189969881888828240e-02 2.815910345568075623390313921846e-01
         	 5.518892594390213401922551383905e-01 4.006282686952233884625229620724e-02 4.080479136914563764726437966601e-01
         	 7.271665681840357997600676753791e-01 9.365925508163130963623643765459e-02 1.791741767343328906036958869663e-01
         	 7.120109530779203943495758721838e-01 2.538906842397914420672577762161e-02 2.625999784981004614436983501946e-01
         	 4.966440289045495060094026484876e-01 1.102600748050966972257924680889e-01 3.930958962903537967648048834235e-01
         	 6.047812780184623759893725036818e-01 1.584933384348142793029978747654e-01 2.367253835467234002187808528106e-01
         	 8.437470933281366880507334826689e-01 2.884404368478932223496258302475e-02 1.274088629870740174698795499353e-01
         	 7.747470890411189969881888828240e-02 2.815910345568075623390313921846e-01 6.409342565390805379621497195330e-01
         	 4.006282686952233884625229620724e-02 4.080479136914563764726437966601e-01 5.518892594390213401922551383905e-01
         	 9.365925508163130963623643765459e-02 1.791741767343328906036958869663e-01 7.271665681840357997600676753791e-01
         	 2.538906842397914420672577762161e-02 2.625999784981004614436983501946e-01 7.120109530779203943495758721838e-01
         	 1.102600748050966972257924680889e-01 3.930958962903537967648048834235e-01 4.966440289045495060094026484876e-01
         	 1.584933384348142793029978747654e-01 2.367253835467234002187808528106e-01 6.047812780184623759893725036818e-01
         	 2.884404368478932223496258302475e-02 1.274088629870740174698795499353e-01 8.437470933281366880507334826689e-01
         	 7.747470890411189969881888828240e-02 6.409342565390805379621497195330e-01 2.815910345568075623390313921846e-01
         	 4.006282686952233884625229620724e-02 5.518892594390213401922551383905e-01 4.080479136914563764726437966601e-01
         	 9.365925508163130963623643765459e-02 7.271665681840357997600676753791e-01 1.791741767343328906036958869663e-01
         	 2.538906842397914420672577762161e-02 7.120109530779203943495758721838e-01 2.625999784981004614436983501946e-01
         	 1.102600748050966972257924680889e-01 4.966440289045495060094026484876e-01 3.930958962903537967648048834235e-01
         	 1.584933384348142793029978747654e-01 6.047812780184623759893725036818e-01 2.367253835467234002187808528106e-01
         	 2.884404368478932223496258302475e-02 8.437470933281366880507334826689e-01 1.274088629870740174698795499353e-01
         	 1.000000000000000000000000000000e+00 0.000000000000000000000000000000e+00 0.000000000000000000000000000000e+00
         	 0.000000000000000000000000000000e+00 1.000000000000000000000000000000e+00 0.000000000000000000000000000000e+00
         	 0.000000000000000000000000000000e+00 0.000000000000000000000000000000e+00 1.000000000000000000000000000000e+00
         	 2.334507667891805304805075138574e-02 9.766549233210819469519492486143e-01 0.000000000000000000000000000000e+00
         	 7.682621767406377921716398304852e-02 9.231737823259362762939872482093e-01 0.000000000000000000000000000000e+00
         	 1.569057654591214379102837028768e-01 8.430942345408785065785650658654e-01 0.000000000000000000000000000000e+00
         	 2.585450894543320776719497189333e-01 7.414549105456679223280502810667e-01 0.000000000000000000000000000000e+00
         	 3.753565349468798717502693307324e-01 6.246434650531200727385794380098e-01 0.000000000000000000000000000000e+00
         	 4.999999999999998889776975374843e-01 5.000000000000001110223024625157e-01 0.000000000000000000000000000000e+00
         	 6.246434650531199617162769754941e-01 3.753565349468800382837230245059e-01 0.000000000000000000000000000000e+00
         	 7.414549105456680333503527435823e-01 2.585450894543319666496472564177e-01 0.000000000000000000000000000000e+00
         	 8.430942345408788396454724534124e-01 1.569057654591211603545275465876e-01 0.000000000000000000000000000000e+00
         	 9.231737823259358322047773981467e-01 7.682621767406416779522260185331e-02 0.000000000000000000000000000000e+00
         	 9.766549233210819469519492486143e-01 2.334507667891805304805075138574e-02 0.000000000000000000000000000000e+00
         	 2.334507667891805304805075138574e-02 0.000000000000000000000000000000e+00 9.766549233210819469519492486143e-01
         	 7.682621767406377921716398304852e-02 0.000000000000000000000000000000e+00 9.231737823259362762939872482093e-01
         	 1.569057654591214379102837028768e-01 0.000000000000000000000000000000e+00 8.430942345408785065785650658654e-01
         	 2.585450894543320776719497189333e-01 0.000000000000000000000000000000e+00 7.414549105456679223280502810667e-01
         	 3.753565349468798717502693307324e-01 0.000000000000000000000000000000e+00 6.246434650531200727385794380098e-01
         	 4.999999999999998889776975374843e-01 0.000000000000000000000000000000e+00 5.000000000000001110223024625157e-01
         	 6.246434650531199617162769754941e-01 0.000000000000000000000000000000e+00 3.753565349468800382837230245059e-01
         	 7.414549105456680333503527435823e-01 0.000000000000000000000000000000e+00 2.585450894543319666496472564177e-01
         	 8.430942345408788396454724534124e-01 0.000000000000000000000000000000e+00 1.569057654591211603545275465876e-01
         	 9.231737823259358322047773981467e-01 0.000000000000000000000000000000e+00 7.682621767406416779522260185331e-02
         	 9.766549233210819469519492486143e-01 0.000000000000000000000000000000e+00 2.334507667891805304805075138574e-02
         	 0.000000000000000000000000000000e+00 2.334507667891805304805075138574e-02 9.766549233210819469519492486143e-01
         	 0.000000000000000000000000000000e+00 7.682621767406377921716398304852e-02 9.231737823259362762939872482093e-01
         	 0.000000000000000000000000000000e+00 1.569057654591214379102837028768e-01 8.430942345408785065785650658654e-01
         	 0.000000000000000000000000000000e+00 2.585450894543320776719497189333e-01 7.414549105456679223280502810667e-01
         	 0.000000000000000000000000000000e+00 3.753565349468798717502693307324e-01 6.246434650531200727385794380098e-01
         	 0.000000000000000000000000000000e+00 4.999999999999998889776975374843e-01 5.000000000000001110223024625157e-01
         	 0.000000000000000000000000000000e+00 6.246434650531199617162769754941e-01 3.753565349468800382837230245059e-01
         	 0.000000000000000000000000000000e+00 7.414549105456680333503527435823e-01 2.585450894543319666496472564177e-01
         	 0.000000000000000000000000000000e+00 8.430942345408788396454724534124e-01 1.569057654591211603545275465876e-01
         	 0.000000000000000000000000000000e+00 9.231737823259358322047773981467e-01 7.682621767406416779522260185331e-02
         	 0.000000000000000000000000000000e+00 9.766549233210819469519492486143e-01 2.334507667891805304805075138574e-02
         	 ];


    case 13

    	 % PASSED (I).

     	 % DEGREE:  13
     	 % POINTS:    105
     	 % LEBESGUE CONSTANT: 8.57673e+00
     	 % DETERMINANT: 2.16493e+135
     	 % CONDITIONING: 3.32262e+02
     	 % MAX LAGRANGE POLYNOMIALS: 1.09934e+00
     	 % VANDERMONDE: ORTHONORMAL DUBINER LEGENDRE.

     	 table=[
       	  0	  6	  8
      	 ];

     	 t=[
         	 2.065503679890194899115840598824e-01
         	 -4.441357958260526705984716500097e-01
         	 8.050678878200937527154223971593e-01
         	 -2.513230617415174728002114079572e-01
         	 -1.033847140757991334147902762197e-01
         	 4.150913700956649354800731543946e-01
         	 2.515520139225252971293400605646e-01
         	 2.043376318896253374113314293936e-01
         	 1.725804028441925430659154017121e-01
         	 5.079859398265721415199891453085e-01
         	 4.451736668217827208593462273711e-01
         	 7.805423184980332385052292920591e-01
         	 1.199646686927147293255657700684e-01
         	 4.579227656512598332305685744359e-01
         	 5.629165179695406751037012327288e-01
         	 3.794723323782358548328375036363e-01
         	 7.575168234357236851650441167294e-01
         	 3.504062922844741745365126917022e-01
         	 5.022307387765790887002026465780e-01
         	 1.641877804894975034777360178850e-01
         	 2.332989111320474262534219178633e-01
         	 2.353926154361998535069488980298e-01
         	 ];

     	 pts=[
         	 1.480452652753508901994905500032e-01 1.480452652753508901994905500032e-01 7.039094694492982196010188999935e-01
         	 8.377435391383915297414120004760e-02 8.377435391383915297414120004760e-02 8.324512921723217218072932155337e-01
         	 3.446157135859970882529879077083e-02 3.446157135859970882529879077083e-02 9.310768572828006517383414575306e-01
         	 1.480452652753508901994905500032e-01 7.039094694492982196010188999935e-01 1.480452652753508901994905500032e-01
         	 8.377435391383915297414120004760e-02 8.324512921723217218072932155337e-01 8.377435391383915297414120004760e-02
         	 3.446157135859970882529879077083e-02 9.310768572828006517383414575306e-01 3.446157135859970882529879077083e-02
         	 7.039094694492982196010188999935e-01 1.480452652753508901994905500032e-01 1.480452652753508901994905500032e-01
         	 8.324512921723217218072932155337e-01 8.377435391383915297414120004760e-02 8.377435391383915297414120004760e-02
         	 9.310768572828006517383414575306e-01 3.446157135859970882529879077083e-02 3.446157135859970882529879077083e-02
         	 4.655749386684967516814026566863e-01 4.655749386684967516814026566863e-01 6.885012266300649663719468662748e-02
         	 3.658220186966510412140962671401e-01 3.658220186966510412140962671401e-01 2.683559626066979175718074657198e-01
         	 4.308181049840558718422300898965e-01 4.308181049840558718422300898965e-01 1.383637900318882563155398202071e-01
         	 4.655749386684967516814026566863e-01 6.885012266300649663719468662748e-02 4.655749386684967516814026566863e-01
         	 3.658220186966510412140962671401e-01 2.683559626066979175718074657198e-01 3.658220186966510412140962671401e-01
         	 4.308181049840558718422300898965e-01 1.383637900318882563155398202071e-01 4.308181049840558718422300898965e-01
         	 6.885012266300649663719468662748e-02 4.655749386684967516814026566863e-01 4.655749386684967516814026566863e-01
         	 2.683559626066979175718074657198e-01 3.658220186966510412140962671401e-01 3.658220186966510412140962671401e-01
         	 1.383637900318882563155398202071e-01 4.308181049840558718422300898965e-01 4.308181049840558718422300898965e-01
         	 1.876198296639073059832725220986e-01 7.505363476334480088425493704563e-01 6.184382270264465741860249181627e-02
         	 2.408988278555256046242760703535e-01 6.203711602337613761903867271030e-01 1.387300119107129914297615869145e-01
         	 1.095911259954575334152337973137e-01 8.671079494311813018470047609298e-01 2.330092457336119249333705738536e-02
         	 3.011955592096039469041102165647e-01 6.516018514940782324629253707826e-01 4.720258929631782063296441265265e-02
         	 2.401186982114374146579649504929e-01 7.423494369880164756025919814419e-01 1.753186480054613749501868369407e-02
         	 4.086944595865063534212424656289e-01 5.728822400760038568989784835139e-01 1.842330033748984519093028211500e-02
         	 2.755611410714366438234890210879e-01 5.088600522034840700769109389512e-01 2.155788067250792305884488087031e-01
         	 3.311895891298100025323947193101e-01 5.665822045660098282837680017110e-01 1.022282063041801691838372789789e-01
         	 1.876198296639073059832725220986e-01 6.184382270264465741860249181627e-02 7.505363476334480088425493704563e-01
         	 2.408988278555256046242760703535e-01 1.387300119107129914297615869145e-01 6.203711602337613761903867271030e-01
         	 1.095911259954575334152337973137e-01 2.330092457336119249333705738536e-02 8.671079494311813018470047609298e-01
         	 3.011955592096039469041102165647e-01 4.720258929631782063296441265265e-02 6.516018514940782324629253707826e-01
         	 2.401186982114374146579649504929e-01 1.753186480054613749501868369407e-02 7.423494369880164756025919814419e-01
         	 4.086944595865063534212424656289e-01 1.842330033748984519093028211500e-02 5.728822400760038568989784835139e-01
         	 2.755611410714366438234890210879e-01 2.155788067250792305884488087031e-01 5.088600522034840700769109389512e-01
         	 3.311895891298100025323947193101e-01 1.022282063041801691838372789789e-01 5.665822045660098282837680017110e-01
         	 7.505363476334480088425493704563e-01 1.876198296639073059832725220986e-01 6.184382270264465741860249181627e-02
         	 6.203711602337613761903867271030e-01 2.408988278555256046242760703535e-01 1.387300119107129914297615869145e-01
         	 8.671079494311813018470047609298e-01 1.095911259954575334152337973137e-01 2.330092457336119249333705738536e-02
         	 6.516018514940782324629253707826e-01 3.011955592096039469041102165647e-01 4.720258929631782063296441265265e-02
         	 7.423494369880164756025919814419e-01 2.401186982114374146579649504929e-01 1.753186480054613749501868369407e-02
         	 5.728822400760038568989784835139e-01 4.086944595865063534212424656289e-01 1.842330033748984519093028211500e-02
         	 5.088600522034840700769109389512e-01 2.755611410714366438234890210879e-01 2.155788067250792305884488087031e-01
         	 5.665822045660098282837680017110e-01 3.311895891298100025323947193101e-01 1.022282063041801691838372789789e-01
         	 7.505363476334480088425493704563e-01 6.184382270264465741860249181627e-02 1.876198296639073059832725220986e-01
         	 6.203711602337613761903867271030e-01 1.387300119107129914297615869145e-01 2.408988278555256046242760703535e-01
         	 8.671079494311813018470047609298e-01 2.330092457336119249333705738536e-02 1.095911259954575334152337973137e-01
         	 6.516018514940782324629253707826e-01 4.720258929631782063296441265265e-02 3.011955592096039469041102165647e-01
         	 7.423494369880164756025919814419e-01 1.753186480054613749501868369407e-02 2.401186982114374146579649504929e-01
         	 5.728822400760038568989784835139e-01 1.842330033748984519093028211500e-02 4.086944595865063534212424656289e-01
         	 5.088600522034840700769109389512e-01 2.155788067250792305884488087031e-01 2.755611410714366438234890210879e-01
         	 5.665822045660098282837680017110e-01 1.022282063041801691838372789789e-01 3.311895891298100025323947193101e-01
         	 6.184382270264465741860249181627e-02 1.876198296639073059832725220986e-01 7.505363476334480088425493704563e-01
         	 1.387300119107129914297615869145e-01 2.408988278555256046242760703535e-01 6.203711602337613761903867271030e-01
         	 2.330092457336119249333705738536e-02 1.095911259954575334152337973137e-01 8.671079494311813018470047609298e-01
         	 4.720258929631782063296441265265e-02 3.011955592096039469041102165647e-01 6.516018514940782324629253707826e-01
         	 1.753186480054613749501868369407e-02 2.401186982114374146579649504929e-01 7.423494369880164756025919814419e-01
         	 1.842330033748984519093028211500e-02 4.086944595865063534212424656289e-01 5.728822400760038568989784835139e-01
         	 2.155788067250792305884488087031e-01 2.755611410714366438234890210879e-01 5.088600522034840700769109389512e-01
         	 1.022282063041801691838372789789e-01 3.311895891298100025323947193101e-01 5.665822045660098282837680017110e-01
         	 6.184382270264465741860249181627e-02 7.505363476334480088425493704563e-01 1.876198296639073059832725220986e-01
         	 1.387300119107129914297615869145e-01 6.203711602337613761903867271030e-01 2.408988278555256046242760703535e-01
         	 2.330092457336119249333705738536e-02 8.671079494311813018470047609298e-01 1.095911259954575334152337973137e-01
         	 4.720258929631782063296441265265e-02 6.516018514940782324629253707826e-01 3.011955592096039469041102165647e-01
         	 1.753186480054613749501868369407e-02 7.423494369880164756025919814419e-01 2.401186982114374146579649504929e-01
         	 1.842330033748984519093028211500e-02 5.728822400760038568989784835139e-01 4.086944595865063534212424656289e-01
         	 2.155788067250792305884488087031e-01 5.088600522034840700769109389512e-01 2.755611410714366438234890210879e-01
         	 1.022282063041801691838372789789e-01 5.665822045660098282837680017110e-01 3.311895891298100025323947193101e-01
         	 1.000000000000000000000000000000e+00 0.000000000000000000000000000000e+00 0.000000000000000000000000000000e+00
         	 0.000000000000000000000000000000e+00 1.000000000000000000000000000000e+00 0.000000000000000000000000000000e+00
         	 0.000000000000000000000000000000e+00 0.000000000000000000000000000000e+00 1.000000000000000000000000000000e+00
         	 2.003247736636959430711613094900e-02 9.799675226336304056928838690510e-01 0.000000000000000000000000000000e+00
         	 6.609947308482655436989716690732e-02 9.339005269151734456301028330927e-01 0.000000000000000000000000000000e+00
         	 1.355657004543369681393016890070e-01 8.644342995456630873718495422509e-01 0.000000000000000000000000000000e+00
         	 2.246802985356765591795635828021e-01 7.753197014643233853092851859401e-01 0.000000000000000000000000000000e+00
         	 3.286379933286436294537224966916e-01 6.713620066713563705462775033084e-01 0.000000000000000000000000000000e+00
         	 4.418340655581481368763263617438e-01 5.581659344418519186348248695140e-01 0.000000000000000000000000000000e+00
         	 5.581659344418519186348248695140e-01 4.418340655581480813651751304860e-01 0.000000000000000000000000000000e+00
         	 6.713620066713563705462775033084e-01 3.286379933286436294537224966916e-01 0.000000000000000000000000000000e+00
         	 7.753197014643234963315876484558e-01 2.246802985356765036684123515442e-01 0.000000000000000000000000000000e+00
         	 8.644342995456628653272446172195e-01 1.355657004543371346727553827805e-01 0.000000000000000000000000000000e+00
         	 9.339005269151735566524052956083e-01 6.609947308482644334759470439167e-02 0.000000000000000000000000000000e+00
         	 9.799675226336305167151863315667e-01 2.003247736636948328481366843334e-02 0.000000000000000000000000000000e+00
         	 2.003247736636959430711613094900e-02 0.000000000000000000000000000000e+00 9.799675226336304056928838690510e-01
         	 6.609947308482655436989716690732e-02 0.000000000000000000000000000000e+00 9.339005269151734456301028330927e-01
         	 1.355657004543369681393016890070e-01 0.000000000000000000000000000000e+00 8.644342995456630873718495422509e-01
         	 2.246802985356765591795635828021e-01 0.000000000000000000000000000000e+00 7.753197014643233853092851859401e-01
         	 3.286379933286436294537224966916e-01 0.000000000000000000000000000000e+00 6.713620066713563705462775033084e-01
         	 4.418340655581481368763263617438e-01 0.000000000000000000000000000000e+00 5.581659344418519186348248695140e-01
         	 5.581659344418519186348248695140e-01 0.000000000000000000000000000000e+00 4.418340655581480813651751304860e-01
         	 6.713620066713563705462775033084e-01 0.000000000000000000000000000000e+00 3.286379933286436294537224966916e-01
         	 7.753197014643234963315876484558e-01 0.000000000000000000000000000000e+00 2.246802985356765036684123515442e-01
         	 8.644342995456628653272446172195e-01 0.000000000000000000000000000000e+00 1.355657004543371346727553827805e-01
         	 9.339005269151735566524052956083e-01 0.000000000000000000000000000000e+00 6.609947308482644334759470439167e-02
         	 9.799675226336305167151863315667e-01 0.000000000000000000000000000000e+00 2.003247736636948328481366843334e-02
         	 0.000000000000000000000000000000e+00 2.003247736636959430711613094900e-02 9.799675226336304056928838690510e-01
         	 0.000000000000000000000000000000e+00 6.609947308482655436989716690732e-02 9.339005269151734456301028330927e-01
         	 0.000000000000000000000000000000e+00 1.355657004543369681393016890070e-01 8.644342995456630873718495422509e-01
         	 0.000000000000000000000000000000e+00 2.246802985356765591795635828021e-01 7.753197014643233853092851859401e-01
         	 0.000000000000000000000000000000e+00 3.286379933286436294537224966916e-01 6.713620066713563705462775033084e-01
         	 0.000000000000000000000000000000e+00 4.418340655581481368763263617438e-01 5.581659344418519186348248695140e-01
         	 0.000000000000000000000000000000e+00 5.581659344418519186348248695140e-01 4.418340655581480813651751304860e-01
         	 0.000000000000000000000000000000e+00 6.713620066713563705462775033084e-01 3.286379933286436294537224966916e-01
         	 0.000000000000000000000000000000e+00 7.753197014643234963315876484558e-01 2.246802985356765036684123515442e-01
         	 0.000000000000000000000000000000e+00 8.644342995456628653272446172195e-01 1.355657004543371346727553827805e-01
         	 0.000000000000000000000000000000e+00 9.339005269151735566524052956083e-01 6.609947308482644334759470439167e-02
         	 0.000000000000000000000000000000e+00 9.799675226336305167151863315667e-01 2.003247736636948328481366843334e-02
         	 ];


    case 14

    	 % PASSED (I).

     	 % DEGREE:  14
     	 % POINTS:    120
     	 % LEBESGUE CONSTANT: 8.81565e+00
     	 % DETERMINANT: -1.23824e+158
     	 % CONDITIONING: 4.80175e+02
     	 % MAX LAGRANGE POLYNOMIALS: 1.18945e+00
     	 % VANDERMONDE: ORTHONORMAL DUBINER LEGENDRE.

     	 table=[
       	  0	  6	 10
      	 ];

     	 t=[
         	 -7.441071552580138526167274903855e-01
         	 -4.370590658381633963891488292575e-01
         	 -1.898745115182994269709126911039e-01
         	 -7.588396379562431515175546792307e-02
         	 5.133881885531978994663404591847e-01
         	 2.508178536157142368701045143098e-01
         	 1.729675653246243449689956150905e-01
         	 3.933840203082858422156675715087e-01
         	 2.862719424775296284124692647310e-01
         	 5.221507463387965453094352596963e-01
         	 5.814281680883168768048108177027e-01
         	 1.269248707986142254977579568731e-01
         	 1.502977921404675121230809509143e-01
         	 3.536282765708248509994859887229e-01
         	 1.172372904225248146925508763161e-01
         	 7.986828797845805238964089767251e-01
         	 3.879538058021835822408718286169e-01
         	 1.896971773482414302947063333704e-01
         	 4.911651916141739349086492438801e-01
         	 2.529613015766049022303718629701e-01
         	 3.400441013036016868475996943744e-01
         	 6.825439368971152331866392160009e-01
         	 7.947682165115046437620094366139e-01
         	 5.733600400663640961340661306167e-01
         	 8.515888796240780878044063229027e-02
         	 1.113384598563587207786795829634e-01
         	 ];

     	 pts=[
         	 2.480357184193379416203839582522e-01 2.480357184193379416203839582522e-01 5.039285631613240612480808522378e-01
         	 1.456863552793877802926658659999e-01 1.456863552793877802926658659999e-01 7.086272894412243283923658054846e-01
         	 6.329150383943313307177902515832e-02 6.329150383943313307177902515832e-02 8.734169923211337893675931809412e-01
         	 2.529465459854143838391848930769e-02 2.529465459854143838391848930769e-02 9.494106908029170677210117901268e-01
         	 2.480357184193379416203839582522e-01 5.039285631613240612480808522378e-01 2.480357184193379416203839582522e-01
         	 1.456863552793877802926658659999e-01 7.086272894412243283923658054846e-01 1.456863552793877802926658659999e-01
         	 6.329150383943313307177902515832e-02 8.734169923211337893675931809412e-01 6.329150383943313307177902515832e-02
         	 2.529465459854143838391848930769e-02 9.494106908029170677210117901268e-01 2.529465459854143838391848930769e-02
         	 5.039285631613240612480808522378e-01 2.480357184193379416203839582522e-01 2.480357184193379416203839582522e-01
         	 7.086272894412243283923658054846e-01 1.456863552793877802926658659999e-01 1.456863552793877802926658659999e-01
         	 8.734169923211337893675931809412e-01 6.329150383943313307177902515832e-02 6.329150383943313307177902515832e-02
         	 9.494106908029170677210117901268e-01 2.529465459854143838391848930769e-02 2.529465459854143838391848930769e-02
         	 4.144353019078003130815091026307e-01 4.144353019078003130815091026307e-01 1.711293961843993738369817947387e-01
         	 4.581970243973809697735077861580e-01 4.581970243973809697735077861580e-01 8.360595120523806045298442768399e-02
         	 4.144353019078003130815091026307e-01 1.711293961843993738369817947387e-01 4.144353019078003130815091026307e-01
         	 4.581970243973809697735077861580e-01 8.360595120523806045298442768399e-02 4.581970243973809697735077861580e-01
         	 1.711293961843993738369817947387e-01 4.144353019078003130815091026307e-01 4.144353019078003130815091026307e-01
         	 8.360595120523806045298442768399e-02 4.581970243973809697735077861580e-01 4.581970243973809697735077861580e-01
         	 2.328433256200428402848956466187e-01 6.207971314222264780369187064935e-01 1.463595429577306816781856468879e-01
         	 3.356649442686338025154668684991e-01 5.253621216168752328101732018695e-01 1.389729341144909646743599296315e-01
         	 2.173235932081969412621447190759e-01 7.084887848223708761707939629559e-01 7.418762196943218256706131796818e-02
         	 3.360380238642644568081152556260e-01 5.889993254408694145496383498539e-01 7.496265069486618415339762577787e-02
         	 3.168899942468522690219856485783e-01 6.569340955504540113807365742105e-01 2.617591020269371959727777721127e-02
         	 1.269728328340639644800091900834e-01 8.095167697311791421554971748265e-01 6.351039743475683785334240383236e-02
         	 9.346022651957634763686399992366e-02 8.882284430310810607878124756098e-01 1.831133044934263320868694790988e-02
         	 2.011513660730161190404174931246e-01 7.745114061393802984412104706280e-01 2.433722778760361027394765187637e-02
         	 3.244865857496181948960156660178e-01 4.096454737120259759208806826791e-01 2.658679405383558291831036513031e-01
         	 4.293343266786438516824375710712e-01 5.406727865350026140944805774780e-01 2.999288678635358973423308270867e-02
         	 2.328433256200428402848956466187e-01 1.463595429577306816781856468879e-01 6.207971314222264780369187064935e-01
         	 3.356649442686338025154668684991e-01 1.389729341144909646743599296315e-01 5.253621216168752328101732018695e-01
         	 2.173235932081969412621447190759e-01 7.418762196943218256706131796818e-02 7.084887848223708761707939629559e-01
         	 3.360380238642644568081152556260e-01 7.496265069486618415339762577787e-02 5.889993254408694145496383498539e-01
         	 3.168899942468522690219856485783e-01 2.617591020269371959727777721127e-02 6.569340955504540113807365742105e-01
         	 1.269728328340639644800091900834e-01 6.351039743475683785334240383236e-02 8.095167697311791421554971748265e-01
         	 9.346022651957634763686399992366e-02 1.831133044934263320868694790988e-02 8.882284430310810607878124756098e-01
         	 2.011513660730161190404174931246e-01 2.433722778760361027394765187637e-02 7.745114061393802984412104706280e-01
         	 3.244865857496181948960156660178e-01 2.658679405383558291831036513031e-01 4.096454737120259759208806826791e-01
         	 4.293343266786438516824375710712e-01 2.999288678635358973423308270867e-02 5.406727865350026140944805774780e-01
         	 6.207971314222264780369187064935e-01 2.328433256200428402848956466187e-01 1.463595429577306816781856468879e-01
         	 5.253621216168752328101732018695e-01 3.356649442686338025154668684991e-01 1.389729341144909646743599296315e-01
         	 7.084887848223708761707939629559e-01 2.173235932081969412621447190759e-01 7.418762196943218256706131796818e-02
         	 5.889993254408694145496383498539e-01 3.360380238642644568081152556260e-01 7.496265069486618415339762577787e-02
         	 6.569340955504540113807365742105e-01 3.168899942468522690219856485783e-01 2.617591020269371959727777721127e-02
         	 8.095167697311791421554971748265e-01 1.269728328340639644800091900834e-01 6.351039743475683785334240383236e-02
         	 8.882284430310810607878124756098e-01 9.346022651957634763686399992366e-02 1.831133044934263320868694790988e-02
         	 7.745114061393802984412104706280e-01 2.011513660730161190404174931246e-01 2.433722778760361027394765187637e-02
         	 4.096454737120259759208806826791e-01 3.244865857496181948960156660178e-01 2.658679405383558291831036513031e-01
         	 5.406727865350026140944805774780e-01 4.293343266786438516824375710712e-01 2.999288678635358973423308270867e-02
         	 6.207971314222264780369187064935e-01 1.463595429577306816781856468879e-01 2.328433256200428402848956466187e-01
         	 5.253621216168752328101732018695e-01 1.389729341144909646743599296315e-01 3.356649442686338025154668684991e-01
         	 7.084887848223708761707939629559e-01 7.418762196943218256706131796818e-02 2.173235932081969412621447190759e-01
         	 5.889993254408694145496383498539e-01 7.496265069486618415339762577787e-02 3.360380238642644568081152556260e-01
         	 6.569340955504540113807365742105e-01 2.617591020269371959727777721127e-02 3.168899942468522690219856485783e-01
         	 8.095167697311791421554971748265e-01 6.351039743475683785334240383236e-02 1.269728328340639644800091900834e-01
         	 8.882284430310810607878124756098e-01 1.831133044934263320868694790988e-02 9.346022651957634763686399992366e-02
         	 7.745114061393802984412104706280e-01 2.433722778760361027394765187637e-02 2.011513660730161190404174931246e-01
         	 4.096454737120259759208806826791e-01 2.658679405383558291831036513031e-01 3.244865857496181948960156660178e-01
         	 5.406727865350026140944805774780e-01 2.999288678635358973423308270867e-02 4.293343266786438516824375710712e-01
         	 1.463595429577306816781856468879e-01 2.328433256200428402848956466187e-01 6.207971314222264780369187064935e-01
         	 1.389729341144909646743599296315e-01 3.356649442686338025154668684991e-01 5.253621216168752328101732018695e-01
         	 7.418762196943218256706131796818e-02 2.173235932081969412621447190759e-01 7.084887848223708761707939629559e-01
         	 7.496265069486618415339762577787e-02 3.360380238642644568081152556260e-01 5.889993254408694145496383498539e-01
         	 2.617591020269371959727777721127e-02 3.168899942468522690219856485783e-01 6.569340955504540113807365742105e-01
         	 6.351039743475683785334240383236e-02 1.269728328340639644800091900834e-01 8.095167697311791421554971748265e-01
         	 1.831133044934263320868694790988e-02 9.346022651957634763686399992366e-02 8.882284430310810607878124756098e-01
         	 2.433722778760361027394765187637e-02 2.011513660730161190404174931246e-01 7.745114061393802984412104706280e-01
         	 2.658679405383558291831036513031e-01 3.244865857496181948960156660178e-01 4.096454737120259759208806826791e-01
         	 2.999288678635358973423308270867e-02 4.293343266786438516824375710712e-01 5.406727865350026140944805774780e-01
         	 1.463595429577306816781856468879e-01 6.207971314222264780369187064935e-01 2.328433256200428402848956466187e-01
         	 1.389729341144909646743599296315e-01 5.253621216168752328101732018695e-01 3.356649442686338025154668684991e-01
         	 7.418762196943218256706131796818e-02 7.084887848223708761707939629559e-01 2.173235932081969412621447190759e-01
         	 7.496265069486618415339762577787e-02 5.889993254408694145496383498539e-01 3.360380238642644568081152556260e-01
         	 2.617591020269371959727777721127e-02 6.569340955504540113807365742105e-01 3.168899942468522690219856485783e-01
         	 6.351039743475683785334240383236e-02 8.095167697311791421554971748265e-01 1.269728328340639644800091900834e-01
         	 1.831133044934263320868694790988e-02 8.882284430310810607878124756098e-01 9.346022651957634763686399992366e-02
         	 2.433722778760361027394765187637e-02 7.745114061393802984412104706280e-01 2.011513660730161190404174931246e-01
         	 2.658679405383558291831036513031e-01 4.096454737120259759208806826791e-01 3.244865857496181948960156660178e-01
         	 2.999288678635358973423308270867e-02 5.406727865350026140944805774780e-01 4.293343266786438516824375710712e-01
         	 1.000000000000000000000000000000e+00 0.000000000000000000000000000000e+00 0.000000000000000000000000000000e+00
         	 0.000000000000000000000000000000e+00 1.000000000000000000000000000000e+00 0.000000000000000000000000000000e+00
         	 0.000000000000000000000000000000e+00 0.000000000000000000000000000000e+00 1.000000000000000000000000000000e+00
         	 1.737703674808060982925894677464e-02 9.826229632519194456818922844832e-01 0.000000000000000000000000000000e+00
         	 5.745897788851178633606764378783e-02 9.425410221114882691750835874700e-01 0.000000000000000000000000000000e+00
         	 1.182401550240923526757796935271e-01 8.817598449759076473242203064729e-01 0.000000000000000000000000000000e+00
         	 1.968733972650772989787526512373e-01 8.031266027349226455100961175049e-01 0.000000000000000000000000000000e+00
         	 2.896809726431638365440335292078e-01 7.103190273568361634559664707922e-01 0.000000000000000000000000000000e+00
         	 3.923230223181028986090268517728e-01 6.076769776818971013909731482272e-01 0.000000000000000000000000000000e+00
         	 4.999999999999998889776975374843e-01 5.000000000000001110223024625157e-01 0.000000000000000000000000000000e+00
         	 6.076769776818971013909731482272e-01 3.923230223181028986090268517728e-01 0.000000000000000000000000000000e+00
         	 7.103190273568363855005713958235e-01 2.896809726431636144994286041765e-01 0.000000000000000000000000000000e+00
         	 8.031266027349228675547010425362e-01 1.968733972650771324452989574638e-01 0.000000000000000000000000000000e+00
         	 8.817598449759076473242203064729e-01 1.182401550240923526757796935271e-01 0.000000000000000000000000000000e+00
         	 9.425410221114880471304786624387e-01 5.745897788851195286952133756131e-02 0.000000000000000000000000000000e+00
         	 9.826229632519192236372873594519e-01 1.737703674808077636271264054812e-02 0.000000000000000000000000000000e+00
         	 1.737703674808060982925894677464e-02 0.000000000000000000000000000000e+00 9.826229632519194456818922844832e-01
         	 5.745897788851178633606764378783e-02 0.000000000000000000000000000000e+00 9.425410221114882691750835874700e-01
         	 1.182401550240923526757796935271e-01 0.000000000000000000000000000000e+00 8.817598449759076473242203064729e-01
         	 1.968733972650772989787526512373e-01 0.000000000000000000000000000000e+00 8.031266027349226455100961175049e-01
         	 2.896809726431638365440335292078e-01 0.000000000000000000000000000000e+00 7.103190273568361634559664707922e-01
         	 3.923230223181028986090268517728e-01 0.000000000000000000000000000000e+00 6.076769776818971013909731482272e-01
         	 4.999999999999998889776975374843e-01 0.000000000000000000000000000000e+00 5.000000000000001110223024625157e-01
         	 6.076769776818971013909731482272e-01 0.000000000000000000000000000000e+00 3.923230223181028986090268517728e-01
         	 7.103190273568363855005713958235e-01 0.000000000000000000000000000000e+00 2.896809726431636144994286041765e-01
         	 8.031266027349228675547010425362e-01 0.000000000000000000000000000000e+00 1.968733972650771324452989574638e-01
         	 8.817598449759076473242203064729e-01 0.000000000000000000000000000000e+00 1.182401550240923526757796935271e-01
         	 9.425410221114880471304786624387e-01 0.000000000000000000000000000000e+00 5.745897788851195286952133756131e-02
         	 9.826229632519192236372873594519e-01 0.000000000000000000000000000000e+00 1.737703674808077636271264054812e-02
         	 0.000000000000000000000000000000e+00 1.737703674808060982925894677464e-02 9.826229632519194456818922844832e-01
         	 0.000000000000000000000000000000e+00 5.745897788851178633606764378783e-02 9.425410221114882691750835874700e-01
         	 0.000000000000000000000000000000e+00 1.182401550240923526757796935271e-01 8.817598449759076473242203064729e-01
         	 0.000000000000000000000000000000e+00 1.968733972650772989787526512373e-01 8.031266027349226455100961175049e-01
         	 0.000000000000000000000000000000e+00 2.896809726431638365440335292078e-01 7.103190273568361634559664707922e-01
         	 0.000000000000000000000000000000e+00 3.923230223181028986090268517728e-01 6.076769776818971013909731482272e-01
         	 0.000000000000000000000000000000e+00 4.999999999999998889776975374843e-01 5.000000000000001110223024625157e-01
         	 0.000000000000000000000000000000e+00 6.076769776818971013909731482272e-01 3.923230223181028986090268517728e-01
         	 0.000000000000000000000000000000e+00 7.103190273568363855005713958235e-01 2.896809726431636144994286041765e-01
         	 0.000000000000000000000000000000e+00 8.031266027349228675547010425362e-01 1.968733972650771324452989574638e-01
         	 0.000000000000000000000000000000e+00 8.817598449759076473242203064729e-01 1.182401550240923526757796935271e-01
         	 0.000000000000000000000000000000e+00 9.425410221114880471304786624387e-01 5.745897788851195286952133756131e-02
         	 0.000000000000000000000000000000e+00 9.826229632519192236372873594519e-01 1.737703674808077636271264054812e-02
         	 ];


    case 15

    	 % PASSED (I).

     	 % DEGREE:  15
     	 % POINTS:    136
     	 % LEBESGUE CONSTANT: 8.90865e+00
     	 % DETERMINANT: 9.40546e+182
     	 % CONDITIONING: 3.96741e+02
     	 % MAX LAGRANGE POLYNOMIALS: 1.09615e+00
     	 % VANDERMONDE: ORTHONORMAL DUBINER LEGENDRE.

     	 table=[
       	  1	  6	 12
      	 ];

     	 t=[
         	 -6.779662526595973959242513728896e-02
         	 -1.901325758944922561521906345661e-01
         	 1.390892255871944427347841610754e-01
         	 5.188545465751882579397147310374e-01
         	 3.149931944041688969271319820109e-01
         	 -3.899988324408221185279899145826e-01
         	 1.258908505699949664791148506993e-01
         	 3.802482712786670604465655287640e-01
         	 5.375490541605270067293531610630e-01
         	 1.299776224883950614952254909440e-01
         	 3.990407540556031307232842664234e-01
         	 8.112172480820292186365350062260e-01
         	 6.095340495976080408269126564846e-01
         	 2.746813164284478969712210982834e-01
         	 1.370823733755393014632772974437e-01
         	 1.340985227812930280499870150379e-01
         	 1.904789645253745222763797073640e-01
         	 3.264589186934468978407153372245e-01
         	 4.676310307765571550042693615978e-01
         	 3.781463579452308265693716293754e-01
         	 3.903523752846169703190071231802e-01
         	 2.764189460367958983688652097044e-01
         	 2.221475276953975841465194207558e-01
         	 1.412719653723670809597479092190e-01
         	 2.296469331724597939814458413821e-01
         	 5.559489069918303050243935103936e-01
         	 7.087263018987821627803214141750e-01
         	 8.121089027806501770001545992272e-01
         	 1.176581306940397975147050146916e-01
         	 6.244150851351933928512494276220e-01
         	 ];

     	 pts=[
         	 3.333333333333333148296162562474e-01 3.333333333333333148296162562474e-01 3.333333333333333148296162562474e-01
         	 2.259887508865324537432606177845e-02 2.259887508865324537432606177845e-02 9.548022498226934606790905490925e-01
         	 6.337752529816408075813427558387e-02 6.337752529816408075813427558387e-02 8.732449494036718107281558332033e-01
         	 1.299996108136073635908047663179e-01 1.299996108136073635908047663179e-01 7.400007783727852173072392361064e-01
         	 2.259887508865324537432606177845e-02 9.548022498226934606790905490925e-01 2.259887508865324537432606177845e-02
         	 6.337752529816408075813427558387e-02 8.732449494036718107281558332033e-01 6.337752529816408075813427558387e-02
         	 1.299996108136073635908047663179e-01 7.400007783727852173072392361064e-01 1.299996108136073635908047663179e-01
         	 9.548022498226934606790905490925e-01 2.259887508865324537432606177845e-02 2.259887508865324537432606177845e-02
         	 8.732449494036718107281558332033e-01 6.337752529816408075813427558387e-02 6.337752529816408075813427558387e-02
         	 7.400007783727852173072392361064e-01 1.299996108136073635908047663179e-01 1.299996108136073635908047663179e-01
         	 4.768184624021342132849099471059e-01 4.768184624021342132849099471059e-01 4.636307519573157343018010578817e-02
         	 4.135242422374686421804312885797e-01 4.135242422374686421804312885797e-01 1.729515155250627156391374228406e-01
         	 4.475011342659718782677202852938e-01 4.475011342659718782677202852938e-01 1.049977314680562434645594294125e-01
         	 4.768184624021342132849099471059e-01 4.636307519573157343018010578817e-02 4.768184624021342132849099471059e-01
         	 4.135242422374686421804312885797e-01 1.729515155250627156391374228406e-01 4.135242422374686421804312885797e-01
         	 4.475011342659718782677202852938e-01 1.049977314680562434645594294125e-01 4.475011342659718782677202852938e-01
         	 4.636307519573157343018010578817e-02 4.768184624021342132849099471059e-01 4.768184624021342132849099471059e-01
         	 1.729515155250627156391374228406e-01 4.135242422374686421804312885797e-01 4.135242422374686421804312885797e-01
         	 1.049977314680562434645594294125e-01 4.475011342659718782677202852938e-01 4.475011342659718782677202852938e-01
         	 1.984381315028134196154496748932e-01 6.660691622793706301308702677488e-01 1.354927062178159502536800573580e-01
         	 2.706592592313675771364955835452e-01 6.488056171765984592170184441784e-01 8.053512359203396364648597227642e-02
         	 2.928073839318821591781727420312e-01 6.831597592164991850083310964692e-01 2.403285685161871132464739275747e-02
         	 2.628566217358005441262491785892e-01 5.392755677725964424951143882936e-01 1.978678104916029578674852018594e-01
         	 3.257909497774679752346571603994e-01 5.479384774728655038700253498973e-01 1.262705727496664653841662584455e-01
         	 4.214455528895491576157894542121e-01 5.627175182619162940866885946889e-01 1.583692884853460380867318235687e-02
         	 3.583733638754480477217612133245e-01 5.880202970479078139476314390777e-01 5.360633907664413833060734759783e-02
         	 1.937972504074645663241227566687e-01 7.497461573992948435929406514333e-01 5.645659219324061783851220752695e-02
         	 1.199382949296624867319138729727e-01 8.286645968284446217566596715187e-01 5.139710824189291926700207113754e-02
         	 8.498011953666545492680484130688e-02 8.970890223173155764158082092763e-01 1.793085814601891314623571815901e-02
         	 3.258604505228824832485656770587e-01 4.435185812169222807632706917502e-01 2.306209682601952359881636311911e-01
         	 1.796047914038433612748946188731e-01 8.040198765390368373928708933818e-01 1.637533205711982908781010337407e-02
         	 1.984381315028134196154496748932e-01 1.354927062178159502536800573580e-01 6.660691622793706301308702677488e-01
         	 2.706592592313675771364955835452e-01 8.053512359203396364648597227642e-02 6.488056171765984592170184441784e-01
         	 2.928073839318821591781727420312e-01 2.403285685161871132464739275747e-02 6.831597592164991850083310964692e-01
         	 2.628566217358005441262491785892e-01 1.978678104916029578674852018594e-01 5.392755677725964424951143882936e-01
         	 3.257909497774679752346571603994e-01 1.262705727496664653841662584455e-01 5.479384774728655038700253498973e-01
         	 4.214455528895491576157894542121e-01 1.583692884853460380867318235687e-02 5.627175182619162940866885946889e-01
         	 3.583733638754480477217612133245e-01 5.360633907664413833060734759783e-02 5.880202970479078139476314390777e-01
         	 1.937972504074645663241227566687e-01 5.645659219324061783851220752695e-02 7.497461573992948435929406514333e-01
         	 1.199382949296624867319138729727e-01 5.139710824189291926700207113754e-02 8.286645968284446217566596715187e-01
         	 8.498011953666545492680484130688e-02 1.793085814601891314623571815901e-02 8.970890223173155764158082092763e-01
         	 3.258604505228824832485656770587e-01 2.306209682601952359881636311911e-01 4.435185812169222807632706917502e-01
         	 1.796047914038433612748946188731e-01 1.637533205711982908781010337407e-02 8.040198765390368373928708933818e-01
         	 6.660691622793706301308702677488e-01 1.984381315028134196154496748932e-01 1.354927062178159502536800573580e-01
         	 6.488056171765984592170184441784e-01 2.706592592313675771364955835452e-01 8.053512359203396364648597227642e-02
         	 6.831597592164991850083310964692e-01 2.928073839318821591781727420312e-01 2.403285685161871132464739275747e-02
         	 5.392755677725964424951143882936e-01 2.628566217358005441262491785892e-01 1.978678104916029578674852018594e-01
         	 5.479384774728655038700253498973e-01 3.257909497774679752346571603994e-01 1.262705727496664653841662584455e-01
         	 5.627175182619162940866885946889e-01 4.214455528895491576157894542121e-01 1.583692884853460380867318235687e-02
         	 5.880202970479078139476314390777e-01 3.583733638754480477217612133245e-01 5.360633907664413833060734759783e-02
         	 7.497461573992948435929406514333e-01 1.937972504074645663241227566687e-01 5.645659219324061783851220752695e-02
         	 8.286645968284446217566596715187e-01 1.199382949296624867319138729727e-01 5.139710824189291926700207113754e-02
         	 8.970890223173155764158082092763e-01 8.498011953666545492680484130688e-02 1.793085814601891314623571815901e-02
         	 4.435185812169222807632706917502e-01 3.258604505228824832485656770587e-01 2.306209682601952359881636311911e-01
         	 8.040198765390368373928708933818e-01 1.796047914038433612748946188731e-01 1.637533205711982908781010337407e-02
         	 6.660691622793706301308702677488e-01 1.354927062178159502536800573580e-01 1.984381315028134196154496748932e-01
         	 6.488056171765984592170184441784e-01 8.053512359203396364648597227642e-02 2.706592592313675771364955835452e-01
         	 6.831597592164991850083310964692e-01 2.403285685161871132464739275747e-02 2.928073839318821591781727420312e-01
         	 5.392755677725964424951143882936e-01 1.978678104916029578674852018594e-01 2.628566217358005441262491785892e-01
         	 5.479384774728655038700253498973e-01 1.262705727496664653841662584455e-01 3.257909497774679752346571603994e-01
         	 5.627175182619162940866885946889e-01 1.583692884853460380867318235687e-02 4.214455528895491576157894542121e-01
         	 5.880202970479078139476314390777e-01 5.360633907664413833060734759783e-02 3.583733638754480477217612133245e-01
         	 7.497461573992948435929406514333e-01 5.645659219324061783851220752695e-02 1.937972504074645663241227566687e-01
         	 8.286645968284446217566596715187e-01 5.139710824189291926700207113754e-02 1.199382949296624867319138729727e-01
         	 8.970890223173155764158082092763e-01 1.793085814601891314623571815901e-02 8.498011953666545492680484130688e-02
         	 4.435185812169222807632706917502e-01 2.306209682601952359881636311911e-01 3.258604505228824832485656770587e-01
         	 8.040198765390368373928708933818e-01 1.637533205711982908781010337407e-02 1.796047914038433612748946188731e-01
         	 1.354927062178159502536800573580e-01 1.984381315028134196154496748932e-01 6.660691622793706301308702677488e-01
         	 8.053512359203396364648597227642e-02 2.706592592313675771364955835452e-01 6.488056171765984592170184441784e-01
         	 2.403285685161871132464739275747e-02 2.928073839318821591781727420312e-01 6.831597592164991850083310964692e-01
         	 1.978678104916029578674852018594e-01 2.628566217358005441262491785892e-01 5.392755677725964424951143882936e-01
         	 1.262705727496664653841662584455e-01 3.257909497774679752346571603994e-01 5.479384774728655038700253498973e-01
         	 1.583692884853460380867318235687e-02 4.214455528895491576157894542121e-01 5.627175182619162940866885946889e-01
         	 5.360633907664413833060734759783e-02 3.583733638754480477217612133245e-01 5.880202970479078139476314390777e-01
         	 5.645659219324061783851220752695e-02 1.937972504074645663241227566687e-01 7.497461573992948435929406514333e-01
         	 5.139710824189291926700207113754e-02 1.199382949296624867319138729727e-01 8.286645968284446217566596715187e-01
         	 1.793085814601891314623571815901e-02 8.498011953666545492680484130688e-02 8.970890223173155764158082092763e-01
         	 2.306209682601952359881636311911e-01 3.258604505228824832485656770587e-01 4.435185812169222807632706917502e-01
         	 1.637533205711982908781010337407e-02 1.796047914038433612748946188731e-01 8.040198765390368373928708933818e-01
         	 1.354927062178159502536800573580e-01 6.660691622793706301308702677488e-01 1.984381315028134196154496748932e-01
         	 8.053512359203396364648597227642e-02 6.488056171765984592170184441784e-01 2.706592592313675771364955835452e-01
         	 2.403285685161871132464739275747e-02 6.831597592164991850083310964692e-01 2.928073839318821591781727420312e-01
         	 1.978678104916029578674852018594e-01 5.392755677725964424951143882936e-01 2.628566217358005441262491785892e-01
         	 1.262705727496664653841662584455e-01 5.479384774728655038700253498973e-01 3.257909497774679752346571603994e-01
         	 1.583692884853460380867318235687e-02 5.627175182619162940866885946889e-01 4.214455528895491576157894542121e-01
         	 5.360633907664413833060734759783e-02 5.880202970479078139476314390777e-01 3.583733638754480477217612133245e-01
         	 5.645659219324061783851220752695e-02 7.497461573992948435929406514333e-01 1.937972504074645663241227566687e-01
         	 5.139710824189291926700207113754e-02 8.286645968284446217566596715187e-01 1.199382949296624867319138729727e-01
         	 1.793085814601891314623571815901e-02 8.970890223173155764158082092763e-01 8.498011953666545492680484130688e-02
         	 2.306209682601952359881636311911e-01 4.435185812169222807632706917502e-01 3.258604505228824832485656770587e-01
         	 1.637533205711982908781010337407e-02 8.040198765390368373928708933818e-01 1.796047914038433612748946188731e-01
         	 1.000000000000000000000000000000e+00 0.000000000000000000000000000000e+00 0.000000000000000000000000000000e+00
         	 0.000000000000000000000000000000e+00 1.000000000000000000000000000000e+00 0.000000000000000000000000000000e+00
         	 0.000000000000000000000000000000e+00 0.000000000000000000000000000000e+00 1.000000000000000000000000000000e+00
         	 1.521597686489117862151942972559e-02 9.847840231351088213784805702744e-01 0.000000000000000000000000000000e+00
         	 5.039973345326398401766709866934e-02 9.496002665467360159823329013307e-01 0.000000000000000000000000000000e+00
         	 1.039958540690923416427438041865e-01 8.960041459309076028461049645557e-01 0.000000000000000000000000000000e+00
         	 1.738056485587534116810104478645e-01 8.261943514412466438301407833933e-01 0.000000000000000000000000000000e+00
         	 2.569702890564312669496871421870e-01 7.430297109435687330503128578130e-01 0.000000000000000000000000000000e+00
         	 3.500847655496184263057557473076e-01 6.499152344503815736942442526924e-01 0.000000000000000000000000000000e+00
         	 4.493368632390252193076207731792e-01 5.506631367609747806923792268208e-01 0.000000000000000000000000000000e+00
         	 5.506631367609745586477743017895e-01 4.493368632390254413522256982105e-01 0.000000000000000000000000000000e+00
         	 6.499152344503815736942442526924e-01 3.500847655496184263057557473076e-01 0.000000000000000000000000000000e+00
         	 7.430297109435688440726153203286e-01 2.569702890564311559273846796714e-01 0.000000000000000000000000000000e+00
         	 8.261943514412466438301407833933e-01 1.738056485587533561698592166067e-01 0.000000000000000000000000000000e+00
         	 8.960041459309076028461049645557e-01 1.039958540690923971538950354443e-01 0.000000000000000000000000000000e+00
         	 9.496002665467360159823329013307e-01 5.039973345326398401766709866934e-02 0.000000000000000000000000000000e+00
         	 9.847840231351090434230854953057e-01 1.521597686489095657691450469429e-02 0.000000000000000000000000000000e+00
         	 1.521597686489117862151942972559e-02 0.000000000000000000000000000000e+00 9.847840231351088213784805702744e-01
         	 5.039973345326398401766709866934e-02 0.000000000000000000000000000000e+00 9.496002665467360159823329013307e-01
         	 1.039958540690923416427438041865e-01 0.000000000000000000000000000000e+00 8.960041459309076028461049645557e-01
         	 1.738056485587534116810104478645e-01 0.000000000000000000000000000000e+00 8.261943514412466438301407833933e-01
         	 2.569702890564312669496871421870e-01 0.000000000000000000000000000000e+00 7.430297109435687330503128578130e-01
         	 3.500847655496184263057557473076e-01 0.000000000000000000000000000000e+00 6.499152344503815736942442526924e-01
         	 4.493368632390252193076207731792e-01 0.000000000000000000000000000000e+00 5.506631367609747806923792268208e-01
         	 5.506631367609745586477743017895e-01 0.000000000000000000000000000000e+00 4.493368632390254413522256982105e-01
         	 6.499152344503815736942442526924e-01 0.000000000000000000000000000000e+00 3.500847655496184263057557473076e-01
         	 7.430297109435688440726153203286e-01 0.000000000000000000000000000000e+00 2.569702890564311559273846796714e-01
         	 8.261943514412466438301407833933e-01 0.000000000000000000000000000000e+00 1.738056485587533561698592166067e-01
         	 8.960041459309076028461049645557e-01 0.000000000000000000000000000000e+00 1.039958540690923971538950354443e-01
         	 9.496002665467360159823329013307e-01 0.000000000000000000000000000000e+00 5.039973345326398401766709866934e-02
         	 9.847840231351090434230854953057e-01 0.000000000000000000000000000000e+00 1.521597686489095657691450469429e-02
         	 0.000000000000000000000000000000e+00 1.521597686489117862151942972559e-02 9.847840231351088213784805702744e-01
         	 0.000000000000000000000000000000e+00 5.039973345326398401766709866934e-02 9.496002665467360159823329013307e-01
         	 0.000000000000000000000000000000e+00 1.039958540690923416427438041865e-01 8.960041459309076028461049645557e-01
         	 0.000000000000000000000000000000e+00 1.738056485587534116810104478645e-01 8.261943514412466438301407833933e-01
         	 0.000000000000000000000000000000e+00 2.569702890564312669496871421870e-01 7.430297109435687330503128578130e-01
         	 0.000000000000000000000000000000e+00 3.500847655496184263057557473076e-01 6.499152344503815736942442526924e-01
         	 0.000000000000000000000000000000e+00 4.493368632390252193076207731792e-01 5.506631367609747806923792268208e-01
         	 0.000000000000000000000000000000e+00 5.506631367609745586477743017895e-01 4.493368632390254413522256982105e-01
         	 0.000000000000000000000000000000e+00 6.499152344503815736942442526924e-01 3.500847655496184263057557473076e-01
         	 0.000000000000000000000000000000e+00 7.430297109435688440726153203286e-01 2.569702890564311559273846796714e-01
         	 0.000000000000000000000000000000e+00 8.261943514412466438301407833933e-01 1.738056485587533561698592166067e-01
         	 0.000000000000000000000000000000e+00 8.960041459309076028461049645557e-01 1.039958540690923971538950354443e-01
         	 0.000000000000000000000000000000e+00 9.496002665467360159823329013307e-01 5.039973345326398401766709866934e-02
         	 0.000000000000000000000000000000e+00 9.847840231351090434230854953057e-01 1.521597686489095657691450469429e-02
         	 ];


    case 16

    	 % PASSED (I).

     	 % DEGREE:  16
     	 % POINTS:    153
     	 % LEBESGUE CONSTANT: 1.06553e+01
     	 % DETERMINANT: 1.73095e+208
     	 % CONDITIONING: 4.54660e+02
     	 % MAX LAGRANGE POLYNOMIALS: 1.18671e+00
     	 % VANDERMONDE: ORTHONORMAL DUBINER LEGENDRE.

     	 table=[
       	  0	  7	 14
      	 ];

     	 t=[
         	 -1.386813309160902507599644195579e-01
         	 4.345237531952573228899439072848e-01
         	 -7.897140499425412407674684800440e-01
         	 -7.847186455357577083979947474290e-02
         	 -4.466364983870534377530248093535e-01
         	 1.354921760116263307338613230968e-01
         	 8.507496293637359929817876036395e-01
         	 6.443917951594017035077399668808e-01
         	 8.341286608456023321522820879181e-01
         	 3.733958714737301565200766617636e-01
         	 5.655806571967766371855645957112e-01
         	 1.330924751862326282925153009273e-01
         	 1.150562467841659969325363022108e-01
         	 4.020918527511314066735792494001e-01
         	 2.737686691168589314671066858864e-01
         	 5.760233324065455740026209241478e-01
         	 3.684504687222819319103450652619e-01
         	 7.316655092862753284599364178575e-02
         	 1.492860719228684407422491631223e-01
         	 2.140361897090985177083410917476e-01
         	 2.917900811042159481267788123660e-01
         	 1.111774635291003787695984783568e-01
         	 1.116091850898671827829744529481e-01
         	 2.307897154948814200103868188307e-01
         	 2.696163634642108619665634705598e-01
         	 8.353608947224058223213205565116e-01
         	 3.544534894981766770527542576019e-01
         	 5.655181370012251074186337973515e-01
         	 1.141516663927263780520249270012e-01
         	 3.487486652614146809270323501551e-01
         	 5.137715598157043261906551379070e-01
         	 7.132773123610302024033558154770e-01
         	 6.056133536549000995208302811079e-01
         	 7.015805680215447814873641618760e-01
         	 4.317792005857310488892153443885e-01
         	 ];

     	 pts=[
         	 5.284047111616667347089304485053e-02 5.284047111616667347089304485053e-02 8.943190577676666253026382946700e-01
         	 2.645455243559301505840153367899e-01 2.645455243559301505840153367899e-01 4.709089512881395878096668639046e-01
         	 2.559645338426510055573892543634e-02 2.559645338426510055573892543634e-02 9.488070932314697225606892061478e-01
         	 1.499953744415702394654488216474e-01 1.499953744415702394654488216474e-01 7.000092511168594100467998941895e-01
         	 5.284047111616667347089304485053e-02 8.943190577676666253026382946700e-01 5.284047111616667347089304485053e-02
         	 2.645455243559301505840153367899e-01 4.709089512881395878096668639046e-01 2.645455243559301505840153367899e-01
         	 2.559645338426510055573892543634e-02 9.488070932314697225606892061478e-01 2.559645338426510055573892543634e-02
         	 1.499953744415702394654488216474e-01 7.000092511168594100467998941895e-01 1.499953744415702394654488216474e-01
         	 8.943190577676666253026382946700e-01 5.284047111616667347089304485053e-02 5.284047111616667347089304485053e-02
         	 4.709089512881395878096668639046e-01 2.645455243559301505840153367899e-01 2.645455243559301505840153367899e-01
         	 9.488070932314697225606892061478e-01 2.559645338426510055573892543634e-02 2.559645338426510055573892543634e-02
         	 7.000092511168594100467998941895e-01 1.499953744415702394654488216474e-01 1.499953744415702394654488216474e-01
         	 4.283192720111305140662238954974e-01 4.283192720111305140662238954974e-01 1.433614559777389718675522090052e-01
         	 4.772486744600083485856600873376e-01 4.772486744600083485856600873376e-01 4.550265107998330282867982532480e-02
         	 3.590252375678640861522694649466e-01 3.590252375678640861522694649466e-01 2.819495248642718276954610701068e-01
         	 4.283192720111305140662238954974e-01 1.433614559777389718675522090052e-01 4.283192720111305140662238954974e-01
         	 4.772486744600083485856600873376e-01 4.550265107998330282867982532480e-02 4.772486744600083485856600873376e-01
         	 3.590252375678640861522694649466e-01 2.819495248642718276954610701068e-01 3.590252375678640861522694649466e-01
         	 1.433614559777389718675522090052e-01 4.283192720111305140662238954974e-01 4.283192720111305140662238954974e-01
         	 4.550265107998330282867982532480e-02 4.772486744600083485856600873376e-01 4.772486744600083485856600873376e-01
         	 2.819495248642718276954610701068e-01 3.590252375678640861522694649466e-01 3.590252375678640861522694649466e-01
         	 4.064266340483982387077332987246e-01 5.139836528036283436193798479508e-01 7.958971314797347318403808458243e-02
         	 4.408916140714010389878296791721e-01 5.391596382131452758201817232475e-01 1.994874771545374070313982883818e-02
         	 3.155166619585914600243370387034e-01 5.566613706105387748834800731856e-01 1.278219674308698206033341193688e-01
         	 3.329777549008310910672037152835e-01 6.152305573515951531149426045886e-01 5.179168774757381132900491138571e-02
         	 7.665376588027764115373940967402e-02 9.117800275056731074130311753834e-01 1.156620661404927918880503057153e-02
         	 2.338026098230794047605485275199e-01 5.863699513874213176123362245562e-01 1.798274387894992498715396322950e-01
         	 2.147217887957071080773374660566e-01 7.742669553673616755773423392384e-01 1.101125583693118858974457907607e-02
         	 3.367659421500994731957234762376e-01 4.592838884885920847089835206134e-01 2.039501693613084420952930031490e-01
         	 3.119742262865882742595147192333e-01 6.662160116048213565065339025750e-01 2.180976210859031372280014693388e-02
         	 2.225573376197091668426963906313e-01 7.378559340872877791994710605650e-01 3.958672829300302620225693317479e-02
         	 1.042596010644970400127462539785e-01 8.219786509556015197119904769352e-01 7.376174797990142639747546127182e-02
         	 1.553621225506644498715047575388e-01 7.636963728963229725010819493036e-01 8.094150455301252211626206189976e-02
         	 1.378422477974028392821992383688e-01 8.352850255545913871202401423943e-01 2.687272664800577359756061923690e-02
         	 2.315357275962031946558994377483e-01 6.738457052373849620607870747335e-01 9.461856716641181552773787188926e-02
         	 4.064266340483982387077332987246e-01 7.958971314797347318403808458243e-02 5.139836528036283436193798479508e-01
         	 4.408916140714010389878296791721e-01 1.994874771545374070313982883818e-02 5.391596382131452758201817232475e-01
         	 3.155166619585914600243370387034e-01 1.278219674308698206033341193688e-01 5.566613706105387748834800731856e-01
         	 3.329777549008310910672037152835e-01 5.179168774757381132900491138571e-02 6.152305573515951531149426045886e-01
         	 7.665376588027764115373940967402e-02 1.156620661404927918880503057153e-02 9.117800275056731074130311753834e-01
         	 2.338026098230794047605485275199e-01 1.798274387894992498715396322950e-01 5.863699513874213176123362245562e-01
         	 2.147217887957071080773374660566e-01 1.101125583693118858974457907607e-02 7.742669553673616755773423392384e-01
         	 3.367659421500994731957234762376e-01 2.039501693613084420952930031490e-01 4.592838884885920847089835206134e-01
         	 3.119742262865882742595147192333e-01 2.180976210859031372280014693388e-02 6.662160116048213565065339025750e-01
         	 2.225573376197091668426963906313e-01 3.958672829300302620225693317479e-02 7.378559340872877791994710605650e-01
         	 1.042596010644970400127462539785e-01 7.376174797990142639747546127182e-02 8.219786509556015197119904769352e-01
         	 1.553621225506644498715047575388e-01 8.094150455301252211626206189976e-02 7.636963728963229725010819493036e-01
         	 1.378422477974028392821992383688e-01 2.687272664800577359756061923690e-02 8.352850255545913871202401423943e-01
         	 2.315357275962031946558994377483e-01 9.461856716641181552773787188926e-02 6.738457052373849620607870747335e-01
         	 5.139836528036283436193798479508e-01 4.064266340483982387077332987246e-01 7.958971314797347318403808458243e-02
         	 5.391596382131452758201817232475e-01 4.408916140714010389878296791721e-01 1.994874771545374070313982883818e-02
         	 5.566613706105387748834800731856e-01 3.155166619585914600243370387034e-01 1.278219674308698206033341193688e-01
         	 6.152305573515951531149426045886e-01 3.329777549008310910672037152835e-01 5.179168774757381132900491138571e-02
         	 9.117800275056731074130311753834e-01 7.665376588027764115373940967402e-02 1.156620661404927918880503057153e-02
         	 5.863699513874213176123362245562e-01 2.338026098230794047605485275199e-01 1.798274387894992498715396322950e-01
         	 7.742669553673616755773423392384e-01 2.147217887957071080773374660566e-01 1.101125583693118858974457907607e-02
         	 4.592838884885920847089835206134e-01 3.367659421500994731957234762376e-01 2.039501693613084420952930031490e-01
         	 6.662160116048213565065339025750e-01 3.119742262865882742595147192333e-01 2.180976210859031372280014693388e-02
         	 7.378559340872877791994710605650e-01 2.225573376197091668426963906313e-01 3.958672829300302620225693317479e-02
         	 8.219786509556015197119904769352e-01 1.042596010644970400127462539785e-01 7.376174797990142639747546127182e-02
         	 7.636963728963229725010819493036e-01 1.553621225506644498715047575388e-01 8.094150455301252211626206189976e-02
         	 8.352850255545913871202401423943e-01 1.378422477974028392821992383688e-01 2.687272664800577359756061923690e-02
         	 6.738457052373849620607870747335e-01 2.315357275962031946558994377483e-01 9.461856716641181552773787188926e-02
         	 5.139836528036283436193798479508e-01 7.958971314797347318403808458243e-02 4.064266340483982387077332987246e-01
         	 5.391596382131452758201817232475e-01 1.994874771545374070313982883818e-02 4.408916140714010389878296791721e-01
         	 5.566613706105387748834800731856e-01 1.278219674308698206033341193688e-01 3.155166619585914600243370387034e-01
         	 6.152305573515951531149426045886e-01 5.179168774757381132900491138571e-02 3.329777549008310910672037152835e-01
         	 9.117800275056731074130311753834e-01 1.156620661404927918880503057153e-02 7.665376588027764115373940967402e-02
         	 5.863699513874213176123362245562e-01 1.798274387894992498715396322950e-01 2.338026098230794047605485275199e-01
         	 7.742669553673616755773423392384e-01 1.101125583693118858974457907607e-02 2.147217887957071080773374660566e-01
         	 4.592838884885920847089835206134e-01 2.039501693613084420952930031490e-01 3.367659421500994731957234762376e-01
         	 6.662160116048213565065339025750e-01 2.180976210859031372280014693388e-02 3.119742262865882742595147192333e-01
         	 7.378559340872877791994710605650e-01 3.958672829300302620225693317479e-02 2.225573376197091668426963906313e-01
         	 8.219786509556015197119904769352e-01 7.376174797990142639747546127182e-02 1.042596010644970400127462539785e-01
         	 7.636963728963229725010819493036e-01 8.094150455301252211626206189976e-02 1.553621225506644498715047575388e-01
         	 8.352850255545913871202401423943e-01 2.687272664800577359756061923690e-02 1.378422477974028392821992383688e-01
         	 6.738457052373849620607870747335e-01 9.461856716641181552773787188926e-02 2.315357275962031946558994377483e-01
         	 7.958971314797347318403808458243e-02 4.064266340483982387077332987246e-01 5.139836528036283436193798479508e-01
         	 1.994874771545374070313982883818e-02 4.408916140714010389878296791721e-01 5.391596382131452758201817232475e-01
         	 1.278219674308698206033341193688e-01 3.155166619585914600243370387034e-01 5.566613706105387748834800731856e-01
         	 5.179168774757381132900491138571e-02 3.329777549008310910672037152835e-01 6.152305573515951531149426045886e-01
         	 1.156620661404927918880503057153e-02 7.665376588027764115373940967402e-02 9.117800275056731074130311753834e-01
         	 1.798274387894992498715396322950e-01 2.338026098230794047605485275199e-01 5.863699513874213176123362245562e-01
         	 1.101125583693118858974457907607e-02 2.147217887957071080773374660566e-01 7.742669553673616755773423392384e-01
         	 2.039501693613084420952930031490e-01 3.367659421500994731957234762376e-01 4.592838884885920847089835206134e-01
         	 2.180976210859031372280014693388e-02 3.119742262865882742595147192333e-01 6.662160116048213565065339025750e-01
         	 3.958672829300302620225693317479e-02 2.225573376197091668426963906313e-01 7.378559340872877791994710605650e-01
         	 7.376174797990142639747546127182e-02 1.042596010644970400127462539785e-01 8.219786509556015197119904769352e-01
         	 8.094150455301252211626206189976e-02 1.553621225506644498715047575388e-01 7.636963728963229725010819493036e-01
         	 2.687272664800577359756061923690e-02 1.378422477974028392821992383688e-01 8.352850255545913871202401423943e-01
         	 9.461856716641181552773787188926e-02 2.315357275962031946558994377483e-01 6.738457052373849620607870747335e-01
         	 7.958971314797347318403808458243e-02 5.139836528036283436193798479508e-01 4.064266340483982387077332987246e-01
         	 1.994874771545374070313982883818e-02 5.391596382131452758201817232475e-01 4.408916140714010389878296791721e-01
         	 1.278219674308698206033341193688e-01 5.566613706105387748834800731856e-01 3.155166619585914600243370387034e-01
         	 5.179168774757381132900491138571e-02 6.152305573515951531149426045886e-01 3.329777549008310910672037152835e-01
         	 1.156620661404927918880503057153e-02 9.117800275056731074130311753834e-01 7.665376588027764115373940967402e-02
         	 1.798274387894992498715396322950e-01 5.863699513874213176123362245562e-01 2.338026098230794047605485275199e-01
         	 1.101125583693118858974457907607e-02 7.742669553673616755773423392384e-01 2.147217887957071080773374660566e-01
         	 2.039501693613084420952930031490e-01 4.592838884885920847089835206134e-01 3.367659421500994731957234762376e-01
         	 2.180976210859031372280014693388e-02 6.662160116048213565065339025750e-01 3.119742262865882742595147192333e-01
         	 3.958672829300302620225693317479e-02 7.378559340872877791994710605650e-01 2.225573376197091668426963906313e-01
         	 7.376174797990142639747546127182e-02 8.219786509556015197119904769352e-01 1.042596010644970400127462539785e-01
         	 8.094150455301252211626206189976e-02 7.636963728963229725010819493036e-01 1.553621225506644498715047575388e-01
         	 2.687272664800577359756061923690e-02 8.352850255545913871202401423943e-01 1.378422477974028392821992383688e-01
         	 9.461856716641181552773787188926e-02 6.738457052373849620607870747335e-01 2.315357275962031946558994377483e-01
         	 1.000000000000000000000000000000e+00 0.000000000000000000000000000000e+00 0.000000000000000000000000000000e+00
         	 0.000000000000000000000000000000e+00 1.000000000000000000000000000000e+00 0.000000000000000000000000000000e+00
         	 0.000000000000000000000000000000e+00 0.000000000000000000000000000000e+00 1.000000000000000000000000000000e+00
         	 1.343391168429097781711334391730e-02 9.865660883157090221828866560827e-01 0.000000000000000000000000000000e+00
         	 4.456000204221327587461587427242e-02 9.554399979577867796365353569854e-01 0.000000000000000000000000000000e+00
         	 9.215187438911487394221921931603e-02 9.078481256108851260577807806840e-01 0.000000000000000000000000000000e+00
         	 1.544855096861576515543390542007e-01 8.455144903138422929345097145415e-01 0.000000000000000000000000000000e+00
         	 2.293073003349492822167121630628e-01 7.706926996650507177832878369372e-01 0.000000000000000000000000000000e+00
         	 3.139127832172615706340934593754e-01 6.860872167827384293659065406246e-01 0.000000000000000000000000000000e+00
         	 4.052440132408411943565340607165e-01 5.947559867591587501323147080257e-01 0.000000000000000000000000000000e+00
         	 4.999999999999999444888487687422e-01 5.000000000000000000000000000000e-01 0.000000000000000000000000000000e+00
         	 5.947559867591587501323147080257e-01 4.052440132408412498676852919743e-01 0.000000000000000000000000000000e+00
         	 6.860872167827384293659065406246e-01 3.139127832172615706340934593754e-01 0.000000000000000000000000000000e+00
         	 7.706926996650507177832878369372e-01 2.293073003349492822167121630628e-01 0.000000000000000000000000000000e+00
         	 8.455144903138422929345097145415e-01 1.544855096861577070654902854585e-01 0.000000000000000000000000000000e+00
         	 9.078481256108852370800832431996e-01 9.215187438911476291991675680038e-02 0.000000000000000000000000000000e+00
         	 9.554399979577867796365353569854e-01 4.456000204221322036346464301459e-02 0.000000000000000000000000000000e+00
         	 9.865660883157091332051891185984e-01 1.343391168429086679481088140165e-02 0.000000000000000000000000000000e+00
         	 1.343391168429097781711334391730e-02 0.000000000000000000000000000000e+00 9.865660883157090221828866560827e-01
         	 4.456000204221327587461587427242e-02 0.000000000000000000000000000000e+00 9.554399979577867796365353569854e-01
         	 9.215187438911487394221921931603e-02 0.000000000000000000000000000000e+00 9.078481256108851260577807806840e-01
         	 1.544855096861576515543390542007e-01 0.000000000000000000000000000000e+00 8.455144903138422929345097145415e-01
         	 2.293073003349492822167121630628e-01 0.000000000000000000000000000000e+00 7.706926996650507177832878369372e-01
         	 3.139127832172615706340934593754e-01 0.000000000000000000000000000000e+00 6.860872167827384293659065406246e-01
         	 4.052440132408411943565340607165e-01 0.000000000000000000000000000000e+00 5.947559867591587501323147080257e-01
         	 4.999999999999999444888487687422e-01 0.000000000000000000000000000000e+00 5.000000000000000000000000000000e-01
         	 5.947559867591587501323147080257e-01 0.000000000000000000000000000000e+00 4.052440132408412498676852919743e-01
         	 6.860872167827384293659065406246e-01 0.000000000000000000000000000000e+00 3.139127832172615706340934593754e-01
         	 7.706926996650507177832878369372e-01 0.000000000000000000000000000000e+00 2.293073003349492822167121630628e-01
         	 8.455144903138422929345097145415e-01 0.000000000000000000000000000000e+00 1.544855096861577070654902854585e-01
         	 9.078481256108852370800832431996e-01 0.000000000000000000000000000000e+00 9.215187438911476291991675680038e-02
         	 9.554399979577867796365353569854e-01 0.000000000000000000000000000000e+00 4.456000204221322036346464301459e-02
         	 9.865660883157091332051891185984e-01 0.000000000000000000000000000000e+00 1.343391168429086679481088140165e-02
         	 0.000000000000000000000000000000e+00 1.343391168429097781711334391730e-02 9.865660883157090221828866560827e-01
         	 0.000000000000000000000000000000e+00 4.456000204221327587461587427242e-02 9.554399979577867796365353569854e-01
         	 0.000000000000000000000000000000e+00 9.215187438911487394221921931603e-02 9.078481256108851260577807806840e-01
         	 0.000000000000000000000000000000e+00 1.544855096861576515543390542007e-01 8.455144903138422929345097145415e-01
         	 0.000000000000000000000000000000e+00 2.293073003349492822167121630628e-01 7.706926996650507177832878369372e-01
         	 0.000000000000000000000000000000e+00 3.139127832172615706340934593754e-01 6.860872167827384293659065406246e-01
         	 0.000000000000000000000000000000e+00 4.052440132408411943565340607165e-01 5.947559867591587501323147080257e-01
         	 0.000000000000000000000000000000e+00 4.999999999999999444888487687422e-01 5.000000000000000000000000000000e-01
         	 0.000000000000000000000000000000e+00 5.947559867591587501323147080257e-01 4.052440132408412498676852919743e-01
         	 0.000000000000000000000000000000e+00 6.860872167827384293659065406246e-01 3.139127832172615706340934593754e-01
         	 0.000000000000000000000000000000e+00 7.706926996650507177832878369372e-01 2.293073003349492822167121630628e-01
         	 0.000000000000000000000000000000e+00 8.455144903138422929345097145415e-01 1.544855096861577070654902854585e-01
         	 0.000000000000000000000000000000e+00 9.078481256108852370800832431996e-01 9.215187438911476291991675680038e-02
         	 0.000000000000000000000000000000e+00 9.554399979577867796365353569854e-01 4.456000204221322036346464301459e-02
         	 0.000000000000000000000000000000e+00 9.865660883157091332051891185984e-01 1.343391168429086679481088140165e-02
         	 ];

    case 17

    	 % PASSED (I).

     	 % DEGREE:  17
     	 % POINTS:    171
     	 % LEBESGUE CONSTANT: 1.14125e+01
     	 % DETERMINANT: -2.30596e+236
     	 % CONDITIONING: 5.73371e+02
     	 % MAX LAGRANGE POLYNOMIALS: 1.08619e+00
     	 % VANDERMONDE: ORTHONORMAL DUBINER LEGENDRE.

     	 table=[
       	  0	  8	 16
      	 ];

     	 t=[
         	 8.446818187813858180845727474662e-01
         	 6.601955488634873026043692334497e-01
         	 -5.837374545507323375659325392917e-01
         	 -6.147336262287616398536371775663e-02
         	 -1.277938672625537064320155877795e-01
         	 2.658009980676434014235098857171e-01
         	 -4.692544563123346446076311622164e-01
         	 1.322494029922949843047774720617e-01
         	 3.791166160781081484465460107458e-01
         	 6.527546505258080555833544167399e-01
         	 1.198287158679138819650233926950e-01
         	 1.926780938724504677050930467885e-01
         	 1.746852346707861991514931787606e-01
         	 2.282931247797210794203692785231e-01
         	 5.915694363174653358505850064830e-02
         	 2.810641040314948435607789178903e-01
         	 4.468376329327975460259381179640e-01
         	 4.473834360345361194077895561350e-01
         	 5.829838687292564491926327718829e-01
         	 5.552797169737045956949827996141e-01
         	 8.344581592912659884220261119481e-01
         	 1.311161293683206496840654153857e-01
         	 1.174768388125400908617024242631e-01
         	 3.068209692848731795500327734771e-01
         	 5.700637855816884647097708693764e-01
         	 2.333964744770715415977946349813e-01
         	 6.530276008009168187129489524523e-01
         	 4.995238327254986621106525035430e-01
         	 3.175297407768052915244538780826e-01
         	 7.047491203664846270982025089324e-01
         	 7.702559237314653417527665624220e-01
         	 3.782056230932271390088317275513e-01
         	 3.939141340720895279048363590846e-01
         	 1.121513837245433908851310889077e-01
         	 3.798574103148317782085996441310e-01
         	 1.900127610059228200345415871197e-01
         	 1.293618364174380641618000709059e-01
         	 1.900273243047330973265474085565e-01
         	 8.546246087805695612615863865358e-01
         	 5.727843167105886035272988010547e-01
         	 ];

     	 pts=[
         	 1.945791515169107699367856412209e-01 1.945791515169107699367856412209e-01 6.108416969661784046152774863003e-01
         	 2.049112087429205350530558860100e-02 2.049112087429205350530558860100e-02 9.590177582514158860504949188908e-01
         	 4.259795575418456881067186259315e-02 4.259795575418456881067186259315e-02 9.148040884916308623786562748137e-01
         	 1.564181521041115296988266436529e-01 1.564181521041115296988266436529e-01 6.871636957917768295800442501786e-01
         	 1.945791515169107699367856412209e-01 6.108416969661784046152774863003e-01 1.945791515169107699367856412209e-01
         	 2.049112087429205350530558860100e-02 9.590177582514158860504949188908e-01 2.049112087429205350530558860100e-02
         	 4.259795575418456881067186259315e-02 9.148040884916308623786562748137e-01 4.259795575418456881067186259315e-02
         	 1.564181521041115296988266436529e-01 6.871636957917768295800442501786e-01 1.564181521041115296988266436529e-01
         	 6.108416969661784046152774863003e-01 1.945791515169107699367856412209e-01 1.945791515169107699367856412209e-01
         	 9.590177582514158860504949188908e-01 2.049112087429205350530558860100e-02 2.049112087429205350530558860100e-02
         	 9.148040884916308623786562748137e-01 4.259795575418456881067186259315e-02 4.259795575418456881067186259315e-02
         	 6.871636957917768295800442501786e-01 1.564181521041115296988266436529e-01 1.564181521041115296988266436529e-01
         	 3.592196968697690118155207983364e-01 3.592196968697690118155207983364e-01 2.815606062604619763689584033273e-01
         	 3.899674085227521347363222048443e-01 3.899674085227521347363222048443e-01 2.200651829544957305273555903113e-01
         	 4.556998336553927386738394034182e-01 4.556998336553927386738394034182e-01 8.860033268921452265232119316352e-02
         	 4.779584328346175303714460369520e-01 4.779584328346175303714460369520e-01 4.408313433076493925710792609607e-02
         	 3.592196968697690118155207983364e-01 2.815606062604619763689584033273e-01 3.592196968697690118155207983364e-01
         	 3.899674085227521347363222048443e-01 2.200651829544957305273555903113e-01 3.899674085227521347363222048443e-01
         	 4.556998336553927386738394034182e-01 8.860033268921452265232119316352e-02 4.556998336553927386738394034182e-01
         	 4.779584328346175303714460369520e-01 4.408313433076493925710792609607e-02 4.779584328346175303714460369520e-01
         	 2.815606062604619763689584033273e-01 3.592196968697690118155207983364e-01 3.592196968697690118155207983364e-01
         	 2.200651829544957305273555903113e-01 3.899674085227521347363222048443e-01 3.899674085227521347363222048443e-01
         	 8.860033268921452265232119316352e-02 4.556998336553927386738394034182e-01 4.556998336553927386738394034182e-01
         	 4.408313433076493925710792609607e-02 4.779584328346175303714460369520e-01 4.779584328346175303714460369520e-01
         	 2.064981741524552216748844557515e-01 7.765619597341436586290797094989e-01 1.693986611340114745161145037855e-02
         	 3.643269502619441713164860630059e-01 5.977234247390156296475538511004e-01 3.794962499904019903596008589375e-02
         	 1.356289190443467074231875812984e-01 7.886565198452635261361365337507e-01 7.571456111038976644067588495091e-02
         	 1.989384047369088248657931217167e-01 6.984622374624075424875968565175e-01 1.025993578006836326466100217658e-01
         	 2.566042921861959036355926855322e-01 5.741340329630012506711977948726e-01 1.692616748508027901820582883374e-01
         	 1.364658140077919801225192486527e-01 8.412149343742766349762973732140e-01 2.231925161793135714560776250437e-02
         	 8.644084936146931297251683190552e-02 8.566967730929346824808590099565e-01 5.686237754559597679104854250909e-02
         	 2.541088096408400942571859104646e-01 6.323144327340671777548664067581e-01 1.135767576250926724767964515195e-01
         	 2.765015607981030631989938228799e-01 6.704156948701927021261326444801e-01 5.308274433170423467487353264005e-02
         	 3.705134447642415285173456140910e-01 4.826648284887848916469010873698e-01 1.468217267469735798357532985392e-01
         	 3.038781746832655006329559910228e-01 6.837355849980972788415556351538e-01 1.238624031863722052548837382346e-02
         	 3.625423658269765203598922198580e-01 5.525551268328993126388581913488e-01 8.490250734012416700124958879314e-02
         	 4.292890810760650044386466106516e-01 5.586509174935030408448710659286e-01 1.206000143043195471648232341977e-02
         	 2.918435801264757101236568814784e-01 4.818709044312088352057799056638e-01 2.262855154423154546705632128578e-01
         	 6.803793687523349009715900592710e-02 9.226625456558029680920185455761e-01 9.299517468963514055246832867851e-03
         	 1.935420559772826898381481441902e-01 7.663263726878712933654469452449e-01 4.013157133484601679640491056489e-02
         	 2.064981741524552216748844557515e-01 1.693986611340114745161145037855e-02 7.765619597341436586290797094989e-01
         	 3.643269502619441713164860630059e-01 3.794962499904019903596008589375e-02 5.977234247390156296475538511004e-01
         	 1.356289190443467074231875812984e-01 7.571456111038976644067588495091e-02 7.886565198452635261361365337507e-01
         	 1.989384047369088248657931217167e-01 1.025993578006836326466100217658e-01 6.984622374624075424875968565175e-01
         	 2.566042921861959036355926855322e-01 1.692616748508027901820582883374e-01 5.741340329630012506711977948726e-01
         	 1.364658140077919801225192486527e-01 2.231925161793135714560776250437e-02 8.412149343742766349762973732140e-01
         	 8.644084936146931297251683190552e-02 5.686237754559597679104854250909e-02 8.566967730929346824808590099565e-01
         	 2.541088096408400942571859104646e-01 1.135767576250926724767964515195e-01 6.323144327340671777548664067581e-01
         	 2.765015607981030631989938228799e-01 5.308274433170423467487353264005e-02 6.704156948701927021261326444801e-01
         	 3.705134447642415285173456140910e-01 1.468217267469735798357532985392e-01 4.826648284887848916469010873698e-01
         	 3.038781746832655006329559910228e-01 1.238624031863722052548837382346e-02 6.837355849980972788415556351538e-01
         	 3.625423658269765203598922198580e-01 8.490250734012416700124958879314e-02 5.525551268328993126388581913488e-01
         	 4.292890810760650044386466106516e-01 1.206000143043195471648232341977e-02 5.586509174935030408448710659286e-01
         	 2.918435801264757101236568814784e-01 2.262855154423154546705632128578e-01 4.818709044312088352057799056638e-01
         	 6.803793687523349009715900592710e-02 9.299517468963514055246832867851e-03 9.226625456558029680920185455761e-01
         	 1.935420559772826898381481441902e-01 4.013157133484601679640491056489e-02 7.663263726878712933654469452449e-01
         	 7.765619597341436586290797094989e-01 2.064981741524552216748844557515e-01 1.693986611340114745161145037855e-02
         	 5.977234247390156296475538511004e-01 3.643269502619441713164860630059e-01 3.794962499904019903596008589375e-02
         	 7.886565198452635261361365337507e-01 1.356289190443467074231875812984e-01 7.571456111038976644067588495091e-02
         	 6.984622374624075424875968565175e-01 1.989384047369088248657931217167e-01 1.025993578006836326466100217658e-01
         	 5.741340329630012506711977948726e-01 2.566042921861959036355926855322e-01 1.692616748508027901820582883374e-01
         	 8.412149343742766349762973732140e-01 1.364658140077919801225192486527e-01 2.231925161793135714560776250437e-02
         	 8.566967730929346824808590099565e-01 8.644084936146931297251683190552e-02 5.686237754559597679104854250909e-02
         	 6.323144327340671777548664067581e-01 2.541088096408400942571859104646e-01 1.135767576250926724767964515195e-01
         	 6.704156948701927021261326444801e-01 2.765015607981030631989938228799e-01 5.308274433170423467487353264005e-02
         	 4.826648284887848916469010873698e-01 3.705134447642415285173456140910e-01 1.468217267469735798357532985392e-01
         	 6.837355849980972788415556351538e-01 3.038781746832655006329559910228e-01 1.238624031863722052548837382346e-02
         	 5.525551268328993126388581913488e-01 3.625423658269765203598922198580e-01 8.490250734012416700124958879314e-02
         	 5.586509174935030408448710659286e-01 4.292890810760650044386466106516e-01 1.206000143043195471648232341977e-02
         	 4.818709044312088352057799056638e-01 2.918435801264757101236568814784e-01 2.262855154423154546705632128578e-01
         	 9.226625456558029680920185455761e-01 6.803793687523349009715900592710e-02 9.299517468963514055246832867851e-03
         	 7.663263726878712933654469452449e-01 1.935420559772826898381481441902e-01 4.013157133484601679640491056489e-02
         	 7.765619597341436586290797094989e-01 1.693986611340114745161145037855e-02 2.064981741524552216748844557515e-01
         	 5.977234247390156296475538511004e-01 3.794962499904019903596008589375e-02 3.643269502619441713164860630059e-01
         	 7.886565198452635261361365337507e-01 7.571456111038976644067588495091e-02 1.356289190443467074231875812984e-01
         	 6.984622374624075424875968565175e-01 1.025993578006836326466100217658e-01 1.989384047369088248657931217167e-01
         	 5.741340329630012506711977948726e-01 1.692616748508027901820582883374e-01 2.566042921861959036355926855322e-01
         	 8.412149343742766349762973732140e-01 2.231925161793135714560776250437e-02 1.364658140077919801225192486527e-01
         	 8.566967730929346824808590099565e-01 5.686237754559597679104854250909e-02 8.644084936146931297251683190552e-02
         	 6.323144327340671777548664067581e-01 1.135767576250926724767964515195e-01 2.541088096408400942571859104646e-01
         	 6.704156948701927021261326444801e-01 5.308274433170423467487353264005e-02 2.765015607981030631989938228799e-01
         	 4.826648284887848916469010873698e-01 1.468217267469735798357532985392e-01 3.705134447642415285173456140910e-01
         	 6.837355849980972788415556351538e-01 1.238624031863722052548837382346e-02 3.038781746832655006329559910228e-01
         	 5.525551268328993126388581913488e-01 8.490250734012416700124958879314e-02 3.625423658269765203598922198580e-01
         	 5.586509174935030408448710659286e-01 1.206000143043195471648232341977e-02 4.292890810760650044386466106516e-01
         	 4.818709044312088352057799056638e-01 2.262855154423154546705632128578e-01 2.918435801264757101236568814784e-01
         	 9.226625456558029680920185455761e-01 9.299517468963514055246832867851e-03 6.803793687523349009715900592710e-02
         	 7.663263726878712933654469452449e-01 4.013157133484601679640491056489e-02 1.935420559772826898381481441902e-01
         	 1.693986611340114745161145037855e-02 2.064981741524552216748844557515e-01 7.765619597341436586290797094989e-01
         	 3.794962499904019903596008589375e-02 3.643269502619441713164860630059e-01 5.977234247390156296475538511004e-01
         	 7.571456111038976644067588495091e-02 1.356289190443467074231875812984e-01 7.886565198452635261361365337507e-01
         	 1.025993578006836326466100217658e-01 1.989384047369088248657931217167e-01 6.984622374624075424875968565175e-01
         	 1.692616748508027901820582883374e-01 2.566042921861959036355926855322e-01 5.741340329630012506711977948726e-01
         	 2.231925161793135714560776250437e-02 1.364658140077919801225192486527e-01 8.412149343742766349762973732140e-01
         	 5.686237754559597679104854250909e-02 8.644084936146931297251683190552e-02 8.566967730929346824808590099565e-01
         	 1.135767576250926724767964515195e-01 2.541088096408400942571859104646e-01 6.323144327340671777548664067581e-01
         	 5.308274433170423467487353264005e-02 2.765015607981030631989938228799e-01 6.704156948701927021261326444801e-01
         	 1.468217267469735798357532985392e-01 3.705134447642415285173456140910e-01 4.826648284887848916469010873698e-01
         	 1.238624031863722052548837382346e-02 3.038781746832655006329559910228e-01 6.837355849980972788415556351538e-01
         	 8.490250734012416700124958879314e-02 3.625423658269765203598922198580e-01 5.525551268328993126388581913488e-01
         	 1.206000143043195471648232341977e-02 4.292890810760650044386466106516e-01 5.586509174935030408448710659286e-01
         	 2.262855154423154546705632128578e-01 2.918435801264757101236568814784e-01 4.818709044312088352057799056638e-01
         	 9.299517468963514055246832867851e-03 6.803793687523349009715900592710e-02 9.226625456558029680920185455761e-01
         	 4.013157133484601679640491056489e-02 1.935420559772826898381481441902e-01 7.663263726878712933654469452449e-01
         	 1.693986611340114745161145037855e-02 7.765619597341436586290797094989e-01 2.064981741524552216748844557515e-01
         	 3.794962499904019903596008589375e-02 5.977234247390156296475538511004e-01 3.643269502619441713164860630059e-01
         	 7.571456111038976644067588495091e-02 7.886565198452635261361365337507e-01 1.356289190443467074231875812984e-01
         	 1.025993578006836326466100217658e-01 6.984622374624075424875968565175e-01 1.989384047369088248657931217167e-01
         	 1.692616748508027901820582883374e-01 5.741340329630012506711977948726e-01 2.566042921861959036355926855322e-01
         	 2.231925161793135714560776250437e-02 8.412149343742766349762973732140e-01 1.364658140077919801225192486527e-01
         	 5.686237754559597679104854250909e-02 8.566967730929346824808590099565e-01 8.644084936146931297251683190552e-02
         	 1.135767576250926724767964515195e-01 6.323144327340671777548664067581e-01 2.541088096408400942571859104646e-01
         	 5.308274433170423467487353264005e-02 6.704156948701927021261326444801e-01 2.765015607981030631989938228799e-01
         	 1.468217267469735798357532985392e-01 4.826648284887848916469010873698e-01 3.705134447642415285173456140910e-01
         	 1.238624031863722052548837382346e-02 6.837355849980972788415556351538e-01 3.038781746832655006329559910228e-01
         	 8.490250734012416700124958879314e-02 5.525551268328993126388581913488e-01 3.625423658269765203598922198580e-01
         	 1.206000143043195471648232341977e-02 5.586509174935030408448710659286e-01 4.292890810760650044386466106516e-01
         	 2.262855154423154546705632128578e-01 4.818709044312088352057799056638e-01 2.918435801264757101236568814784e-01
         	 9.299517468963514055246832867851e-03 9.226625456558029680920185455761e-01 6.803793687523349009715900592710e-02
         	 4.013157133484601679640491056489e-02 7.663263726878712933654469452449e-01 1.935420559772826898381481441902e-01
         	 1.000000000000000000000000000000e+00 0.000000000000000000000000000000e+00 0.000000000000000000000000000000e+00
         	 0.000000000000000000000000000000e+00 1.000000000000000000000000000000e+00 0.000000000000000000000000000000e+00
         	 0.000000000000000000000000000000e+00 0.000000000000000000000000000000e+00 1.000000000000000000000000000000e+00
         	 1.194722129390074494281748229696e-02 9.880527787060993105683337489609e-01 0.000000000000000000000000000000e+00
         	 3.967540732623298094239316924359e-02 9.603245926737670190576068307564e-01 0.000000000000000000000000000000e+00
         	 8.220323239095506107076971602510e-02 9.177967676090449389292302839749e-01 0.000000000000000000000000000000e+00
         	 1.381603353583786275571299029252e-01 8.618396646416213169317188658169e-01 0.000000000000000000000000000000e+00
         	 2.057475828406691298333441864088e-01 7.942524171593308146555045823334e-01 0.000000000000000000000000000000e+00
         	 2.827924815439379901960137431161e-01 7.172075184560620098039862568839e-01 0.000000000000000000000000000000e+00
         	 3.668186735608596205082676533493e-01 6.331813264391403794917323466507e-01 0.000000000000000000000000000000e+00
         	 4.551254532576739508797913913440e-01 5.448745467423260491202086086560e-01 0.000000000000000000000000000000e+00
         	 5.448745467423260491202086086560e-01 4.551254532576739508797913913440e-01 0.000000000000000000000000000000e+00
         	 6.331813264391406015363372716820e-01 3.668186735608593984636627283180e-01 0.000000000000000000000000000000e+00
         	 7.172075184560620098039862568839e-01 2.827924815439379901960137431161e-01 0.000000000000000000000000000000e+00
         	 7.942524171593308146555045823334e-01 2.057475828406691853444954176666e-01 0.000000000000000000000000000000e+00
         	 8.618396646416213169317188658169e-01 1.381603353583786830682811341831e-01 0.000000000000000000000000000000e+00
         	 9.177967676090450499515327464906e-01 8.220323239095495004846725350944e-02 0.000000000000000000000000000000e+00
         	 9.603245926737669080353043682408e-01 3.967540732623309196469563175924e-02 0.000000000000000000000000000000e+00
         	 9.880527787060993105683337489609e-01 1.194722129390068943166625103913e-02 0.000000000000000000000000000000e+00
         	 1.194722129390074494281748229696e-02 0.000000000000000000000000000000e+00 9.880527787060993105683337489609e-01
         	 3.967540732623298094239316924359e-02 0.000000000000000000000000000000e+00 9.603245926737670190576068307564e-01
         	 8.220323239095506107076971602510e-02 0.000000000000000000000000000000e+00 9.177967676090449389292302839749e-01
         	 1.381603353583786275571299029252e-01 0.000000000000000000000000000000e+00 8.618396646416213169317188658169e-01
         	 2.057475828406691298333441864088e-01 0.000000000000000000000000000000e+00 7.942524171593308146555045823334e-01
         	 2.827924815439379901960137431161e-01 0.000000000000000000000000000000e+00 7.172075184560620098039862568839e-01
         	 3.668186735608596205082676533493e-01 0.000000000000000000000000000000e+00 6.331813264391403794917323466507e-01
         	 4.551254532576739508797913913440e-01 0.000000000000000000000000000000e+00 5.448745467423260491202086086560e-01
         	 5.448745467423260491202086086560e-01 0.000000000000000000000000000000e+00 4.551254532576739508797913913440e-01
         	 6.331813264391406015363372716820e-01 0.000000000000000000000000000000e+00 3.668186735608593984636627283180e-01
         	 7.172075184560620098039862568839e-01 0.000000000000000000000000000000e+00 2.827924815439379901960137431161e-01
         	 7.942524171593308146555045823334e-01 0.000000000000000000000000000000e+00 2.057475828406691853444954176666e-01
         	 8.618396646416213169317188658169e-01 0.000000000000000000000000000000e+00 1.381603353583786830682811341831e-01
         	 9.177967676090450499515327464906e-01 0.000000000000000000000000000000e+00 8.220323239095495004846725350944e-02
         	 9.603245926737669080353043682408e-01 0.000000000000000000000000000000e+00 3.967540732623309196469563175924e-02
         	 9.880527787060993105683337489609e-01 0.000000000000000000000000000000e+00 1.194722129390068943166625103913e-02
         	 0.000000000000000000000000000000e+00 1.194722129390074494281748229696e-02 9.880527787060993105683337489609e-01
         	 0.000000000000000000000000000000e+00 3.967540732623298094239316924359e-02 9.603245926737670190576068307564e-01
         	 0.000000000000000000000000000000e+00 8.220323239095506107076971602510e-02 9.177967676090449389292302839749e-01
         	 0.000000000000000000000000000000e+00 1.381603353583786275571299029252e-01 8.618396646416213169317188658169e-01
         	 0.000000000000000000000000000000e+00 2.057475828406691298333441864088e-01 7.942524171593308146555045823334e-01
         	 0.000000000000000000000000000000e+00 2.827924815439379901960137431161e-01 7.172075184560620098039862568839e-01
         	 0.000000000000000000000000000000e+00 3.668186735608596205082676533493e-01 6.331813264391403794917323466507e-01
         	 0.000000000000000000000000000000e+00 4.551254532576739508797913913440e-01 5.448745467423260491202086086560e-01
         	 0.000000000000000000000000000000e+00 5.448745467423260491202086086560e-01 4.551254532576739508797913913440e-01
         	 0.000000000000000000000000000000e+00 6.331813264391406015363372716820e-01 3.668186735608593984636627283180e-01
         	 0.000000000000000000000000000000e+00 7.172075184560620098039862568839e-01 2.827924815439379901960137431161e-01
         	 0.000000000000000000000000000000e+00 7.942524171593308146555045823334e-01 2.057475828406691853444954176666e-01
         	 0.000000000000000000000000000000e+00 8.618396646416213169317188658169e-01 1.381603353583786830682811341831e-01
         	 0.000000000000000000000000000000e+00 9.177967676090450499515327464906e-01 8.220323239095495004846725350944e-02
         	 0.000000000000000000000000000000e+00 9.603245926737669080353043682408e-01 3.967540732623309196469563175924e-02
         	 0.000000000000000000000000000000e+00 9.880527787060993105683337489609e-01 1.194722129390068943166625103913e-02
         	 ];


    case 18

    	 % PASSED (I).

     	 % DEGREE:  18
     	 % POINTS:    190
     	 % LEBESGUE CONSTANT: 1.26889e+01
     	 % DETERMINANT: -1.11594e+267
     	 % CONDITIONING: 4.72717e+02
     	 % MAX LAGRANGE POLYNOMIALS: 1.07067e+00
     	 % VANDERMONDE: ORTHONORMAL DUBINER LEGENDRE.

     	 table=[
       	  1	  7	 19
      	 ];

     	 t=[
         	 -5.603498734773882938853262203338e-01
         	 2.338355927348825802347676017234e-01
         	 5.813194995687650523663592139201e-01
         	 -5.530877941081898535591321319771e-02
         	 -2.392423549575602714778455037958e-01
         	 3.639524720804632185178206782439e-01
         	 -1.374821277331608471161672468952e-01
         	 1.052388437611346122535493918804e-01
         	 1.160146475711420904763926387204e-01
         	 2.597414059525333107636413387809e-01
         	 8.958763671543079620818161856732e-02
         	 5.105600333665315515574434357404e-01
         	 3.847366022243777217148874569830e-01
         	 8.343678766623181808359532851682e-02
         	 8.505157858166439988067963895446e-01
         	 1.114217676404247320265383791593e-01
         	 6.219327331395372304712054756237e-01
         	 3.906825904643661528936604554474e-01
         	 1.870861788137102854623350367547e-01
         	 7.860267255472977998564942936355e-01
         	 2.679756544921105820833417965332e-01
         	 2.817468381902507035263738544018e-01
         	 6.182554315416747270361952359963e-01
         	 4.194499655309087415844260249287e-01
         	 4.309137960771961539663266194111e-01
         	 1.555515723358025792499859107920e-01
         	 2.433587772138979254954449515935e-01
         	 7.539081300732844992396053385164e-01
         	 6.565300653800509866897527899710e-01
         	 8.736659930399562901115473323443e-01
         	 1.997798990059275192621157657413e-01
         	 3.991797063414151969240606376843e-01
         	 6.447936870099297834713070187718e-01
         	 1.084736783899709483547368904510e-01
         	 5.286943879698684511936335184146e-01
         	 3.253433496348395181918533580756e-01
         	 1.798454496566186389117092403467e-01
         	 7.734727812704789151609929831466e-01
         	 7.633578320961893759477590037932e-02
         	 5.365295093018743743940035528794e-01
         	 3.298424337486250967899081842916e-01
         	 2.510577044846307726011502836627e-01
         	 5.564611026221089051801982350298e-01
         	 4.762793874929180937272121809656e-01
         	 1.049202986194723852264587549143e-01
         	 ];

     	 pts=[
         	 3.333333333333333148296162562474e-01 3.333333333333333148296162562474e-01 3.333333333333333148296162562474e-01
         	 1.867832911591294220432502015683e-01 1.867832911591294220432502015683e-01 6.264334176817411004023483656056e-01
         	 1.843625980360632729548875374803e-02 1.843625980360632729548875374803e-02 9.631274803927872829589773573389e-01
         	 7.974745165252009049261516793194e-02 7.974745165252009049261516793194e-02 8.405050966949597635036184328783e-01
         	 4.582737591105361107945981302692e-02 4.582737591105361107945981302692e-02 9.083452481778927500855047583173e-01
         	 1.867832911591294220432502015683e-01 6.264334176817411004023483656056e-01 1.867832911591294220432502015683e-01
         	 1.843625980360632729548875374803e-02 9.631274803927872829589773573389e-01 1.843625980360632729548875374803e-02
         	 7.974745165252009049261516793194e-02 8.405050966949597635036184328783e-01 7.974745165252009049261516793194e-02
         	 4.582737591105361107945981302692e-02 9.083452481778927500855047583173e-01 4.582737591105361107945981302692e-02
         	 6.264334176817411004023483656056e-01 1.867832911591294220432502015683e-01 1.867832911591294220432502015683e-01
         	 9.631274803927872829589773573389e-01 1.843625980360632729548875374803e-02 1.843625980360632729548875374803e-02
         	 8.405050966949597635036184328783e-01 7.974745165252009049261516793194e-02 7.974745165252009049261516793194e-02
         	 9.083452481778927500855047583173e-01 4.582737591105361107945981302692e-02 4.582737591105361107945981302692e-02
         	 4.610274012108529495534980924276e-01 4.610274012108529495534980924276e-01 7.794519757829410089300381514477e-02
         	 4.031134167385391764426572080993e-01 4.031134167385391764426572080993e-01 1.937731665229216471146855838015e-01
         	 4.393412546532561302470298869594e-01 4.393412546532561302470298869594e-01 1.213174906934877395059402260813e-01
         	 4.610274012108529495534980924276e-01 7.794519757829410089300381514477e-02 4.610274012108529495534980924276e-01
         	 4.031134167385391764426572080993e-01 1.937731665229216471146855838015e-01 4.031134167385391764426572080993e-01
         	 4.393412546532561302470298869594e-01 1.213174906934877395059402260813e-01 4.393412546532561302470298869594e-01
         	 7.794519757829410089300381514477e-02 4.610274012108529495534980924276e-01 4.610274012108529495534980924276e-01
         	 1.937731665229216471146855838015e-01 4.031134167385391764426572080993e-01 4.031134167385391764426572080993e-01
         	 1.213174906934877395059402260813e-01 4.393412546532561302470298869594e-01 4.393412546532561302470298869594e-01
         	 2.697535482222230829307818567031e-01 5.131123254361209529150755770388e-01 2.171341263416559641541425662581e-01
         	 1.013663979040955176458282949170e-01 8.552745279773800168854336334334e-01 4.335907411852446546873807164957e-02
         	 1.577802125320718618084470108442e-01 8.143102779121228484981998008152e-01 2.790950955580528969335318834055e-02
         	 5.704260843925303137158522304162e-02 9.307086014792093076053447475715e-01 1.224879008153767490085783720133e-02
         	 3.518333725591127336684849069570e-01 5.516132715650402529306006726983e-01 9.655335587584701340091442034463e-02
         	 2.643961982569245638963195688120e-01 6.635759045983397053092289752385e-01 7.202789714473578630560268720728e-02
         	 1.323082356077286969586737086502e-01 7.771019226176585359411319586798e-01 9.058984177461271158904310141224e-02
         	 4.389280715061170123902911655023e-01 5.474017498960880301339670950256e-01 1.367017859779495747574173947214e-02
         	 1.756721652834479507898635120000e-01 7.043665532533164297390726460435e-01 1.199612814632355917154882263276e-01
         	 3.285410056449763471775327161595e-01 6.538843552798158098582348429773e-01 1.757463907520784296423244086327e-02
         	 3.384986151918548125117069957923e-01 5.183440648484733959122650048812e-01 1.431573199596718470871792305843e-01
         	 1.066901027121254230678459862247e-01 8.801628839826043382288389693713e-01 1.314701330527023870331504440401e-02
         	 4.388925265213433069000359409984e-01 5.152283097309622306170240335632e-01 4.587916374769451799409125669627e-02
         	 1.991527726480603055492224484624e-01 7.356822819499346799432260013418e-01 6.516494540200501450755155019579e-02
         	 2.703436617821667331540425038838e-01 6.001860955307918299439506881754e-01 1.294702426870414369020068079408e-01
         	 3.526900037620688821426995218644e-01 6.037477082466996547438498055271e-01 4.356228799123151862460190386628e-02
         	 2.177546267144484792854797206019e-01 7.742157293365573567101023400028e-01 8.029643948994191759993555024266e-03
         	 2.463925035152266518334585043704e-01 7.226718910081446622939438384492e-01 3.093560547662865811702204155154e-02
         	 3.242851625161429773847032720369e-01 4.292054611356153626111620269512e-01 2.465093763482417155152859322698e-01
         	 2.697535482222230829307818567031e-01 2.171341263416559641541425662581e-01 5.131123254361209529150755770388e-01
         	 1.013663979040955176458282949170e-01 4.335907411852446546873807164957e-02 8.552745279773800168854336334334e-01
         	 1.577802125320718618084470108442e-01 2.790950955580528969335318834055e-02 8.143102779121228484981998008152e-01
         	 5.704260843925303137158522304162e-02 1.224879008153767490085783720133e-02 9.307086014792093076053447475715e-01
         	 3.518333725591127336684849069570e-01 9.655335587584701340091442034463e-02 5.516132715650402529306006726983e-01
         	 2.643961982569245638963195688120e-01 7.202789714473578630560268720728e-02 6.635759045983397053092289752385e-01
         	 1.323082356077286969586737086502e-01 9.058984177461271158904310141224e-02 7.771019226176585359411319586798e-01
         	 4.389280715061170123902911655023e-01 1.367017859779495747574173947214e-02 5.474017498960880301339670950256e-01
         	 1.756721652834479507898635120000e-01 1.199612814632355917154882263276e-01 7.043665532533164297390726460435e-01
         	 3.285410056449763471775327161595e-01 1.757463907520784296423244086327e-02 6.538843552798158098582348429773e-01
         	 3.384986151918548125117069957923e-01 1.431573199596718470871792305843e-01 5.183440648484733959122650048812e-01
         	 1.066901027121254230678459862247e-01 1.314701330527023870331504440401e-02 8.801628839826043382288389693713e-01
         	 4.388925265213433069000359409984e-01 4.587916374769451799409125669627e-02 5.152283097309622306170240335632e-01
         	 1.991527726480603055492224484624e-01 6.516494540200501450755155019579e-02 7.356822819499346799432260013418e-01
         	 2.703436617821667331540425038838e-01 1.294702426870414369020068079408e-01 6.001860955307918299439506881754e-01
         	 3.526900037620688821426995218644e-01 4.356228799123151862460190386628e-02 6.037477082466996547438498055271e-01
         	 2.177546267144484792854797206019e-01 8.029643948994191759993555024266e-03 7.742157293365573567101023400028e-01
         	 2.463925035152266518334585043704e-01 3.093560547662865811702204155154e-02 7.226718910081446622939438384492e-01
         	 3.242851625161429773847032720369e-01 2.465093763482417155152859322698e-01 4.292054611356153626111620269512e-01
         	 5.131123254361209529150755770388e-01 2.697535482222230829307818567031e-01 2.171341263416559641541425662581e-01
         	 8.552745279773800168854336334334e-01 1.013663979040955176458282949170e-01 4.335907411852446546873807164957e-02
         	 8.143102779121228484981998008152e-01 1.577802125320718618084470108442e-01 2.790950955580528969335318834055e-02
         	 9.307086014792093076053447475715e-01 5.704260843925303137158522304162e-02 1.224879008153767490085783720133e-02
         	 5.516132715650402529306006726983e-01 3.518333725591127336684849069570e-01 9.655335587584701340091442034463e-02
         	 6.635759045983397053092289752385e-01 2.643961982569245638963195688120e-01 7.202789714473578630560268720728e-02
         	 7.771019226176585359411319586798e-01 1.323082356077286969586737086502e-01 9.058984177461271158904310141224e-02
         	 5.474017498960880301339670950256e-01 4.389280715061170123902911655023e-01 1.367017859779495747574173947214e-02
         	 7.043665532533164297390726460435e-01 1.756721652834479507898635120000e-01 1.199612814632355917154882263276e-01
         	 6.538843552798158098582348429773e-01 3.285410056449763471775327161595e-01 1.757463907520784296423244086327e-02
         	 5.183440648484733959122650048812e-01 3.384986151918548125117069957923e-01 1.431573199596718470871792305843e-01
         	 8.801628839826043382288389693713e-01 1.066901027121254230678459862247e-01 1.314701330527023870331504440401e-02
         	 5.152283097309622306170240335632e-01 4.388925265213433069000359409984e-01 4.587916374769451799409125669627e-02
         	 7.356822819499346799432260013418e-01 1.991527726480603055492224484624e-01 6.516494540200501450755155019579e-02
         	 6.001860955307918299439506881754e-01 2.703436617821667331540425038838e-01 1.294702426870414369020068079408e-01
         	 6.037477082466996547438498055271e-01 3.526900037620688821426995218644e-01 4.356228799123151862460190386628e-02
         	 7.742157293365573567101023400028e-01 2.177546267144484792854797206019e-01 8.029643948994191759993555024266e-03
         	 7.226718910081446622939438384492e-01 2.463925035152266518334585043704e-01 3.093560547662865811702204155154e-02
         	 4.292054611356153626111620269512e-01 3.242851625161429773847032720369e-01 2.465093763482417155152859322698e-01
         	 5.131123254361209529150755770388e-01 2.171341263416559641541425662581e-01 2.697535482222230829307818567031e-01
         	 8.552745279773800168854336334334e-01 4.335907411852446546873807164957e-02 1.013663979040955176458282949170e-01
         	 8.143102779121228484981998008152e-01 2.790950955580528969335318834055e-02 1.577802125320718618084470108442e-01
         	 9.307086014792093076053447475715e-01 1.224879008153767490085783720133e-02 5.704260843925303137158522304162e-02
         	 5.516132715650402529306006726983e-01 9.655335587584701340091442034463e-02 3.518333725591127336684849069570e-01
         	 6.635759045983397053092289752385e-01 7.202789714473578630560268720728e-02 2.643961982569245638963195688120e-01
         	 7.771019226176585359411319586798e-01 9.058984177461271158904310141224e-02 1.323082356077286969586737086502e-01
         	 5.474017498960880301339670950256e-01 1.367017859779495747574173947214e-02 4.389280715061170123902911655023e-01
         	 7.043665532533164297390726460435e-01 1.199612814632355917154882263276e-01 1.756721652834479507898635120000e-01
         	 6.538843552798158098582348429773e-01 1.757463907520784296423244086327e-02 3.285410056449763471775327161595e-01
         	 5.183440648484733959122650048812e-01 1.431573199596718470871792305843e-01 3.384986151918548125117069957923e-01
         	 8.801628839826043382288389693713e-01 1.314701330527023870331504440401e-02 1.066901027121254230678459862247e-01
         	 5.152283097309622306170240335632e-01 4.587916374769451799409125669627e-02 4.388925265213433069000359409984e-01
         	 7.356822819499346799432260013418e-01 6.516494540200501450755155019579e-02 1.991527726480603055492224484624e-01
         	 6.001860955307918299439506881754e-01 1.294702426870414369020068079408e-01 2.703436617821667331540425038838e-01
         	 6.037477082466996547438498055271e-01 4.356228799123151862460190386628e-02 3.526900037620688821426995218644e-01
         	 7.742157293365573567101023400028e-01 8.029643948994191759993555024266e-03 2.177546267144484792854797206019e-01
         	 7.226718910081446622939438384492e-01 3.093560547662865811702204155154e-02 2.463925035152266518334585043704e-01
         	 4.292054611356153626111620269512e-01 2.465093763482417155152859322698e-01 3.242851625161429773847032720369e-01
         	 2.171341263416559641541425662581e-01 2.697535482222230829307818567031e-01 5.131123254361209529150755770388e-01
         	 4.335907411852446546873807164957e-02 1.013663979040955176458282949170e-01 8.552745279773800168854336334334e-01
         	 2.790950955580528969335318834055e-02 1.577802125320718618084470108442e-01 8.143102779121228484981998008152e-01
         	 1.224879008153767490085783720133e-02 5.704260843925303137158522304162e-02 9.307086014792093076053447475715e-01
         	 9.655335587584701340091442034463e-02 3.518333725591127336684849069570e-01 5.516132715650402529306006726983e-01
         	 7.202789714473578630560268720728e-02 2.643961982569245638963195688120e-01 6.635759045983397053092289752385e-01
         	 9.058984177461271158904310141224e-02 1.323082356077286969586737086502e-01 7.771019226176585359411319586798e-01
         	 1.367017859779495747574173947214e-02 4.389280715061170123902911655023e-01 5.474017498960880301339670950256e-01
         	 1.199612814632355917154882263276e-01 1.756721652834479507898635120000e-01 7.043665532533164297390726460435e-01
         	 1.757463907520784296423244086327e-02 3.285410056449763471775327161595e-01 6.538843552798158098582348429773e-01
         	 1.431573199596718470871792305843e-01 3.384986151918548125117069957923e-01 5.183440648484733959122650048812e-01
         	 1.314701330527023870331504440401e-02 1.066901027121254230678459862247e-01 8.801628839826043382288389693713e-01
         	 4.587916374769451799409125669627e-02 4.388925265213433069000359409984e-01 5.152283097309622306170240335632e-01
         	 6.516494540200501450755155019579e-02 1.991527726480603055492224484624e-01 7.356822819499346799432260013418e-01
         	 1.294702426870414369020068079408e-01 2.703436617821667331540425038838e-01 6.001860955307918299439506881754e-01
         	 4.356228799123151862460190386628e-02 3.526900037620688821426995218644e-01 6.037477082466996547438498055271e-01
         	 8.029643948994191759993555024266e-03 2.177546267144484792854797206019e-01 7.742157293365573567101023400028e-01
         	 3.093560547662865811702204155154e-02 2.463925035152266518334585043704e-01 7.226718910081446622939438384492e-01
         	 2.465093763482417155152859322698e-01 3.242851625161429773847032720369e-01 4.292054611356153626111620269512e-01
         	 2.171341263416559641541425662581e-01 5.131123254361209529150755770388e-01 2.697535482222230829307818567031e-01
         	 4.335907411852446546873807164957e-02 8.552745279773800168854336334334e-01 1.013663979040955176458282949170e-01
         	 2.790950955580528969335318834055e-02 8.143102779121228484981998008152e-01 1.577802125320718618084470108442e-01
         	 1.224879008153767490085783720133e-02 9.307086014792093076053447475715e-01 5.704260843925303137158522304162e-02
         	 9.655335587584701340091442034463e-02 5.516132715650402529306006726983e-01 3.518333725591127336684849069570e-01
         	 7.202789714473578630560268720728e-02 6.635759045983397053092289752385e-01 2.643961982569245638963195688120e-01
         	 9.058984177461271158904310141224e-02 7.771019226176585359411319586798e-01 1.323082356077286969586737086502e-01
         	 1.367017859779495747574173947214e-02 5.474017498960880301339670950256e-01 4.389280715061170123902911655023e-01
         	 1.199612814632355917154882263276e-01 7.043665532533164297390726460435e-01 1.756721652834479507898635120000e-01
         	 1.757463907520784296423244086327e-02 6.538843552798158098582348429773e-01 3.285410056449763471775327161595e-01
         	 1.431573199596718470871792305843e-01 5.183440648484733959122650048812e-01 3.384986151918548125117069957923e-01
         	 1.314701330527023870331504440401e-02 8.801628839826043382288389693713e-01 1.066901027121254230678459862247e-01
         	 4.587916374769451799409125669627e-02 5.152283097309622306170240335632e-01 4.388925265213433069000359409984e-01
         	 6.516494540200501450755155019579e-02 7.356822819499346799432260013418e-01 1.991527726480603055492224484624e-01
         	 1.294702426870414369020068079408e-01 6.001860955307918299439506881754e-01 2.703436617821667331540425038838e-01
         	 4.356228799123151862460190386628e-02 6.037477082466996547438498055271e-01 3.526900037620688821426995218644e-01
         	 8.029643948994191759993555024266e-03 7.742157293365573567101023400028e-01 2.177546267144484792854797206019e-01
         	 3.093560547662865811702204155154e-02 7.226718910081446622939438384492e-01 2.463925035152266518334585043704e-01
         	 2.465093763482417155152859322698e-01 4.292054611356153626111620269512e-01 3.242851625161429773847032720369e-01
         	 1.000000000000000000000000000000e+00 0.000000000000000000000000000000e+00 0.000000000000000000000000000000e+00
         	 0.000000000000000000000000000000e+00 1.000000000000000000000000000000e+00 0.000000000000000000000000000000e+00
         	 0.000000000000000000000000000000e+00 0.000000000000000000000000000000e+00 1.000000000000000000000000000000e+00
         	 1.069411688896010348415188673243e-02 9.893058831110399520269993445254e-01 0.000000000000000000000000000000e+00
         	 3.554923592370679008567435630539e-02 9.644507640762931544031744124368e-01 0.000000000000000000000000000000e+00
         	 7.376971110167684919645125773968e-02 9.262302888983231508035487422603e-01 0.000000000000000000000000000000e+00
         	 1.242528987236936610649706835829e-01 8.757471012763062834238780851592e-01 0.000000000000000000000000000000e+00
         	 1.855459313673898380514515338291e-01 8.144540686326101619485484661709e-01 0.000000000000000000000000000000e+00
         	 2.558853571596433340573639725335e-01 7.441146428403566659426360274665e-01 0.000000000000000000000000000000e+00
         	 3.332475760877505743806636928639e-01 6.667524239122494256193363071361e-01 0.000000000000000000000000000000e+00
         	 4.154069882953593251251334095286e-01 5.845930117046407303860178217292e-01 0.000000000000000000000000000000e+00
         	 5.000000000000000000000000000000e-01 5.000000000000000000000000000000e-01 0.000000000000000000000000000000e+00
         	 5.845930117046408414083202842448e-01 4.154069882953591585916797157552e-01 0.000000000000000000000000000000e+00
         	 6.667524239122492035747313821048e-01 3.332475760877507964252686178952e-01 0.000000000000000000000000000000e+00
         	 7.441146428403569990095434150135e-01 2.558853571596430009904565849865e-01 0.000000000000000000000000000000e+00
         	 8.144540686326102729708509286866e-01 1.855459313673897270291490713134e-01 0.000000000000000000000000000000e+00
         	 8.757471012763063944461805476749e-01 1.242528987236936055538194523251e-01 0.000000000000000000000000000000e+00
         	 9.262302888983231508035487422603e-01 7.376971110167684919645125773968e-02 0.000000000000000000000000000000e+00
         	 9.644507640762930433808719499211e-01 3.554923592370695661912805007887e-02 0.000000000000000000000000000000e+00
         	 9.893058831110401740716042695567e-01 1.069411688895982592839573044330e-02 0.000000000000000000000000000000e+00
         	 1.069411688896010348415188673243e-02 0.000000000000000000000000000000e+00 9.893058831110399520269993445254e-01
         	 3.554923592370679008567435630539e-02 0.000000000000000000000000000000e+00 9.644507640762931544031744124368e-01
         	 7.376971110167684919645125773968e-02 0.000000000000000000000000000000e+00 9.262302888983231508035487422603e-01
         	 1.242528987236936610649706835829e-01 0.000000000000000000000000000000e+00 8.757471012763062834238780851592e-01
         	 1.855459313673898380514515338291e-01 0.000000000000000000000000000000e+00 8.144540686326101619485484661709e-01
         	 2.558853571596433340573639725335e-01 0.000000000000000000000000000000e+00 7.441146428403566659426360274665e-01
         	 3.332475760877505743806636928639e-01 0.000000000000000000000000000000e+00 6.667524239122494256193363071361e-01
         	 4.154069882953593251251334095286e-01 0.000000000000000000000000000000e+00 5.845930117046407303860178217292e-01
         	 5.000000000000000000000000000000e-01 0.000000000000000000000000000000e+00 5.000000000000000000000000000000e-01
         	 5.845930117046408414083202842448e-01 0.000000000000000000000000000000e+00 4.154069882953591585916797157552e-01
         	 6.667524239122492035747313821048e-01 0.000000000000000000000000000000e+00 3.332475760877507964252686178952e-01
         	 7.441146428403569990095434150135e-01 0.000000000000000000000000000000e+00 2.558853571596430009904565849865e-01
         	 8.144540686326102729708509286866e-01 0.000000000000000000000000000000e+00 1.855459313673897270291490713134e-01
         	 8.757471012763063944461805476749e-01 0.000000000000000000000000000000e+00 1.242528987236936055538194523251e-01
         	 9.262302888983231508035487422603e-01 0.000000000000000000000000000000e+00 7.376971110167684919645125773968e-02
         	 9.644507640762930433808719499211e-01 0.000000000000000000000000000000e+00 3.554923592370695661912805007887e-02
         	 9.893058831110401740716042695567e-01 0.000000000000000000000000000000e+00 1.069411688895982592839573044330e-02
         	 0.000000000000000000000000000000e+00 1.069411688896010348415188673243e-02 9.893058831110399520269993445254e-01
         	 0.000000000000000000000000000000e+00 3.554923592370679008567435630539e-02 9.644507640762931544031744124368e-01
         	 0.000000000000000000000000000000e+00 7.376971110167684919645125773968e-02 9.262302888983231508035487422603e-01
         	 0.000000000000000000000000000000e+00 1.242528987236936610649706835829e-01 8.757471012763062834238780851592e-01
         	 0.000000000000000000000000000000e+00 1.855459313673898380514515338291e-01 8.144540686326101619485484661709e-01
         	 0.000000000000000000000000000000e+00 2.558853571596433340573639725335e-01 7.441146428403566659426360274665e-01
         	 0.000000000000000000000000000000e+00 3.332475760877505743806636928639e-01 6.667524239122494256193363071361e-01
         	 0.000000000000000000000000000000e+00 4.154069882953593251251334095286e-01 5.845930117046407303860178217292e-01
         	 0.000000000000000000000000000000e+00 5.000000000000000000000000000000e-01 5.000000000000000000000000000000e-01
         	 0.000000000000000000000000000000e+00 5.845930117046408414083202842448e-01 4.154069882953591585916797157552e-01
         	 0.000000000000000000000000000000e+00 6.667524239122492035747313821048e-01 3.332475760877507964252686178952e-01
         	 0.000000000000000000000000000000e+00 7.441146428403569990095434150135e-01 2.558853571596430009904565849865e-01
         	 0.000000000000000000000000000000e+00 8.144540686326102729708509286866e-01 1.855459313673897270291490713134e-01
         	 0.000000000000000000000000000000e+00 8.757471012763063944461805476749e-01 1.242528987236936055538194523251e-01
         	 0.000000000000000000000000000000e+00 9.262302888983231508035487422603e-01 7.376971110167684919645125773968e-02
         	 0.000000000000000000000000000000e+00 9.644507640762930433808719499211e-01 3.554923592370695661912805007887e-02
         	 0.000000000000000000000000000000e+00 9.893058831110401740716042695567e-01 1.069411688895982592839573044330e-02
         	 ];

end

% STATS
% |DEGR|  LEBESGUE   | ABS.DET.VAND.| COND. VAND. | LAGR. |
stats_matrix=[
    1 1.00000e+00 5.87878e+01 3.70699e+00 1.00000e+00
    2 1.66667e+00 3.13712e+04 1.01810e+01 1.00000e+00
    3 2.11244e+00 3.44701e+08 2.03638e+01 1.00000e+00
    4 2.58801e+00 8.98221e+13 3.95876e+01 1.02814e+00
    5 3.08116e+00 6.69351e+20 5.28526e+01 1.05314e+00
    6 3.59605e+00 1.87536e+29 7.13009e+01 1.02909e+00
    7 4.14590e+00 1.94719e+39 9.41441e+01 1.02500e+00
    8 4.77382e+00 7.59934e+50 1.18408e+02 1.03994e+00
    9 5.49425e+00 1.43106e+64 1.41026e+02 1.03863e+00
    10 6.28492e+00 2.40480e+79 1.84334e+02 1.08256e+00
    11 7.00203e+00 2.11926e+96 2.62281e+02 1.18378e+00
    12 7.25934e+00 2.07917e+115 2.28046e+02 1.04342e+00
    13 8.57673e+00 2.16493e+135 3.32262e+02 1.09934e+00
    14 8.81565e+00 1.23824e+158 4.80175e+02 1.18945e+00
    15 8.90865e+00 9.40546e+182 3.96741e+02 1.09615e+00
    16 1.06553e+01 1.73095e+208 4.54660e+02 1.18671e+00
    17 1.14147e+01 2.25105e+236 5.47919e+02 1.08768e+00
    18 1.26889e+01 1.11594e+267 4.72717e+02 1.07067e+00
    ];
